@@ -3,9 +3,9 @@ package com.sun.tools.javac.resources;
 public final class version extends java.util.ListResourceBundle {
     protected final Object[][] getContents() {
         return new Object[][] {
-            { "full", "19.0.1+10" },
-            { "jdk", "19.0.1" },
-            { "release", "19.0.1" },
+            { "full", "22" },
+            { "jdk", "22" },
+            { "release", "22" },
         };
     }
 }
