@@ -38,10 +38,10 @@ class VersionProps {
 
     // This field is read by HotSpot
     private static final String java_version =
-        "21.0.2";
+        "22";
 
     private static final String java_version_date =
-        "2024-01-16";
+        "2024-03-19";
 
     // This field is read by HotSpot
     private static final String java_runtime_name =
@@ -49,16 +49,16 @@ class VersionProps {
 
     // This field is read by HotSpot
     private static final String java_runtime_version =
-        "21.0.2+13";
+        "22";
 
     private static final String VERSION_NUMBER =
-        "21.0.2";
+        "22";
 
     private static final String VERSION_SPECIFICATION =
-        "21";
+        "22";
 
     private static final String VERSION_BUILD =
-        "13";
+        "";
 
     private static final String VERSION_PRE =
         "";
@@ -70,10 +70,10 @@ class VersionProps {
         "".startsWith("LTS");
 
     private static final String CLASSFILE_MAJOR_MINOR =
-        "65.0";
+        "66.0";
 
     private static final String VENDOR =
-        "N/A";
+        "Arch Linux";
 
     private static final String VENDOR_URL =
         "https://openjdk.org/";
