@@ -254,7 +254,7 @@ class ZoneName {
         "America/Resolute", "America_Central", "America/Chicago",
         "America/Rio_Branco", "Acre", "America/Rio_Branco",
         "America/Rosario", "Argentina", "America/Buenos_Aires",
-        "America/Santa_Isabel", "Mexico_Northwest", "America/Santa_Isabel",
+        "America/Santa_Isabel", "America_Pacific", "America/Los_Angeles",
         "America/Santarem", "Brasilia", "America/Sao_Paulo",
         "America/Santiago", "Chile", "America/Santiago",
         "America/Santo_Domingo", "Atlantic", "America/Halifax",
