@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2022, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,7 +26,7 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
  * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
@@ -70,9 +70,9 @@ public class TimeZoneNames_en extends TimeZoneNamesBundle {
                "Greenwich Mean Time",
                "GMT",
                "",
+               "GMT",
                "",
-               "",
-               "",
+               "GMT",
             };
         final String[] Acre = new String[] {
                "Acre Standard Time",
@@ -100,11 +100,11 @@ public class TimeZoneNames_en extends TimeZoneNamesBundle {
             };
         final String[] Cuba = new String[] {
                "Cuba Standard Time",
-               "",
+               "CST",
                "Cuba Daylight Time",
-               "",
+               "CDT",
                "Cuba Time",
-               "",
+               "CT",
             };
         final String[] Fiji = new String[] {
                "Fiji Standard Time",
@@ -196,11 +196,11 @@ public class TimeZoneNames_en extends TimeZoneNamesBundle {
             };
         final String[] China = new String[] {
                "China Standard Time",
-               "",
+               "CST",
                "China Daylight Time",
-               "",
+               "CDT",
                "China Time",
-               "",
+               "CT",
             };
         final String[] Cocos = new String[] {
                "Cocos Islands Time",
@@ -228,19 +228,19 @@ public class TimeZoneNames_en extends TimeZoneNamesBundle {
             };
         final String[] Japan = new String[] {
                "Japan Standard Time",
-               "",
+               "JST",
                "Japan Daylight Time",
-               "",
+               "JDT",
                "Japan Time",
-               "",
+               "JT",
             };
         final String[] Korea = new String[] {
                "Korean Standard Time",
-               "",
+               "KST",
                "Korean Daylight Time",
-               "",
+               "KST",
                "Korean Time",
-               "",
+               "KST",
             };
         final String[] Nauru = new String[] {
                "Nauru Time",
@@ -268,11 +268,11 @@ public class TimeZoneNames_en extends TimeZoneNamesBundle {
             };
         final String[] Samoa = new String[] {
                "Samoa Standard Time",
-               "",
+               "SST",
                "Samoa Daylight Time",
-               "",
+               "SST",
                "Samoa Time",
-               "",
+               "SST",
             };
         final String[] Syowa = new String[] {
                "Syowa Time",
@@ -290,6 +290,14 @@ public class TimeZoneNames_en extends TimeZoneNamesBundle {
                "Tonga Time",
                "",
             };
+        final String[] Yukon = new String[] {
+               "Yukon Time",
+               "MST",
+               "",
+               "MST",
+               "",
+               "MST",
+            };
         final String[] Alaska = new String[] {
                "Alaska Standard Time",
                "AKST",
@@ -316,11 +324,11 @@ public class TimeZoneNames_en extends TimeZoneNamesBundle {
             };
         final String[] Azores = new String[] {
                "Azores Standard Time",
-               "",
+               "HMT",
                "Azores Summer Time",
-               "",
+               "HMT",
                "Azores Time",
-               "",
+               "HMT",
             };
         final String[] Bhutan = new String[] {
                "Bhutan Time",
@@ -356,11 +364,11 @@ public class TimeZoneNames_en extends TimeZoneNamesBundle {
             };
         final String[] Israel = new String[] {
                "Israel Standard Time",
-               "",
+               "IST",
                "Israel Daylight Time",
-               "",
+               "IDT",
                "Israel Time",
-               "",
+               "IT",
             };
         final String[] Kosrae = new String[] {
                "Kosrae Time",
@@ -380,11 +388,11 @@ public class TimeZoneNames_en extends TimeZoneNamesBundle {
             };
         final String[] Moscow = new String[] {
                "Moscow Standard Time",
-               "",
+               "MSK",
                "Moscow Summer Time",
-               "",
+               "MSK",
                "Moscow Time",
-               "",
+               "MSK",
             };
         final String[] Ponape = new String[] {
                "Ponape Time",
@@ -412,11 +420,11 @@ public class TimeZoneNames_en extends TimeZoneNamesBundle {
             };
         final String[] Taipei = new String[] {
                "Taipei Standard Time",
-               "",
+               "CST",
                "Taipei Daylight Time",
-               "",
+               "CDT",
                "Taipei Time",
-               "",
+               "CT",
             };
         final String[] Tuvalu = new String[] {
                "Tuvalu Time",
@@ -620,11 +628,11 @@ public class TimeZoneNames_en extends TimeZoneNamesBundle {
             };
         final String[] Chamorro = new String[] {
                "Chamorro Standard Time",
+               "ChST",
                "",
+               "ChST",
                "",
-               "",
-               "",
-               "",
+               "ChST",
             };
         final String[] Colombia = new String[] {
                "Colombia Standard Time",
@@ -668,11 +676,11 @@ public class TimeZoneNames_en extends TimeZoneNamesBundle {
             };
         final String[] Pakistan = new String[] {
                "Pakistan Standard Time",
-               "",
+               "PKT",
                "Pakistan Summer Time",
-               "",
+               "PKST",
                "Pakistan Time",
-               "",
+               "PKT",
             };
         final String[] Paraguay = new String[] {
                "Paraguay Standard Time",
@@ -732,11 +740,11 @@ public class TimeZoneNames_en extends TimeZoneNamesBundle {
             };
         final String[] Hong_Kong = new String[] {
                "Hong Kong Standard Time",
-               "",
+               "HKT",
                "Hong Kong Summer Time",
-               "",
+               "HKST",
                "Hong Kong Time",
-               "",
+               "HKT",
             };
         final String[] Indochina = new String[] {
                "Indochina Time",
@@ -804,11 +812,11 @@ public class TimeZoneNames_en extends TimeZoneNamesBundle {
             };
         final String[] Volgograd = new String[] {
                "Volgograd Standard Time",
-               "",
+               "MSK",
                "Volgograd Summer Time",
-               "",
+               "MSK",
                "Volgograd Time",
-               "",
+               "MSK",
             };
         final String[] Azerbaijan = new String[] {
                "Azerbaijan Standard Time",
@@ -884,11 +892,11 @@ public class TimeZoneNames_en extends TimeZoneNamesBundle {
             };
         final String[] New_Zealand = new String[] {
                "New Zealand Standard Time",
-               "",
+               "NZST",
                "New Zealand Daylight Time",
-               "",
+               "NZDT",
                "New Zealand Time",
-               "",
+               "NZT",
             };
         final String[] Novosibirsk = new String[] {
                "Novosibirsk Standard Time",
@@ -900,11 +908,11 @@ public class TimeZoneNames_en extends TimeZoneNamesBundle {
             };
         final String[] Philippines = new String[] {
                "Philippine Standard Time",
-               "",
+               "PST",
                "Philippine Summer Time",
-               "",
+               "PDT",
                "Philippine Time",
-               "",
+               "PT",
             };
         final String[] Vladivostok = new String[] {
                "Vladivostok Standard Time",
@@ -932,11 +940,11 @@ public class TimeZoneNames_en extends TimeZoneNamesBundle {
             };
         final String[] Newfoundland = new String[] {
                "Newfoundland Standard Time",
-               "",
+               "NST",
                "Newfoundland Daylight Time",
-               "",
+               "NDT",
                "Newfoundland Time",
-               "",
+               "NT",
             };
         final String[] Turkmenistan = new String[] {
                "Turkmenistan Standard Time",
@@ -980,27 +988,27 @@ public class TimeZoneNames_en extends TimeZoneNamesBundle {
             };
         final String[] Africa_Central = new String[] {
                "Central Africa Time",
+               "SAST",
                "",
+               "SAST",
                "",
-               "",
-               "",
-               "",
+               "SAST",
             };
         final String[] Africa_Eastern = new String[] {
                "East Africa Time",
+               "EAT",
                "",
+               "EAT",
                "",
-               "",
-               "",
-               "",
+               "EAT",
             };
         final String[] Africa_Western = new String[] {
                "West Africa Standard Time",
-               "",
+               "WAT",
                "West Africa Summer Time",
-               "",
+               "WAT",
                "West Africa Time",
-               "",
+               "WAT",
             };
         final String[] DumontDUrville = new String[] {
                "Dumont-d\u2019Urville Time",
@@ -1012,43 +1020,43 @@ public class TimeZoneNames_en extends TimeZoneNamesBundle {
             };
         final String[] Europe_Central = new String[] {
                "Central European Standard Time",
-               "",
+               "CET",
                "Central European Summer Time",
-               "",
+               "CEST",
                "Central European Time",
-               "",
+               "CET",
             };
         final String[] Europe_Eastern = new String[] {
                "Eastern European Standard Time",
-               "",
+               "EET",
                "Eastern European Summer Time",
-               "",
+               "EEST",
                "Eastern European Time",
-               "",
+               "EET",
             };
         final String[] Europe_Western = new String[] {
                "Western European Standard Time",
-               "",
+               "FMT",
                "Western European Summer Time",
-               "",
+               "FMT",
                "Western European Time",
-               "",
+               "FMT",
             };
         final String[] Mexico_Pacific = new String[] {
                "Mexican Pacific Standard Time",
-               "",
+               "MST",
                "Mexican Pacific Daylight Time",
-               "",
+               "MDT",
                "Mexican Pacific Time",
-               "",
+               "MT",
             };
         final String[] Africa_Southern = new String[] {
                "South Africa Standard Time",
+               "SAST",
                "",
+               "SAST",
                "",
-               "",
-               "",
-               "",
+               "SAST",
             };
         final String[] America_Central = new String[] {
                "Central Standard Time",
@@ -1148,19 +1156,19 @@ public class TimeZoneNames_en extends TimeZoneNamesBundle {
             };
         final String[] Australia_Central = new String[] {
                "Australian Central Standard Time",
-               "",
+               "ACST",
                "Australian Central Daylight Time",
-               "",
+               "ACDT",
                "Central Australia Time",
-               "",
+               "ACT",
             };
         final String[] Australia_Eastern = new String[] {
                "Australian Eastern Standard Time",
-               "",
+               "AEST",
                "Australian Eastern Daylight Time",
-               "",
+               "AEDT",
                "Eastern Australia Time",
-               "",
+               "AET",
             };
         final String[] Australia_Western = new String[] {
                "Australian Western Standard Time",
@@ -1188,27 +1196,27 @@ public class TimeZoneNames_en extends TimeZoneNamesBundle {
             };
         final String[] Indonesia_Central = new String[] {
                "Central Indonesia Time",
+               "WITA",
                "",
+               "WITA",
                "",
-               "",
-               "",
-               "",
+               "WITA",
             };
         final String[] Indonesia_Eastern = new String[] {
                "Eastern Indonesia Time",
+               "WIT",
                "",
+               "WIT",
                "",
-               "",
-               "",
-               "",
+               "WIT",
             };
         final String[] Indonesia_Western = new String[] {
                "Western Indonesia Time",
+               "WIB",
                "",
+               "WIB",
                "",
-               "",
-               "",
-               "",
+               "WIB",
             };
         final String[] Kazakhstan_Eastern = new String[] {
                "East Kazakhstan Time",
@@ -1296,7 +1304,6 @@ public class TimeZoneNames_en extends TimeZoneNamesBundle {
             { "Asia/Hovd", Hovd },
             { "Asia/Omsk", Omsk },
             { "Asia/Oral", Kazakhstan_Western },
-            { "Asia/Amman", Europe_Eastern },
             { "Asia/Aqtau", Kazakhstan_Western },
             { "Asia/Chita", Yakutsk },
             { "Asia/Dhaka", Bangladesh },
@@ -1392,7 +1399,6 @@ public class TimeZoneNames_en extends TimeZoneNamesBundle {
             { "America/Thule", Atlantic },
             { "Asia/Ashgabat", Turkmenistan },
             { "Asia/Calcutta", India },
-            { "Asia/Damascus", Europe_Eastern },
             { "Asia/Dushanbe", Tajikistan },
             { "Asia/Jayapura", Indonesia_Eastern },
             { "Asia/Katmandu", Nepal },
@@ -1409,9 +1415,9 @@ public class TimeZoneNames_en extends TimeZoneNamesBundle {
                     "Greenwich Mean Time",
                     "GMT",
                     "Irish Standard Time",
+                    "IST",
                     "",
-                    "",
-                    "",
+                    "GMT",
                 }
             },
             { "Europe/Jersey", GMT },
@@ -1421,9 +1427,9 @@ public class TimeZoneNames_en extends TimeZoneNamesBundle {
                     "Greenwich Mean Time",
                     "GMT",
                     "British Summer Time",
+                    "BST",
                     "",
-                    "",
-                    "",
+                    "GMT",
                 }
             },
             { "Europe/Madrid", Europe_Central },
@@ -1464,7 +1470,7 @@ public class TimeZoneNames_en extends TimeZoneNamesBundle {
             { "America/Cancun", America_Eastern },
             { "America/Cayman", America_Eastern },
             { "America/Cuiaba", Amazon },
-            { "America/Dawson", America_Mountain },
+            { "America/Dawson", Yukon },
             { "America/Guyana", Guyana },
             { "America/Havana", Cuba },
             { "America/Inuvik", America_Mountain },
@@ -1492,9 +1498,9 @@ public class TimeZoneNames_en extends TimeZoneNamesBundle {
                     "Greenwich Mean Time",
                     "GMT",
                     "British Summer Time",
+                    "BST",
                     "",
-                    "",
-                    "",
+                    "GMT",
                 }
             },
             { "Europe/Tallinn", Europe_Eastern },
@@ -1540,7 +1546,7 @@ public class TimeZoneNames_en extends TimeZoneNamesBundle {
             { "America/Moncton", Atlantic },
             { "America/Nipigon", America_Eastern },
             { "America/Noronha", Noronha },
-            { "America/Ojinaga", America_Mountain },
+            { "America/Ojinaga", America_Central },
             { "America/Tijuana", America_Pacific },
             { "America/Toronto", America_Eastern },
             { "America/Tortola", Atlantic },
@@ -1626,7 +1632,7 @@ public class TimeZoneNames_en extends TimeZoneNamesBundle {
             { "America/Araguaina", Brasilia },
             { "America/Boa_Vista", Amazon },
             { "America/Catamarca", Argentina },
-            { "America/Chihuahua", Mexico_Pacific },
+            { "America/Chihuahua", America_Central },
             { "America/Fortaleza", Brasilia },
             { "America/Glace_Bay", Atlantic },
             { "America/Goose_Bay", Atlantic },
@@ -1671,7 +1677,7 @@ public class TimeZoneNames_en extends TimeZoneNamesBundle {
             { "America/Paramaribo", Suriname },
             { "America/Rio_Branco", Acre },
             { "America/St_Vincent", Atlantic },
-            { "America/Whitehorse", America_Mountain },
+            { "America/Whitehorse", Yukon },
             { "Antarctica/McMurdo", New_Zealand },
             { "Antarctica/Rothera", Rothera },
             { "Asia/Yekaterinburg", Yekaterinburg },
@@ -1714,6 +1720,7 @@ public class TimeZoneNames_en extends TimeZoneNamesBundle {
             { "Antarctica/Macquarie", Australia_Eastern },
             { "Pacific/Port_Moresby", Papua_New_Guinea },
             { "America/Cambridge_Bay", America_Mountain },
+            { "America/Ciudad_Juarez", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
             { "America/Indiana/Vevay", America_Eastern },
             { "America/Lower_Princes", Atlantic },
@@ -1743,16 +1750,10 @@ public class TimeZoneNames_en extends TimeZoneNamesBundle {
             { "America/North_Dakota/Center", America_Central },
             { "timezone.excity.Asia/Saigon", "Ho Chi Minh City" },
             { "timezone.excity.Etc/Unknown", "Unknown City" },
-            { "timezone.excity.Europe/Kiev", "Kiev" },
             { "timezone.excity.Asia/Qostanay", "Kostanay" },
             { "America/Argentina/Rio_Gallegos", Argentina },
             { "America/North_Dakota/New_Salem", America_Central },
-            { "timezone.excity.Indian/Reunion", "R\u00e9union" },
-            { "timezone.excity.Africa/Sao_Tome", "S\u00e3o Tom\u00e9" },
-            { "timezone.excity.America/Curacao", "Cura\u00e7ao" },
             { "timezone.excity.Europe/Uzhgorod", "Uzhhorod" },
-            { "timezone.excity.America/Asuncion", "Asunci\u00f3n" },
-            { "timezone.excity.America/St_Barthelemy", "St. Barth\u00e9lemy" },
         };
         return data;
     }
