@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -71,171 +67,32 @@ public class CurrencyNames_es extends OpenListResourceBundle {
     @Override
     protected final Object[][] getContents() {
         final Object[][] data = new Object[][] {
-            { "AED", "AED" },
-            { "AFN", "AFN" },
-            { "ALL", "ALL" },
-            { "AMD", "AMD" },
-            { "ANG", "ANG" },
-            { "AOA", "AOA" },
-            { "ARS", "ARS" },
             { "AUD", "AUD" },
-            { "AWG", "AWG" },
-            { "AZN", "AZN" },
-            { "BAM", "BAM" },
-            { "BBD", "BBD" },
-            { "BDT", "BDT" },
-            { "BGN", "BGN" },
-            { "BHD", "BHD" },
-            { "BIF", "BIF" },
-            { "BMD", "BMD" },
-            { "BND", "BND" },
-            { "BOB", "BOB" },
             { "BRL", "BRL" },
-            { "BSD", "BSD" },
-            { "BTN", "BTN" },
-            { "BWP", "BWP" },
-            { "BYN", "BYN" },
-            { "BYR", "BYR" },
-            { "BZD", "BZD" },
-            { "CDF", "CDF" },
-            { "CHF", "CHF" },
-            { "CLP", "CLP" },
-            { "CNH", "CNH" },
+            { "CAD", "CAD" },
             { "CNY", "CNY" },
-            { "COP", "COP" },
-            { "CRC", "CRC" },
-            { "CUC", "CUC" },
-            { "CUP", "CUP" },
-            { "CVE", "CVE" },
-            { "CZK", "CZK" },
-            { "DJF", "DJF" },
-            { "DKK", "DKK" },
-            { "DOP", "DOP" },
-            { "DZD", "DZD" },
-            { "EGP", "EGP" },
-            { "ERN", "ERN" },
             { "ESP", "\u20a7" },
-            { "ETB", "ETB" },
-            { "FJD", "FJD" },
-            { "FKP", "FKP" },
             { "GBP", "GBP" },
-            { "GEL", "GEL" },
-            { "GHS", "GHS" },
-            { "GIP", "GIP" },
-            { "GMD", "GMD" },
-            { "GNF", "GNF" },
-            { "GTQ", "GTQ" },
-            { "GYD", "GYD" },
             { "HKD", "HKD" },
-            { "HNL", "HNL" },
-            { "HRK", "HRK" },
-            { "HTG", "HTG" },
-            { "HUF", "HUF" },
-            { "IDR", "IDR" },
             { "ILS", "ILS" },
             { "INR", "INR" },
-            { "IQD", "IQD" },
-            { "IRR", "IRR" },
-            { "ISK", "ISK" },
-            { "JMD", "JMD" },
-            { "JOD", "JOD" },
             { "JPY", "JPY" },
-            { "KES", "KES" },
-            { "KGS", "KGS" },
-            { "KHR", "KHR" },
-            { "KMF", "KMF" },
-            { "KPW", "KPW" },
             { "KRW", "KRW" },
-            { "KWD", "KWD" },
-            { "KYD", "KYD" },
-            { "KZT", "KZT" },
-            { "LAK", "LAK" },
-            { "LBP", "LBP" },
-            { "LKR", "LKR" },
-            { "LRD", "LRD" },
-            { "LTL", "LTL" },
-            { "LVL", "LVL" },
-            { "LYD", "LYD" },
-            { "MAD", "MAD" },
-            { "MDL", "MDL" },
-            { "MGA", "MGA" },
-            { "MKD", "MKD" },
-            { "MMK", "MMK" },
-            { "MNT", "MNT" },
-            { "MOP", "MOP" },
-            { "MRO", "MRO" },
-            { "MRU", "MRU" },
-            { "MUR", "MUR" },
-            { "MVR", "MVR" },
-            { "MWK", "MWK" },
             { "MXN", "MXN" },
-            { "MYR", "MYR" },
-            { "MZN", "MZN" },
-            { "NAD", "NAD" },
-            { "NGN", "NGN" },
-            { "NIO", "NIO" },
-            { "NOK", "NOK" },
-            { "NPR", "NPR" },
             { "NZD", "NZD" },
-            { "OMR", "OMR" },
-            { "PAB", "PAB" },
-            { "PEN", "PEN" },
-            { "PGK", "PGK" },
             { "PHP", "PHP" },
-            { "PKR", "PKR" },
-            { "PLN", "PLN" },
-            { "PYG", "PYG" },
-            { "QAR", "QAR" },
-            { "RON", "RON" },
-            { "RSD", "RSD" },
-            { "RUB", "RUB" },
-            { "RWF", "RWF" },
-            { "SAR", "SAR" },
-            { "SBD", "SBD" },
-            { "SCR", "SCR" },
-            { "SDG", "SDG" },
-            { "SEK", "SEK" },
-            { "SGD", "SGD" },
-            { "SHP", "SHP" },
-            { "SLL", "SLL" },
-            { "SOS", "SOS" },
-            { "SRD", "SRD" },
-            { "SSP", "SSP" },
-            { "STD", "STD" },
-            { "STN", "STN" },
-            { "SYP", "SYP" },
-            { "SZL", "SZL" },
             { "THB", "\u0e3f" },
-            { "TJS", "TJS" },
-            { "TMT", "TMT" },
-            { "TND", "TND" },
-            { "TOP", "TOP" },
-            { "TRY", "TRY" },
-            { "TTD", "TTD" },
             { "TWD", "TWD" },
-            { "TZS", "TZS" },
-            { "UAH", "UAH" },
-            { "UGX", "UGX" },
-            { "UYU", "UYU" },
-            { "UYW", "UYW" },
-            { "UZS", "UZS" },
-            { "VEF", "VEF" },
-            { "VES", "VES" },
-            { "VUV", "VUV" },
-            { "WST", "WST" },
             { "XAF", "XAF" },
             { "XCD", "XCD" },
             { "XOF", "XOF" },
-            { "YER", "YER" },
-            { "ZAR", "ZAR" },
-            { "ZMW", "ZMW" },
             { "adp", "peseta andorrana" },
             { "aed", "d\u00edrham de los Emiratos \u00c1rabes Unidos" },
             { "afa", "afgani (1927\u20132002)" },
             { "afn", "afgani" },
             { "all", "lek" },
             { "amd", "dram" },
-            { "ang", "flor\u00edn de las Antillas Neerlandesas" },
+            { "ang", "flor\u00edn antillano" },
             { "aoa", "kuanza" },
             { "aok", "kwanza angole\u00f1o (1977\u20131990)" },
             { "aon", "nuevo kwanza angole\u00f1o (1990\u20132000)" },
@@ -256,10 +113,10 @@ public class CurrencyNames_es extends OpenListResourceBundle {
             { "bef", "franco belga" },
             { "bel", "franco belga (financiero)" },
             { "bgl", "lev fuerte b\u00falgaro" },
-            { "bgn", "lev b\u00falgaro" },
-            { "bhd", "dinar bahrein\u00ed" },
+            { "bgn", "leva b\u00falgara" },
+            { "bhd", "dinar barein\u00ed" },
             { "bif", "franco burund\u00e9s" },
-            { "bmd", "d\u00f3lar de Bermudas" },
+            { "bmd", "d\u00f3lar bermude\u00f1o" },
             { "bnd", "d\u00f3lar bruneano" },
             { "bob", "boliviano" },
             { "bop", "peso boliviano" },
@@ -336,7 +193,7 @@ public class CurrencyNames_es extends OpenListResourceBundle {
             { "hnl", "lempira hondure\u00f1o" },
             { "hrd", "dinar croata" },
             { "hrk", "kuna" },
-            { "htg", "gourde haitiano" },
+            { "htg", "gurde haitiano" },
             { "huf", "forinto h\u00fangaro" },
             { "idr", "rupia indonesia" },
             { "iep", "libra irlandesa" },
@@ -358,12 +215,12 @@ public class CurrencyNames_es extends OpenListResourceBundle {
             { "krw", "won surcoreano" },
             { "kwd", "dinar kuwait\u00ed" },
             { "kyd", "d\u00f3lar de las Islas Caim\u00e1n" },
-            { "kzt", "tenge kazako" },
+            { "kzt", "tengue kazajo" },
             { "lak", "kip" },
             { "lbp", "libra libanesa" },
             { "lkr", "rupia esrilanquesa" },
             { "lrd", "d\u00f3lar liberiano" },
-            { "lsl", "loti lesothense" },
+            { "lsl", "loti lesotense" },
             { "ltl", "litas lituano" },
             { "ltt", "talonas lituano" },
             { "luc", "franco convertible luxemburgu\u00e9s" },
@@ -399,7 +256,7 @@ public class CurrencyNames_es extends OpenListResourceBundle {
             { "nad", "d\u00f3lar namibio" },
             { "ngn", "naira" },
             { "nic", "c\u00f3rdoba nicarag\u00fcense (1988\u20131991)" },
-            { "nio", "c\u00f3rdoba nicarag\u00fcense" },
+            { "nio", "c\u00f3rdoba oro" },
             { "nlg", "flor\u00edn neerland\u00e9s" },
             { "nok", "corona noruega" },
             { "npr", "rupia nepal\u00ed" },
@@ -435,7 +292,8 @@ public class CurrencyNames_es extends OpenListResourceBundle {
             { "shp", "libra de Santa Elena" },
             { "sit", "t\u00f3lar esloveno" },
             { "skk", "corona eslovaca" },
-            { "sll", "leona" },
+            { "sle", "leona" },
+            { "sll", "leona (1964\u20142022)" },
             { "sos", "chel\u00edn somal\u00ed" },
             { "srd", "d\u00f3lar surinam\u00e9s" },
             { "srg", "flor\u00edn surinam\u00e9s" },
