@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2023, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -68,16 +68,16 @@ public class TimeZoneNames_ceb extends TimeZoneNamesBundle {
     protected final Object[][] getContents() {
         final String[] GMT = new String[] {
                "Oras sa Greenwich Mean",
+               "GMT",
                "",
+               "GMT",
                "",
-               "",
-               "",
-               "",
+               "GMT",
             };
         final String[] Apia = new String[] {
                "Tamdanang Oras sa Apia",
                "",
-               "Oras sa Tag-init sa Apia",
+               "Daylight Time sa Apia",
                "",
                "Oras sa Apia",
                "",
@@ -92,11 +92,11 @@ public class TimeZoneNames_ceb extends TimeZoneNamesBundle {
             };
         final String[] Cuba = new String[] {
                "Tamdanang Oras sa Cuba",
-               "",
+               "CST",
                "Oras sa Tag-init sa Cuba",
-               "",
+               "CDT",
                "Oras sa Cuba",
-               "",
+               "CT",
             };
         final String[] Fiji = new String[] {
                "Tamdanang Oras sa Fiji",
@@ -180,11 +180,11 @@ public class TimeZoneNames_ceb extends TimeZoneNamesBundle {
             };
         final String[] China = new String[] {
                "Tamdanang Oras sa Tsina",
-               "",
+               "CST",
                "Oras sa Tag-init sa Tsina",
-               "",
+               "CDT",
                "Oras sa Tsina",
-               "",
+               "CT",
             };
         final String[] Cocos = new String[] {
                "Oras sa Cocos Islands",
@@ -212,19 +212,19 @@ public class TimeZoneNames_ceb extends TimeZoneNamesBundle {
             };
         final String[] Japan = new String[] {
                "Tamdanang Oras sa Japan",
-               "",
+               "JST",
                "Oras sa Adlawan sa Japan",
-               "",
+               "JDT",
                "Oras sa Japan",
-               "",
+               "JT",
             };
         final String[] Korea = new String[] {
                "Tamdanang Oras sa Korea",
-               "",
+               "KST",
                "Oras sa Tag-init sa Korea",
-               "",
+               "KST",
                "Oras sa Korea",
-               "",
+               "KST",
             };
         final String[] Nauru = new String[] {
                "Oras sa Nauru",
@@ -252,11 +252,11 @@ public class TimeZoneNames_ceb extends TimeZoneNamesBundle {
             };
         final String[] Samoa = new String[] {
                "Tamdanang Oras sa Samoa",
-               "",
-               "Oras sa Tag-init sa Samoa",
-               "",
+               "SST",
+               "Daylight Time sa Samoa",
+               "SST",
                "Oras sa Samoa",
-               "",
+               "SST",
             };
         final String[] Syowa = new String[] {
                "Oras sa Syowa",
@@ -276,16 +276,16 @@ public class TimeZoneNames_ceb extends TimeZoneNamesBundle {
             };
         final String[] Yukon = new String[] {
                "Oras sa Yukon",
+               "MST",
                "",
+               "MST",
                "",
-               "",
-               "",
-               "",
+               "MST",
             };
         final String[] Alaska = new String[] {
                "Tamdanang Oras sa Alaska",
                "",
-               "Oras sa Tag-init sa Alaska",
+               "Daylight Time sa Alaska",
                "",
                "Oras sa Alaska",
                "",
@@ -300,11 +300,11 @@ public class TimeZoneNames_ceb extends TimeZoneNamesBundle {
             };
         final String[] Azores = new String[] {
                "Tamdanang Oras sa Azores",
-               "",
+               "HMT",
                "Oras sa Tag-init sa Azores",
-               "",
+               "HMT",
                "Oras sa Azores",
-               "",
+               "HMT",
             };
         final String[] Bhutan = new String[] {
                "Oras sa Bhutan",
@@ -340,11 +340,11 @@ public class TimeZoneNames_ceb extends TimeZoneNamesBundle {
             };
         final String[] Israel = new String[] {
                "Tamdanang Oras sa Israel",
-               "",
+               "IST",
                "Oras sa Tag-init sa Israel",
-               "",
+               "IDT",
                "Oras sa Israel",
-               "",
+               "IT",
             };
         final String[] Kosrae = new String[] {
                "Oras sa Kosrae",
@@ -364,11 +364,11 @@ public class TimeZoneNames_ceb extends TimeZoneNamesBundle {
             };
         final String[] Moscow = new String[] {
                "Tamdanang Oras sa Moscow",
-               "",
+               "MSK",
                "Oras sa Tag-init sa Moscow",
-               "",
+               "MSK",
                "Oras sa Moscow",
-               "",
+               "MSK",
             };
         final String[] Ponape = new String[] {
                "Oras sa Ponape",
@@ -388,11 +388,11 @@ public class TimeZoneNames_ceb extends TimeZoneNamesBundle {
             };
         final String[] Taipei = new String[] {
                "Tamdanang Oras sa Taipei",
-               "",
+               "CST",
                "Oras sa Tag-init sa Taipei",
-               "",
+               "CDT",
                "Oras sa Taipei",
-               "",
+               "CT",
             };
         final String[] Tuvalu = new String[] {
                "Oras sa Tuvalu",
@@ -579,12 +579,12 @@ public class TimeZoneNames_ceb extends TimeZoneNamesBundle {
                "",
             };
         final String[] Atlantic = new String[] {
-               "Tamdanang Oras sa Atlantiko",
-               "",
-               "Oras sa Tag-init sa Atlantiko",
-               "",
-               "Oras sa Atlantiko",
-               "",
+               "Atlantic Standard Time",
+               "AST",
+               "Atlantic Daylight Time",
+               "ADT",
+               "Atlantic Time",
+               "AT",
             };
         final String[] Brasilia = new String[] {
                "Tamdanang Oras sa Brasilia",
@@ -596,11 +596,11 @@ public class TimeZoneNames_ceb extends TimeZoneNamesBundle {
             };
         final String[] Chamorro = new String[] {
                "Tamdanang Oras sa Chamorro",
+               "ChST",
                "",
+               "ChST",
                "",
-               "",
-               "",
-               "",
+               "ChST",
             };
         final String[] Colombia = new String[] {
                "Tamdanang Oras sa Colombia",
@@ -644,11 +644,11 @@ public class TimeZoneNames_ceb extends TimeZoneNamesBundle {
             };
         final String[] Pakistan = new String[] {
                "Tamdanang Oras sa Pakistan",
-               "",
+               "PKT",
                "Oras sa Tag-init sa Pakistan",
-               "",
+               "PKST",
                "Oras sa Pakistan",
-               "",
+               "PKT",
             };
         final String[] Paraguay = new String[] {
                "Tamdanang Oras sa Paraguay",
@@ -708,11 +708,11 @@ public class TimeZoneNames_ceb extends TimeZoneNamesBundle {
             };
         final String[] Hong_Kong = new String[] {
                "Tamdanang Oras sa Hong Kong",
-               "",
+               "HKT",
                "Oras sa Tag-init sa Hong Kong",
-               "",
+               "HKST",
                "Oras sa Hong Kong",
-               "",
+               "HKT",
             };
         final String[] Indochina = new String[] {
                "Oras sa Indochina",
@@ -772,11 +772,11 @@ public class TimeZoneNames_ceb extends TimeZoneNamesBundle {
             };
         final String[] Volgograd = new String[] {
                "Tamdanang Oras sa Volgograd",
-               "",
+               "MSK",
                "Oras sa Tag-init sa Volgograd",
-               "",
+               "MSK",
                "Oras sa Volgograd",
-               "",
+               "MSK",
             };
         final String[] Azerbaijan = new String[] {
                "Tamdanang Oras sa Azerbaijan",
@@ -852,11 +852,11 @@ public class TimeZoneNames_ceb extends TimeZoneNamesBundle {
             };
         final String[] New_Zealand = new String[] {
                "Tamdanang Oras sa New Zealand",
-               "",
+               "NZST",
                "Oras sa Tag-init sa New Zealand",
-               "",
+               "NZDT",
                "Oras sa New Zealand",
-               "",
+               "NZT",
             };
         final String[] Novosibirsk = new String[] {
                "Tamdanang Oras sa Novosibirsk",
@@ -868,11 +868,11 @@ public class TimeZoneNames_ceb extends TimeZoneNamesBundle {
             };
         final String[] Philippines = new String[] {
                "Tamdanang Oras sa Pilipinas",
-               "",
+               "PST",
                "Oras sa Tag-init sa Pilipinas",
-               "",
+               "PDT",
                "Oras sa Pilipinas",
-               "",
+               "PT",
             };
         final String[] Vladivostok = new String[] {
                "Tamdanang Oras sa Vladivostok",
@@ -900,11 +900,11 @@ public class TimeZoneNames_ceb extends TimeZoneNamesBundle {
             };
         final String[] Newfoundland = new String[] {
                "Tamdanang Oras sa Newfoundland",
-               "",
+               "NST",
                "Oras sa Tag-init sa Newfoundland",
-               "",
+               "NDT",
                "Oras sa Newfoundland",
-               "",
+               "NT",
             };
         final String[] Turkmenistan = new String[] {
                "Tamdanang Oras sa Turkmenistan",
@@ -948,27 +948,27 @@ public class TimeZoneNames_ceb extends TimeZoneNamesBundle {
             };
         final String[] Africa_Central = new String[] {
                "Oras sa Central Africa",
+               "SAST",
                "",
+               "SAST",
                "",
-               "",
-               "",
-               "",
+               "SAST",
             };
         final String[] Africa_Eastern = new String[] {
                "Oras sa East Africa",
+               "EAT",
                "",
+               "EAT",
                "",
-               "",
-               "",
-               "",
+               "EAT",
             };
         final String[] Africa_Western = new String[] {
                "Tamdanang Oras sa West Africa",
-               "",
+               "WAT",
                "Oras sa Tag-init sa West Africa",
-               "",
+               "WAT",
                "Oras sa West Africa",
-               "",
+               "WAT",
             };
         final String[] DumontDUrville = new String[] {
                "Oras sa Dumont-d\u2019Urville",
@@ -980,67 +980,67 @@ public class TimeZoneNames_ceb extends TimeZoneNamesBundle {
             };
         final String[] Europe_Central = new String[] {
                "Tamdanang Oras sa Central Europe",
-               "",
+               "CET",
                "Oras sa Tag-init sa Central Europe",
-               "",
+               "CEST",
                "Oras sa Central Europe",
-               "",
+               "CET",
             };
         final String[] Europe_Eastern = new String[] {
                "Tamdanang Oras sa Eastern Europe",
-               "",
+               "EET",
                "Oras sa Tag-init sa Eastern Europe",
-               "",
+               "EEST",
                "Oras sa Eastern Europe",
-               "",
+               "EET",
             };
         final String[] Europe_Western = new String[] {
                "Tamdanang Oras sa Western Europe",
-               "",
+               "FMT",
                "Oras sa Tag-init sa Western Europe",
-               "",
+               "FMT",
                "Oras sa Western Europe",
-               "",
+               "FMT",
             };
         final String[] Mexico_Pacific = new String[] {
                "Tamdanang Oras sa Mexican Pacific",
-               "",
+               "MST",
                "Oras sa Tag-init sa Mexican Pacific",
-               "",
+               "MDT",
                "Oras sa Mexican Pacific",
-               "",
+               "MT",
             };
         final String[] Africa_Southern = new String[] {
                "Tamdanang Oras sa South Africa",
+               "SAST",
                "",
+               "SAST",
                "",
-               "",
-               "",
-               "",
+               "SAST",
             };
         final String[] America_Central = new String[] {
-               "Sentong Tamdanan nga Oras",
-               "",
-               "Sentrong Oras sa Tag-init",
-               "",
-               "Sentrong Oras",
-               "",
+               "Central Standard Time",
+               "CST",
+               "Central Daylight Time",
+               "CDT",
+               "Central Time",
+               "CT",
             };
         final String[] America_Eastern = new String[] {
-               "Tamdanan nga Oras sa Sidlakan",
-               "",
-               "Oras sa Tag-init sa Sidlakan",
-               "",
-               "Oras sa Sidlakan",
-               "",
+               "Eastern Standard Time",
+               "EST",
+               "Eastern Daylight Time",
+               "EST",
+               "Eastern Time",
+               "EST",
             };
         final String[] America_Pacific = new String[] {
-               "Tamdanang Oras sa Pasipiko",
-               "",
-               "Oras sa Tag-init sa Pasipiko",
-               "",
-               "Oras sa Pasipiko",
-               "",
+               "Pacific Standard Time",
+               "PST",
+               "Pacific Daylight Time",
+               "PDT",
+               "Pacific Time",
+               "PT",
             };
         final String[] French_Southern = new String[] {
                "Oras sa French Southern ug Antarctic",
@@ -1060,11 +1060,11 @@ public class TimeZoneNames_ceb extends TimeZoneNamesBundle {
             };
         final String[] Hawaii_Aleutian = new String[] {
                "Tamdanang Oras sa Hawaii-Aleutian",
-               "",
+               "HST",
                "Oras sa Tag-init sa Hawaii-Aleutian",
-               "",
+               "HST",
                "Oras sa Hawaii-Aleutian",
-               "",
+               "HST",
             };
         final String[] Phoenix_Islands = new String[] {
                "Oras sa Phoenix Islands",
@@ -1083,12 +1083,12 @@ public class TimeZoneNames_ceb extends TimeZoneNamesBundle {
                "",
             };
         final String[] America_Mountain = new String[] {
-               "Tamdanang Oras sa Kabukiran",
-               "",
-               "Oras sa Tag-init sa Kabukiran",
-               "",
-               "Oras sa Kabukiran",
-               "",
+               "Mountain Standard Time",
+               "MST",
+               "Mountain Daylight Time",
+               "MDT",
+               "Mountain Time",
+               "MT",
             };
         final String[] Marshall_Islands = new String[] {
                "Oras sa Marshall Islands",
@@ -1116,19 +1116,19 @@ public class TimeZoneNames_ceb extends TimeZoneNamesBundle {
             };
         final String[] Australia_Central = new String[] {
                "Tamdanang Oras sa Central Australia",
-               "",
+               "ACST",
                "Oras sa Tag-init sa Central Australia",
-               "",
+               "ACDT",
                "Oras sa Central Australia",
-               "",
+               "ACT",
             };
         final String[] Australia_Eastern = new String[] {
                "Tamdanang Oras sa Eastern Australia",
-               "",
+               "AEST",
                "Oras sa Tag-init sa Eastern Australia",
-               "",
+               "AEDT",
                "Oras sa Eastern Australia",
-               "",
+               "AET",
             };
         final String[] Australia_Western = new String[] {
                "Tamdanang Oras sa Western Australia",
@@ -1156,27 +1156,27 @@ public class TimeZoneNames_ceb extends TimeZoneNamesBundle {
             };
         final String[] Indonesia_Central = new String[] {
                "Oras sa Central Indonesia",
+               "WITA",
                "",
+               "WITA",
                "",
-               "",
-               "",
-               "",
+               "WITA",
             };
         final String[] Indonesia_Eastern = new String[] {
                "Oras sa Eastern Indonesia",
+               "WIT",
                "",
+               "WIT",
                "",
-               "",
-               "",
-               "",
+               "WIT",
             };
         final String[] Indonesia_Western = new String[] {
                "Oras sa Western Indonesia",
+               "WIB",
                "",
+               "WIB",
                "",
-               "",
-               "",
-               "",
+               "WIB",
             };
         final String[] Kazakhstan_Eastern = new String[] {
                "Oras sa East Kazakhstan",
@@ -1255,7 +1255,6 @@ public class TimeZoneNames_ceb extends TimeZoneNamesBundle {
             { "Asia/Hovd", Hovd },
             { "Asia/Omsk", Omsk },
             { "Asia/Oral", Kazakhstan_Western },
-            { "Asia/Amman", Europe_Eastern },
             { "Asia/Aqtau", Kazakhstan_Western },
             { "Asia/Chita", Yakutsk },
             { "Asia/Dhaka", Bangladesh },
@@ -1350,7 +1349,6 @@ public class TimeZoneNames_ceb extends TimeZoneNamesBundle {
             { "America/Thule", Atlantic },
             { "Asia/Ashgabat", Turkmenistan },
             { "Asia/Calcutta", India },
-            { "Asia/Damascus", Europe_Eastern },
             { "Asia/Dushanbe", Tajikistan },
             { "Asia/Jayapura", Indonesia_Eastern },
             { "Asia/Katmandu", Nepal },
@@ -1365,11 +1363,11 @@ public class TimeZoneNames_ceb extends TimeZoneNamesBundle {
             { "Europe/Dublin",
                 new String[] {
                     "Oras sa Greenwich Mean",
-                    "",
+                    "GMT",
                     "Tamdanang Oras sa Irish",
+                    "IST",
                     "",
-                    "",
-                    "",
+                    "GMT",
                 }
             },
             { "Europe/Jersey", GMT },
@@ -1377,11 +1375,11 @@ public class TimeZoneNames_ceb extends TimeZoneNamesBundle {
             { "Europe/London",
                 new String[] {
                     "Oras sa Greenwich Mean",
-                    "",
+                    "GMT",
                     "Oras sa Tag-init sa British",
+                    "BST",
                     "",
-                    "",
-                    "",
+                    "GMT",
                 }
             },
             { "Europe/Madrid", Europe_Central },
@@ -1437,11 +1435,11 @@ public class TimeZoneNames_ceb extends TimeZoneNamesBundle {
             { "Europe/Belfast",
                 new String[] {
                     "Oras sa Greenwich Mean",
-                    "",
+                    "GMT",
                     "Oras sa Tag-init sa British",
+                    "BST",
                     "",
-                    "",
-                    "",
+                    "GMT",
                 }
             },
             { "Europe/Tallinn", Europe_Eastern },
@@ -1658,6 +1656,7 @@ public class TimeZoneNames_ceb extends TimeZoneNamesBundle {
             { "Antarctica/Macquarie", Australia_Eastern },
             { "Pacific/Port_Moresby", Papua_New_Guinea },
             { "America/Cambridge_Bay", America_Mountain },
+            { "America/Ciudad_Juarez", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
             { "America/Indiana/Vevay", America_Eastern },
             { "America/Lower_Princes", Atlantic },
