@@ -68,19 +68,19 @@ public class TimeZoneNames_dz extends TimeZoneNamesBundle {
     protected final Object[][] getContents() {
         final String[] GMT = new String[] {
                "\u0f42\u0f72\u0f62\u0f72\u0f53\u0f0b\u0f5d\u0f72\u0f46\u0f0b\u0f63\u0f74\u0f0b\u0f61\u0f7c\u0f51\u0f0b\u0f54\u0f60\u0f72\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
+               "GMT",
                "",
+               "GMT",
                "",
-               "",
-               "",
-               "",
+               "GMT",
             };
         final String[] Cuba = new String[] {
                "\u0f40\u0f72\u0f60\u0f74\u0f0b\u0f56\u0fb7\u0f0b\u0f5a\u0f51\u0f0b\u0f63\u0fa1\u0f53\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
-               "",
+               "CST",
                "\u0f40\u0f72\u0f60\u0f74\u0f0b\u0f56\u0fb7\u0f0b\u0f49\u0f72\u0f53\u0f0b\u0f66\u0fb2\u0f74\u0f44\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
-               "",
+               "CDT",
                "\u0f40\u0f72\u0f60\u0f74\u0f0b\u0f56\u0fb7\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
-               "",
+               "CT",
             };
         final String[] Gulf = new String[] {
                "\u0f42\u0f71\u0f63\u0f55\u0f72\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
@@ -124,11 +124,11 @@ public class TimeZoneNames_dz extends TimeZoneNamesBundle {
             };
         final String[] China = new String[] {
                "\u0f62\u0f92\u0fb1\u0f0b\u0f53\u0f42\u0f0b\u0f5a\u0f51\u0f0b\u0f63\u0fa1\u0f53\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
-               "",
+               "CST",
                "\u0f62\u0f92\u0fb1\u0f0b\u0f53\u0f42\u0f0b\u0f49\u0f72\u0f53\u0f0b\u0f66\u0fb2\u0f74\u0f44\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
-               "",
+               "CDT",
                "\u0f62\u0f92\u0fb1\u0f0b\u0f53\u0f42\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
-               "",
+               "CT",
             };
         final String[] India = new String[] {
                "\u0f62\u0f92\u0fb1\u0f0b\u0f42\u0f62\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
@@ -140,19 +140,19 @@ public class TimeZoneNames_dz extends TimeZoneNamesBundle {
             };
         final String[] Japan = new String[] {
                "\u0f47\u0f0b\u0f54\u0f71\u0f53\u0f0b\u0f5a\u0f51\u0f0b\u0f63\u0fa1\u0f53\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
-               "",
+               "JST",
                "\u0f47\u0f0b\u0f54\u0f71\u0f53\u0f0b\u0f49\u0f72\u0f53\u0f0b\u0f66\u0fb2\u0f74\u0f44\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
-               "",
+               "JDT",
                "\u0f47\u0f0b\u0f54\u0f71\u0f53\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
-               "",
+               "JT",
             };
         final String[] Korea = new String[] {
                "\u0f40\u0f7c\u0f0b\u0f62\u0f72\u0f0b\u0f61\u0f0b\u0f5a\u0f51\u0f0b\u0f63\u0fa1\u0f53\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
-               "",
+               "KST",
                "\u0f40\u0f7c\u0f0b\u0f62\u0f72\u0f0b\u0f61\u0f0b\u0f49\u0f72\u0f53\u0f0b\u0f66\u0fb2\u0f74\u0f44\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
-               "",
+               "KST",
                "\u0f40\u0f7c\u0f0b\u0f62\u0f72\u0f0b\u0f61\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
-               "",
+               "KST",
             };
         final String[] Nepal = new String[] {
                "\u0f53\u0f7a\u0f0b\u0f54\u0f71\u0f63\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
@@ -180,11 +180,11 @@ public class TimeZoneNames_dz extends TimeZoneNamesBundle {
             };
         final String[] Azores = new String[] {
                "\u0f68\u0f7a\u0f0b\u0f5b\u0f7c\u0f62\u0f66\u0f0b\u0f5a\u0f51\u0f0b\u0f63\u0fa1\u0f53\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
-               "",
+               "HMT",
                "\u0f68\u0f7a\u0f0b\u0f5b\u0f7c\u0f62\u0f66\u0f0b\u0f56\u0fb1\u0f71\u0f62\u0f0b\u0f51\u0f74\u0f66\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
-               "",
+               "HMT",
                "\u0f68\u0f7a\u0f0b\u0f5b\u0f7c\u0f62\u0f66\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
-               "",
+               "HMT",
             };
         final String[] Bhutan = new String[] {
                "\u0f60\u0f56\u0fb2\u0f74\u0f42\u0f0b\u0f61\u0f74\u0f63\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
@@ -212,19 +212,19 @@ public class TimeZoneNames_dz extends TimeZoneNamesBundle {
             };
         final String[] Israel = new String[] {
                "\u0f68\u0f72\u0f66\u0f0b\u0f62\u0f7a\u0f63\u0f0b\u0f5a\u0f51\u0f0b\u0f63\u0fa1\u0f53\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
-               "",
+               "IST",
                "\u0f68\u0f72\u0f66\u0f0b\u0f62\u0f7a\u0f63\u0f0b\u0f49\u0f72\u0f53\u0f0b\u0f66\u0fb2\u0f74\u0f44\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
-               "",
+               "IDT",
                "\u0f68\u0f72\u0f66\u0f0b\u0f62\u0f7a\u0f63\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
-               "",
+               "IT",
             };
         final String[] Moscow = new String[] {
                "\u0f58\u0f7d\u0f66\u0f0b\u0f40\u0f7c\u0f0b\u0f5a\u0f51\u0f0b\u0f63\u0fa1\u0f53\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
-               "",
+               "MSK",
                "\u0f58\u0f7d\u0f66\u0f0b\u0f40\u0f7c\u0f0b\u0f56\u0fb1\u0f71\u0f62\u0f0b\u0f51\u0f74\u0f66\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
-               "",
+               "MSK",
                "\u0f58\u0f7d\u0f66\u0f0b\u0f40\u0f7c\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
-               "",
+               "MSK",
             };
         final String[] Arabian = new String[] {
                "\u0f68\u0f0b\u0f62\u0f7a\u0f0b\u0f56\u0fb7\u0f72\u0f0b\u0f61\u0f53\u0f0b\u0f5a\u0f51\u0f0b\u0f63\u0fa1\u0f53\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
@@ -316,11 +316,11 @@ public class TimeZoneNames_dz extends TimeZoneNamesBundle {
             };
         final String[] Atlantic = new String[] {
                "\u0f68\u0f7a\u0f4a\u0f0b\u0f63\u0f7a\u0f53\u0f0b\u0f4a\u0f72\u0f40\u0f0b\u0f5a\u0f51\u0f0b\u0f63\u0fa1\u0f53\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
-               "",
+               "AST",
                "\u0f68\u0f7a\u0f4a\u0f0b\u0f63\u0f7a\u0f53\u0f0b\u0f4a\u0f72\u0f40\u0f0b\u0f49\u0f72\u0f53\u0f0b\u0f66\u0fb2\u0f74\u0f44\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
-               "",
+               "ADT",
                "\u0f68\u0f7a\u0f4a\u0f0b\u0f63\u0f7a\u0f53\u0f0b\u0f4a\u0f72\u0f40\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
-               "",
+               "AT",
             };
         final String[] Brasilia = new String[] {
                "\u0f56\u0fb2\u0f0b\u0f5b\u0f72\u0f0b\u0f63\u0f72\u0f0b\u0f61\u0f0b\u0f5a\u0f51\u0f0b\u0f63\u0fa1\u0f53\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
@@ -356,11 +356,11 @@ public class TimeZoneNames_dz extends TimeZoneNamesBundle {
             };
         final String[] Pakistan = new String[] {
                "\u0f54\u0f0b\u0f40\u0f72\u0f0b\u0f66\u0f84\u0f4f\u0f71\u0f53\u0f0b\u0f5a\u0f51\u0f0b\u0f63\u0fa1\u0f53\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
-               "",
+               "PKT",
                "\u0f54\u0f0b\u0f40\u0f72\u0f0b\u0f66\u0f84\u0f4f\u0f71\u0f53\u0f0b\u0f56\u0fb1\u0f71\u0f62\u0f0b\u0f51\u0f74\u0f66\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
-               "",
+               "PKST",
                "\u0f54\u0f0b\u0f40\u0f72\u0f0b\u0f66\u0f84\u0f4f\u0f71\u0f53\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
-               "",
+               "PKT",
             };
         final String[] Paraguay = new String[] {
                "\u0f54\u0f0b\u0f62\u0f0b\u0f42\u0f74\u0f0b\u0f5d\u0f60\u0f72\u0f0b\u0f5a\u0f51\u0f0b\u0f63\u0fa1\u0f53\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
@@ -436,11 +436,11 @@ public class TimeZoneNames_dz extends TimeZoneNamesBundle {
             };
         final String[] Volgograd = new String[] {
                "\u0f56\u0f71\u0f7c\u0f63\u0f0b\u0f42\u0f7c\u0f0b\u0f42\u0f72\u0f62\u0f7a\u0f4c\u0f0b\u0f5a\u0f51\u0f0b\u0f63\u0fa1\u0f53\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
-               "",
+               "MSK",
                "\u0f56\u0f71\u0f7c\u0f63\u0f0b\u0f42\u0f7c\u0f0b\u0f42\u0f72\u0f62\u0f7a\u0f4c\u0f0b\u0f56\u0fb1\u0f71\u0f62\u0f0b\u0f51\u0f74\u0f66\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
-               "",
+               "MSK",
                "\u0f56\u0f71\u0f7c\u0f63\u0f0b\u0f42\u0f7c\u0f0b\u0f42\u0f72\u0f62\u0f7a\u0f4c\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
-               "",
+               "MSK",
             };
         final String[] Azerbaijan = new String[] {
                "\u0f68\u0f0b\u0f5b\u0f62\u0f0b\u0f56\u0fb7\u0f60\u0f72\u0f0b\u0f47\u0f71\u0f53\u0f0b\u0f5a\u0f51\u0f0b\u0f63\u0fa1\u0f53\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
@@ -500,11 +500,11 @@ public class TimeZoneNames_dz extends TimeZoneNamesBundle {
             };
         final String[] New_Zealand = new String[] {
                "\u0f53\u0f72\u0f60\u0f74\u0f0b\u0f5b\u0f72\u0f0b\u0f63\u0f7a\u0f53\u0f4c\u0f0b\u0f5a\u0f51\u0f0b\u0f63\u0fa1\u0f53\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
-               "",
+               "NZST",
                "\u0f53\u0f72\u0f60\u0f74\u0f0b\u0f5b\u0f72\u0f0b\u0f63\u0f7a\u0f53\u0f4c\u0f0b\u0f49\u0f72\u0f53\u0f0b\u0f66\u0fb2\u0f74\u0f44\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
-               "",
+               "NZDT",
                "\u0f53\u0f72\u0f60\u0f74\u0f0b\u0f5b\u0f72\u0f0b\u0f63\u0f7a\u0f53\u0f4c\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
-               "",
+               "NZT",
             };
         final String[] Novosibirsk = new String[] {
                "\u0f53\u0f7c\u0f0b\u0f56\u0f7c\u0f0b\u0f66\u0f72\u0f0b\u0f56\u0f72\u0f62\u0f66\u0f40\u0f72\u0f0b\u0f5a\u0f51\u0f0b\u0f63\u0fa1\u0f53\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
@@ -532,11 +532,11 @@ public class TimeZoneNames_dz extends TimeZoneNamesBundle {
             };
         final String[] Newfoundland = new String[] {
                "\u0f53\u0f72\u0f60\u0f74\u0f0b\u0f55\u0f60\u0f74\u0f53\u0f4c\u0f0b\u0f63\u0f7a\u0f53\u0f4c\u0f0b\u0f5a\u0f51\u0f0b\u0f63\u0fa1\u0f53\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
-               "",
+               "NST",
                "\u0f53\u0f72\u0f60\u0f74\u0f0b\u0f55\u0f60\u0f74\u0f53\u0f4c\u0f0b\u0f63\u0f7a\u0f53\u0f4c\u0f0b\u0f49\u0f72\u0f53\u0f0b\u0f66\u0fb2\u0f74\u0f44\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
-               "",
+               "NDT",
                "\u0f53\u0f72\u0f60\u0f74\u0f0b\u0f55\u0f60\u0f74\u0f53\u0f4c\u0f0b\u0f63\u0f7a\u0f53\u0f4c\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
-               "",
+               "NT",
             };
         final String[] French_Guiana = new String[] {
                "\u0f55\u0f72\u0f62\u0f7a\u0f53\u0f45\u0f0b\u0f42\u0f72\u0f0b\u0f61\u0f0b\u0f53\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
@@ -556,91 +556,91 @@ public class TimeZoneNames_dz extends TimeZoneNamesBundle {
             };
         final String[] Africa_Central = new String[] {
                "\u0f51\u0f56\u0f74\u0f66\u0f0b\u0f55\u0fb1\u0f7c\u0f42\u0f66\u0f0b\u0f68\u0f55\u0f0b\u0f62\u0f72\u0f0b\u0f40\u0f71\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
+               "SAST",
                "",
+               "SAST",
                "",
-               "",
-               "",
-               "",
+               "SAST",
             };
         final String[] Africa_Eastern = new String[] {
                "\u0f64\u0f62\u0f0b\u0f55\u0fb1\u0f7c\u0f42\u0f66\u0f0b\u0f68\u0f55\u0f0b\u0f62\u0f72\u0f0b\u0f40\u0f71\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
+               "EAT",
                "",
+               "EAT",
                "",
-               "",
-               "",
-               "",
+               "EAT",
             };
         final String[] Africa_Western = new String[] {
                "\u0f53\u0f74\u0f56\u0f0b\u0f55\u0fb1\u0f7c\u0f42\u0f66\u0f0b\u0f68\u0f55\u0f0b\u0f62\u0f72\u0f0b\u0f40\u0f71\u0f0b\u0f5a\u0f51\u0f0b\u0f63\u0fa1\u0f53\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
-               "",
+               "WAT",
                "\u0f53\u0f74\u0f56\u0f0b\u0f55\u0fb1\u0f7c\u0f42\u0f66\u0f0b\u0f68\u0f55\u0f0b\u0f62\u0f72\u0f0b\u0f40\u0f71\u0f0b\u0f56\u0fb1\u0f71\u0f62\u0f0b\u0f51\u0f74\u0f66\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
-               "",
+               "WAT",
                "\u0f53\u0f74\u0f56\u0f0b\u0f55\u0fb1\u0f7c\u0f42\u0f66\u0f0b\u0f68\u0f55\u0f0b\u0f62\u0f72\u0f0b\u0f40\u0f71\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
-               "",
+               "WAT",
             };
         final String[] Europe_Central = new String[] {
                "\u0f51\u0f56\u0f74\u0f66\u0f0b\u0f55\u0fb1\u0f7c\u0f42\u0f66\u0f0b\u0f61\u0f74\u0f0b\u0f62\u0f7c\u0f0b\u0f54\u0f7a\u0f53\u0f0b\u0f5a\u0f51\u0f0b\u0f63\u0fa1\u0f53\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
-               "",
+               "CET",
                "\u0f51\u0f56\u0f74\u0f66\u0f0b\u0f55\u0fb1\u0f7c\u0f42\u0f66\u0f0b\u0f61\u0f74\u0f0b\u0f62\u0f7c\u0f0b\u0f54\u0f7a\u0f53\u0f0b\u0f56\u0fb1\u0f71\u0f62\u0f0b\u0f51\u0f74\u0f66\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
-               "",
+               "CEST",
                "\u0f51\u0f56\u0f74\u0f66\u0f0b\u0f55\u0fb1\u0f7c\u0f42\u0f66\u0f0b\u0f61\u0f74\u0f0b\u0f62\u0f7c\u0f0b\u0f54\u0f7a\u0f53\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
-               "",
+               "CET",
             };
         final String[] Europe_Eastern = new String[] {
                "\u0f64\u0f62\u0f0b\u0f55\u0fb1\u0f7c\u0f42\u0f66\u0f0b\u0f61\u0f74\u0f0b\u0f62\u0f7c\u0f0b\u0f54\u0f7a\u0f53\u0f0b\u0f5a\u0f51\u0f0b\u0f63\u0fa1\u0f53\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
-               "",
+               "EET",
                "\u0f64\u0f62\u0f0b\u0f55\u0fb1\u0f7c\u0f42\u0f66\u0f0b\u0f61\u0f74\u0f0b\u0f62\u0f7c\u0f0b\u0f54\u0f7a\u0f53\u0f0b\u0f56\u0fb1\u0f71\u0f62\u0f0b\u0f51\u0f74\u0f66\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
-               "",
+               "EEST",
                "\u0f64\u0f62\u0f0b\u0f55\u0fb1\u0f7c\u0f42\u0f66\u0f0b\u0f61\u0f74\u0f0b\u0f62\u0f7c\u0f0b\u0f54\u0f7a\u0f53\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
-               "",
+               "EET",
             };
         final String[] Europe_Western = new String[] {
                "\u0f53\u0f74\u0f56\u0f0b\u0f55\u0fb1\u0f7c\u0f42\u0f66\u0f0b\u0f61\u0f74\u0f0b\u0f62\u0f7c\u0f0b\u0f54\u0f7a\u0f53\u0f0b\u0f5a\u0f51\u0f0b\u0f63\u0fa1\u0f53\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
-               "",
+               "FMT",
                "\u0f53\u0f74\u0f56\u0f0b\u0f55\u0fb1\u0f7c\u0f42\u0f66\u0f0b\u0f61\u0f74\u0f0b\u0f62\u0f7c\u0f0b\u0f54\u0f7a\u0f53\u0f0b\u0f56\u0fb1\u0f71\u0f62\u0f0b\u0f51\u0f74\u0f66\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
-               "",
+               "FMT",
                "\u0f53\u0f74\u0f56\u0f0b\u0f55\u0fb1\u0f7c\u0f42\u0f66\u0f0b\u0f61\u0f74\u0f0b\u0f62\u0f7c\u0f0b\u0f54\u0f7a\u0f53\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
-               "",
+               "FMT",
             };
         final String[] Africa_Southern = new String[] {
                "\u0f63\u0fb7\u0f7c\u0f0b\u0f55\u0fb1\u0f7c\u0f42\u0f66\u0f0b\u0f68\u0f55\u0f0b\u0f62\u0f72\u0f0b\u0f40\u0f71\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
+               "SAST",
                "",
+               "SAST",
                "",
-               "",
-               "",
-               "",
+               "SAST",
             };
         final String[] America_Central = new String[] {
                "\u0f56\u0fb1\u0f44\u0f0b\u0f68\u0f0b\u0f58\u0f72\u0f0b\u0f62\u0f72\u0f0b\u0f40\u0f0b\u0f51\u0f56\u0f74\u0f66\u0f0b\u0f55\u0fb1\u0f7c\u0f42\u0f66\u0f0b\u0f5a\u0f51\u0f0b\u0f63\u0fa1\u0f53\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
-               "",
+               "CST",
                "\u0f56\u0fb1\u0f44\u0f0b\u0f68\u0f0b\u0f58\u0f72\u0f0b\u0f62\u0f72\u0f0b\u0f40\u0f0b\u0f51\u0f56\u0f74\u0f66\u0f0b\u0f55\u0fb1\u0f7c\u0f42\u0f66\u0f0b\u0f49\u0f72\u0f53\u0f0b\u0f66\u0fb2\u0f74\u0f44\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
-               "",
+               "CDT",
                "\u0f56\u0fb1\u0f44\u0f0b\u0f68\u0f0b\u0f58\u0f72\u0f0b\u0f62\u0f72\u0f0b\u0f40\u0f0b\u0f51\u0f56\u0f74\u0f66\u0f0b\u0f55\u0fb1\u0f7c\u0f42\u0f66\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
-               "",
+               "CT",
             };
         final String[] America_Eastern = new String[] {
                "\u0f56\u0fb1\u0f44\u0f0b\u0f68\u0f0b\u0f58\u0f72\u0f0b\u0f62\u0f72\u0f0b\u0f40\u0f0b\u0f64\u0f62\u0f0b\u0f55\u0fb1\u0f7c\u0f42\u0f66\u0f0b\u0f5a\u0f51\u0f0b\u0f63\u0fa1\u0f53\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
-               "",
+               "EST",
                "\u0f56\u0fb1\u0f44\u0f0b\u0f68\u0f0b\u0f58\u0f72\u0f0b\u0f62\u0f72\u0f0b\u0f40\u0f0b\u0f64\u0f62\u0f0b\u0f55\u0fb1\u0f7c\u0f42\u0f66\u0f0b\u0f49\u0f72\u0f53\u0f0b\u0f66\u0fb2\u0f74\u0f44\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
-               "",
+               "EST",
                "\u0f56\u0fb1\u0f44\u0f0b\u0f68\u0f0b\u0f58\u0f72\u0f0b\u0f62\u0f72\u0f0b\u0f40\u0f0b\u0f64\u0f62\u0f0b\u0f55\u0fb1\u0f7c\u0f42\u0f66\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
-               "",
+               "EST",
             };
         final String[] America_Pacific = new String[] {
                "\u0f56\u0fb1\u0f44\u0f0b\u0f68\u0f0b\u0f58\u0f72\u0f0b\u0f62\u0f72\u0f0b\u0f40\u0f0b\u0f54\u0f7a\u0f0b\u0f66\u0f72\u0f0b\u0f55\u0f72\u0f42\u0f0b\u0f5a\u0f51\u0f0b\u0f63\u0fa1\u0f53\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
-               "",
+               "PST",
                "\u0f56\u0fb1\u0f44\u0f0b\u0f68\u0f0b\u0f58\u0f72\u0f0b\u0f62\u0f72\u0f0b\u0f40\u0f0b\u0f54\u0f7a\u0f0b\u0f66\u0f72\u0f0b\u0f55\u0f72\u0f42\u0f0b\u0f49\u0f72\u0f53\u0f0b\u0f66\u0fb2\u0f74\u0f44\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
-               "",
+               "PDT",
                "\u0f56\u0fb1\u0f44\u0f0b\u0f68\u0f0b\u0f58\u0f72\u0f0b\u0f62\u0f72\u0f0b\u0f40\u0f0b\u0f54\u0f7a\u0f0b\u0f66\u0f72\u0f0b\u0f55\u0f72\u0f42\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
-               "",
+               "PT",
             };
         final String[] Hawaii_Aleutian = new String[] {
                "\u0f67\u0f0b\u0f5d\u0f60\u0f72\u0f0b-\u0f68\u0f7a\u0f0b\u0f63\u0f72\u0f60\u0f74\u0f0b\u0f64\u0f7a\u0f53\u0f0b\u0f5a\u0f51\u0f0b\u0f63\u0fa1\u0f53\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
-               "",
+               "HST",
                "\u0f67\u0f0b\u0f5d\u0f60\u0f72\u0f0b-\u0f68\u0f7a\u0f0b\u0f63\u0f72\u0f60\u0f74\u0f0b\u0f64\u0f7a\u0f53\u0f0b\u0f49\u0f72\u0f53\u0f0b\u0f66\u0fb2\u0f74\u0f44\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
-               "",
+               "HST",
                "\u0f67\u0f0b\u0f5d\u0f60\u0f72\u0f0b-\u0f68\u0f7a\u0f0b\u0f63\u0f72\u0f60\u0f74\u0f0b\u0f64\u0f7a\u0f53\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
-               "",
+               "HST",
             };
         final String[] Pierre_Miquelon = new String[] {
                "\u0f54\u0f60\u0f72\u0f0b\u0f62\u0f72\u0f0b\u0f51\u0f44\u0f0b\u0f58\u0f72\u0f0b\u0f40\u0f72\u0f0b\u0f63\u0f71\u0f7c\u0f53\u0f0b\u0f5a\u0f51\u0f0b\u0f63\u0fa1\u0f53\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
@@ -652,27 +652,27 @@ public class TimeZoneNames_dz extends TimeZoneNamesBundle {
             };
         final String[] America_Mountain = new String[] {
                "\u0f56\u0fb1\u0f44\u0f0b\u0f68\u0f0b\u0f58\u0f72\u0f0b\u0f62\u0f72\u0f0b\u0f40\u0f0b\u0f58\u0f60\u0f74\u0f0b\u0f4a\u0f7a\u0f53\u0f0b\u0f5a\u0f51\u0f0b\u0f63\u0fa1\u0f53\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
-               "",
+               "MST",
                "\u0f56\u0fb1\u0f44\u0f0b\u0f68\u0f0b\u0f58\u0f72\u0f0b\u0f62\u0f72\u0f0b\u0f40\u0f0b\u0f58\u0f60\u0f74\u0f0b\u0f4a\u0f7a\u0f53\u0f0b\u0f49\u0f72\u0f53\u0f0b\u0f66\u0fb2\u0f74\u0f44\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
-               "",
+               "MDT",
                "\u0f56\u0fb1\u0f44\u0f0b\u0f68\u0f0b\u0f58\u0f72\u0f0b\u0f62\u0f72\u0f0b\u0f40\u0f0b\u0f58\u0f60\u0f74\u0f0b\u0f4a\u0f7a\u0f53\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
-               "",
+               "MT",
             };
         final String[] Australia_Central = new String[] {
                "\u0f51\u0f56\u0f74\u0f66\u0f0b\u0f55\u0fb1\u0f7c\u0f42\u0f66\u0f0b\u0f68\u0f71\u0f7c\u0f66\u0f0b\u0f4a\u0fb2\u0f7a\u0f63\u0f0b\u0f63\u0f72\u0f0b\u0f61\u0f0b\u0f5a\u0f51\u0f0b\u0f63\u0fa1\u0f53\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
-               "",
+               "ACST",
                "\u0f51\u0f56\u0f74\u0f66\u0f0b\u0f55\u0fb1\u0f7c\u0f42\u0f66\u0f0b\u0f68\u0f71\u0f7c\u0f66\u0f0b\u0f4a\u0fb2\u0f7a\u0f63\u0f0b\u0f63\u0f72\u0f0b\u0f61\u0f0b\u0f49\u0f72\u0f53\u0f0b\u0f66\u0fb2\u0f74\u0f44\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
-               "",
+               "ACDT",
                "\u0f51\u0f56\u0f74\u0f66\u0f0b\u0f55\u0fb1\u0f7c\u0f42\u0f66\u0f0b\u0f68\u0f71\u0f7c\u0f66\u0f0b\u0f4a\u0fb2\u0f7a\u0f63\u0f0b\u0f63\u0f72\u0f0b\u0f61\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
-               "",
+               "ACT",
             };
         final String[] Australia_Eastern = new String[] {
                "\u0f64\u0f62\u0f0b\u0f55\u0fb1\u0f7c\u0f42\u0f66\u0f0b\u0f55\u0fb1\u0f7c\u0f42\u0f66\u0f0b\u0f68\u0f71\u0f7c\u0f66\u0f0b\u0f4a\u0fb2\u0f7a\u0f63\u0f0b\u0f63\u0f72\u0f0b\u0f61\u0f0b\u0f5a\u0f51\u0f0b\u0f63\u0fa1\u0f53\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
-               "",
+               "AEST",
                "\u0f64\u0f62\u0f0b\u0f55\u0fb1\u0f7c\u0f42\u0f66\u0f0b\u0f55\u0fb1\u0f7c\u0f42\u0f66\u0f0b\u0f68\u0f71\u0f7c\u0f66\u0f0b\u0f4a\u0fb2\u0f7a\u0f63\u0f0b\u0f63\u0f72\u0f0b\u0f61\u0f0b\u0f49\u0f72\u0f53\u0f0b\u0f66\u0fb2\u0f74\u0f44\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
-               "",
+               "AEDT",
                "\u0f64\u0f62\u0f0b\u0f55\u0fb1\u0f7c\u0f42\u0f66\u0f0b\u0f55\u0fb1\u0f7c\u0f42\u0f66\u0f0b\u0f68\u0f71\u0f7c\u0f66\u0f0b\u0f4a\u0fb2\u0f7a\u0f63\u0f0b\u0f63\u0f72\u0f0b\u0f61\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
-               "",
+               "AET",
             };
         final String[] Australia_Western = new String[] {
                "\u0f53\u0f74\u0f56\u0f0b\u0f55\u0fb1\u0f7c\u0f42\u0f66\u0f0b\u0f68\u0f71\u0f7c\u0f66\u0f0b\u0f4a\u0fb2\u0f7a\u0f63\u0f0b\u0f63\u0f72\u0f0b\u0f61\u0f0b\u0f5a\u0f51\u0f0b\u0f63\u0fa1\u0f53\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
@@ -700,27 +700,27 @@ public class TimeZoneNames_dz extends TimeZoneNamesBundle {
             };
         final String[] Indonesia_Central = new String[] {
                "\u0f51\u0f56\u0f74\u0f66\u0f0b\u0f55\u0fb1\u0f7c\u0f42\u0f66\u0f0b\u0f68\u0f72\u0f53\u0f0b\u0f4c\u0f7c\u0f0b\u0f53\u0f7a\u0f0b\u0f64\u0f72\u0f0b\u0f61\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
+               "WITA",
                "",
+               "WITA",
                "",
-               "",
-               "",
-               "",
+               "WITA",
             };
         final String[] Indonesia_Eastern = new String[] {
                "\u0f64\u0f62\u0f0b\u0f55\u0fb1\u0f7c\u0f42\u0f66\u0f0b\u0f68\u0f72\u0f53\u0f0b\u0f4c\u0f7c\u0f0b\u0f53\u0f7a\u0f0b\u0f64\u0f72\u0f0b\u0f61\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
+               "WIT",
                "",
+               "WIT",
                "",
-               "",
-               "",
-               "",
+               "WIT",
             };
         final String[] Indonesia_Western = new String[] {
                "\u0f53\u0f74\u0f56\u0f0b\u0f55\u0fb1\u0f7c\u0f42\u0f66\u0f0b\u0f68\u0f72\u0f53\u0f0b\u0f4c\u0f7c\u0f0b\u0f53\u0f7a\u0f0b\u0f64\u0f72\u0f0b\u0f61\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
+               "WIB",
                "",
+               "WIB",
                "",
-               "",
-               "",
-               "",
+               "WIB",
             };
         final String[] Australia_CentralWestern = new String[] {
                "\u0f51\u0f56\u0f74\u0f66\u0f0b\u0f53\u0f74\u0f56\u0f0b\u0f55\u0fb1\u0f7c\u0f42\u0f66\u0f0b\u0f68\u0f71\u0f7c\u0f66\u0f0b\u0f4a\u0fb2\u0f7a\u0f63\u0f0b\u0f63\u0f72\u0f0b\u0f61\u0f0b\u0f5a\u0f51\u0f0b\u0f63\u0fa1\u0f53\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
@@ -861,11 +861,11 @@ public class TimeZoneNames_dz extends TimeZoneNamesBundle {
             { "Europe/Dublin",
                 new String[] {
                     "\u0f42\u0f72\u0f62\u0f72\u0f53\u0f0b\u0f5d\u0f72\u0f46\u0f0b\u0f63\u0f74\u0f0b\u0f61\u0f7c\u0f51\u0f0b\u0f54\u0f60\u0f72\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
-                    "",
+                    "GMT",
                     "\u0f68\u0f71\u0f0b\u0f61\u0f62\u0f72\u0f64\u0f0b\u0f56\u0fb1\u0f71\u0f62\u0f0b\u0f51\u0f74\u0f66\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
+                    "IST",
                     "",
-                    "",
-                    "",
+                    "GMT",
                 }
             },
             { "Europe/Jersey", GMT },
@@ -873,11 +873,11 @@ public class TimeZoneNames_dz extends TimeZoneNamesBundle {
             { "Europe/London",
                 new String[] {
                     "\u0f42\u0f72\u0f62\u0f72\u0f53\u0f0b\u0f5d\u0f72\u0f46\u0f0b\u0f63\u0f74\u0f0b\u0f61\u0f7c\u0f51\u0f0b\u0f54\u0f60\u0f72\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
-                    "",
+                    "GMT",
                     "\u0f56\u0fb2\u0f71\u0f72\u0f0b\u0f4a\u0f72\u0f64\u0f0b\u0f56\u0fb1\u0f71\u0f62\u0f0b\u0f51\u0f74\u0f66\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
+                    "BST",
                     "",
-                    "",
-                    "",
+                    "GMT",
                 }
             },
             { "Europe/Madrid", Europe_Central },
@@ -925,11 +925,11 @@ public class TimeZoneNames_dz extends TimeZoneNamesBundle {
             { "Europe/Belfast",
                 new String[] {
                     "\u0f42\u0f72\u0f62\u0f72\u0f53\u0f0b\u0f5d\u0f72\u0f46\u0f0b\u0f63\u0f74\u0f0b\u0f61\u0f7c\u0f51\u0f0b\u0f54\u0f60\u0f72\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
-                    "",
+                    "GMT",
                     "\u0f56\u0fb2\u0f71\u0f72\u0f0b\u0f4a\u0f72\u0f64\u0f0b\u0f56\u0fb1\u0f71\u0f62\u0f0b\u0f51\u0f74\u0f66\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
+                    "BST",
                     "",
-                    "",
-                    "",
+                    "GMT",
                 }
             },
             { "Europe/Tallinn", Europe_Eastern },
