@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,7 +26,7 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
  * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
@@ -78,17 +78,17 @@ public class TimeZoneNames_en_KE extends TimeZoneNamesBundle {
                "Central Africa Time",
                "CAT",
                "",
+               "SAST",
                "",
-               "",
-               "",
+               "SAST",
             };
         final String[] Africa_Eastern = new String[] {
                "East Africa Time",
                "EAT",
                "",
+               "EAT",
                "",
-               "",
-               "",
+               "EAT",
             };
         final String[] Africa_Western = new String[] {
                "West Africa Standard Time",
@@ -102,15 +102,15 @@ public class TimeZoneNames_en_KE extends TimeZoneNamesBundle {
                "South Africa Standard Time",
                "SAST",
                "",
+               "SAST",
                "",
-               "",
-               "",
+               "SAST",
             };
         final Object[][] data = new Object[][] {
             { "UTC", EMPTY_ZONE },
             { "CAT", Africa_Central },
             { "EAT", Africa_Eastern },
-            { "Africa/Juba", Africa_Eastern },
+            { "Africa/Juba", Africa_Central },
             { "Africa/Lagos", Africa_Western },
             { "Africa/Asmera", Africa_Eastern },
             { "Africa/Bangui", Africa_Western },
