@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2022, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -92,11 +92,11 @@ public class TimeZoneNames_fr_CA extends TimeZoneNamesBundle {
             };
         final String[] Cuba = new String[] {
                "heure normale de Cuba",
-               "",
+               "CST",
                "heure avanc\u00e9e de Cuba",
-               "",
+               "CDT",
                "heure de Cuba",
-               "",
+               "CT",
             };
         final String[] Fiji = new String[] {
                "heure normale des \u00eeles Fidji",
@@ -122,6 +122,14 @@ public class TimeZoneNames_fr_CA extends TimeZoneNamesBundle {
                "heure de l\u2019Iran",
                "",
             };
+        final String[] Niue = new String[] {
+               "heure de Niou\u00e9",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Omsk = new String[] {
                "heure normale d\u2019Omsk",
                "",
@@ -148,35 +156,35 @@ public class TimeZoneNames_fr_CA extends TimeZoneNamesBundle {
             };
         final String[] China = new String[] {
                "heure normale de Chine",
-               "",
+               "CST",
                "heure avanc\u00e9e de Chine",
-               "",
+               "CDT",
                "heure de Chine",
-               "",
+               "CT",
             };
         final String[] Japan = new String[] {
                "heure normale du Japon",
-               "",
+               "JST",
                "heure avanc\u00e9e du Japon",
-               "",
+               "JDT",
                "heure du Japon",
-               "",
+               "JT",
             };
         final String[] Korea = new String[] {
                "heure normale de la Cor\u00e9e",
-               "",
+               "KST",
                "heure avanc\u00e9e de Cor\u00e9e",
-               "",
+               "KST",
                "heure de la Cor\u00e9e",
-               "",
+               "KST",
             };
         final String[] Samoa = new String[] {
                "heure normale des Samoa",
-               "",
+               "SST",
                "heure avanc\u00e9e des Samoa",
-               "",
+               "SST",
                "heure des Samoa",
-               "",
+               "SST",
             };
         final String[] Tonga = new String[] {
                "heure normale des Tonga",
@@ -212,10 +220,18 @@ public class TimeZoneNames_fr_CA extends TimeZoneNamesBundle {
             };
         final String[] Azores = new String[] {
                "heure normale des A\u00e7ores",
-               "",
+               "HMT",
                "heure avanc\u00e9e des A\u00e7ores",
-               "",
+               "HMT",
                "heure des A\u00e7ores",
+               "HMT",
+            };
+        final String[] Brunei = new String[] {
+               "heure du Brun\u00e9i",
+               "",
+               "",
+               "",
+               "",
                "",
             };
         final String[] Easter = new String[] {
@@ -228,27 +244,27 @@ public class TimeZoneNames_fr_CA extends TimeZoneNamesBundle {
             };
         final String[] Israel = new String[] {
                "heure normale d\u2019Isra\u00ebl",
-               "",
+               "IST",
                "heure avanc\u00e9e d\u2019Isra\u00ebl",
-               "",
+               "IDT",
                "heure d\u2019Isra\u00ebl",
-               "",
+               "IT",
             };
         final String[] Moscow = new String[] {
                "heure normale de Moscou",
-               "",
+               "MSK",
                "heure avanc\u00e9e de Moscou",
-               "",
+               "MSK",
                "heure de Moscou",
-               "",
+               "MSK",
             };
         final String[] Taipei = new String[] {
                "heure normale de Taipei",
-               "",
+               "CST",
                "heure avanc\u00e9e de Taipei",
-               "",
+               "CDT",
                "heure de Taipei",
-               "",
+               "CT",
             };
         final String[] Arabian = new String[] {
                "heure normale de l\u2019Arabie",
@@ -340,11 +356,11 @@ public class TimeZoneNames_fr_CA extends TimeZoneNamesBundle {
             };
         final String[] Atlantic = new String[] {
                "heure normale de l\u2019Atlantique",
-               "",
+               "AST",
                "heure avanc\u00e9e de l\u2019Atlantique",
-               "",
+               "ADT",
                "heure de l\u2019Atlantique",
-               "",
+               "AT",
             };
         final String[] Brasilia = new String[] {
                "heure normale de Brasilia",
@@ -380,11 +396,11 @@ public class TimeZoneNames_fr_CA extends TimeZoneNamesBundle {
             };
         final String[] Pakistan = new String[] {
                "heure normale du Pakistan",
-               "",
+               "PKT",
                "heure avanc\u00e9e du Pakistan",
-               "",
+               "PKST",
                "heure du Pakistan",
-               "",
+               "PKT",
             };
         final String[] Paraguay = new String[] {
                "heure normale du Paraguay",
@@ -412,11 +428,11 @@ public class TimeZoneNames_fr_CA extends TimeZoneNamesBundle {
             };
         final String[] Hong_Kong = new String[] {
                "heure normale de Hong Kong",
-               "",
+               "HKT",
                "heure avanc\u00e9e de Hong Kong",
-               "",
+               "HKST",
                "heure de Hong Kong",
-               "",
+               "HKT",
             };
         final String[] Kamchatka = new String[] {
                "heure normale de Petropavlovsk-Kamchatski",
@@ -444,11 +460,11 @@ public class TimeZoneNames_fr_CA extends TimeZoneNamesBundle {
             };
         final String[] Volgograd = new String[] {
                "heure normale de Volgograd",
-               "",
+               "MSK",
                "heure avanc\u00e9e de Volgograd",
-               "",
+               "MSK",
                "heure de Volgograd",
-               "",
+               "MSK",
             };
         final String[] Azerbaijan = new String[] {
                "heure normale de l\u2019Azerba\u00efdjan",
@@ -500,11 +516,11 @@ public class TimeZoneNames_fr_CA extends TimeZoneNamesBundle {
             };
         final String[] New_Zealand = new String[] {
                "heure normale de la Nouvelle-Z\u00e9lande",
-               "",
+               "NZST",
                "heure avanc\u00e9e de la Nouvelle-Z\u00e9lande",
-               "",
+               "NZDT",
                "heure de la Nouvelle-Z\u00e9lande",
-               "",
+               "NZT",
             };
         final String[] Novosibirsk = new String[] {
                "heure normale de Novossibirsk",
@@ -516,11 +532,11 @@ public class TimeZoneNames_fr_CA extends TimeZoneNamesBundle {
             };
         final String[] Philippines = new String[] {
                "heure normale des Philippines",
-               "",
+               "PST",
                "heure avanc\u00e9e des Philippines",
-               "",
+               "PDT",
                "heure des Philippines",
-               "",
+               "PT",
             };
         final String[] Vladivostok = new String[] {
                "heure normale de Vladivostok",
@@ -572,67 +588,67 @@ public class TimeZoneNames_fr_CA extends TimeZoneNamesBundle {
             };
         final String[] Africa_Central = new String[] {
                "heure d\u2019Afrique centrale",
+               "SAST",
                "",
+               "SAST",
                "",
-               "",
-               "",
-               "",
+               "SAST",
             };
         final String[] Africa_Eastern = new String[] {
                "heure d\u2019Afrique orientale",
+               "EAT",
                "",
+               "EAT",
                "",
-               "",
-               "",
-               "",
+               "EAT",
             };
         final String[] Africa_Western = new String[] {
                "heure normale d\u2019Afrique de l\u2019Ouest",
-               "",
+               "WAT",
                "heure avanc\u00e9e d\u2019Afrique de l\u2019Ouest",
-               "",
+               "WAT",
                "heure d\u2019Afrique de l\u2019Ouest",
-               "",
+               "WAT",
             };
         final String[] Europe_Central = new String[] {
                "heure normale de l\u2019Europe centrale",
-               "",
+               "CET",
                "heure avanc\u00e9e de l\u2019Europe centrale",
-               "",
+               "CEST",
                "heure de l\u2019Europe centrale",
-               "",
+               "CET",
             };
         final String[] Europe_Eastern = new String[] {
                "heure normale de l\u2019Europe de l\u2019Est",
-               "",
+               "EET",
                "heure avanc\u00e9e de l\u2019Europe de l\u2019Est",
-               "",
+               "EEST",
                "heure de l\u2019Europe de l\u2019Est",
-               "",
+               "EET",
             };
         final String[] Europe_Western = new String[] {
                "heure normale de l\u2019Europe de l\u2019Ouest",
-               "",
+               "FMT",
                "heure avanc\u00e9e de l\u2019Europe de l\u2019Ouest",
-               "",
+               "FMT",
                "heure de l\u2019Europe de l\u2019Ouest",
-               "",
+               "FMT",
             };
         final String[] Mexico_Pacific = new String[] {
                "heure normale du Pacifique mexicain",
-               "",
+               "MST",
                "heure avanc\u00e9e du Pacifique mexicain",
-               "",
+               "MDT",
                "heure du Pacifique mexicain",
-               "",
+               "MT",
             };
         final String[] Africa_Southern = new String[] {
                "heure normale d\u2019Afrique du Sud",
+               "SAST",
                "",
+               "SAST",
                "",
-               "",
-               "",
-               "",
+               "SAST",
             };
         final String[] America_Central = new String[] {
                "heure normale du Centre",
@@ -660,11 +676,11 @@ public class TimeZoneNames_fr_CA extends TimeZoneNamesBundle {
             };
         final String[] Hawaii_Aleutian = new String[] {
                "heure normale d\u2019Hawa\u00ef-Al\u00e9outiennes",
-               "",
+               "HST",
                "heure avanc\u00e9e d\u2019Hawa\u00ef-Al\u00e9outiennes",
-               "",
+               "HST",
                "heure d\u2019Hawa\u00ef-Al\u00e9outiennes",
-               "",
+               "HST",
             };
         final String[] Pierre_Miquelon = new String[] {
                "heure normale de Saint-Pierre-et-Miquelon",
@@ -692,19 +708,19 @@ public class TimeZoneNames_fr_CA extends TimeZoneNamesBundle {
             };
         final String[] Australia_Central = new String[] {
                "heure normale du centre de l\u2019Australie",
-               "",
+               "ACST",
                "heure avanc\u00e9e du centre de l\u2019Australie",
-               "",
+               "ACDT",
                "heure du centre de l\u2019Australie",
-               "",
+               "ACT",
             };
         final String[] Australia_Eastern = new String[] {
                "heure normale de l\u2019Est de l\u2019Australie",
-               "",
+               "AEST",
                "heure avanc\u00e9e de l\u2019Est de l\u2019Australie",
-               "",
+               "AEDT",
                "heure de l\u2019Est de l\u2019Australie",
-               "",
+               "AET",
             };
         final String[] Australia_Western = new String[] {
                "heure normale de l\u2019Ouest de l\u2019Australie",
@@ -785,7 +801,6 @@ public class TimeZoneNames_fr_CA extends TimeZoneNamesBundle {
             { "Asia/Gaza", Europe_Eastern },
             { "Asia/Hovd", Hovd },
             { "Asia/Omsk", Omsk },
-            { "Asia/Amman", Europe_Eastern },
             { "Asia/Chita", Yakutsk },
             { "Asia/Dhaka", Bangladesh },
             { "Asia/Macau", China },
@@ -794,6 +809,7 @@ public class TimeZoneNames_fr_CA extends TimeZoneNamesBundle {
             { "Africa/Juba", Africa_Central },
             { "Asia/Anadyr", Anadyr },
             { "Asia/Beirut", Europe_Eastern },
+            { "Asia/Brunei", Brunei },
             { "Asia/Harbin", China },
             { "Asia/Hebron", Europe_Eastern },
             { "Asia/Kuwait", Arabian },
@@ -827,6 +843,7 @@ public class TimeZoneNames_fr_CA extends TimeZoneNamesBundle {
             { "Europe/Vaduz", Europe_Central },
             { "Pacific/Apia", Apia },
             { "Pacific/Fiji", Fiji },
+            { "Pacific/Niue", Niue },
             { "SystemV/AST4", Atlantic },
             { "SystemV/CST6", America_Central },
             { "SystemV/EST5", America_Eastern },
@@ -849,7 +866,6 @@ public class TimeZoneNames_fr_CA extends TimeZoneNamesBundle {
             { "America/Jujuy", Argentina },
             { "America/Thule", Atlantic },
             { "Asia/Ashgabat", Turkmenistan },
-            { "Asia/Damascus", Europe_Eastern },
             { "Asia/Khandyga", Yakutsk },
             { "Asia/Sakhalin", Sakhalin },
             { "Asia/Tashkent", Uzbekistan },
@@ -859,22 +875,22 @@ public class TimeZoneNames_fr_CA extends TimeZoneNamesBundle {
             { "Europe/Dublin",
                 new String[] {
                     "",
-                    "",
+                    "GMT",
                     "heure avanc\u00e9e irlandaise",
+                    "IST",
                     "",
-                    "",
-                    "",
+                    "GMT",
                 }
             },
             { "Europe/Lisbon", Europe_Western },
             { "Europe/London",
                 new String[] {
                     "",
-                    "",
+                    "GMT",
                     "heure avanc\u00e9e britannique",
+                    "BST",
                     "",
-                    "",
-                    "",
+                    "GMT",
                 }
             },
             { "Europe/Madrid", Europe_Central },
@@ -919,11 +935,11 @@ public class TimeZoneNames_fr_CA extends TimeZoneNamesBundle {
             { "Europe/Belfast",
                 new String[] {
                     "",
-                    "",
+                    "GMT",
                     "heure avanc\u00e9e britannique",
+                    "BST",
                     "",
-                    "",
-                    "",
+                    "GMT",
                 }
             },
             { "Europe/Tallinn", Europe_Eastern },
@@ -957,7 +973,7 @@ public class TimeZoneNames_fr_CA extends TimeZoneNamesBundle {
             { "America/Moncton", Atlantic },
             { "America/Nipigon", America_Eastern },
             { "America/Noronha", Noronha },
-            { "America/Ojinaga", America_Mountain },
+            { "America/Ojinaga", America_Central },
             { "America/Tijuana", America_Pacific },
             { "America/Toronto", America_Eastern },
             { "America/Tortola", Atlantic },
@@ -1028,7 +1044,7 @@ public class TimeZoneNames_fr_CA extends TimeZoneNamesBundle {
             { "America/Araguaina", Brasilia },
             { "America/Boa_Vista", Amazon },
             { "America/Catamarca", Argentina },
-            { "America/Chihuahua", Mexico_Pacific },
+            { "America/Chihuahua", America_Central },
             { "America/Fortaleza", Brasilia },
             { "America/Glace_Bay", Atlantic },
             { "America/Goose_Bay", Atlantic },
@@ -1097,6 +1113,7 @@ public class TimeZoneNames_fr_CA extends TimeZoneNamesBundle {
             { "America/Scoresbysund", Greenland_Eastern },
             { "Antarctica/Macquarie", Australia_Eastern },
             { "America/Cambridge_Bay", America_Mountain },
+            { "America/Ciudad_Juarez", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
             { "America/Indiana/Vevay", America_Eastern },
             { "America/Lower_Princes", Atlantic },
@@ -1124,6 +1141,7 @@ public class TimeZoneNames_fr_CA extends TimeZoneNamesBundle {
             { "America/North_Dakota/Beulah", America_Central },
             { "America/North_Dakota/Center", America_Central },
             { "timezone.excity.Asia/Thimphu", "Thimphou" },
+            { "timezone.excity.Pacific/Palau", "Palau" },
             { "America/Argentina/Rio_Gallegos", Argentina },
             { "America/North_Dakota/New_Salem", America_Central },
             { "timezone.excity.Africa/Tripoli", "Tripoli [Libye]" },
@@ -1137,6 +1155,8 @@ public class TimeZoneNames_fr_CA extends TimeZoneNamesBundle {
             { "timezone.excity.America/St_Kitts", "Saint-Christophe-et-Ni\u00e9v\u00e8s" },
             { "timezone.excity.America/St_Thomas", "Saint Thomas" },
             { "timezone.excity.Europe/Isle_of_Man", "\u00eele de Man" },
+            { "timezone.excity.America/Tegucigalpa", "T\u00e9gucigalpa" },
+            { "timezone.excity.Antarctica/DumontDUrville", "Dumont d\u2019Urville" },
             { "timezone.excity.America/North_Dakota/Beulah", "Beulah [Dakota du Nord]" },
             { "timezone.excity.America/North_Dakota/Center", "Center [Dakota du Nord]" },
             { "timezone.excity.America/North_Dakota/New_Salem", "New Salem, Dakota du Nord" },
