@@ -68,11 +68,11 @@ public class TimeZoneNames_ha extends TimeZoneNamesBundle {
     protected final Object[][] getContents() {
         final String[] GMT = new String[] {
                "Lokacin Greenwhich a London",
+               "GMT",
                "",
+               "GMT",
                "",
-               "",
-               "",
-               "",
+               "GMT",
             };
         final String[] Apia = new String[] {
                "Tsayayyen Lokacin Apia",
@@ -92,11 +92,11 @@ public class TimeZoneNames_ha extends TimeZoneNamesBundle {
             };
         final String[] Cuba = new String[] {
                "Tsayayyen Lokacin Kuba",
-               "",
+               "CST",
                "Lokacin Rana na Kuba",
-               "",
+               "CDT",
                "Lokaci na Kuba",
-               "",
+               "CT",
             };
         final String[] Fiji = new String[] {
                "Tsayayyen Lokacin Fiji",
@@ -180,11 +180,11 @@ public class TimeZoneNames_ha extends TimeZoneNamesBundle {
             };
         final String[] China = new String[] {
                "Tsayayyen Lokacin Sin",
-               "",
+               "CST",
                "Lokacin Rana na Sin",
-               "",
+               "CDT",
                "Lokacin Sin",
-               "",
+               "CT",
             };
         final String[] Cocos = new String[] {
                "Lokacin Cocos Islands",
@@ -212,19 +212,19 @@ public class TimeZoneNames_ha extends TimeZoneNamesBundle {
             };
         final String[] Japan = new String[] {
                "Japan Standard Time",
-               "",
+               "JST",
                "Japan Daylight Time",
-               "",
+               "JDT",
                "Lokacin Japan",
-               "",
+               "JT",
             };
         final String[] Korea = new String[] {
                "Tsayayyen Lokacin Koriya",
-               "",
+               "KST",
                "Lokacin Rana na Koriya",
-               "",
+               "KST",
                "Lokacin Koriya",
-               "",
+               "KST",
             };
         final String[] Nauru = new String[] {
                "Lokacin Nauru",
@@ -252,11 +252,11 @@ public class TimeZoneNames_ha extends TimeZoneNamesBundle {
             };
         final String[] Samoa = new String[] {
                "Tsayayyen Lokacin Samoa",
-               "",
+               "SST",
                "Lokacin Rana na Vote Samoa",
-               "",
+               "SST",
                "Lokacin Samoa",
-               "",
+               "SST",
             };
         final String[] Syowa = new String[] {
                "Lokacin Syowa",
@@ -276,11 +276,11 @@ public class TimeZoneNames_ha extends TimeZoneNamesBundle {
             };
         final String[] Yukon = new String[] {
                "Lokacin Yukon",
+               "MST",
                "",
+               "MST",
                "",
-               "",
-               "",
-               "",
+               "MST",
             };
         final String[] Alaska = new String[] {
                "Tsayayyen Lokacin Alaska",
@@ -300,11 +300,11 @@ public class TimeZoneNames_ha extends TimeZoneNamesBundle {
             };
         final String[] Azores = new String[] {
                "Lokacin Azores Daidaitacce",
-               "",
+               "HMT",
                "Lokacin Azure na Bazara",
-               "",
+               "HMT",
                "Lokacin Azores",
-               "",
+               "HMT",
             };
         final String[] Bhutan = new String[] {
                "Bhutan Time",
@@ -340,11 +340,11 @@ public class TimeZoneNames_ha extends TimeZoneNamesBundle {
             };
         final String[] Israel = new String[] {
                "Israel Standard Time",
-               "",
+               "IST",
                "Israel Daylight Time",
-               "",
+               "IDT",
                "Lokacin Isra\u02bcila",
-               "",
+               "IT",
             };
         final String[] Kosrae = new String[] {
                "Lokacin Kosrae",
@@ -364,11 +364,11 @@ public class TimeZoneNames_ha extends TimeZoneNamesBundle {
             };
         final String[] Moscow = new String[] {
                "Tsayayyen Lokacin Moscow",
-               "",
+               "MSK",
                "Lokacin Bazara na Moscow",
-               "",
+               "MSK",
                "Lokacin Moscow",
-               "",
+               "MSK",
             };
         final String[] Ponape = new String[] {
                "Lokacin Ponape",
@@ -388,11 +388,11 @@ public class TimeZoneNames_ha extends TimeZoneNamesBundle {
             };
         final String[] Taipei = new String[] {
                "Tsayayyen Lokacin Taipei",
-               "",
+               "CST",
                "Lokacin Rana na Taipei",
-               "",
+               "CDT",
                "Lokacin Taipei",
-               "",
+               "CT",
             };
         final String[] Tuvalu = new String[] {
                "Lokacin Tuvalu",
@@ -580,11 +580,11 @@ public class TimeZoneNames_ha extends TimeZoneNamesBundle {
             };
         final String[] Atlantic = new String[] {
                "Tsayayyen Lokacin Kanada, Puerto Rico da Virgin Islands",
-               "",
+               "AST",
                "Lokacin Rana na Kanada, Puerto Rico da Virgin Islands",
-               "",
+               "ADT",
                "Lokacin Kanada, Puerto Rico da Virgin Islands",
-               "",
+               "AT",
             };
         final String[] Brasilia = new String[] {
                "Tsayayyen Lokacin Brasillia",
@@ -596,11 +596,11 @@ public class TimeZoneNames_ha extends TimeZoneNamesBundle {
             };
         final String[] Chamorro = new String[] {
                "Tsayayyen Lokacin Chamorro",
+               "ChST",
                "",
+               "ChST",
                "",
-               "",
-               "",
-               "",
+               "ChST",
             };
         final String[] Colombia = new String[] {
                "Tsayayyen Lokacin Colombia",
@@ -644,11 +644,11 @@ public class TimeZoneNames_ha extends TimeZoneNamesBundle {
             };
         final String[] Pakistan = new String[] {
                "Tsayayyen Lokacin Pakistan",
-               "",
+               "PKT",
                "Lokacin Bazara na Pakistan",
-               "",
+               "PKST",
                "Lokacin Pakistan",
-               "",
+               "PKT",
             };
         final String[] Paraguay = new String[] {
                "Tsayayyen Lokacin Paraguay",
@@ -708,11 +708,11 @@ public class TimeZoneNames_ha extends TimeZoneNamesBundle {
             };
         final String[] Hong_Kong = new String[] {
                "Tsayayyen Lokacin Hong Kong",
-               "",
+               "HKT",
                "Lokacin Bazara na Hong Kong",
-               "",
+               "HKST",
                "Lokacin Hong Kong",
-               "",
+               "HKT",
             };
         final String[] Indochina = new String[] {
                "Lokacin Indochina",
@@ -772,11 +772,11 @@ public class TimeZoneNames_ha extends TimeZoneNamesBundle {
             };
         final String[] Volgograd = new String[] {
                "Tsayayyen Lokacin Volgograd",
-               "",
+               "MSK",
                "Lokacin Bazara na Volgograd",
-               "",
+               "MSK",
                "Lokacin Volgograd",
-               "",
+               "MSK",
             };
         final String[] Azerbaijan = new String[] {
                "Tsayayyen Lokacin Azerbaijan",
@@ -852,11 +852,11 @@ public class TimeZoneNames_ha extends TimeZoneNamesBundle {
             };
         final String[] New_Zealand = new String[] {
                "Tsayayyen Lokacin New Zealand",
-               "",
+               "NZST",
                "Lokacin Rana na New Zealand",
-               "",
+               "NZDT",
                "Lokacin New Zealand",
-               "",
+               "NZT",
             };
         final String[] Novosibirsk = new String[] {
                "Novosibirsk Standard Time",
@@ -868,11 +868,11 @@ public class TimeZoneNames_ha extends TimeZoneNamesBundle {
             };
         final String[] Philippines = new String[] {
                "Tsayayyen Lokacin Philippine",
-               "",
+               "PST",
                "Lokacin Bazara na Philippine",
-               "",
+               "PDT",
                "Lokacin Philippine",
-               "",
+               "PT",
             };
         final String[] Vladivostok = new String[] {
                "Tsayayyen Lokacin Vladivostok",
@@ -900,11 +900,11 @@ public class TimeZoneNames_ha extends TimeZoneNamesBundle {
             };
         final String[] Newfoundland = new String[] {
                "Lokaci Tsayayye ta Newfoundland",
-               "",
+               "NST",
                "Lokaci rana ta Newfoundland",
-               "",
+               "NDT",
                "Lokacin Newfoundland",
-               "",
+               "NT",
             };
         final String[] Turkmenistan = new String[] {
                "Tsayayyen Lokacin Turkmenistan",
@@ -948,27 +948,27 @@ public class TimeZoneNames_ha extends TimeZoneNamesBundle {
             };
         final String[] Africa_Central = new String[] {
                "Lokacin Afirka ta Tsakiya",
+               "SAST",
                "",
+               "SAST",
                "",
-               "",
-               "",
-               "",
+               "SAST",
             };
         final String[] Africa_Eastern = new String[] {
                "Lokacin Gabashin Afirka",
+               "EAT",
                "",
+               "EAT",
                "",
-               "",
-               "",
-               "",
+               "EAT",
             };
         final String[] Africa_Western = new String[] {
                "Tsayayyen Lokacin Afirka ta Yamma",
-               "",
+               "WAT",
                "Lokacin Bazara na Afirka ta Yamma",
-               "",
+               "WAT",
                "Lokacin Afirka ta Yamma",
-               "",
+               "WAT",
             };
         final String[] DumontDUrville = new String[] {
                "Lokacin Dumont-d\u2019Urville",
@@ -980,67 +980,67 @@ public class TimeZoneNames_ha extends TimeZoneNamesBundle {
             };
         final String[] Europe_Central = new String[] {
                "Ida Tsakiyar a Lokaci Turai",
-               "",
+               "CET",
                "Tsakiyar bazara a lokaci turai",
-               "",
+               "CEST",
                "Tsakiyar a lokaci turai",
-               "",
+               "CET",
             };
         final String[] Europe_Eastern = new String[] {
                "Ida lokaci a turai gabas",
-               "",
+               "EET",
                "Gabas a lokaci turai da bazara",
-               "",
+               "EEST",
                "Lokaci a turai gabas",
-               "",
+               "EET",
             };
         final String[] Europe_Western = new String[] {
                "Ida lokaci ta yammacin turai",
-               "",
+               "FMT",
                "Ida lokaci ta yammacin turai da bazara",
-               "",
+               "FMT",
                "Lokaci ta yammacin turai",
-               "",
+               "FMT",
             };
         final String[] Mexico_Pacific = new String[] {
                "Tsayayyen Lokacin Mekziko Pacific",
-               "",
+               "MST",
                "Lokacin Rana na Mekziko Pacific",
-               "",
+               "MDT",
                "Lokacin Mekziko Pacific",
-               "",
+               "MT",
             };
         final String[] Africa_Southern = new String[] {
                "South Africa Standard Time",
+               "SAST",
                "",
+               "SAST",
                "",
-               "",
-               "",
-               "",
+               "SAST",
             };
         final String[] America_Central = new String[] {
                "Tsayayyen Lokaci dake Arewacin Amurika ta Tsakiya",
-               "",
+               "CST",
                "Lokacin Rana dake Arewacin Amurika ta Tsakiya",
-               "",
+               "CDT",
                "Lokaci dake Amurika arewa ta tsakiyar",
-               "",
+               "CT",
             };
         final String[] America_Eastern = new String[] {
                "Tsayayyen Lokacin Gabas dake Arewacin Amurika",
-               "",
+               "EST",
                "Lokacin Rana ta Gabas dake Arewacin Amurika",
-               "",
+               "EST",
                "Lokacin Gabas dake Arewacin Amurikaa",
-               "",
+               "EST",
             };
         final String[] America_Pacific = new String[] {
                "Lokaci Tsayayye na Arewacin Amurika",
-               "",
+               "PST",
                "Lokacin Rana na Arewacin Amurka",
-               "",
+               "PDT",
                "Lokacin Arewacin Amurika",
-               "",
+               "PT",
             };
         final String[] French_Southern = new String[] {
                "Lokacin Kudancin Faransa da Antarctic",
@@ -1060,11 +1060,11 @@ public class TimeZoneNames_ha extends TimeZoneNamesBundle {
             };
         final String[] Hawaii_Aleutian = new String[] {
                "Tsayayyen Lokacin Hawaii-Aleutian",
-               "",
+               "HST",
                "Lokacin Rana na Hawaii-Aleutian",
-               "",
+               "HST",
                "Lokaci na Hawaii-Aleutian",
-               "",
+               "HST",
             };
         final String[] Phoenix_Islands = new String[] {
                "Lokacin Phoenix Islands",
@@ -1084,11 +1084,11 @@ public class TimeZoneNames_ha extends TimeZoneNamesBundle {
             };
         final String[] America_Mountain = new String[] {
                "Lokaci tsayayye na tsauni a Arewacin Amurica",
-               "",
+               "MST",
                "Lokacin Rana na Tsaunin Arewacin Amurka",
-               "",
+               "MDT",
                "Lokacin Tsauni na Arewacin Amurka",
-               "",
+               "MT",
             };
         final String[] Marshall_Islands = new String[] {
                "Lokacin Marshall Islands",
@@ -1116,19 +1116,19 @@ public class TimeZoneNames_ha extends TimeZoneNamesBundle {
             };
         final String[] Australia_Central = new String[] {
                "Tsayayyen Lokacin Tsakiyar Austiraliya",
-               "",
+               "ACST",
                "Lokacin Rana na Tsakiyar Austiraliya",
-               "",
+               "ACDT",
                "Central Australia Time",
-               "",
+               "ACT",
             };
         final String[] Australia_Eastern = new String[] {
                "Australian Eastern Standard Time",
-               "",
+               "AEST",
                "Lokacin Rana na Gabashin Austiraliya",
-               "",
+               "AEDT",
                "Lokacin Gabashin Austiraliya",
-               "",
+               "AET",
             };
         final String[] Australia_Western = new String[] {
                "Tsayayyen Lokacin Yammacin Austiralia",
@@ -1156,27 +1156,27 @@ public class TimeZoneNames_ha extends TimeZoneNamesBundle {
             };
         final String[] Indonesia_Central = new String[] {
                "Lokacin Indonesia ta Tsakiya",
+               "WITA",
                "",
+               "WITA",
                "",
-               "",
-               "",
-               "",
+               "WITA",
             };
         final String[] Indonesia_Eastern = new String[] {
                "Eastern Indonesia Time",
+               "WIT",
                "",
+               "WIT",
                "",
-               "",
-               "",
-               "",
+               "WIT",
             };
         final String[] Indonesia_Western = new String[] {
                "Lokacin Yammacin Indonesia",
+               "WIB",
                "",
+               "WIB",
                "",
-               "",
-               "",
-               "",
+               "WIB",
             };
         final String[] Kazakhstan_Eastern = new String[] {
                "Lokacin Gabashin Kazakhstan",
@@ -1363,11 +1363,11 @@ public class TimeZoneNames_ha extends TimeZoneNamesBundle {
             { "Europe/Dublin",
                 new String[] {
                     "Lokacin Greenwhich a London",
-                    "",
+                    "GMT",
                     "Tsayayyen Lokacin Irish",
+                    "IST",
                     "",
-                    "",
-                    "",
+                    "GMT",
                 }
             },
             { "Europe/Jersey", GMT },
@@ -1375,11 +1375,11 @@ public class TimeZoneNames_ha extends TimeZoneNamesBundle {
             { "Europe/London",
                 new String[] {
                     "Lokacin Greenwhich a London",
-                    "",
+                    "GMT",
                     "Lokacin Bazara na Birtaniya",
+                    "BST",
                     "",
-                    "",
-                    "",
+                    "GMT",
                 }
             },
             { "Europe/Madrid", Europe_Central },
@@ -1435,11 +1435,11 @@ public class TimeZoneNames_ha extends TimeZoneNamesBundle {
             { "Europe/Belfast",
                 new String[] {
                     "Lokacin Greenwhich a London",
-                    "",
+                    "GMT",
                     "Lokacin Bazara na Birtaniya",
+                    "BST",
                     "",
-                    "",
-                    "",
+                    "GMT",
                 }
             },
             { "Europe/Tallinn", Europe_Eastern },
@@ -1677,21 +1677,14 @@ public class TimeZoneNames_ha extends TimeZoneNamesBundle {
             { "America/Indiana/Tell_City", America_Central },
             { "America/Indiana/Vincennes", America_Eastern },
             { "Antarctica/DumontDUrville", DumontDUrville },
-            { "timezone.excity.Asia/Aden", "Aden" },
-            { "timezone.excity.Asia/Baku", "Baku" },
             { "America/Argentina/La_Rioja", Argentina },
             { "America/Argentina/San_Juan", Argentina },
             { "America/Argentina/San_Luis", Argentina },
             { "America/Indiana/Petersburg", America_Eastern },
-            { "timezone.excity.Asia/Amman", "Amman" },
             { "America/Kentucky/Monticello", America_Eastern },
             { "America/North_Dakota/Beulah", America_Central },
             { "America/North_Dakota/Center", America_Central },
-            { "timezone.excity.Asia/Beirut", "Beirut" },
             { "timezone.excity.Etc/Unknown", "Birni da ba a sani ba" },
-            { "timezone.excity.Asia/Baghdad", "Baghdad" },
-            { "timezone.excity.Asia/Bahrain", "Bahrain" },
-            { "timezone.excity.Asia/Bangkok", "Bangkok" },
             { "America/Argentina/Rio_Gallegos", Argentina },
             { "America/North_Dakota/New_Salem", America_Central },
             { "timezone.excity.America/North_Dakota/Beulah", "Beulah, Arewacin Dakota" },
