@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2022, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -68,11 +68,11 @@ public class TimeZoneNames_ig extends TimeZoneNamesBundle {
     protected final Object[][] getContents() {
         final String[] GMT = new String[] {
                "Oge Mpaghara Greemwich Mean",
+               "GMT",
                "",
+               "GMT",
                "",
-               "",
-               "",
-               "",
+               "GMT",
             };
         final String[] Apia = new String[] {
                "Oge Izugbe Apia",
@@ -92,11 +92,11 @@ public class TimeZoneNames_ig extends TimeZoneNamesBundle {
             };
         final String[] Cuba = new String[] {
                "Oge Izugbe Cuba",
-               "",
+               "CST",
                "Oge Ihe Mpaghara Cuba",
-               "",
+               "CDT",
                "Oge Cuba",
-               "",
+               "CT",
             };
         final String[] Fiji = new String[] {
                "Oge Izugbe Fiji",
@@ -180,11 +180,11 @@ public class TimeZoneNames_ig extends TimeZoneNamesBundle {
             };
         final String[] China = new String[] {
                "Oge Izugbe China",
-               "",
+               "CST",
                "Oge Ihe China",
-               "",
+               "CDT",
                "Oge China",
-               "",
+               "CT",
             };
         final String[] Cocos = new String[] {
                "Oge Cocos Islands",
@@ -212,19 +212,19 @@ public class TimeZoneNames_ig extends TimeZoneNamesBundle {
             };
         final String[] Japan = new String[] {
                "Oge Izugbe Japan",
-               "",
+               "JST",
                "Oge Ihe Japan",
-               "",
+               "JDT",
                "Oge Japan",
-               "",
+               "JT",
             };
         final String[] Korea = new String[] {
                "Oge Izugbe Korea",
-               "",
+               "KST",
                "Oge Ihe Korea",
-               "",
+               "KST",
                "Oge Korea",
-               "",
+               "KST",
             };
         final String[] Nauru = new String[] {
                "Oge Nauru",
@@ -252,11 +252,11 @@ public class TimeZoneNames_ig extends TimeZoneNamesBundle {
             };
         final String[] Samoa = new String[] {
                "Oge Izugbe Samoa",
-               "",
+               "SST",
                "Oge Ihe Samoa",
-               "",
+               "SST",
                "Oge Samoa",
-               "",
+               "SST",
             };
         final String[] Syowa = new String[] {
                "Oge Syowa",
@@ -276,11 +276,11 @@ public class TimeZoneNames_ig extends TimeZoneNamesBundle {
             };
         final String[] Yukon = new String[] {
                "Oge Yukon",
+               "MST",
                "",
+               "MST",
                "",
-               "",
-               "",
-               "",
+               "MST",
             };
         final String[] Alaska = new String[] {
                "Oge Izugbe Alaska",
@@ -300,11 +300,11 @@ public class TimeZoneNames_ig extends TimeZoneNamesBundle {
             };
         final String[] Azores = new String[] {
                "Oge Izugbe Azores",
-               "",
+               "HMT",
                "Oge Okpom\u1ecdk\u1ee5 Azores",
-               "",
+               "HMT",
                "Oge Azores",
-               "",
+               "HMT",
             };
         final String[] Bhutan = new String[] {
                "Oge Bhutan",
@@ -340,11 +340,11 @@ public class TimeZoneNames_ig extends TimeZoneNamesBundle {
             };
         final String[] Israel = new String[] {
                "Oge Izugbe Israel",
-               "",
+               "IST",
                "Oge Ihe Israel",
-               "",
+               "IDT",
                "Oge Israel",
-               "",
+               "IT",
             };
         final String[] Kosrae = new String[] {
                "Oge Kosrae",
@@ -364,11 +364,11 @@ public class TimeZoneNames_ig extends TimeZoneNamesBundle {
             };
         final String[] Moscow = new String[] {
                "Oge Izugbe Moscow",
-               "",
+               "MSK",
                "Oge Okpom\u1ecdk\u1ee5 Moscow",
-               "",
+               "MSK",
                "Oge Moscow",
-               "",
+               "MSK",
             };
         final String[] Ponape = new String[] {
                "Oge Ponape",
@@ -388,11 +388,11 @@ public class TimeZoneNames_ig extends TimeZoneNamesBundle {
             };
         final String[] Taipei = new String[] {
                "Oge Izugbe Taipei",
-               "",
+               "CST",
                "Oge Ihe Taipei",
-               "",
+               "CDT",
                "Oge Taipei",
-               "",
+               "CT",
             };
         final String[] Tuvalu = new String[] {
                "Oge Tuvalu",
@@ -580,11 +580,11 @@ public class TimeZoneNames_ig extends TimeZoneNamesBundle {
             };
         final String[] Atlantic = new String[] {
                "Oge Izugbe Mpaghara Atlantic",
-               "",
+               "AST",
                "Oge Ihe Mpaghara Atlantic",
-               "",
+               "ADT",
                "Oge Mpaghara Atlantic",
-               "",
+               "AT",
             };
         final String[] Brasilia = new String[] {
                "Oge Izugbe Brasilia",
@@ -596,11 +596,11 @@ public class TimeZoneNames_ig extends TimeZoneNamesBundle {
             };
         final String[] Chamorro = new String[] {
                "Oge Izugbe Chamorro",
+               "ChST",
                "",
+               "ChST",
                "",
-               "",
-               "",
-               "",
+               "ChST",
             };
         final String[] Colombia = new String[] {
                "Oge Izugbe Columbia",
@@ -644,11 +644,11 @@ public class TimeZoneNames_ig extends TimeZoneNamesBundle {
             };
         final String[] Pakistan = new String[] {
                "Oge Izugbe Pakistan",
-               "",
+               "PKT",
                "Oge Okpom\u1ecdk\u1ee5 Pakistan",
-               "",
+               "PKST",
                "Oge Pakistan",
-               "",
+               "PKT",
             };
         final String[] Paraguay = new String[] {
                "Oge Izugbe Paraguay",
@@ -708,11 +708,11 @@ public class TimeZoneNames_ig extends TimeZoneNamesBundle {
             };
         final String[] Hong_Kong = new String[] {
                "Oge Izugbe Hong Kong",
-               "",
+               "HKT",
                "Oge Okpom\u1ecdk\u1ee5 Hong Kong",
-               "",
+               "HKST",
                "Oge Hong Kong",
-               "",
+               "HKT",
             };
         final String[] Indochina = new String[] {
                "Oge Indochina",
@@ -772,11 +772,11 @@ public class TimeZoneNames_ig extends TimeZoneNamesBundle {
             };
         final String[] Volgograd = new String[] {
                "Oge Izugbe Volgograd",
-               "",
+               "MSK",
                "Oge Okpom\u1ecdk\u1ee5 Volgograd",
-               "",
+               "MSK",
                "Oge Volgograd",
-               "",
+               "MSK",
             };
         final String[] Azerbaijan = new String[] {
                "Oge Izugbe Azerbaijan",
@@ -852,11 +852,11 @@ public class TimeZoneNames_ig extends TimeZoneNamesBundle {
             };
         final String[] New_Zealand = new String[] {
                "Oge Izugbe New Zealand",
-               "",
+               "NZST",
                "Oge Ihe New Zealand",
-               "",
+               "NZDT",
                "Oge New Zealand",
-               "",
+               "NZT",
             };
         final String[] Novosibirsk = new String[] {
                "Oge Izugbe Novosibirsk",
@@ -868,11 +868,11 @@ public class TimeZoneNames_ig extends TimeZoneNamesBundle {
             };
         final String[] Philippines = new String[] {
                "Oge Izugbe Philippine",
-               "",
+               "PST",
                "Oge Okpom\u1ecdk\u1ee5 Philippine",
-               "",
+               "PDT",
                "Oge Philippine",
-               "",
+               "PT",
             };
         final String[] Vladivostok = new String[] {
                "Oge Izugbe Vladivostok",
@@ -900,11 +900,11 @@ public class TimeZoneNames_ig extends TimeZoneNamesBundle {
             };
         final String[] Newfoundland = new String[] {
                "Oge Izugbe Newfoundland",
-               "",
+               "NST",
                "Oge Ihe Newfoundland",
-               "",
+               "NDT",
                "Oge Newfoundland",
-               "",
+               "NT",
             };
         final String[] Turkmenistan = new String[] {
                "Oge Izugbe Turkmenist",
@@ -948,27 +948,27 @@ public class TimeZoneNames_ig extends TimeZoneNamesBundle {
             };
         final String[] Africa_Central = new String[] {
                "Oge Etiti Afr\u1ecbka",
+               "SAST",
                "",
+               "SAST",
                "",
-               "",
-               "",
-               "",
+               "SAST",
             };
         final String[] Africa_Eastern = new String[] {
                "Oge Mpaghara \u1eccw\u1ee5wa Anyanw\u1ee5 Afr\u1ecbka",
+               "EAT",
                "",
+               "EAT",
                "",
-               "",
-               "",
-               "",
+               "EAT",
             };
         final String[] Africa_Western = new String[] {
                "Oge Izugbe Mpaghara \u1eccd\u1ecbda Anyanw\u1ee5 Afr\u1ecbka",
-               "",
+               "WAT",
                "Oge Okpom\u1ecdk\u1ee5 Mpaghara \u1eccd\u1ecbda Anyanw\u1ee5 Afr\u1ecbka",
-               "",
+               "WAT",
                "Oge Mpaghara \u1eccd\u1ecbda Anyanw\u1ee5 Afr\u1ecbka",
-               "",
+               "WAT",
             };
         final String[] DumontDUrville = new String[] {
                "Oge Dumont-d\u2019Urville",
@@ -980,67 +980,67 @@ public class TimeZoneNames_ig extends TimeZoneNamesBundle {
             };
         final String[] Europe_Central = new String[] {
                "Oge Izugbe Mpaghara Etiti Europe",
-               "",
+               "CET",
                "Oge Okpom\u1ecdk\u1ee5 Mpaghara Etiti Europe",
-               "",
+               "CEST",
                "Oge Mpaghara Etiti Europe",
-               "",
+               "CET",
             };
         final String[] Europe_Eastern = new String[] {
                "Oge Izugbe Mpaghara \u1eccw\u1ee5wa Anyanw\u1ee5 Europe",
-               "",
+               "EET",
                "Oge Okpom\u1ecdk\u1ee5 Mpaghara \u1eccw\u1ee5wa Anyanw\u1ee5 Europe",
-               "",
+               "EEST",
                "Oge Mpaghara \u1eccw\u1ee5wa Anyanw\u1ee5 Europe",
-               "",
+               "EET",
             };
         final String[] Europe_Western = new String[] {
                "Oge Izugbe Mpaghara \u1eccd\u1ecbda Anyanw\u1ee5 Europe",
-               "",
+               "FMT",
                "Oge Okpom\u1ecdk\u1ee5 Mpaghara \u1eccd\u1ecbda Anyanw\u1ee5 Europe",
-               "",
+               "FMT",
                "Oge Mpaghara \u1eccd\u1ecbda Anyanw\u1ee5 Europe",
-               "",
+               "FMT",
             };
         final String[] Mexico_Pacific = new String[] {
                "Oge Izugbe Mexican Pacific",
-               "",
+               "MST",
                "Oge Ihe Mexican Pacific",
-               "",
+               "MDT",
                "Oge Mexican Pacific",
-               "",
+               "MT",
             };
         final String[] Africa_Southern = new String[] {
                "Oge Izugbe Mpaghara Mgbada Ugwu Afr\u1ecbka",
+               "SAST",
                "",
+               "SAST",
                "",
-               "",
-               "",
-               "",
+               "SAST",
             };
         final String[] America_Central = new String[] {
                "Oge Izugbe Mpaghara Etiti",
-               "",
+               "CST",
                "Oge Ihe Mpaghara Etiti",
-               "",
+               "CDT",
                "Oge Mpaghara Etiti",
-               "",
+               "CT",
             };
         final String[] America_Eastern = new String[] {
                "Oge Izugbe Mpaghara \u1eccw\u1ee5wa Anyanw\u1ee5",
-               "",
+               "EST",
                "Oge Ihe Mpaghara \u1eccw\u1ee5wa Anyanw\u1ee5",
-               "",
+               "EST",
                "Oge Mpaghara \u1eccw\u1ee5wa Anyanw\u1ee5",
-               "",
+               "EST",
             };
         final String[] America_Pacific = new String[] {
                "Oge Izugbe Mpaghara Pacific",
-               "",
+               "PST",
                "Oge Ihe Mpaghara Pacific",
-               "",
+               "PDT",
                "Oge Mpaghara Pacific",
-               "",
+               "PT",
             };
         final String[] French_Southern = new String[] {
                "Oge French Southern & Antarctic",
@@ -1060,11 +1060,11 @@ public class TimeZoneNames_ig extends TimeZoneNamesBundle {
             };
         final String[] Hawaii_Aleutian = new String[] {
                "Oge Izugbe Hawaii-Aleutian",
-               "",
+               "HST",
                "Oge Ihe Hawaii-Aleutian",
-               "",
+               "HST",
                "Oge Hawaii-Aleutian",
-               "",
+               "HST",
             };
         final String[] Phoenix_Islands = new String[] {
                "Oge Phoenix Islands",
@@ -1084,11 +1084,11 @@ public class TimeZoneNames_ig extends TimeZoneNamesBundle {
             };
         final String[] America_Mountain = new String[] {
                "Oge Izugbe Mpaghara Ugwu",
-               "",
+               "MST",
                "Oge Ihe Mpaghara Ugwu",
-               "",
+               "MDT",
                "Oge Mpaghara Ugwu",
-               "",
+               "MT",
             };
         final String[] Marshall_Islands = new String[] {
                "Oge Marshall Islands",
@@ -1116,19 +1116,19 @@ public class TimeZoneNames_ig extends TimeZoneNamesBundle {
             };
         final String[] Australia_Central = new String[] {
                "Oge Izugbe Etiti Australia",
-               "",
+               "ACST",
                "Oge Ihe Etiti Australia",
-               "",
+               "ACDT",
                "Oge Etiti Australia",
-               "",
+               "ACT",
             };
         final String[] Australia_Eastern = new String[] {
                "Oge Izugbe Mpaghara \u1eccw\u1ee5wa Anyanw\u1ee5 Australia",
-               "",
+               "AEST",
                "Oge Ihe Mpaghara \u1eccw\u1ee5wa Anyanw\u1ee5 Australia",
-               "",
+               "AEDT",
                "Oge Mpaghara \u1eccw\u1ee5wa Anyanw\u1ee5 Australia",
-               "",
+               "AET",
             };
         final String[] Australia_Western = new String[] {
                "Oge Izugbe Mpaghara \u1eccd\u1ecbda Anyanw\u1ee5 Australia",
@@ -1156,27 +1156,27 @@ public class TimeZoneNames_ig extends TimeZoneNamesBundle {
             };
         final String[] Indonesia_Central = new String[] {
                "Oge Etiti Indonesia",
+               "WITA",
                "",
+               "WITA",
                "",
-               "",
-               "",
-               "",
+               "WITA",
             };
         final String[] Indonesia_Eastern = new String[] {
                "Oge Mpaghara \u1eccw\u1ee5wa Anyanw\u1ee5 Indonesia",
+               "WIT",
                "",
+               "WIT",
                "",
-               "",
-               "",
-               "",
+               "WIT",
             };
         final String[] Indonesia_Western = new String[] {
                "Oge Mpaghara \u1eccd\u1ecbda Anyanw\u1ee5 Indonesia",
+               "WIB",
                "",
+               "WIB",
                "",
-               "",
-               "",
-               "",
+               "WIB",
             };
         final String[] Kazakhstan_Eastern = new String[] {
                "Oge Mpaghara \u1eccw\u1ee5wa Anyanw\u1ee5 Kazakhstan",
@@ -1255,7 +1255,6 @@ public class TimeZoneNames_ig extends TimeZoneNamesBundle {
             { "Asia/Hovd", Hovd },
             { "Asia/Omsk", Omsk },
             { "Asia/Oral", Kazakhstan_Western },
-            { "Asia/Amman", Europe_Eastern },
             { "Asia/Aqtau", Kazakhstan_Western },
             { "Asia/Chita", Yakutsk },
             { "Asia/Dhaka", Bangladesh },
@@ -1350,7 +1349,6 @@ public class TimeZoneNames_ig extends TimeZoneNamesBundle {
             { "America/Thule", Atlantic },
             { "Asia/Ashgabat", Turkmenistan },
             { "Asia/Calcutta", India },
-            { "Asia/Damascus", Europe_Eastern },
             { "Asia/Dushanbe", Tajikistan },
             { "Asia/Jayapura", Indonesia_Eastern },
             { "Asia/Katmandu", Nepal },
@@ -1365,11 +1363,11 @@ public class TimeZoneNames_ig extends TimeZoneNamesBundle {
             { "Europe/Dublin",
                 new String[] {
                     "Oge Mpaghara Greemwich Mean",
-                    "",
+                    "GMT",
                     "Oge Okpom\u1ecdk\u1ee5 Ireland",
+                    "IST",
                     "",
-                    "",
-                    "",
+                    "GMT",
                 }
             },
             { "Europe/Jersey", GMT },
@@ -1377,11 +1375,11 @@ public class TimeZoneNames_ig extends TimeZoneNamesBundle {
             { "Europe/London",
                 new String[] {
                     "Oge Mpaghara Greemwich Mean",
-                    "",
+                    "GMT",
                     "Oge Okpom\u1ecdk\u1ee5 Britain",
+                    "BST",
                     "",
-                    "",
-                    "",
+                    "GMT",
                 }
             },
             { "Europe/Madrid", Europe_Central },
@@ -1437,11 +1435,11 @@ public class TimeZoneNames_ig extends TimeZoneNamesBundle {
             { "Europe/Belfast",
                 new String[] {
                     "Oge Mpaghara Greemwich Mean",
-                    "",
+                    "GMT",
                     "Oge Okpom\u1ecdk\u1ee5 Britain",
+                    "BST",
                     "",
-                    "",
-                    "",
+                    "GMT",
                 }
             },
             { "Europe/Tallinn", Europe_Eastern },
@@ -1487,7 +1485,7 @@ public class TimeZoneNames_ig extends TimeZoneNamesBundle {
             { "America/Moncton", Atlantic },
             { "America/Nipigon", America_Eastern },
             { "America/Noronha", Noronha },
-            { "America/Ojinaga", America_Mountain },
+            { "America/Ojinaga", America_Central },
             { "America/Tijuana", America_Pacific },
             { "America/Toronto", America_Eastern },
             { "America/Tortola", Atlantic },
@@ -1571,7 +1569,7 @@ public class TimeZoneNames_ig extends TimeZoneNamesBundle {
             { "America/Araguaina", Brasilia },
             { "America/Boa_Vista", Amazon },
             { "America/Catamarca", Argentina },
-            { "America/Chihuahua", Mexico_Pacific },
+            { "America/Chihuahua", America_Central },
             { "America/Fortaleza", Brasilia },
             { "America/Glace_Bay", Atlantic },
             { "America/Goose_Bay", Atlantic },
@@ -1658,6 +1656,7 @@ public class TimeZoneNames_ig extends TimeZoneNamesBundle {
             { "Antarctica/Macquarie", Australia_Eastern },
             { "Pacific/Port_Moresby", Papua_New_Guinea },
             { "America/Cambridge_Bay", America_Mountain },
+            { "America/Ciudad_Juarez", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
             { "America/Indiana/Vevay", America_Eastern },
             { "America/Lower_Princes", Atlantic },
@@ -1688,7 +1687,6 @@ public class TimeZoneNames_ig extends TimeZoneNamesBundle {
             { "timezone.excity.Etc/Unknown", "Obodo Amagh\u1ecb" },
             { "America/Argentina/Rio_Gallegos", Argentina },
             { "America/North_Dakota/New_Salem", America_Central },
-            { "timezone.excity.America/Araguaina", "Araguaina" },
         };
         return data;
     }
