@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2023, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -68,19 +68,19 @@ public class TimeZoneNames_ksh extends TimeZoneNamesBundle {
     protected final Object[][] getContents() {
         final String[] GMT = new String[] {
                "Greenwich sing Standat-Zick",
+               "GMT",
                "",
+               "GMT",
                "",
-               "",
-               "",
-               "",
+               "GMT",
             };
         final String[] Azores = new String[] {
                "de Azore ier jew\u00f6hnlijje Zick",
-               "",
+               "HMT",
                "de Azore ier Summerzick",
-               "",
+               "HMT",
                "de Azore ier Zick",
-               "",
+               "HMT",
             };
         final String[] Reunion = new String[] {
                "Zigg vun Reunion",
@@ -132,27 +132,27 @@ public class TimeZoneNames_ksh extends TimeZoneNamesBundle {
             };
         final String[] Africa_Central = new String[] {
                "Zentraal-Affrekaanesche Zigg",
+               "SAST",
                "",
+               "SAST",
                "",
-               "",
-               "",
-               "",
+               "SAST",
             };
         final String[] Africa_Eastern = new String[] {
                "O\u00df-Affrekaanesche Zigg",
+               "EAT",
                "",
+               "EAT",
                "",
-               "",
-               "",
-               "",
+               "EAT",
             };
         final String[] Africa_Western = new String[] {
                "Jew\u00f6hnlijje W\u00e4\u00df-Affrekaanesche Zigg",
-               "",
+               "WAT",
                "W\u00e4\u00df-Affrekaanesche Sommerzigg",
-               "",
+               "WAT",
                "W\u00e4\u00df-Affrekaanesche Zigg",
-               "",
+               "WAT",
             };
         final String[] Europe_Central = new String[] {
                "Meddel-Europpa sing jew\u00f6hnlijje Zick",
@@ -180,11 +180,11 @@ public class TimeZoneNames_ksh extends TimeZoneNamesBundle {
             };
         final String[] Africa_Southern = new String[] {
                "S\u00f6d-Affrekaanesche Zigg",
+               "SAST",
                "",
+               "SAST",
                "",
-               "",
-               "",
-               "",
+               "SAST",
             };
         final Object[][] data = new Object[][] {
             { "Europe/Paris", Europe_Central },
@@ -197,7 +197,6 @@ public class TimeZoneNames_ksh extends TimeZoneNamesBundle {
             { "ECT", Europe_Central },
             { "Etc/GMT", GMT },
             { "Asia/Gaza", Europe_Eastern },
-            { "Asia/Amman", Europe_Eastern },
             { "Africa/Juba", Africa_Central },
             { "Africa/Lome", GMT },
             { "Asia/Beirut", Europe_Eastern },
@@ -231,17 +230,16 @@ public class TimeZoneNames_ksh extends TimeZoneNamesBundle {
             { "Africa/Maputo", Africa_Central },
             { "Africa/Maseru", Africa_Southern },
             { "Africa/Niamey", Africa_Western },
-            { "Asia/Damascus", Europe_Eastern },
             { "Europe/Athens", Europe_Eastern },
             { "Europe/Berlin", Europe_Central },
             { "Europe/Dublin",
                 new String[] {
                     "Greenwich sing Standat-Zick",
-                    "",
+                    "GMT",
                     "Irland sing Summerzick",
+                    "IST",
                     "",
-                    "",
-                    "",
+                    "GMT",
                 }
             },
             { "Europe/Jersey", GMT },
@@ -249,11 +247,11 @@ public class TimeZoneNames_ksh extends TimeZoneNamesBundle {
             { "Europe/London",
                 new String[] {
                     "Greenwich sing Standat-Zick",
-                    "",
+                    "GMT",
                     "Jru\u00dfbretannije sing Summerzick",
+                    "BST",
                     "",
-                    "",
-                    "",
+                    "GMT",
                 }
             },
             { "Europe/Madrid", Europe_Central },
@@ -278,11 +276,11 @@ public class TimeZoneNames_ksh extends TimeZoneNamesBundle {
             { "Europe/Belfast",
                 new String[] {
                     "Greenwich sing Standat-Zick",
-                    "",
+                    "GMT",
                     "Jru\u00dfbretannije sing Summerzick",
+                    "BST",
                     "",
-                    "",
-                    "",
+                    "GMT",
                 }
             },
             { "Europe/Tallinn", Europe_Eastern },
