@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,7 +26,7 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
  * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
@@ -68,11 +68,11 @@ public class TimeZoneNames_lb extends TimeZoneNamesBundle {
     protected final Object[][] getContents() {
         final String[] GMT = new String[] {
                "M\u00ebttler Greenwich-Z\u00e4it",
+               "GMT",
                "",
+               "GMT",
                "",
-               "",
-               "",
-               "",
+               "GMT",
             };
         final String[] Acre = new String[] {
                "Acre-Normalz\u00e4it",
@@ -92,11 +92,11 @@ public class TimeZoneNames_lb extends TimeZoneNamesBundle {
             };
         final String[] Cuba = new String[] {
                "Kubanesch Normalz\u00e4it",
-               "",
+               "CST",
                "Kubanesch Summerz\u00e4it",
-               "",
+               "CDT",
                "Kubanesch Z\u00e4it",
-               "",
+               "CT",
             };
         final String[] Fiji = new String[] {
                "Fidschi-Normalz\u00e4it",
@@ -180,11 +180,11 @@ public class TimeZoneNames_lb extends TimeZoneNamesBundle {
             };
         final String[] China = new String[] {
                "Chinesesch Normalz\u00e4it",
-               "",
+               "CST",
                "Chinesesch Summerz\u00e4it",
-               "",
+               "CDT",
                "Chinesesch Z\u00e4it",
-               "",
+               "CT",
             };
         final String[] Cocos = new String[] {
                "Kokosinselen-Z\u00e4it",
@@ -212,19 +212,19 @@ public class TimeZoneNames_lb extends TimeZoneNamesBundle {
             };
         final String[] Japan = new String[] {
                "Japanesch Normalz\u00e4it",
-               "",
+               "JST",
                "Japanesch Summerz\u00e4it",
-               "",
+               "JDT",
                "Japanesch Z\u00e4it",
-               "",
+               "JT",
             };
         final String[] Korea = new String[] {
                "Koreanesch Normalz\u00e4it",
-               "",
+               "KST",
                "Koreanesch Summerz\u00e4it",
-               "",
+               "KST",
                "Koreanesch Z\u00e4it",
-               "",
+               "KST",
             };
         final String[] Nauru = new String[] {
                "Nauru-Z\u00e4it",
@@ -252,11 +252,11 @@ public class TimeZoneNames_lb extends TimeZoneNamesBundle {
             };
         final String[] Samoa = new String[] {
                "Samoa-Normalz\u00e4it",
-               "",
+               "SST",
                "Samoa-Summerz\u00e4it",
-               "",
+               "SST",
                "Samoa-Z\u00e4it",
-               "",
+               "SST",
             };
         final String[] Syowa = new String[] {
                "Syowa-Z\u00e4it",
@@ -300,11 +300,11 @@ public class TimeZoneNames_lb extends TimeZoneNamesBundle {
             };
         final String[] Azores = new String[] {
                "Azoren-Normalz\u00e4it",
-               "",
+               "HMT",
                "Azoren-Summerz\u00e4it",
-               "",
+               "HMT",
                "Azoren-Z\u00e4it",
-               "",
+               "HMT",
             };
         final String[] Bhutan = new String[] {
                "Bhutan-Z\u00e4it",
@@ -340,11 +340,11 @@ public class TimeZoneNames_lb extends TimeZoneNamesBundle {
             };
         final String[] Israel = new String[] {
                "Israelesch Normalz\u00e4it",
-               "",
+               "IST",
                "Israelesch Summerz\u00e4it",
-               "",
+               "IDT",
                "Israelesch Z\u00e4it",
-               "",
+               "IT",
             };
         final String[] Kosrae = new String[] {
                "Kosrae-Z\u00e4it",
@@ -364,11 +364,11 @@ public class TimeZoneNames_lb extends TimeZoneNamesBundle {
             };
         final String[] Moscow = new String[] {
                "Moskauer Normalz\u00e4it",
-               "",
+               "MSK",
                "Moskauer Summerz\u00e4it",
-               "",
+               "MSK",
                "Moskauer Z\u00e4it",
-               "",
+               "MSK",
             };
         final String[] Ponape = new String[] {
                "Ponape-Z\u00e4it",
@@ -396,11 +396,11 @@ public class TimeZoneNames_lb extends TimeZoneNamesBundle {
             };
         final String[] Taipei = new String[] {
                "Taipei-Normalz\u00e4it",
-               "",
+               "CST",
                "Taipei-Summerz\u00e4it",
-               "",
+               "CDT",
                "Taipei-Z\u00e4it",
-               "",
+               "CT",
             };
         final String[] Tuvalu = new String[] {
                "Tuvalu-Z\u00e4it",
@@ -580,11 +580,11 @@ public class TimeZoneNames_lb extends TimeZoneNamesBundle {
             };
         final String[] Atlantic = new String[] {
                "Atlantik-Normalz\u00e4it",
-               "",
+               "AST",
                "Atlantik-Summerz\u00e4it",
-               "",
+               "ADT",
                "Atlantik-Z\u00e4it",
-               "",
+               "AT",
             };
         final String[] Brasilia = new String[] {
                "Bras\u00edlia-Normalz\u00e4it",
@@ -596,11 +596,11 @@ public class TimeZoneNames_lb extends TimeZoneNamesBundle {
             };
         final String[] Chamorro = new String[] {
                "Chamorro-Z\u00e4it",
+               "ChST",
                "",
+               "ChST",
                "",
-               "",
-               "",
-               "",
+               "ChST",
             };
         final String[] Colombia = new String[] {
                "Kolumbianesch Normalz\u00e4it",
@@ -644,11 +644,11 @@ public class TimeZoneNames_lb extends TimeZoneNamesBundle {
             };
         final String[] Pakistan = new String[] {
                "Pakistanesch Normalz\u00e4it",
-               "",
+               "PKT",
                "Pakistanesch Summerz\u00e4it",
-               "",
+               "PKST",
                "Pakistanesch Z\u00e4it",
-               "",
+               "PKT",
             };
         final String[] Paraguay = new String[] {
                "Paraguayanesch Normalz\u00e4it",
@@ -708,11 +708,11 @@ public class TimeZoneNames_lb extends TimeZoneNamesBundle {
             };
         final String[] Hong_Kong = new String[] {
                "Hong-Kong-Normalz\u00e4it",
-               "",
+               "HKT",
                "Hong-Kong-Summerz\u00e4it",
-               "",
+               "HKST",
                "Hong-Kong-Z\u00e4it",
-               "",
+               "HKT",
             };
         final String[] Indochina = new String[] {
                "Indochina-Z\u00e4it",
@@ -780,11 +780,11 @@ public class TimeZoneNames_lb extends TimeZoneNamesBundle {
             };
         final String[] Volgograd = new String[] {
                "Wolgograd-Normalz\u00e4it",
-               "",
+               "MSK",
                "Wolgograd-Summerz\u00e4it",
-               "",
+               "MSK",
                "Wolgograd-Z\u00e4it",
-               "",
+               "MSK",
             };
         final String[] Azerbaijan = new String[] {
                "Aserbeidschanesch Normalz\u00e4it",
@@ -868,11 +868,11 @@ public class TimeZoneNames_lb extends TimeZoneNamesBundle {
             };
         final String[] New_Zealand = new String[] {
                "Neis\u00e9iland-Normalz\u00e4it",
-               "",
+               "NZST",
                "Neis\u00e9iland-Summerz\u00e4it",
-               "",
+               "NZDT",
                "Neis\u00e9iland-Z\u00e4it",
-               "",
+               "NZT",
             };
         final String[] Novosibirsk = new String[] {
                "Nowosibirsk-Normalz\u00e4it",
@@ -884,11 +884,11 @@ public class TimeZoneNames_lb extends TimeZoneNamesBundle {
             };
         final String[] Philippines = new String[] {
                "Philippinnesch Normalz\u00e4it",
-               "",
+               "PST",
                "Philippinnesch Summerz\u00e4it",
-               "",
+               "PDT",
                "Philippinnesch Z\u00e4it",
-               "",
+               "PT",
             };
         final String[] Vladivostok = new String[] {
                "Wladiwostok-Normalz\u00e4it",
@@ -916,11 +916,11 @@ public class TimeZoneNames_lb extends TimeZoneNamesBundle {
             };
         final String[] Newfoundland = new String[] {
                "Neifundland-Normalz\u00e4it",
-               "",
+               "NST",
                "Neifundland-Summerz\u00e4it",
-               "",
+               "NDT",
                "Neifundland-Z\u00e4it",
-               "",
+               "NT",
             };
         final String[] Turkmenistan = new String[] {
                "Turkmenistan-Normalz\u00e4it",
@@ -964,27 +964,27 @@ public class TimeZoneNames_lb extends TimeZoneNamesBundle {
             };
         final String[] Africa_Central = new String[] {
                "Zentralafrikanesch Z\u00e4it",
+               "SAST",
                "",
+               "SAST",
                "",
-               "",
-               "",
-               "",
+               "SAST",
             };
         final String[] Africa_Eastern = new String[] {
                "Ostafrikanesch Z\u00e4it",
+               "EAT",
                "",
+               "EAT",
                "",
-               "",
-               "",
-               "",
+               "EAT",
             };
         final String[] Africa_Western = new String[] {
                "Westafrikanesch Normalz\u00e4it",
-               "",
+               "WAT",
                "Westafrikanesch Summerz\u00e4it",
-               "",
+               "WAT",
                "Westafrikanesch Z\u00e4it",
-               "",
+               "WAT",
             };
         final String[] DumontDUrville = new String[] {
                "Dumont-d\u2019Urville-Z\u00e4it",
@@ -996,67 +996,67 @@ public class TimeZoneNames_lb extends TimeZoneNamesBundle {
             };
         final String[] Europe_Central = new String[] {
                "M\u00ebtteleurop\u00e4esch Normalz\u00e4it",
-               "",
+               "CET",
                "M\u00ebtteleurop\u00e4esch Summerz\u00e4it",
-               "",
+               "CEST",
                "M\u00ebtteleurop\u00e4esch Z\u00e4it",
-               "",
+               "CET",
             };
         final String[] Europe_Eastern = new String[] {
                "Osteurop\u00e4esch Normalz\u00e4it",
-               "",
+               "EET",
                "Osteurop\u00e4esch Summerz\u00e4it",
-               "",
+               "EEST",
                "Osteurop\u00e4esch Z\u00e4it",
-               "",
+               "EET",
             };
         final String[] Europe_Western = new String[] {
                "Westeurop\u00e4esch Normalz\u00e4it",
-               "",
+               "FMT",
                "Westeurop\u00e4esch Summerz\u00e4it",
-               "",
+               "FMT",
                "Westeurop\u00e4esch Z\u00e4it",
-               "",
+               "FMT",
             };
         final String[] Mexico_Pacific = new String[] {
                "Mexikanesch Pazifik-Normalz\u00e4it",
-               "",
+               "MST",
                "Mexikanesch Pazifik-Summerz\u00e4it",
-               "",
+               "MDT",
                "Mexikanesch Pazifikz\u00e4it",
-               "",
+               "MT",
             };
         final String[] Africa_Southern = new String[] {
                "S\u00fcdafrikanesch Z\u00e4it",
+               "SAST",
                "",
+               "SAST",
                "",
-               "",
-               "",
-               "",
+               "SAST",
             };
         final String[] America_Central = new String[] {
                "Nordamerikanesch Inland-Normalz\u00e4it",
-               "",
+               "CST",
                "Nordamerikanesch Inland-Summerz\u00e4it",
-               "",
+               "CDT",
                "Nordamerikanesch Inlandz\u00e4it",
-               "",
+               "CT",
             };
         final String[] America_Eastern = new String[] {
                "Nordamerikanesch Ostk\u00fcsten-Normalz\u00e4it",
-               "",
+               "EST",
                "Nordamerikanesch Ostk\u00fcsten-Summerz\u00e4it",
-               "",
+               "EST",
                "Nordamerikanesch Ostk\u00fcstenz\u00e4it",
-               "",
+               "EST",
             };
         final String[] America_Pacific = new String[] {
                "Nordamerikanesch Westk\u00fcsten-Normalz\u00e4it",
-               "",
+               "PST",
                "Nordamerikanesch Westk\u00fcsten-Summerz\u00e4it",
-               "",
+               "PDT",
                "Nordamerikanesch Westk\u00fcstenz\u00e4it",
-               "",
+               "PT",
             };
         final String[] French_Southern = new String[] {
                "Frans\u00e9isch S\u00fcd- an Antarktisgebidder-Z\u00e4it",
@@ -1076,11 +1076,11 @@ public class TimeZoneNames_lb extends TimeZoneNamesBundle {
             };
         final String[] Hawaii_Aleutian = new String[] {
                "Hawaii-Aleuten-Normalz\u00e4it",
-               "",
+               "HST",
                "Hawaii-Aleuten-Summerz\u00e4it",
-               "",
+               "HST",
                "Hawaii-Aleuten-Z\u00e4it",
-               "",
+               "HST",
             };
         final String[] Phoenix_Islands = new String[] {
                "Phoenixinselen-Z\u00e4it",
@@ -1100,11 +1100,11 @@ public class TimeZoneNames_lb extends TimeZoneNamesBundle {
             };
         final String[] America_Mountain = new String[] {
                "Rocky-Mountain-Normalz\u00e4it",
-               "",
+               "MST",
                "Rocky-Mountain-Summerz\u00e4it",
-               "",
+               "MDT",
                "Rocky-Mountain-Z\u00e4it",
-               "",
+               "MT",
             };
         final String[] Marshall_Islands = new String[] {
                "Marshallinselen-Z\u00e4it",
@@ -1132,19 +1132,19 @@ public class TimeZoneNames_lb extends TimeZoneNamesBundle {
             };
         final String[] Australia_Central = new String[] {
                "Zentralaustralesch Normalz\u00e4it",
-               "",
+               "ACST",
                "Zentralaustralesch Summerz\u00e4it",
-               "",
+               "ACDT",
                "Zentralaustralesch Z\u00e4it",
-               "",
+               "ACT",
             };
         final String[] Australia_Eastern = new String[] {
                "Ostaustralesch Normalz\u00e4it",
-               "",
+               "AEST",
                "Ostaustralesch Summerz\u00e4it",
-               "",
+               "AEDT",
                "Ostaustralesch Z\u00e4it",
-               "",
+               "AET",
             };
         final String[] Australia_Western = new String[] {
                "Westaustralesch Normalz\u00e4it",
@@ -1172,27 +1172,27 @@ public class TimeZoneNames_lb extends TimeZoneNamesBundle {
             };
         final String[] Indonesia_Central = new String[] {
                "Zentralindonesesch Z\u00e4it",
+               "WITA",
                "",
+               "WITA",
                "",
-               "",
-               "",
-               "",
+               "WITA",
             };
         final String[] Indonesia_Eastern = new String[] {
                "Ostindonesesch Z\u00e4it",
+               "WIT",
                "",
+               "WIT",
                "",
-               "",
-               "",
-               "",
+               "WIT",
             };
         final String[] Indonesia_Western = new String[] {
                "Westindonesesch Z\u00e4it",
+               "WIB",
                "",
+               "WIB",
                "",
-               "",
-               "",
-               "",
+               "WIB",
             };
         final String[] Kazakhstan_Eastern = new String[] {
                "Ostkasachesch Z\u00e4it",
@@ -1269,7 +1269,6 @@ public class TimeZoneNames_lb extends TimeZoneNamesBundle {
             { "Asia/Hovd", Hovd },
             { "Asia/Omsk", Omsk },
             { "Asia/Oral", Kazakhstan_Western },
-            { "Asia/Amman", Europe_Eastern },
             { "Asia/Aqtau", Kazakhstan_Western },
             { "Asia/Chita", Yakutsk },
             { "Asia/Dhaka", Bangladesh },
@@ -1278,7 +1277,7 @@ public class TimeZoneNames_lb extends TimeZoneNamesBundle {
             { "Asia/Macau", China },
             { "Asia/Qatar", Arabian },
             { "Asia/Seoul", Korea },
-            { "Africa/Juba", Africa_Eastern },
+            { "Africa/Juba", Africa_Central },
             { "Africa/Lome", GMT },
             { "Asia/Almaty", Kazakhstan_Eastern },
             { "Asia/Anadyr", Anadyr },
@@ -1364,7 +1363,6 @@ public class TimeZoneNames_lb extends TimeZoneNamesBundle {
             { "America/Thule", Atlantic },
             { "Asia/Ashgabat", Turkmenistan },
             { "Asia/Calcutta", India },
-            { "Asia/Damascus", Europe_Eastern },
             { "Asia/Dushanbe", Tajikistan },
             { "Asia/Jayapura", Indonesia_Eastern },
             { "Asia/Katmandu", Nepal },
@@ -1379,11 +1377,11 @@ public class TimeZoneNames_lb extends TimeZoneNamesBundle {
             { "Europe/Dublin",
                 new String[] {
                     "M\u00ebttler Greenwich-Z\u00e4it",
-                    "",
+                    "GMT",
                     "Iresch Summerz\u00e4it",
+                    "IST",
                     "",
-                    "",
-                    "",
+                    "GMT",
                 }
             },
             { "Europe/Jersey", GMT },
@@ -1391,11 +1389,11 @@ public class TimeZoneNames_lb extends TimeZoneNamesBundle {
             { "Europe/London",
                 new String[] {
                     "M\u00ebttler Greenwich-Z\u00e4it",
-                    "",
+                    "GMT",
                     "Britesch Summerz\u00e4it",
+                    "BST",
                     "",
-                    "",
-                    "",
+                    "GMT",
                 }
             },
             { "Europe/Madrid", Europe_Central },
@@ -1427,7 +1425,6 @@ public class TimeZoneNames_lb extends TimeZoneNamesBundle {
             { "America/Cancun", America_Eastern },
             { "America/Cayman", America_Eastern },
             { "America/Cuiaba", Amazon },
-            { "America/Dawson", America_Mountain },
             { "America/Guyana", Guyana },
             { "America/Havana", Cuba },
             { "America/Inuvik", America_Mountain },
@@ -1453,11 +1450,11 @@ public class TimeZoneNames_lb extends TimeZoneNamesBundle {
             { "Europe/Belfast",
                 new String[] {
                     "M\u00ebttler Greenwich-Z\u00e4it",
-                    "",
+                    "GMT",
                     "Britesch Summerz\u00e4it",
+                    "BST",
                     "",
-                    "",
-                    "",
+                    "GMT",
                 }
             },
             { "Europe/Tallinn", Europe_Eastern },
@@ -1503,7 +1500,7 @@ public class TimeZoneNames_lb extends TimeZoneNamesBundle {
             { "America/Moncton", Atlantic },
             { "America/Nipigon", America_Eastern },
             { "America/Noronha", Noronha },
-            { "America/Ojinaga", America_Mountain },
+            { "America/Ojinaga", America_Central },
             { "America/Tijuana", America_Pacific },
             { "America/Toronto", America_Eastern },
             { "America/Tortola", Atlantic },
@@ -1588,7 +1585,7 @@ public class TimeZoneNames_lb extends TimeZoneNamesBundle {
             { "America/Araguaina", Brasilia },
             { "America/Boa_Vista", Amazon },
             { "America/Catamarca", Argentina },
-            { "America/Chihuahua", Mexico_Pacific },
+            { "America/Chihuahua", America_Central },
             { "America/Fortaleza", Brasilia },
             { "America/Glace_Bay", Atlantic },
             { "America/Goose_Bay", Atlantic },
@@ -1633,7 +1630,6 @@ public class TimeZoneNames_lb extends TimeZoneNamesBundle {
             { "America/Paramaribo", Suriname },
             { "America/Rio_Branco", Acre },
             { "America/St_Vincent", Atlantic },
-            { "America/Whitehorse", America_Mountain },
             { "Antarctica/McMurdo", New_Zealand },
             { "Antarctica/Rothera", Rothera },
             { "Asia/Yekaterinburg", Yekaterinburg },
@@ -1676,6 +1672,7 @@ public class TimeZoneNames_lb extends TimeZoneNamesBundle {
             { "Antarctica/Macquarie", Australia_Eastern },
             { "Pacific/Port_Moresby", Papua_New_Guinea },
             { "America/Cambridge_Bay", America_Mountain },
+            { "America/Ciudad_Juarez", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
             { "America/Indiana/Vevay", America_Eastern },
             { "America/Lower_Princes", Atlantic },
@@ -1715,7 +1712,6 @@ public class TimeZoneNames_lb extends TimeZoneNamesBundle {
             { "timezone.excity.Etc/Unknown", "Onbekannt" },
             { "timezone.excity.Europe/Kiev", "Kiew" },
             { "timezone.excity.Europe/Rome", "Roum" },
-            { "timezone.excity.Africa/Accra", "Accra" },
             { "timezone.excity.Africa/Cairo", "Kairo" },
             { "timezone.excity.Asia/Baghdad", "Bagdad" },
             { "timezone.excity.Asia/Bishkek", "Bischkek" },
@@ -1742,22 +1738,17 @@ public class TimeZoneNames_lb extends TimeZoneNamesBundle {
             { "America/Argentina/Rio_Gallegos", Argentina },
             { "America/North_Dakota/New_Salem", America_Central },
             { "timezone.excity.Africa/Algiers", "Alger" },
-            { "timezone.excity.Africa/Tripoli", "Tripoli" },
             { "timezone.excity.America/Cayman", "Kaimaninselen" },
             { "timezone.excity.America/Havana", "Havanna" },
-            { "timezone.excity.Asia/Hong_Kong", "Hong Kong" },
             { "timezone.excity.Asia/Kamchatka", "Kamtschatka" },
             { "timezone.excity.Asia/Pyongyang", "Pj\u00f6ngjang" },
             { "timezone.excity.Asia/Singapore", "Singapur" },
             { "timezone.excity.Europe/Vatican", "Vatikan" },
             { "timezone.excity.Europe/Vilnius", "Wilna" },
-            { "timezone.excity.Indian/Reunion", "R\u00e9union" },
             { "timezone.excity.Pacific/Easter", "Ouschterinsel" },
             { "timezone.excity.Africa/Djibouti", "Dschibuti" },
             { "timezone.excity.Africa/El_Aaiun", "El Aai\u00fan" },
             { "timezone.excity.Africa/Khartoum", "Khartum" },
-            { "timezone.excity.Africa/Sao_Tome", "S\u00e3o Tom\u00e9" },
-            { "timezone.excity.America/Curacao", "Cura\u00e7ao" },
             { "timezone.excity.America/Jamaica", "Jamaika" },
             { "timezone.excity.Atlantic/Azores", "Azoren" },
             { "timezone.excity.Atlantic/Canary", "Kanaresch Inselen" },
@@ -1768,7 +1759,6 @@ public class TimeZoneNames_lb extends TimeZoneNamesBundle {
             { "timezone.excity.Europe/Uzhgorod", "Uschgorod" },
             { "timezone.excity.Indian/Maldives", "Maldiven" },
             { "timezone.excity.Africa/Mogadishu", "Mogadischu" },
-            { "timezone.excity.America/Asuncion", "Asunci\u00f3n" },
             { "timezone.excity.Asia/Krasnoyarsk", "Krasnojarsk" },
             { "timezone.excity.Asia/Novosibirsk", "Nowosibirsk" },
             { "timezone.excity.Asia/Vladivostok", "Wladiwostok" },
@@ -1786,7 +1776,6 @@ public class TimeZoneNames_lb extends TimeZoneNamesBundle {
             { "timezone.excity.America/El_Salvador", "Salvador" },
             { "timezone.excity.America/Mexico_City", "Mexiko-Stad" },
             { "timezone.excity.Atlantic/Cape_Verde", "Kap Verde" },
-            { "timezone.excity.Africa/Dar_es_Salaam", "Dar es Salaam" },
             { "timezone.excity.America/Port_of_Spain", "Port-of-Spain" },
             { "timezone.excity.America/St_Barthelemy", "Saint-Barth\u00e9lemy" },
             { "timezone.excity.Atlantic/South_Georgia", "S\u00fcdgeorgien" },
