@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2023, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -68,11 +68,11 @@ public class TimeZoneNames_lv extends TimeZoneNamesBundle {
     protected final Object[][] getContents() {
         final String[] GMT = new String[] {
                "Grini\u010das laiks",
+               "GMT",
                "",
+               "GMT",
                "",
-               "",
-               "",
-               "",
+               "GMT",
             };
         final String[] Apia = new String[] {
                "Apijas ziemas laiks",
@@ -92,11 +92,11 @@ public class TimeZoneNames_lv extends TimeZoneNamesBundle {
             };
         final String[] Cuba = new String[] {
                "Kubas ziemas laiks",
-               "",
+               "CST",
                "Kubas vasaras laiks",
-               "",
+               "CDT",
                "Kubas laiks",
-               "",
+               "CT",
             };
         final String[] Fiji = new String[] {
                "Fid\u017ei ziemas laiks",
@@ -180,11 +180,11 @@ public class TimeZoneNames_lv extends TimeZoneNamesBundle {
             };
         final String[] China = new String[] {
                "\u0136\u012bnas ziemas laiks",
-               "",
+               "CST",
                "\u0136\u012bnas vasaras laiks",
-               "",
+               "CDT",
                "\u0136\u012bnas laiks",
-               "",
+               "CT",
             };
         final String[] Cocos = new String[] {
                "Kokosu (K\u012blinga) salu laiks",
@@ -212,19 +212,19 @@ public class TimeZoneNames_lv extends TimeZoneNamesBundle {
             };
         final String[] Japan = new String[] {
                "Jap\u0101nas ziemas laiks",
-               "",
+               "JST",
                "Jap\u0101nas vasaras laiks",
-               "",
+               "JDT",
                "Jap\u0101nas laiks",
-               "",
+               "JT",
             };
         final String[] Korea = new String[] {
                "Korejas ziemas laiks",
-               "",
+               "KST",
                "Korejas vasaras laiks",
-               "",
+               "KST",
                "Korejas laiks",
-               "",
+               "KST",
             };
         final String[] Nauru = new String[] {
                "Nauru laiks",
@@ -252,11 +252,11 @@ public class TimeZoneNames_lv extends TimeZoneNamesBundle {
             };
         final String[] Samoa = new String[] {
                "Samoa ziemas laiks",
-               "",
+               "SST",
                "Samoa vasaras laiks",
-               "",
+               "SST",
                "Samoa laiks",
-               "",
+               "SST",
             };
         final String[] Syowa = new String[] {
                "\u0160ovas laiks",
@@ -276,11 +276,11 @@ public class TimeZoneNames_lv extends TimeZoneNamesBundle {
             };
         final String[] Yukon = new String[] {
                "Jukonas laiks",
+               "MST",
                "",
+               "MST",
                "",
-               "",
-               "",
-               "",
+               "MST",
             };
         final String[] Alaska = new String[] {
                "A\u013caskas ziemas laiks",
@@ -308,11 +308,11 @@ public class TimeZoneNames_lv extends TimeZoneNamesBundle {
             };
         final String[] Azores = new String[] {
                "Azoru salu ziemas laiks",
-               "",
+               "HMT",
                "Azoru salu vasaras laiks",
-               "",
+               "HMT",
                "Azoru salu laiks",
-               "",
+               "HMT",
             };
         final String[] Bhutan = new String[] {
                "But\u0101nas laiks",
@@ -348,11 +348,11 @@ public class TimeZoneNames_lv extends TimeZoneNamesBundle {
             };
         final String[] Israel = new String[] {
                "Izra\u0113las ziemas laiks",
-               "",
+               "IST",
                "Izra\u0113las vasaras laiks",
-               "",
+               "IDT",
                "Izra\u0113las laiks",
-               "",
+               "IT",
             };
         final String[] Kosrae = new String[] {
                "Kosrae laiks",
@@ -372,11 +372,11 @@ public class TimeZoneNames_lv extends TimeZoneNamesBundle {
             };
         final String[] Moscow = new String[] {
                "Maskavas ziemas laiks",
-               "",
+               "MSK",
                "Maskavas vasaras laiks",
-               "",
+               "MSK",
                "Maskavas laiks",
-               "",
+               "MSK",
             };
         final String[] Ponape = new String[] {
                "Ponap\u0113 laiks",
@@ -404,11 +404,11 @@ public class TimeZoneNames_lv extends TimeZoneNamesBundle {
             };
         final String[] Taipei = new String[] {
                "Taibei ziemas laiks",
-               "",
+               "CST",
                "Taibei vasaras laiks",
-               "",
+               "CDT",
                "Taibei laiks",
-               "",
+               "CT",
             };
         final String[] Tuvalu = new String[] {
                "Tuvalu laiks",
@@ -596,11 +596,11 @@ public class TimeZoneNames_lv extends TimeZoneNamesBundle {
             };
         final String[] Atlantic = new String[] {
                "Atlantijas ziemas laiks",
-               "",
+               "AST",
                "Atlantijas vasaras laiks",
-               "",
+               "ADT",
                "Atlantijas laiks",
-               "",
+               "AT",
             };
         final String[] Brasilia = new String[] {
                "Braz\u012blijas ziemas laiks",
@@ -612,11 +612,11 @@ public class TimeZoneNames_lv extends TimeZoneNamesBundle {
             };
         final String[] Chamorro = new String[] {
                "\u010camorra ziemas laiks",
+               "ChST",
                "",
+               "ChST",
                "",
-               "",
-               "",
-               "",
+               "ChST",
             };
         final String[] Colombia = new String[] {
                "Kolumbijas ziemas laiks",
@@ -660,11 +660,11 @@ public class TimeZoneNames_lv extends TimeZoneNamesBundle {
             };
         final String[] Pakistan = new String[] {
                "Pakist\u0101nas ziemas laiks",
-               "",
+               "PKT",
                "Pakist\u0101nas vasaras laiks",
-               "",
+               "PKST",
                "Pakist\u0101nas laiks",
-               "",
+               "PKT",
             };
         final String[] Paraguay = new String[] {
                "Paragvajas ziemas laiks",
@@ -724,11 +724,11 @@ public class TimeZoneNames_lv extends TimeZoneNamesBundle {
             };
         final String[] Hong_Kong = new String[] {
                "Honkongas ziemas laiks",
-               "",
+               "HKT",
                "Honkongas vasaras laiks",
-               "",
+               "HKST",
                "Honkongas laiks",
-               "",
+               "HKT",
             };
         final String[] Indochina = new String[] {
                "Indo\u0137\u012bnas laiks",
@@ -796,11 +796,11 @@ public class TimeZoneNames_lv extends TimeZoneNamesBundle {
             };
         final String[] Volgograd = new String[] {
                "Volgogradas ziemas laiks",
-               "",
+               "MSK",
                "Volgogradas vasaras laiks",
-               "",
+               "MSK",
                "Volgogradas laiks",
-               "",
+               "MSK",
             };
         final String[] Azerbaijan = new String[] {
                "Azerbaid\u017e\u0101nas ziemas laiks",
@@ -876,11 +876,11 @@ public class TimeZoneNames_lv extends TimeZoneNamesBundle {
             };
         final String[] New_Zealand = new String[] {
                "Jaunz\u0113landes ziemas laiks",
-               "",
+               "NZST",
                "Jaunz\u0113landes vasaras laiks",
-               "",
+               "NZDT",
                "Jaunz\u0113landes laiks",
-               "",
+               "NZT",
             };
         final String[] Novosibirsk = new String[] {
                "Novosibirskas ziemas laiks",
@@ -892,11 +892,11 @@ public class TimeZoneNames_lv extends TimeZoneNamesBundle {
             };
         final String[] Philippines = new String[] {
                "Filip\u012bnu ziemas laiks",
-               "",
+               "PST",
                "Filip\u012bnu vasaras laiks",
-               "",
+               "PDT",
                "Filip\u012bnu laiks",
-               "",
+               "PT",
             };
         final String[] Vladivostok = new String[] {
                "Vladivostokas ziemas laiks",
@@ -924,11 +924,11 @@ public class TimeZoneNames_lv extends TimeZoneNamesBundle {
             };
         final String[] Newfoundland = new String[] {
                "\u0145\u016bfaundlendas ziemas laiks",
-               "",
+               "NST",
                "\u0145\u016bfaundlendas vasaras laiks",
-               "",
+               "NDT",
                "\u0145\u016bfaundlendas laiks",
-               "",
+               "NT",
             };
         final String[] Turkmenistan = new String[] {
                "Turkmenist\u0101nas ziemas laiks",
@@ -972,27 +972,27 @@ public class TimeZoneNames_lv extends TimeZoneNamesBundle {
             };
         final String[] Africa_Central = new String[] {
                "Centr\u0101l\u0101frikas laiks",
+               "SAST",
                "",
+               "SAST",
                "",
-               "",
-               "",
-               "",
+               "SAST",
             };
         final String[] Africa_Eastern = new String[] {
                "Austrum\u0101frikas laiks",
+               "EAT",
                "",
+               "EAT",
                "",
-               "",
-               "",
-               "",
+               "EAT",
             };
         final String[] Africa_Western = new String[] {
                "Rietum\u0101frikas ziemas laiks",
-               "",
+               "WAT",
                "Rietum\u0101frikas vasaras laiks",
-               "",
+               "WAT",
                "Rietum\u0101frikas laiks",
-               "",
+               "WAT",
             };
         final String[] DumontDUrville = new String[] {
                "Dimondirvilas laiks",
@@ -1028,43 +1028,43 @@ public class TimeZoneNames_lv extends TimeZoneNamesBundle {
             };
         final String[] Mexico_Pacific = new String[] {
                "Meksikas Klus\u0101 oke\u0101na piekrastes ziemas laiks",
-               "",
+               "MST",
                "Meksikas Klus\u0101 oke\u0101na piekrastes vasaras laiks",
-               "",
+               "MDT",
                "Meksikas Klus\u0101 oke\u0101na piekrastes laiks",
-               "",
+               "MT",
             };
         final String[] Africa_Southern = new String[] {
                "Dienvid\u0101frikas ziemas laiks",
+               "SAST",
                "",
+               "SAST",
                "",
-               "",
-               "",
-               "",
+               "SAST",
             };
         final String[] America_Central = new String[] {
                "Centr\u0101lais ziemas laiks",
-               "",
+               "CST",
                "Centr\u0101lais vasaras laiks",
-               "",
+               "CDT",
                "Centr\u0101lais laiks",
-               "",
+               "CT",
             };
         final String[] America_Eastern = new String[] {
                "Austrumu ziemas laiks",
-               "",
+               "EST",
                "Austrumu vasaras laiks",
-               "",
+               "EST",
                "Austrumu laiks",
-               "",
+               "EST",
             };
         final String[] America_Pacific = new String[] {
                "Klus\u0101 oke\u0101na ziemas laiks",
-               "",
+               "PST",
                "Klus\u0101 oke\u0101na vasaras laiks",
-               "",
+               "PDT",
                "Klus\u0101 oke\u0101na laiks",
-               "",
+               "PT",
             };
         final String[] French_Southern = new String[] {
                "Francijas Dienvidj\u016bru un Antarktikas teritorijas laiks",
@@ -1084,11 +1084,11 @@ public class TimeZoneNames_lv extends TimeZoneNamesBundle {
             };
         final String[] Hawaii_Aleutian = new String[] {
                "Havaju\u2013Aleutu ziemas laiks",
-               "",
+               "HST",
                "Havaju\u2013Aleutu vasaras laiks",
-               "",
+               "HST",
                "Havaju\u2013Aleutu laiks",
-               "",
+               "HST",
             };
         final String[] Phoenix_Islands = new String[] {
                "F\u0113niksa salu laiks",
@@ -1108,11 +1108,11 @@ public class TimeZoneNames_lv extends TimeZoneNamesBundle {
             };
         final String[] America_Mountain = new String[] {
                "Kalnu ziemas laiks",
-               "",
+               "MST",
                "Kalnu vasaras laiks",
-               "",
+               "MDT",
                "Kalnu laiks",
-               "",
+               "MT",
             };
         final String[] Marshall_Islands = new String[] {
                "M\u0101r\u0161ala salu laiks",
@@ -1140,19 +1140,19 @@ public class TimeZoneNames_lv extends TimeZoneNamesBundle {
             };
         final String[] Australia_Central = new String[] {
                "Austr\u0101lijas centr\u0101lais ziemas laiks",
-               "",
+               "ACST",
                "Austr\u0101lijas centr\u0101lais vasaras laiks",
-               "",
+               "ACDT",
                "Austr\u0101lijas centr\u0101lais laiks",
-               "",
+               "ACT",
             };
         final String[] Australia_Eastern = new String[] {
                "Austr\u0101lijas austrumu ziemas laiks",
-               "",
+               "AEST",
                "Austr\u0101lijas austrumu vasaras laiks",
-               "",
+               "AEDT",
                "Austr\u0101lijas austrumu laiks",
-               "",
+               "AET",
             };
         final String[] Australia_Western = new String[] {
                "Austr\u0101lijas rietumu ziemas laiks",
@@ -1180,27 +1180,27 @@ public class TimeZoneNames_lv extends TimeZoneNamesBundle {
             };
         final String[] Indonesia_Central = new String[] {
                "Centr\u0101lindon\u0113zijas laiks",
+               "WITA",
                "",
+               "WITA",
                "",
-               "",
-               "",
-               "",
+               "WITA",
             };
         final String[] Indonesia_Eastern = new String[] {
                "Austrumindon\u0113zijas laiks",
+               "WIT",
                "",
+               "WIT",
                "",
-               "",
-               "",
-               "",
+               "WIT",
             };
         final String[] Indonesia_Western = new String[] {
                "Rietumindon\u0113zijas laiks",
+               "WIB",
                "",
+               "WIB",
                "",
-               "",
-               "",
-               "",
+               "WIB",
             };
         final String[] Kazakhstan_Eastern = new String[] {
                "Austrumkazahst\u0101nas laiks",
@@ -1279,7 +1279,6 @@ public class TimeZoneNames_lv extends TimeZoneNamesBundle {
             { "Asia/Hovd", Hovd },
             { "Asia/Omsk", Omsk },
             { "Asia/Oral", Kazakhstan_Western },
-            { "Asia/Amman", Europe_Eastern },
             { "Asia/Aqtau", Kazakhstan_Western },
             { "Asia/Chita", Yakutsk },
             { "Asia/Dhaka", Bangladesh },
@@ -1375,7 +1374,6 @@ public class TimeZoneNames_lv extends TimeZoneNamesBundle {
             { "America/Thule", Atlantic },
             { "Asia/Ashgabat", Turkmenistan },
             { "Asia/Calcutta", India },
-            { "Asia/Damascus", Europe_Eastern },
             { "Asia/Dushanbe", Tajikistan },
             { "Asia/Jayapura", Indonesia_Eastern },
             { "Asia/Katmandu", Nepal },
@@ -1390,11 +1388,11 @@ public class TimeZoneNames_lv extends TimeZoneNamesBundle {
             { "Europe/Dublin",
                 new String[] {
                     "Grini\u010das laiks",
-                    "",
+                    "GMT",
                     "\u012arijas ziemas laiks",
+                    "IST",
                     "",
-                    "",
-                    "",
+                    "GMT",
                 }
             },
             { "Europe/Jersey", GMT },
@@ -1402,11 +1400,11 @@ public class TimeZoneNames_lv extends TimeZoneNamesBundle {
             { "Europe/London",
                 new String[] {
                     "Grini\u010das laiks",
-                    "",
+                    "GMT",
                     "Lielbrit\u0101nijas vasaras laiks",
+                    "BST",
                     "",
-                    "",
-                    "",
+                    "GMT",
                 }
             },
             { "Europe/Madrid", Europe_Central },
@@ -1464,11 +1462,11 @@ public class TimeZoneNames_lv extends TimeZoneNamesBundle {
             { "Europe/Belfast",
                 new String[] {
                     "Grini\u010das laiks",
-                    "",
+                    "GMT",
                     "Lielbrit\u0101nijas vasaras laiks",
+                    "BST",
                     "",
-                    "",
-                    "",
+                    "GMT",
                 }
             },
             { "Europe/Tallinn", Europe_Eastern },
@@ -1685,6 +1683,7 @@ public class TimeZoneNames_lv extends TimeZoneNamesBundle {
             { "Antarctica/Macquarie", Australia_Eastern },
             { "Pacific/Port_Moresby", Papua_New_Guinea },
             { "America/Cambridge_Bay", America_Mountain },
+            { "America/Ciudad_Juarez", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
             { "America/Indiana/Vevay", America_Eastern },
             { "America/Lower_Princes", Atlantic },
@@ -1706,9 +1705,6 @@ public class TimeZoneNames_lv extends TimeZoneNamesBundle {
             { "America/Indiana/Vincennes", America_Eastern },
             { "Antarctica/DumontDUrville", DumontDUrville },
             { "timezone.excity.Asia/Aden", "Adena" },
-            { "timezone.excity.Asia/Baku", "Baku" },
-            { "timezone.excity.Asia/Dili", "Dili" },
-            { "timezone.excity.Asia/Gaza", "Gaza" },
             { "timezone.excity.Asia/Hovd", "Hovda" },
             { "timezone.excity.Asia/Omsk", "Omska" },
             { "timezone.excity.Asia/Oral", "Orala" },
@@ -1731,7 +1727,6 @@ public class TimeZoneNames_lv extends TimeZoneNamesBundle {
             { "America/North_Dakota/Beulah", America_Central },
             { "America/North_Dakota/Center", America_Central },
             { "timezone.excity.Africa/Juba", "D\u017e\u016bba" },
-            { "timezone.excity.Africa/Lome", "Lome" },
             { "timezone.excity.Asia/Almaty", "Almati" },
             { "timezone.excity.Asia/Anadyr", "Anadira" },
             { "timezone.excity.Asia/Aqtobe", "Aktebe" },
@@ -1740,7 +1735,6 @@ public class TimeZoneNames_lv extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Brunei", "Bruneja" },
             { "timezone.excity.Asia/Hebron", "Hebrona" },
             { "timezone.excity.Asia/Kuwait", "Kuveita" },
-            { "timezone.excity.Asia/Manila", "Manila" },
             { "timezone.excity.Asia/Muscat", "Maskata" },
             { "timezone.excity.Asia/Riyadh", "Rij\u0101da" },
             { "timezone.excity.Asia/Saigon", "Ho\u0161imina" },
@@ -1749,7 +1743,6 @@ public class TimeZoneNames_lv extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Urumqi", "Urum\u010di" },
             { "timezone.excity.Etc/Unknown", "nezin\u0101ma pils\u0113ta" },
             { "timezone.excity.Europe/Kiev", "Kijeva" },
-            { "timezone.excity.Europe/Oslo", "Oslo" },
             { "timezone.excity.Europe/Riga", "R\u012bga" },
             { "timezone.excity.Europe/Rome", "Roma" },
             { "timezone.excity.Indian/Mahe", "Mae" },
@@ -1760,7 +1753,6 @@ public class TimeZoneNames_lv extends TimeZoneNamesBundle {
             { "timezone.excity.Africa/Lagos", "Lagosa" },
             { "timezone.excity.Africa/Tunis", "Tunisa" },
             { "timezone.excity.America/Adak", "Adaka" },
-            { "timezone.excity.America/Lima", "Lima" },
             { "timezone.excity.America/Nome", "Noma" },
             { "timezone.excity.Asia/Baghdad", "Bagd\u0101de" },
             { "timezone.excity.Asia/Bahrain", "Bahreina" },
@@ -1775,12 +1767,9 @@ public class TimeZoneNames_lv extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Magadan", "Magadana" },
             { "timezone.excity.Asia/Nicosia", "Nikosija" },
             { "timezone.excity.Asia/Rangoon", "Ranguna" },
-            { "timezone.excity.Asia/Tbilisi", "Tbilisi" },
-            { "timezone.excity.Asia/Thimphu", "Thimphu" },
             { "timezone.excity.Asia/Yakutsk", "Jakutska" },
             { "timezone.excity.Asia/Yerevan", "Erev\u0101na" },
             { "timezone.excity.Europe/Kirov", "Kirova" },
-            { "timezone.excity.Europe/Malta", "Malta" },
             { "timezone.excity.Europe/Minsk", "Minska" },
             { "timezone.excity.Europe/Paris", "Par\u012bze" },
             { "timezone.excity.Europe/Sofia", "Sofija" },
@@ -1789,28 +1778,18 @@ public class TimeZoneNames_lv extends TimeZoneNamesBundle {
             { "timezone.excity.Pacific/Apia", "Apija" },
             { "timezone.excity.Pacific/Fiji", "Fid\u017ei" },
             { "timezone.excity.Pacific/Guam", "Guama" },
-            { "timezone.excity.Pacific/Niue", "Niue" },
             { "timezone.excity.Pacific/Truk", "\u010c\u016bka" },
             { "timezone.excity.Pacific/Wake", "Veika sala" },
-            { "timezone.excity.Africa/Bamako", "Bamako" },
             { "timezone.excity.Africa/Bangui", "Bangi" },
             { "timezone.excity.Africa/Banjul", "Band\u017eula" },
             { "timezone.excity.Africa/Bissau", "Bisava" },
             { "timezone.excity.Africa/Douala", "Duala" },
-            { "timezone.excity.Africa/Harare", "Harare" },
-            { "timezone.excity.Africa/Kigali", "Kigali" },
-            { "timezone.excity.Africa/Luanda", "Luanda" },
-            { "timezone.excity.Africa/Lusaka", "Lusaka" },
-            { "timezone.excity.Africa/Malabo", "Malabo" },
             { "timezone.excity.Africa/Maputo", "Maputu" },
-            { "timezone.excity.Africa/Maseru", "Maseru" },
             { "timezone.excity.Africa/Niamey", "Niameja" },
-            { "timezone.excity.America/Aruba", "Aruba" },
             { "timezone.excity.America/Bahia", "Baija" },
             { "timezone.excity.America/Belem", "Belena" },
             { "timezone.excity.America/Boise", "Boisisitija" },
             { "timezone.excity.America/Jujuy", "Huhuja" },
-            { "timezone.excity.America/Sitka", "Sitka" },
             { "timezone.excity.America/Thule", "Tule" },
             { "timezone.excity.Asia/Ashgabat", "A\u0161gabata" },
             { "timezone.excity.Asia/Calcutta", "Kalk\u0101ta" },
@@ -1835,36 +1814,26 @@ public class TimeZoneNames_lv extends TimeZoneNamesBundle {
             { "timezone.excity.Europe/Monaco", "Monako" },
             { "timezone.excity.Europe/Moscow", "Maskava" },
             { "timezone.excity.Europe/Prague", "Pr\u0101ga" },
-            { "timezone.excity.Europe/Samara", "Samara" },
-            { "timezone.excity.Europe/Skopje", "Skopje" },
             { "timezone.excity.Europe/Tirane", "Tir\u0101na" },
             { "timezone.excity.Europe/Vienna", "V\u012bne" },
             { "timezone.excity.Europe/Warsaw", "Var\u0161ava" },
             { "timezone.excity.Europe/Zagreb", "Zagreba" },
             { "timezone.excity.Europe/Zurich", "C\u012brihe" },
-            { "timezone.excity.Indian/Chagos", "\u010cagosu arhipel\u0101gs" },
+            { "timezone.excity.Indian/Chagos", "\u010cagosa" },
             { "timezone.excity.Indian/Comoro", "Komoras" },
-            { "timezone.excity.Pacific/Efate", "Efate" },
-            { "timezone.excity.Pacific/Nauru", "Nauru" },
-            { "timezone.excity.Pacific/Palau", "Palau" },
             { "America/Argentina/Rio_Gallegos", Argentina },
             { "America/North_Dakota/New_Salem", America_Central },
             { "timezone.excity.Africa/Abidjan", "Abid\u017eana" },
             { "timezone.excity.Africa/Algiers", "Al\u017e\u012bra" },
             { "timezone.excity.Africa/Conakry", "Konakri" },
-            { "timezone.excity.Africa/Kampala", "Kampala" },
-            { "timezone.excity.Africa/Mbabane", "Mbabane" },
-            { "timezone.excity.Africa/Nairobi", "Nairobi" },
             { "timezone.excity.Africa/Tripoli", "Tripole" },
             { "timezone.excity.America/Belize", "Beliza" },
-            { "timezone.excity.America/Bogota", "Bogota" },
             { "timezone.excity.America/Cancun", "Kankuna" },
             { "timezone.excity.America/Cayman", "Kaimanu salas" },
             { "timezone.excity.America/Cuiaba", "Kujaba" },
             { "timezone.excity.America/Dawson", "Dousona" },
             { "timezone.excity.America/Denver", "Denvera" },
             { "timezone.excity.America/Guyana", "Gaj\u0101na" },
-            { "timezone.excity.America/Havana", "Havana" },
             { "timezone.excity.America/Inuvik", "Inuvika" },
             { "timezone.excity.America/Juneau", "D\u017euno" },
             { "timezone.excity.America/La_Paz", "Lapasa" },
@@ -1872,10 +1841,8 @@ public class TimeZoneNames_lv extends TimeZoneNamesBundle {
             { "timezone.excity.America/Manaus", "Manausa" },
             { "timezone.excity.America/Merida", "Merida" },
             { "timezone.excity.America/Nassau", "Naso" },
-            { "timezone.excity.America/Panama", "Panama" },
             { "timezone.excity.America/Recife", "Resifi" },
             { "timezone.excity.America/Regina", "Rid\u017eaina" },
-            { "timezone.excity.Asia/Famagusta", "Famagusta" },
             { "timezone.excity.Asia/Hong_Kong", "Honkonga" },
             { "timezone.excity.Asia/Jerusalem", "Jeruzaleme" },
             { "timezone.excity.Asia/Kamchatka", "Kam\u010datka" },
@@ -1907,7 +1874,6 @@ public class TimeZoneNames_lv extends TimeZoneNamesBundle {
             { "timezone.excity.Africa/Djibouti", "D\u017eibutija" },
             { "timezone.excity.Africa/El_Aaiun", "Aj\u016bna" },
             { "timezone.excity.Africa/Freetown", "Fr\u012btauna" },
-            { "timezone.excity.Africa/Gaborone", "Gaborone" },
             { "timezone.excity.Africa/Khartoum", "Hart\u016bma" },
             { "timezone.excity.Africa/Kinshasa", "Kin\u0161asa" },
             { "timezone.excity.Africa/Monrovia", "Monrovija" },
@@ -1936,8 +1902,6 @@ public class TimeZoneNames_lv extends TimeZoneNamesBundle {
             { "timezone.excity.America/Ojinaga", "Ohinaga" },
             { "timezone.excity.America/Phoenix", "F\u012bniksa" },
             { "timezone.excity.America/Tijuana", "Tihuana" },
-            { "timezone.excity.America/Toronto", "Toronto" },
-            { "timezone.excity.America/Tortola", "Tortola" },
             { "timezone.excity.America/Yakutat", "Jakutata" },
             { "timezone.excity.Asia/Choibalsan", "\u010coibalsana" },
             { "timezone.excity.Asia/Phnom_Penh", "Pnompe\u0146a" },
@@ -1952,13 +1916,11 @@ public class TimeZoneNames_lv extends TimeZoneNamesBundle {
             { "timezone.excity.Europe/Busingen", "B\u012bzingene" },
             { "timezone.excity.Europe/Chisinau", "Ki\u0161i\u0146eva" },
             { "timezone.excity.Europe/Guernsey", "G\u0113rnsija" },
-            { "timezone.excity.Europe/Helsinki", "Helsinki" },
             { "timezone.excity.Europe/Istanbul", "Stambula" },
             { "timezone.excity.Europe/Sarajevo", "Sarajeva" },
             { "timezone.excity.Europe/Uzhgorod", "U\u017ehoroda" },
             { "timezone.excity.Indian/Maldives", "Mald\u012bvija" },
             { "timezone.excity.Pacific/Chatham", "\u010cetema" },
-            { "timezone.excity.Pacific/Fakaofo", "Fakaofo" },
             { "timezone.excity.Pacific/Gambier", "Gambj\u0113 salas" },
             { "timezone.excity.Pacific/Norfolk", "Norfolka" },
             { "timezone.excity.Africa/Bujumbura", "Bu\u017eumbura" },
@@ -1968,7 +1930,6 @@ public class TimeZoneNames_lv extends TimeZoneNamesBundle {
             { "timezone.excity.America/Barbados", "Barbadosa" },
             { "timezone.excity.America/Dominica", "Dominika" },
             { "timezone.excity.America/Edmonton", "Edmontona" },
-            { "timezone.excity.America/Eirunepe", "Eirunepe" },
             { "timezone.excity.America/Mazatlan", "Masatlana" },
             { "timezone.excity.America/Miquelon", "Mikelona" },
             { "timezone.excity.America/New_York", "\u0145ujorka" },
@@ -1987,8 +1948,6 @@ public class TimeZoneNames_lv extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Novosibirsk", "Novosibirska" },
             { "timezone.excity.Asia/Ulaanbaatar", "Ulanbatora" },
             { "timezone.excity.Asia/Vladivostok", "Vladivostoka" },
-            { "timezone.excity.Atlantic/Bermuda", "Bermuda" },
-            { "timezone.excity.Atlantic/Madeira", "Madeira" },
             { "timezone.excity.Atlantic/Stanley", "Stenli" },
             { "timezone.excity.Australia/Currie", "Kari" },
             { "timezone.excity.Australia/Darwin", "D\u0101rvina" },
@@ -2000,7 +1959,6 @@ public class TimeZoneNames_lv extends TimeZoneNamesBundle {
             { "timezone.excity.Europe/Gibraltar", "Gibralt\u0101rs" },
             { "timezone.excity.Europe/Ljubljana", "\u013bub\u013cana" },
             { "timezone.excity.Europe/Mariehamn", "Mariehamna" },
-            { "timezone.excity.Europe/Podgorica", "Podgorica" },
             { "timezone.excity.Europe/Stockholm", "Stokholma" },
             { "timezone.excity.Europe/Ulyanovsk", "U\u013cjanovska" },
             { "timezone.excity.Europe/Volgograd", "Volgograda" },
@@ -2008,7 +1966,6 @@ public class TimeZoneNames_lv extends TimeZoneNamesBundle {
             { "timezone.excity.Indian/Kerguelen", "Kergel\u0113na sala" },
             { "timezone.excity.Indian/Mauritius", "Maur\u012bcija" },
             { "timezone.excity.Pacific/Auckland", "Oklenda" },
-            { "timezone.excity.Pacific/Funafuti", "Funafuti" },
             { "timezone.excity.Pacific/Honolulu", "Honolulu" },
             { "timezone.excity.Pacific/Johnston", "D\u017eonstona atols" },
             { "timezone.excity.Pacific/Pitcairn", "Pitk\u0113rna" },
@@ -2022,7 +1979,6 @@ public class TimeZoneNames_lv extends TimeZoneNamesBundle {
             { "timezone.excity.America/Boa_Vista", "Boavista" },
             { "timezone.excity.America/Catamarca", "Katamarka" },
             { "timezone.excity.America/Chihuahua", "\u010civava" },
-            { "timezone.excity.America/Fortaleza", "Fortaleza" },
             { "timezone.excity.America/Glace_Bay", "Gleisbeja" },
             { "timezone.excity.America/Goose_Bay", "G\u016bsbeja" },
             { "timezone.excity.America/Guatemala", "Gvatemala" },
@@ -2038,7 +1994,6 @@ public class TimeZoneNames_lv extends TimeZoneNamesBundle {
             { "timezone.excity.Antarctica/Vostok", "Vostoka" },
             { "timezone.excity.Asia/Kuala_Lumpur", "Kualalumpura" },
             { "timezone.excity.Asia/Novokuznetsk", "Novokuz\u0146ecka" },
-            { "timezone.excity.Europe/Bratislava", "Bratislava" },
             { "timezone.excity.Europe/Copenhagen", "Kopenh\u0101gena" },
             { "timezone.excity.Europe/Luxembourg", "Luksemburga" },
             { "timezone.excity.Europe/San_Marino", "Sanmar\u012bno" },
@@ -2049,8 +2004,6 @@ public class TimeZoneNames_lv extends TimeZoneNamesBundle {
             { "timezone.excity.Pacific/Kwajalein", "Kvad\u017ealeina" },
             { "timezone.excity.Pacific/Marquesas", "Mar\u0137\u012bza salas" },
             { "timezone.excity.Pacific/Pago_Pago", "Pagopago" },
-            { "timezone.excity.Pacific/Rarotonga", "Rarotonga" },
-            { "timezone.excity.Pacific/Tongatapu", "Tongatapu" },
             { "timezone.excity.Africa/Addis_Ababa", "Adisabeba" },
             { "timezone.excity.Africa/Brazzaville", "Brazavila" },
             { "timezone.excity.Africa/Ouagadougou", "Vagadugu" },
@@ -2061,10 +2014,7 @@ public class TimeZoneNames_lv extends TimeZoneNamesBundle {
             { "timezone.excity.America/Kralendijk", "Kr\u0101lendeika" },
             { "timezone.excity.America/Louisville", "L\u016bivila" },
             { "timezone.excity.America/Martinique", "Martinika" },
-            { "timezone.excity.America/Metlakatla", "Metlakatla" },
-            { "timezone.excity.America/Montevideo", "Montevideo" },
             { "timezone.excity.America/Montserrat", "Montserrata" },
-            { "timezone.excity.America/Paramaribo", "Paramaribo" },
             { "timezone.excity.America/Rio_Branco", "Riobranko" },
             { "timezone.excity.America/St_Vincent", "Sentvinsenta" },
             { "timezone.excity.America/Whitehorse", "Vaithorsa" },
@@ -2114,6 +2064,7 @@ public class TimeZoneNames_lv extends TimeZoneNamesBundle {
             { "timezone.excity.Pacific/Bougainville", "Bugenvila sala" },
             { "timezone.excity.Pacific/Port_Moresby", "Portmorsbi" },
             { "timezone.excity.America/Cambridge_Bay", "Kembrid\u017ebeja" },
+            { "timezone.excity.America/Ciudad_Juarez", "Huaresa" },
             { "timezone.excity.America/Coral_Harbour", "Atikokana" },
             { "timezone.excity.America/Indiana/Vevay", "V\u012bveja, Indi\u0101na" },
             { "timezone.excity.America/Lower_Princes", "Louerprinseskvotera" },
@@ -2125,7 +2076,6 @@ public class TimeZoneNames_lv extends TimeZoneNamesBundle {
             { "timezone.excity.America/Bahia_Banderas", "Bajabanderasa" },
             { "timezone.excity.America/Port-au-Prince", "Portoprensa" },
             { "timezone.excity.Atlantic/South_Georgia", "Dienvidd\u017eord\u017eija" },
-            { "timezone.excity.America/Argentina/Salta", "Salta" },
             { "timezone.excity.America/Indiana/Marengo", "Marengo, Indi\u0101na" },
             { "timezone.excity.America/Indiana/Winamac", "Vinamaka, Indi\u0101na" },
             { "timezone.excity.America/Argentina/Tucuman", "Tukumana" },
