@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2023, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -68,11 +68,11 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
     protected final Object[][] getContents() {
         final String[] GMT = new String[] {
                "Hora de Greenwich",
+               "GMT",
                "",
+               "GMT",
                "",
-               "",
-               "",
-               "",
+               "GMT",
             };
         final String[] Acre = new String[] {
                "Hora padr\u00e3o do Acre",
@@ -100,11 +100,11 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
             };
         final String[] Cuba = new String[] {
                "Hora padr\u00e3o de Cuba",
-               "",
+               "CST",
                "Hora de ver\u00e3o de Cuba",
-               "",
+               "CDT",
                "Hora de Cuba",
-               "",
+               "CT",
             };
         final String[] Fiji = new String[] {
                "Hora padr\u00e3o de Fiji",
@@ -188,11 +188,11 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
             };
         final String[] China = new String[] {
                "Hora padr\u00e3o da China",
-               "",
+               "CST",
                "Hora de ver\u00e3o da China",
-               "",
+               "CDT",
                "Hora da China",
-               "",
+               "CT",
             };
         final String[] Cocos = new String[] {
                "Hora das Ilhas Cocos",
@@ -220,19 +220,19 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
             };
         final String[] Japan = new String[] {
                "Hora padr\u00e3o do Jap\u00e3o",
-               "",
+               "JST",
                "Hora de ver\u00e3o do Jap\u00e3o",
-               "",
+               "JDT",
                "Hora do Jap\u00e3o",
-               "",
+               "JT",
             };
         final String[] Korea = new String[] {
                "Hora padr\u00e3o da Coreia",
-               "",
+               "KST",
                "Hora de ver\u00e3o da Coreia",
-               "",
+               "KST",
                "Hora da Coreia",
-               "",
+               "KST",
             };
         final String[] Nauru = new String[] {
                "Hora de Nauru",
@@ -260,11 +260,11 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
             };
         final String[] Samoa = new String[] {
                "Hora padr\u00e3o de Samoa",
-               "",
+               "SST",
                "Hora de ver\u00e3o de Samoa",
-               "",
+               "SST",
                "Hora de Samoa",
-               "",
+               "SST",
             };
         final String[] Syowa = new String[] {
                "Hora de Syowa",
@@ -284,11 +284,11 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
             };
         final String[] Yukon = new String[] {
                "Hora do Yukon",
+               "MST",
                "",
+               "MST",
                "",
-               "",
-               "",
-               "",
+               "MST",
             };
         final String[] Alaska = new String[] {
                "Hora padr\u00e3o do Alasca",
@@ -356,11 +356,11 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
             };
         final String[] Israel = new String[] {
                "Hora padr\u00e3o de Israel",
-               "",
+               "IST",
                "Hora de ver\u00e3o de Israel",
-               "",
+               "IDT",
                "Hora de Israel",
-               "",
+               "IT",
             };
         final String[] Kosrae = new String[] {
                "Hora de Kosrae",
@@ -380,11 +380,11 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
             };
         final String[] Moscow = new String[] {
                "Hora padr\u00e3o de Moscovo",
-               "",
+               "MSK",
                "Hora de ver\u00e3o de Moscovo",
-               "",
+               "MSK",
                "Hora de Moscovo",
-               "",
+               "MSK",
             };
         final String[] Ponape = new String[] {
                "Hora de Ponape",
@@ -412,11 +412,11 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
             };
         final String[] Taipei = new String[] {
                "Hora padr\u00e3o de Taip\u00e9",
-               "",
+               "CST",
                "Hora de ver\u00e3o de Taip\u00e9",
-               "",
+               "CDT",
                "Hora de Taip\u00e9",
-               "",
+               "CT",
             };
         final String[] Tuvalu = new String[] {
                "Hora de Tuvalu",
@@ -604,11 +604,11 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
             };
         final String[] Atlantic = new String[] {
                "Hora padr\u00e3o do Atl\u00e2ntico",
-               "",
+               "AST",
                "Hora de ver\u00e3o do Atl\u00e2ntico",
-               "",
+               "ADT",
                "Hora do Atl\u00e2ntico",
-               "",
+               "AT",
             };
         final String[] Brasilia = new String[] {
                "Hora padr\u00e3o de Bras\u00edlia",
@@ -620,11 +620,11 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
             };
         final String[] Chamorro = new String[] {
                "Hora padr\u00e3o de Chamorro",
+               "ChST",
                "",
+               "ChST",
                "",
-               "",
-               "",
-               "",
+               "ChST",
             };
         final String[] Colombia = new String[] {
                "Hora padr\u00e3o da Col\u00f4mbia",
@@ -668,11 +668,11 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
             };
         final String[] Pakistan = new String[] {
                "Hora padr\u00e3o do Paquist\u00e3o",
-               "",
+               "PKT",
                "Hora de ver\u00e3o do Paquist\u00e3o",
-               "",
+               "PKST",
                "Hora do Paquist\u00e3o",
-               "",
+               "PKT",
             };
         final String[] Paraguay = new String[] {
                "Hora padr\u00e3o do Paraguai",
@@ -732,11 +732,11 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
             };
         final String[] Hong_Kong = new String[] {
                "Hora padr\u00e3o de Hong Kong",
-               "",
+               "HKT",
                "Hora de ver\u00e3o de Hong Kong",
-               "",
+               "HKST",
                "Hora de Hong Kong",
-               "",
+               "HKT",
             };
         final String[] Indochina = new String[] {
                "Hora da Indochina",
@@ -804,11 +804,11 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
             };
         final String[] Volgograd = new String[] {
                "Hora padr\u00e3o de Volgogrado",
-               "",
+               "MSK",
                "Hora de ver\u00e3o de Volgogrado",
-               "",
+               "MSK",
                "Hora de Volgogrado",
-               "",
+               "MSK",
             };
         final String[] Azerbaijan = new String[] {
                "Hora padr\u00e3o do Azerbaij\u00e3o",
@@ -884,11 +884,11 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
             };
         final String[] New_Zealand = new String[] {
                "Hora padr\u00e3o da Nova Zel\u00e2ndia",
-               "",
+               "NZST",
                "Hora de ver\u00e3o da Nova Zel\u00e2ndia",
-               "",
+               "NZDT",
                "Hora da Nova Zel\u00e2ndia",
-               "",
+               "NZT",
             };
         final String[] Novosibirsk = new String[] {
                "Hora padr\u00e3o de Novosibirsk",
@@ -900,11 +900,11 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
             };
         final String[] Philippines = new String[] {
                "Hora padr\u00e3o das Filipinas",
-               "",
+               "PST",
                "Hora de ver\u00e3o das Filipinas",
-               "",
+               "PDT",
                "Hora das Filipinas",
-               "",
+               "PT",
             };
         final String[] Vladivostok = new String[] {
                "Hora padr\u00e3o de Vladivostok",
@@ -932,11 +932,11 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
             };
         final String[] Newfoundland = new String[] {
                "Hora padr\u00e3o da Terra Nova",
-               "",
+               "NST",
                "Hora de ver\u00e3o da Terra Nova",
-               "",
+               "NDT",
                "Hora da Terra Nova",
-               "",
+               "NT",
             };
         final String[] Turkmenistan = new String[] {
                "Hora padr\u00e3o do Turquemenist\u00e3o",
@@ -980,27 +980,27 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
             };
         final String[] Africa_Central = new String[] {
                "Hora da \u00c1frica Central",
+               "SAST",
                "",
+               "SAST",
                "",
-               "",
-               "",
-               "",
+               "SAST",
             };
         final String[] Africa_Eastern = new String[] {
                "Hora da \u00c1frica Oriental",
+               "EAT",
                "",
+               "EAT",
                "",
-               "",
-               "",
-               "",
+               "EAT",
             };
         final String[] Africa_Western = new String[] {
                "Hora padr\u00e3o da \u00c1frica Ocidental",
-               "",
+               "WAT",
                "Hora de ver\u00e3o da \u00c1frica Ocidental",
-               "",
+               "WAT",
                "Hora da \u00c1frica Ocidental",
-               "",
+               "WAT",
             };
         final String[] DumontDUrville = new String[] {
                "Hora de Dumont-d\u2019Urville",
@@ -1036,43 +1036,43 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
             };
         final String[] Mexico_Pacific = new String[] {
                "Hora padr\u00e3o do Pac\u00edfico Mexicano",
-               "",
+               "MST",
                "Hora de ver\u00e3o do Pac\u00edfico Mexicano",
-               "",
+               "MDT",
                "Hora do Pac\u00edfico Mexicano",
-               "",
+               "MT",
             };
         final String[] Africa_Southern = new String[] {
                "Hora da \u00c1frica do Sul",
+               "SAST",
                "",
+               "SAST",
                "",
-               "",
-               "",
-               "",
+               "SAST",
             };
         final String[] America_Central = new String[] {
                "Hora padr\u00e3o central norte-americana",
-               "",
+               "CST",
                "Hora de ver\u00e3o central norte-americana",
-               "",
+               "CDT",
                "Hora central norte-americana",
-               "",
+               "CT",
             };
         final String[] America_Eastern = new String[] {
                "Hora padr\u00e3o oriental norte-americana",
-               "",
+               "EST",
                "Hora de ver\u00e3o oriental norte-americana",
-               "",
+               "EST",
                "Hora oriental norte-americana",
-               "",
+               "EST",
             };
         final String[] America_Pacific = new String[] {
                "Hora padr\u00e3o do Pac\u00edfico norte-americana",
-               "",
+               "PST",
                "Hora de ver\u00e3o do Pac\u00edfico norte-americana",
-               "",
+               "PDT",
                "Hora do Pac\u00edfico norte-americana",
-               "",
+               "PT",
             };
         final String[] French_Southern = new String[] {
                "Hora das Terras Austrais e Ant\u00e1rcticas Francesas",
@@ -1092,11 +1092,11 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
             };
         final String[] Hawaii_Aleutian = new String[] {
                "Hora padr\u00e3o do Havai e Aleutas",
-               "",
+               "HST",
                "Hora de ver\u00e3o do Havai e Aleutas",
-               "",
+               "HST",
                "Hora do Havai e Aleutas",
-               "",
+               "HST",
             };
         final String[] Phoenix_Islands = new String[] {
                "Hora das Ilhas F\u00e9nix",
@@ -1116,11 +1116,11 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
             };
         final String[] America_Mountain = new String[] {
                "Hora padr\u00e3o de montanha norte-americana",
-               "",
+               "MST",
                "Hora de ver\u00e3o de montanha norte-americana",
-               "",
+               "MDT",
                "Hora de montanha norte-americana",
-               "",
+               "MT",
             };
         final String[] Marshall_Islands = new String[] {
                "Hora das Ilhas Marshall",
@@ -1148,19 +1148,19 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
             };
         final String[] Australia_Central = new String[] {
                "Hora padr\u00e3o da Austr\u00e1lia Central",
-               "",
+               "ACST",
                "Hora de ver\u00e3o da Austr\u00e1lia Central",
-               "",
+               "ACDT",
                "Hora da Austr\u00e1lia Central",
-               "",
+               "ACT",
             };
         final String[] Australia_Eastern = new String[] {
                "Hora padr\u00e3o da Austr\u00e1lia Oriental",
-               "",
+               "AEST",
                "Hora de ver\u00e3o da Austr\u00e1lia Oriental",
-               "",
+               "AEDT",
                "Hora da Austr\u00e1lia Oriental",
-               "",
+               "AET",
             };
         final String[] Australia_Western = new String[] {
                "Hora padr\u00e3o da Austr\u00e1lia Ocidental",
@@ -1188,27 +1188,27 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
             };
         final String[] Indonesia_Central = new String[] {
                "Hora da Indon\u00e9sia Central",
+               "WITA",
                "",
+               "WITA",
                "",
-               "",
-               "",
-               "",
+               "WITA",
             };
         final String[] Indonesia_Eastern = new String[] {
                "Hora da Indon\u00e9sia Oriental",
+               "WIT",
                "",
+               "WIT",
                "",
-               "",
-               "",
-               "",
+               "WIT",
             };
         final String[] Indonesia_Western = new String[] {
                "Hora da Indon\u00e9sia Ocidental",
+               "WIB",
                "",
+               "WIB",
                "",
-               "",
-               "",
-               "",
+               "WIB",
             };
         final String[] Kazakhstan_Eastern = new String[] {
                "Hora do Cazaquist\u00e3o Oriental",
@@ -1287,7 +1287,6 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
             { "Asia/Hovd", Hovd },
             { "Asia/Omsk", Omsk },
             { "Asia/Oral", Kazakhstan_Western },
-            { "Asia/Amman", Europe_Eastern },
             { "Asia/Aqtau", Kazakhstan_Western },
             { "Asia/Chita", Yakutsk },
             { "Asia/Dhaka", Bangladesh },
@@ -1383,7 +1382,6 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
             { "America/Thule", Atlantic },
             { "Asia/Ashgabat", Turkmenistan },
             { "Asia/Calcutta", India },
-            { "Asia/Damascus", Europe_Eastern },
             { "Asia/Dushanbe", Tajikistan },
             { "Asia/Jayapura", Indonesia_Eastern },
             { "Asia/Katmandu", Nepal },
@@ -1398,11 +1396,11 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
             { "Europe/Dublin",
                 new String[] {
                     "Hora de Greenwich",
-                    "",
+                    "GMT",
                     "Hora de ver\u00e3o da Irlanda",
+                    "IST",
                     "",
-                    "",
-                    "",
+                    "GMT",
                 }
             },
             { "Europe/Jersey", GMT },
@@ -1410,11 +1408,11 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
             { "Europe/London",
                 new String[] {
                     "Hora de Greenwich",
-                    "",
+                    "GMT",
                     "Hora de ver\u00e3o Brit\u00e2nica",
+                    "BST",
                     "",
-                    "",
-                    "",
+                    "GMT",
                 }
             },
             { "Europe/Madrid", Europe_Central },
@@ -1472,11 +1470,11 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
             { "Europe/Belfast",
                 new String[] {
                     "Hora de Greenwich",
-                    "",
+                    "GMT",
                     "Hora de ver\u00e3o Brit\u00e2nica",
+                    "BST",
                     "",
-                    "",
-                    "",
+                    "GMT",
                 }
             },
             { "Europe/Tallinn", Europe_Eastern },
@@ -1695,6 +1693,7 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
             { "Antarctica/Macquarie", Australia_Eastern },
             { "Pacific/Port_Moresby", Papua_New_Guinea },
             { "America/Cambridge_Bay", America_Mountain },
+            { "America/Ciudad_Juarez", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
             { "America/Indiana/Vevay", America_Eastern },
             { "America/Lower_Princes", Atlantic },
