@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -72,10 +68,26 @@ public class TimeZoneNames_sat extends TimeZoneNamesBundle {
     protected final Object[][] getContents() {
         final String[] GMT = new String[] {
                "\u1c5c\u1c68\u1c64\u1c71\u1c63\u1c64\u1c6a \u1c62\u1c64\u1c71 \u1c5a\u1c60\u1c5b\u1c5a",
+               "GMT",
                "",
+               "BST",
                "",
+               "GMT",
+            };
+        final String[] Alaska = new String[] {
+               "\u1c5f\u1c79\u1c5e\u1c5f\u1c65\u1c60\u1c5f \u1c6e\u1c65\u1c74\u1c6e\u1c71\u1c70\u1c5f\u1c68\u1c70 \u1c5a\u1c60\u1c5b\u1c5a",
                "",
+               "\u1c5f\u1c79\u1c5e\u1c5f\u1c65\u1c60\u1c5f \u1c65\u1c64\u1c67\u1c5f\u1c5c \u1c5a\u1c60\u1c5b\u1c5a",
                "",
+               "\u1c5f\u1c79\u1c5e\u1c5f\u1c65\u1c60\u1c5f \u1c5a\u1c60\u1c5b\u1c5a",
+               "",
+            };
+        final String[] Amazon = new String[] {
+               "\u1c5f\u1c62\u1c5f\u1c61\u1c5a\u1c71 \u1c6e\u1c74\u1c6e\u1c71\u1c70\u1c5f\u1c68\u1c70 \u1c5a\u1c60\u1c74\u1c5a",
+               "",
+               "\u1c5f\u1c62\u1c5f\u1c61\u1c5a\u1c71 \u1c65\u1c64\u1c5b\u1c69\u1c5d \u1c5a\u1c60\u1c74\u1c5a",
+               "",
+               "\u1c5f\u1c62\u1c5f\u1c61\u1c5a\u1c71 \u1c5a\u1c60\u1c74\u1c5a",
                "",
             };
         final String[] ETC_UTC = new String[] {
@@ -88,67 +100,75 @@ public class TimeZoneNames_sat extends TimeZoneNamesBundle {
             };
         final String[] Atlantic = new String[] {
                "\u1c6e\u1c74\u1c5e\u1c5f\u1c71\u1c74\u1c64\u1c60 \u1c6e\u1c65\u1c74\u1c6e\u1c71\u1c70\u1c5f\u1c68\u1c70 \u1c5a\u1c60\u1c5b\u1c5a",
-               "",
+               "AST",
                "\u1c6e\u1c74\u1c5e\u1c5f\u1c71\u1c74\u1c64\u1c60 \u1c65\u1c64\u1c67\u1c5f\u1c5c \u1c5a\u1c60\u1c5b\u1c5a",
-               "",
+               "ADT",
                "\u1c6e\u1c74\u1c5e\u1c5f\u1c71\u1c74\u1c64\u1c60 \u1c5a\u1c60\u1c5b\u1c5a",
+               "AT",
+            };
+        final String[] Argentina = new String[] {
+               "\u1c5f\u1c79\u1c68\u1c61\u1c6e\u1c71\u1c74\u1c64\u1c71\u1c5f \u1c6e\u1c74\u1c6e\u1c71\u1c70\u1c5f\u1c68\u1c70 \u1c5a\u1c60\u1c74\u1c5a",
+               "",
+               "\u1c5f\u1c79\u1c68\u1c61\u1c6e\u1c71\u1c74\u1c64\u1c71\u1c5f \u1c65\u1c64\u1c5b\u1c69\u1c5d \u1c5a\u1c60\u1c74\u1c5a",
+               "",
+               "\u1c5f\u1c79\u1c68\u1c61\u1c6e\u1c71\u1c74\u1c64\u1c71\u1c5f \u1c5a\u1c60\u1c74\u1c5a",
                "",
             };
         final String[] Europe_Central = new String[] {
                "\u1c65\u1c6e\u1c71\u1c74\u1c68\u1c5f\u1c5e \u1c69\u1c68\u1c5a\u1c6f\u1c64\u1c6d\u1c5f\u1c71 \u1c6e\u1c65\u1c74\u1c6e\u1c71\u1c70\u1c5f\u1c68\u1c70 \u1c5a\u1c60\u1c5b\u1c5a",
-               "",
+               "CET",
                "\u1c65\u1c6e\u1c71\u1c74\u1c68\u1c5f\u1c5e \u1c69\u1c68\u1c5a\u1c6f\u1c64\u1c6d\u1c5f\u1c71 \u1c65\u1c5f\u1c62\u1c5f\u1c68 \u1c5a\u1c60\u1c5b\u1c5a",
-               "",
+               "CEST",
                "\u1c65\u1c6e\u1c71\u1c74\u1c68\u1c5f\u1c5e \u1c69\u1c68\u1c5a\u1c6f\u1c64\u1c6d\u1c5f\u1c71 \u1c5a\u1c60\u1c5b\u1c5a",
-               "",
+               "CET",
             };
         final String[] Europe_Eastern = new String[] {
                "\u1c64\u1c65\u1c74\u1c5f\u1c68\u1c71 \u1c69\u1c68\u1c5a\u1c6f\u1c64\u1c6d\u1c5f\u1c71 \u1c6e\u1c65\u1c74\u1c6e\u1c71\u1c70\u1c5f\u1c68\u1c70 \u1c5a\u1c60\u1c5b\u1c5a",
-               "",
+               "EET",
                "\u1c64\u1c65\u1c74\u1c5f\u1c68\u1c71 \u1c69\u1c68\u1c5a\u1c6f\u1c64\u1c6d\u1c5f\u1c71 \u1c65\u1c5f\u1c62\u1c5f\u1c68 \u1c5a\u1c60\u1c5b\u1c5a",
-               "",
+               "EEST",
                "\u1c64\u1c65\u1c74\u1c5f\u1c68\u1c71 \u1c69\u1c68\u1c5a\u1c6f\u1c64\u1c6d\u1c5f\u1c71 \u1c5a\u1c60\u1c5b\u1c5a",
-               "",
+               "EET",
             };
         final String[] Europe_Western = new String[] {
                "\u1c63\u1c6e\u1c65\u1c74\u1c5f\u1c68\u1c71 \u1c69\u1c68\u1c5a\u1c6f\u1c64\u1c6d\u1c5f\u1c71 \u1c6e\u1c65\u1c74\u1c6e\u1c71\u1c70\u1c5f\u1c68\u1c70 \u1c5a\u1c60\u1c5b\u1c5a",
-               "",
+               "FMT",
                "\u1c63\u1c6e\u1c65\u1c74\u1c5f\u1c68\u1c71 \u1c69\u1c68\u1c5a\u1c6f\u1c64\u1c6d\u1c5f\u1c71 \u1c65\u1c5f\u1c62\u1c5f\u1c68 \u1c5a\u1c60\u1c5b\u1c5a",
-               "",
+               "FMT",
                "\u1c63\u1c6e\u1c65\u1c74\u1c5f\u1c68\u1c71 \u1c69\u1c68\u1c5a\u1c6f\u1c64\u1c6d\u1c5f\u1c71 \u1c5a\u1c60\u1c5b\u1c5a",
-               "",
+               "FMT",
             };
         final String[] America_Central = new String[] {
                "\u1c5b\u1c5f\u1c71\u1c5f\u1c5e\u1c5f \u1c6e\u1c65\u1c74\u1c6e\u1c71\u1c70\u1c5f\u1c68\u1c70 \u1c5a\u1c60\u1c5b\u1c5a",
-               "",
+               "CST",
                "\u1c5b\u1c5f\u1c71\u1c5f\u1c5e\u1c5f \u1c65\u1c64\u1c67\u1c5f\u1c5c \u1c5a\u1c60\u1c5b\u1c5a",
-               "",
+               "CDT",
                "\u1c5b\u1c5f\u1c71\u1c5f\u1c5e\u1c5f \u1c5a\u1c60\u1c5b\u1c5a",
-               "",
+               "CT",
             };
         final String[] America_Eastern = new String[] {
                "\u1c64\u1c65\u1c74\u1c5f\u1c68\u1c71 \u1c6e\u1c65\u1c74\u1c6e\u1c71\u1c70\u1c5f\u1c68\u1c70 \u1c5a\u1c60\u1c5b\u1c5a",
-               "",
+               "EST",
                "\u1c64\u1c65\u1c74\u1c5f\u1c68\u1c71 \u1c65\u1c64\u1c67\u1c5f\u1c5c \u1c75\u1c5a\u1c60\u1c5b\u1c5a",
-               "",
+               "EST",
                "\u1c64\u1c65\u1c74\u1c5f\u1c68\u1c71 \u1c5a\u1c60\u1c5b\u1c5a",
-               "",
+               "EST",
             };
         final String[] America_Pacific = new String[] {
                "\u1c6f\u1c6e\u1c65\u1c64\u1c6f\u1c77\u1c64\u1c60 \u1c6e\u1c65\u1c74\u1c6e\u1c71\u1c70\u1c5f\u1c68\u1c70 \u1c5a\u1c60\u1c5b\u1c5a",
-               "",
+               "PST",
                "\u1c6f\u1c6e\u1c65\u1c64\u1c6f\u1c77\u1c64\u1c60 \u1c65\u1c64\u1c67\u1c5f\u1c5c \u1c5a\u1c60\u1c5b\u1c5a",
-               "",
+               "PDT",
                "\u1c6f\u1c6e\u1c65\u1c64\u1c6f\u1c77\u1c64\u1c60 \u1c5a\u1c60\u1c5b\u1c5a",
-               "",
+               "PT",
             };
         final String[] America_Mountain = new String[] {
                "\u1c62\u1c5f\u1c69\u1c71\u1c74\u1c6e\u1c71 \u1c6e\u1c65\u1c74\u1c6e\u1c71\u1c70\u1c5f\u1c68\u1c70 \u1c5a\u1c60\u1c5b\u1c5a",
-               "",
+               "MST",
                "\u1c62\u1c5f\u1c69\u1c71\u1c74\u1c6e\u1c71 \u1c65\u1c64\u1c67\u1c5f\u1c5c \u1c5a\u1c60\u1c5b\u1c5a",
-               "",
+               "MDT",
                "\u1c62\u1c5f\u1c69\u1c71\u1c74\u1c6e\u1c71 \u1c5a\u1c60\u1c5b\u1c5a",
-               "",
+               "MT",
             };
         final Object[][] data = new Object[][] {
             { "America/Los_Angeles", America_Pacific },
@@ -157,12 +177,15 @@ public class TimeZoneNames_sat extends TimeZoneNamesBundle {
             { "America/Chicago", America_Central },
             { "America/New_York", America_Eastern },
             { "America/Indianapolis", America_Eastern },
+            { "America/Anchorage", Alaska },
             { "America/Halifax", Atlantic },
+            { "America/Sitka", Alaska },
             { "Europe/Paris", Europe_Central },
             { "GMT", GMT },
             { "Europe/Bucharest", Europe_Eastern },
             { "UTC", ETC_UTC },
             { "ART", Europe_Eastern },
+            { "AST", Alaska },
             { "CST", America_Central },
             { "ECT", Europe_Central },
             { "PNT", America_Mountain },
@@ -175,7 +198,6 @@ public class TimeZoneNames_sat extends TimeZoneNamesBundle {
             { "MST7MDT", America_Mountain },
             { "PST8PDT", America_Pacific },
             { "Asia/Gaza", Europe_Eastern },
-            { "Asia/Amman", Europe_Eastern },
             { "Africa/Lome", GMT },
             { "Asia/Beirut", Europe_Eastern },
             { "Asia/Hebron", Europe_Eastern },
@@ -188,6 +210,7 @@ public class TimeZoneNames_sat extends TimeZoneNamesBundle {
             { "Africa/Ceuta", Europe_Central },
             { "Africa/Dakar", GMT },
             { "Africa/Tunis", Europe_Central },
+            { "America/Nome", Alaska },
             { "Asia/Nicosia", Europe_Eastern },
             { "Europe/Malta", Europe_Central },
             { "Europe/Sofia", Europe_Eastern },
@@ -201,8 +224,8 @@ public class TimeZoneNames_sat extends TimeZoneNamesBundle {
             { "Africa/Bissau", GMT },
             { "America/Aruba", Atlantic },
             { "America/Boise", America_Mountain },
+            { "America/Jujuy", Argentina },
             { "America/Thule", Atlantic },
-            { "Asia/Damascus", Europe_Eastern },
             { "Europe/Athens", Europe_Eastern },
             { "Europe/Berlin", Europe_Central },
             { "Europe/Dublin", GMT },
@@ -225,8 +248,10 @@ public class TimeZoneNames_sat extends TimeZoneNamesBundle {
             { "America/Belize", America_Central },
             { "America/Cancun", America_Eastern },
             { "America/Cayman", America_Eastern },
-            { "America/Dawson", America_Pacific },
+            { "America/Cuiaba", Amazon },
             { "America/Inuvik", America_Mountain },
+            { "America/Juneau", Alaska },
+            { "America/Manaus", Amazon },
             { "America/Merida", America_Central },
             { "America/Nassau", America_Eastern },
             { "America/Panama", America_Eastern },
@@ -241,6 +266,7 @@ public class TimeZoneNames_sat extends TimeZoneNamesBundle {
             { "Africa/Sao_Tome", GMT },
             { "Africa/Timbuktu", GMT },
             { "America/Antigua", Atlantic },
+            { "America/Cordoba", Argentina },
             { "America/Creston", America_Mountain },
             { "America/Curacao", Atlantic },
             { "America/Detroit", America_Eastern },
@@ -249,12 +275,14 @@ public class TimeZoneNames_sat extends TimeZoneNamesBundle {
             { "America/Jamaica", America_Eastern },
             { "America/Managua", America_Central },
             { "America/Marigot", Atlantic },
+            { "America/Mendoza", Argentina },
             { "America/Moncton", Atlantic },
             { "America/Nipigon", America_Eastern },
-            { "America/Ojinaga", America_Mountain },
+            { "America/Ojinaga", America_Central },
             { "America/Tijuana", America_Pacific },
             { "America/Toronto", America_Eastern },
             { "America/Tortola", Atlantic },
+            { "America/Yakutat", Alaska },
             { "Atlantic/Canary", Europe_Western },
             { "Atlantic/Faeroe", Europe_Western },
             { "Europe/Belgrade", Europe_Central },
@@ -271,6 +299,7 @@ public class TimeZoneNames_sat extends TimeZoneNamesBundle {
             { "SystemV/EST5EDT", America_Eastern },
             { "SystemV/MST7MDT", America_Mountain },
             { "SystemV/PST8PDT", America_Pacific },
+            { "SystemV/YST9YDT", Alaska },
             { "America/Anguilla", Atlantic },
             { "America/Barbados", Atlantic },
             { "America/Dominica", Atlantic },
@@ -291,6 +320,9 @@ public class TimeZoneNames_sat extends TimeZoneNamesBundle {
             { "Europe/Podgorica", Europe_Central },
             { "Europe/Stockholm", Europe_Central },
             { "Africa/Nouakchott", GMT },
+            { "America/Boa_Vista", Amazon },
+            { "America/Catamarca", Argentina },
+            { "America/Chihuahua", America_Central },
             { "America/Glace_Bay", Atlantic },
             { "America/Goose_Bay", Atlantic },
             { "America/Guatemala", America_Central },
@@ -311,9 +343,9 @@ public class TimeZoneNames_sat extends TimeZoneNamesBundle {
             { "America/Kralendijk", Atlantic },
             { "America/Louisville", America_Eastern },
             { "America/Martinique", Atlantic },
+            { "America/Metlakatla", Alaska },
             { "America/Montserrat", Atlantic },
             { "America/St_Vincent", Atlantic },
-            { "America/Whitehorse", America_Pacific },
             { "Atlantic/Jan_Mayen", Europe_Central },
             { "Atlantic/Reykjavik", GMT },
             { "Atlantic/St_Helena", GMT },
@@ -323,6 +355,7 @@ public class TimeZoneNames_sat extends TimeZoneNamesBundle {
             { "America/Fort_Nelson", America_Mountain },
             { "America/Mexico_City", America_Central },
             { "America/Pangnirtung", America_Eastern },
+            { "America/Porto_Velho", Amazon },
             { "America/Puerto_Rico", Atlantic },
             { "America/Rainy_River", America_Central },
             { "America/Tegucigalpa", America_Central },
@@ -330,11 +363,14 @@ public class TimeZoneNames_sat extends TimeZoneNamesBundle {
             { "America/Yellowknife", America_Mountain },
             { "Arctic/Longyearbyen", Europe_Central },
             { "America/Blanc-Sablon", Atlantic },
+            { "America/Buenos_Aires", Argentina },
+            { "America/Campo_Grande", Amazon },
             { "America/Danmarkshavn", GMT },
             { "America/Dawson_Creek", America_Mountain },
             { "America/Indiana/Knox", America_Central },
             { "America/Rankin_Inlet", America_Central },
             { "America/Cambridge_Bay", America_Mountain },
+            { "America/Ciudad_Juarez", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
             { "America/Indiana/Vevay", America_Eastern },
             { "America/Lower_Princes", Atlantic },
@@ -344,15 +380,22 @@ public class TimeZoneNames_sat extends TimeZoneNamesBundle {
             { "America/Swift_Current", America_Central },
             { "America/Bahia_Banderas", America_Central },
             { "America/Port-au-Prince", America_Eastern },
+            { "America/Argentina/Salta", Argentina },
             { "America/Indiana/Marengo", America_Eastern },
             { "America/Indiana/Winamac", America_Eastern },
+            { "America/Argentina/Tucuman", Argentina },
+            { "America/Argentina/Ushuaia", Argentina },
             { "America/Indiana/Tell_City", America_Central },
             { "America/Indiana/Vincennes", America_Eastern },
+            { "America/Argentina/La_Rioja", Argentina },
+            { "America/Argentina/San_Juan", Argentina },
+            { "America/Argentina/San_Luis", Argentina },
             { "America/Indiana/Petersburg", America_Eastern },
             { "America/Kentucky/Monticello", America_Eastern },
             { "America/North_Dakota/Beulah", America_Central },
             { "America/North_Dakota/Center", America_Central },
             { "timezone.excity.Etc/Unknown", "\u1c75\u1c5f\u1c5d \u1c6a\u1c64\u1c71\u1c66\u1c5f\u1c79\u1c63 \u1c75\u1c5f\u1c61\u1c5f\u1c68" },
+            { "America/Argentina/Rio_Gallegos", Argentina },
             { "America/North_Dakota/New_Salem", America_Central },
         };
         return data;
