@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2022, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,7 +26,7 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
  * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
@@ -67,15 +67,15 @@ public class TimeZoneNames_sd_Deva extends TimeZoneNamesBundle {
     @Override
     protected final Object[][] getContents() {
         final String[] GMT = new String[] {
-               "\u0917\u094d\u0930\u0940\u0928 \u0935\u093f\u091a\u0941 \u092e\u0940\u0928 \u091f\u093e\u0907\u092e\u0941",
-               "",
-               "",
-               "",
+               "\u0917\u094d\u0930\u0940\u0928\u0935\u093f\u091a \u092e\u0940\u0928 \u0935\u0915\u094d\u0924\u0941",
+               "GMT",
                "",
+               "BST",
                "",
+               "GMT",
             };
         final String[] ETC_UTC = new String[] {
-               "\u0906\u0938\u094d\u0925\u093e\u0928\u0940 \u091a\u093e\u0932\u0942 \u091f\u093e\u0907\u092e\u0941",
+               "\u0917\u0926\u093f\u0952\u092f\u0932 \u0906\u0932\u092e\u0940 \u0935\u0915\u094d\u0924\u0941",
                "UTC",
                "",
                "",
@@ -83,68 +83,68 @@ public class TimeZoneNames_sd_Deva extends TimeZoneNamesBundle {
                "",
             };
         final String[] Atlantic = new String[] {
-               "\u0905\u0902\u091f\u0932\u093e\u0902\u091f\u093f\u0915 \u091c\u0947 \u092e\u0905\u092f\u093e\u0930\u0940 \u0935\u093e\u0930\u094b \u092d\u0947\u0930\u094b",
-               "",
-               "\u0905\u0902\u091f\u0932\u093e\u0902\u091f\u093f\u0915 \u091c\u0947 \u097e\u0940\u0902\u0939 \u0935\u093e\u0930\u094b \u092d\u0947\u0930\u094b",
-               "",
-               "\u0905\u091f\u0932\u093e\u0902\u091f\u093f\u0915 \u091f\u093e\u0907\u092e\u0941",
-               "",
+               "\u0905\u091f\u0932\u093e\u0902\u091f\u093f\u0915 \u092e\u0905\u092f\u093e\u0930\u0940 \u0935\u0915\u094d\u0924",
+               "AST",
+               "\u0905\u091f\u0932\u093e\u0902\u091f\u093f\u0915 \u0926\u0940\u0902\u0952\u0939 \u091c\u094b \u0935\u0915\u094d\u0924",
+               "ADT",
+               "\u0905\u091f\u0932\u093e\u0902\u091f\u093f\u0915 \u0935\u0915\u094d\u0924",
+               "AT",
             };
         final String[] Europe_Central = new String[] {
-               "\u0938\u0947\u0902\u091f\u0930\u0932\u0941 \u092f\u0942\u0930\u092a\u0940 \u092e\u092f\u0906\u0930\u0940 \u0935\u093e\u0930\u094b \u091f\u093e\u0907\u092e\u0941",
-               "",
-               "\u0938\u0947\u0902\u091f\u0930\u0932\u0941 \u092f\u0942\u0930\u092a\u0940 \u0917\u0930\u092e\u0940 \u0935\u093e\u0930\u094b \u091f\u093e\u0907\u092e\u0941",
-               "",
-               "\u0938\u0947\u0902\u091f\u0930\u0932\u0941 \u092f\u0942\u0930\u092a\u0940 \u091f\u093e\u0907\u092e\u0941",
-               "",
+               "\u092e\u0930\u0915\u091c\u093c\u0940 \u092f\u0942\u0930\u094b\u092a\u0940 \u092e\u0905\u092f\u093e\u0930\u0940 \u0935\u0915\u094d\u0924\u0941",
+               "CET",
+               "\u092e\u0930\u0915\u091c\u093c\u0940 \u092f\u0942\u0930\u094b\u092a\u0940 \u0909\u0928\u0939\u093e\u0930\u0947 \u091c\u094b \u0935\u0915\u094d\u0924\u0941",
+               "CEST",
+               "\u092e\u0930\u0915\u091c\u093c\u0940 \u092f\u0942\u0930\u094b\u092a\u0940 \u0935\u0915\u094d\u0924",
+               "CET",
             };
         final String[] Europe_Eastern = new String[] {
-               "\u0909\u092d\u093f\u0930\u0902\u0926\u094b \u092f\u0942\u0930\u094b\u092a\u0940 \u092e\u0905\u092f\u093e\u0930\u0940 \u0935\u093e\u0930\u094b \u0935\u0915\u094d\u0924\u0941",
-               "",
-               "\u0909\u092d\u093f\u0930\u0902\u0926\u094b \u092f\u0942\u0930\u094b\u092a\u0940 \u0917\u0930\u092e\u0940 \u0935\u093e\u0930\u094b \u0935\u0915\u094d\u0924\u0941",
-               "",
-               "\u0909\u092d\u093f\u0930\u0902\u0926\u094b \u092f\u0942\u0930\u094b\u092a\u0940 \u091f\u093e\u0907\u092e\u0941",
-               "",
+               "\u0913\u092d\u0930\u0940 \u092f\u0942\u0930\u094b\u092a\u0940 \u092e\u0905\u092f\u093e\u0930\u0940 \u0935\u0915\u094d\u0924\u0941",
+               "EET",
+               "\u0913\u092d\u0930\u0940 \u092f\u0942\u0930\u094b\u092a\u0940 \u0909\u0928\u0939\u093e\u0930\u0947 \u091c\u094b \u0935\u0915\u094d\u0924\u0941",
+               "EEST",
+               "\u0913\u092d\u0930\u0940 \u092f\u0942\u0930\u094b\u092a\u0940 \u0935\u0915\u094d\u0924\u0941",
+               "EET",
             };
         final String[] Europe_Western = new String[] {
-               "\u0909\u0932\u0939\u0902\u0926\u094b \u091c\u0947 \u092e\u0905\u092f\u093e\u0930\u0940 \u0935\u093e\u0930\u094b \u0935\u0915\u094d\u0924\u0941",
-               "",
-               "\u0909\u0932\u0939\u0902\u0926\u094b \u091c\u0947 \u092f\u0942\u0930\u094b\u092a\u0940\u0905 \u0917\u0930\u092e\u0940 \u0935\u093e\u0930\u094b \u0935\u0915\u094d\u0924\u0941",
-               "",
-               "\u0909\u0932\u0939\u0902\u0926\u094b \u0935\u093e\u0930\u094b \u092f\u0942\u0930\u094b\u092a\u0940 \u0935\u093e\u0930\u094b \u0935\u0915\u094d\u0924\u0941",
-               "",
+               "\u0909\u0932\u0939\u0902\u0926\u094b \u092f\u0942\u0930\u094b\u092a\u0940 \u092e\u0905\u092f\u093e\u0930\u0940 \u0935\u0915\u094d\u0924\u0941",
+               "FMT",
+               "\u0909\u0932\u0939\u0902\u0926\u094b \u092f\u0942\u0930\u094b\u092a\u0940 \u0909\u0928\u0939\u093e\u0930\u0947 \u091c\u094b \u0935\u0915\u094d\u0924\u0941",
+               "FMT",
+               "\u0909\u0932\u0939\u0902\u0926\u094b \u092f\u0942\u0930\u094b\u092a\u0940 \u0935\u0915\u094d\u0924\u0941",
+               "FMT",
             };
         final String[] America_Central = new String[] {
-               "\u0935\u093f\u091a\u094b \u092e\u0905\u092f\u093e\u0930\u0940 \u092d\u0947\u0930\u094b",
-               "",
-               "\u0935\u093f\u091a\u094b \u097e\u0940\u0902\u0939 \u0935\u093e\u0930\u094b \u092d\u0947\u0930\u094b",
-               "",
-               "\u0935\u093f\u091a\u094b \u092d\u0947\u0930\u094b",
-               "",
+               "\u092e\u0930\u0915\u091c\u093c\u0940 \u092e\u0905\u092f\u093e\u0930\u0940 \u0935\u0915\u094d\u0924",
+               "CST",
+               "\u092e\u0930\u0915\u091c\u093c\u0940 \u0926\u0940\u0902\u0952\u0939 \u091c\u094b \u0935\u0915\u094d\u0924",
+               "CDT",
+               "\u092e\u0930\u0915\u091c\u093c\u0940 \u0935\u0915\u094d\u0924",
+               "CT",
             };
         final String[] America_Eastern = new String[] {
-               "\u0909\u092d\u093f\u0930\u0902\u0926\u094b \u092e\u0905\u092f\u093e\u0930\u0940 \u0935\u093e\u0930\u094b \u092d\u0947\u0930\u094b",
-               "",
-               "\u0909\u092d\u093f\u0930\u0902\u0926\u094b \u0935\u093f\u091a\u094b \u0935\u093e\u0930\u094b \u092d\u0947\u0930\u094b",
-               "",
-               "\u0909\u092d\u093f\u0930\u0902\u0926\u094b \u092d\u0947\u0930\u094b",
-               "",
+               "\u0913\u092d\u0930\u0940 \u092e\u0905\u092f\u093e\u0930\u0940 \u0935\u0915\u094d\u0924",
+               "EST",
+               "\u0913\u092d\u0930\u0940 \u0926\u0940\u0902\u0952\u0939 \u091c\u094b \u0935\u0915\u094d\u0924",
+               "EST",
+               "\u0913\u092d\u0930\u0940 \u0935\u0915\u094d\u0924",
+               "EST",
             };
         final String[] America_Pacific = new String[] {
-               "\u092a\u0947\u0938\u0940\u092b\u093f\u0915 \u0935\u093e\u0930\u094b \u092e\u0905\u092f\u093e\u0930\u0940 \u0935\u093e\u0930\u094b \u092d\u0947\u0930\u094b",
-               "",
-               "\u092a\u0947\u0938\u0940\u092b\u093f\u0915 \u091c\u094b \u097e\u0940\u0902\u0939 \u0935\u093e\u0930\u094b \u092d\u0947\u0930\u094b",
-               "",
-               "\u092a\u0947\u0938\u0940\u092b\u093f\u0915 \u0935\u093e\u0930\u094b \u091f\u093e\u0907\u092e\u0941",
-               "",
+               "\u092a\u0947\u0938\u093f\u092b\u093f\u0915 \u092e\u0905\u092f\u093e\u0930\u0940 \u0935\u0915\u094d\u0924",
+               "PST",
+               "\u092a\u0947\u0938\u093f\u092b\u093f\u0915 \u0926\u0940\u0902\u0952\u0939 \u091c\u094b \u0935\u0915\u094d\u0924",
+               "PDT",
+               "\u092a\u0947\u0938\u093f\u092b\u093f\u0915 \u0935\u0915\u094d\u0924",
+               "PT",
             };
         final String[] America_Mountain = new String[] {
-               "\u091f\u0915\u0930\u0941 \u0935\u093e\u0930\u094b \u092e\u0905\u092f\u093e\u0930\u0940 \u092d\u0947\u0930\u094b",
-               "",
-               "\u091f\u0915\u0930\u0941 \u091c\u094b \u097e\u0940\u0902\u0939 \u0935\u093e\u0930\u094b \u092d\u0947\u0930\u094b",
-               "",
-               "\u091f\u0915\u0930\u0941 \u0935\u093e\u0930\u094b \u092d\u0947\u0930\u094b",
-               "",
+               "\u092a\u0939\u093e\u0921\u093c\u0940 \u092e\u0905\u092f\u093e\u0930\u0940 \u0935\u0915\u094d\u0924",
+               "MST",
+               "\u092a\u0939\u093e\u0921\u093c\u0940 \u0926\u0940\u0902\u0952\u0939 \u091c\u094b \u0935\u0915\u094d\u0924",
+               "MDT",
+               "\u092a\u0939\u093e\u0921\u093c\u0940 \u0935\u0915\u094d\u0924",
+               "MT",
             };
         final Object[][] data = new Object[][] {
             { "America/Los_Angeles", America_Pacific },
@@ -171,7 +171,6 @@ public class TimeZoneNames_sd_Deva extends TimeZoneNamesBundle {
             { "MST7MDT", America_Mountain },
             { "PST8PDT", America_Pacific },
             { "Asia/Gaza", Europe_Eastern },
-            { "Asia/Amman", Europe_Eastern },
             { "Africa/Lome", GMT },
             { "Asia/Beirut", Europe_Eastern },
             { "Asia/Hebron", Europe_Eastern },
@@ -198,7 +197,6 @@ public class TimeZoneNames_sd_Deva extends TimeZoneNamesBundle {
             { "America/Aruba", Atlantic },
             { "America/Boise", America_Mountain },
             { "America/Thule", Atlantic },
-            { "Asia/Damascus", Europe_Eastern },
             { "Europe/Athens", Europe_Eastern },
             { "Europe/Berlin", Europe_Central },
             { "Europe/Dublin", GMT },
@@ -221,7 +219,6 @@ public class TimeZoneNames_sd_Deva extends TimeZoneNamesBundle {
             { "America/Belize", America_Central },
             { "America/Cancun", America_Eastern },
             { "America/Cayman", America_Eastern },
-            { "America/Dawson", America_Mountain },
             { "America/Inuvik", America_Mountain },
             { "America/Merida", America_Central },
             { "America/Nassau", America_Eastern },
@@ -247,7 +244,7 @@ public class TimeZoneNames_sd_Deva extends TimeZoneNamesBundle {
             { "America/Marigot", Atlantic },
             { "America/Moncton", Atlantic },
             { "America/Nipigon", America_Eastern },
-            { "America/Ojinaga", America_Mountain },
+            { "America/Ojinaga", America_Central },
             { "America/Tijuana", America_Pacific },
             { "America/Toronto", America_Eastern },
             { "America/Tortola", Atlantic },
@@ -287,6 +284,7 @@ public class TimeZoneNames_sd_Deva extends TimeZoneNamesBundle {
             { "Europe/Podgorica", Europe_Central },
             { "Europe/Stockholm", Europe_Central },
             { "Africa/Nouakchott", GMT },
+            { "America/Chihuahua", America_Central },
             { "America/Glace_Bay", Atlantic },
             { "America/Goose_Bay", Atlantic },
             { "America/Guatemala", America_Central },
@@ -309,7 +307,6 @@ public class TimeZoneNames_sd_Deva extends TimeZoneNamesBundle {
             { "America/Martinique", Atlantic },
             { "America/Montserrat", Atlantic },
             { "America/St_Vincent", Atlantic },
-            { "America/Whitehorse", America_Mountain },
             { "Atlantic/Jan_Mayen", Europe_Central },
             { "Atlantic/Reykjavik", GMT },
             { "Atlantic/St_Helena", GMT },
@@ -331,6 +328,7 @@ public class TimeZoneNames_sd_Deva extends TimeZoneNamesBundle {
             { "America/Indiana/Knox", America_Central },
             { "America/Rankin_Inlet", America_Central },
             { "America/Cambridge_Bay", America_Mountain },
+            { "America/Ciudad_Juarez", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
             { "America/Indiana/Vevay", America_Eastern },
             { "America/Lower_Princes", Atlantic },
@@ -348,7 +346,7 @@ public class TimeZoneNames_sd_Deva extends TimeZoneNamesBundle {
             { "America/Kentucky/Monticello", America_Eastern },
             { "America/North_Dakota/Beulah", America_Central },
             { "America/North_Dakota/Center", America_Central },
-            { "timezone.excity.Etc/Unknown", "\u092c\u0947\u0916\u092c\u0930\u094b \u0936\u0939\u0930\u0941" },
+            { "timezone.excity.Etc/Unknown", "\u0905\u0923\u091c\u093e\u0952\u0924\u0932 \u0936\u0939\u0930\u0941" },
             { "America/North_Dakota/New_Salem", America_Central },
         };
         return data;
