@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2023, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -70,9 +70,9 @@ public class TimeZoneNames_sr_Cyrl_BA extends TimeZoneNamesBundle {
                "\u0421\u0440\u0435\u0434\u045a\u0435 \u0432\u0440\u0438\u0458\u0435\u043c\u0435 \u043f\u043e \u0413\u0440\u0438\u043d\u0438\u0447\u0443",
                "GMT",
                "",
+               "GMT",
                "",
-               "",
-               "",
+               "GMT",
             };
         final String[] Apia = new String[] {
                "\u0410\u043f\u0438\u0458\u0430, \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0434\u043d\u043e \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
@@ -92,11 +92,11 @@ public class TimeZoneNames_sr_Cyrl_BA extends TimeZoneNamesBundle {
             };
         final String[] Cuba = new String[] {
                "\u041a\u0443\u0431\u0430, \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0434\u043d\u043e \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
-               "",
+               "CST",
                "\u041a\u0443\u0431\u0430, \u0459\u0435\u0442\u045a\u0435 \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
-               "",
+               "CDT",
                "\u041a\u0443\u0431\u0430",
-               "",
+               "CT",
             };
         final String[] Fiji = new String[] {
                "\u0424\u0438\u045f\u0438, \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0434\u043d\u043e \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
@@ -180,11 +180,11 @@ public class TimeZoneNames_sr_Cyrl_BA extends TimeZoneNamesBundle {
             };
         final String[] China = new String[] {
                "\u041a\u0438\u043d\u0435\u0441\u043a\u043e \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0434\u043d\u043e \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
-               "",
+               "CST",
                "\u041a\u0438\u043d\u0430, \u0459\u0435\u0442\u045a\u0435 \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
-               "",
+               "CDT",
                "\u041a\u0438\u043d\u0430 \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
-               "",
+               "CT",
             };
         final String[] Cocos = new String[] {
                "\u041a\u043e\u043a\u043e\u0441\u043e\u0432\u0430 (\u041a\u0438\u043b\u0438\u043d\u0433) \u043e\u0441\u0442\u0440\u0432\u0430 \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
@@ -212,19 +212,19 @@ public class TimeZoneNames_sr_Cyrl_BA extends TimeZoneNamesBundle {
             };
         final String[] Japan = new String[] {
                "\u0408\u0430\u043f\u0430\u043d\u0441\u043a\u043e \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0434\u043d\u043e \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
-               "",
+               "JST",
                "\u0408\u0430\u043f\u0430\u043d\u0441\u043a\u043e \u0459\u0435\u0442\u045a\u0435 \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
-               "",
+               "JDT",
                "\u0408\u0430\u043f\u0430\u043d\u0441\u043a\u043e \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
-               "",
+               "JT",
             };
         final String[] Korea = new String[] {
                "\u041a\u043e\u0440\u0435\u0458\u0441\u043a\u043e \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0434\u043d\u043e \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
-               "",
+               "KST",
                "\u041a\u043e\u0440\u0435\u0458\u0441\u043a\u043e \u0459\u0435\u0442\u045a\u0435 \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
-               "",
+               "KST",
                "\u041a\u043e\u0440\u0435\u0458\u0441\u043a\u043e \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
-               "",
+               "KST",
             };
         final String[] Nauru = new String[] {
                "\u041d\u0430\u0443\u0440\u0443 \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
@@ -252,11 +252,11 @@ public class TimeZoneNames_sr_Cyrl_BA extends TimeZoneNamesBundle {
             };
         final String[] Samoa = new String[] {
                "\u0421\u0430\u043c\u043e\u0430, \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0434\u043d\u043e \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
-               "",
+               "SST",
                "\u0421\u0430\u043c\u043e\u0430, \u0459\u0435\u0442\u045a\u0435 \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
-               "",
+               "SST",
                "\u0421\u0430\u043c\u043e\u0430 \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
-               "",
+               "SST",
             };
         final String[] Syowa = new String[] {
                "\u0428\u043e\u0432\u0430 \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
@@ -292,11 +292,11 @@ public class TimeZoneNames_sr_Cyrl_BA extends TimeZoneNamesBundle {
             };
         final String[] Azores = new String[] {
                "\u0410\u0437\u043e\u0440\u0438, \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0434\u043d\u043e \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
-               "",
+               "HMT",
                "\u0410\u0437\u043e\u0440\u0438, \u0459\u0435\u0442\u045a\u0435 \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
-               "",
+               "HMT",
                "\u0410\u0437\u043e\u0440\u0438 \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
-               "",
+               "HMT",
             };
         final String[] Bhutan = new String[] {
                "\u0411\u0443\u0442\u0430\u043d \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
@@ -332,11 +332,11 @@ public class TimeZoneNames_sr_Cyrl_BA extends TimeZoneNamesBundle {
             };
         final String[] Israel = new String[] {
                "\u0418\u0437\u0440\u0430\u0435\u043b\u0441\u043a\u043e \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0434\u043d\u043e \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
-               "",
+               "IST",
                "\u0418\u0437\u0440\u0430\u0435\u043b\u0441\u043a\u043e \u0459\u0435\u0442\u045a\u0435 \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
-               "",
+               "IDT",
                "\u0418\u0437\u0440\u0430\u0435\u043b\u0441\u043a\u043e \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
-               "",
+               "IT",
             };
         final String[] Kosrae = new String[] {
                "\u041a\u043e\u0448\u0440\u0435 \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
@@ -356,11 +356,11 @@ public class TimeZoneNames_sr_Cyrl_BA extends TimeZoneNamesBundle {
             };
         final String[] Moscow = new String[] {
                "\u041c\u043e\u0441\u043a\u0432\u0430, \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0434\u043d\u043e \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
-               "",
+               "MSK",
                "\u041c\u043e\u0441\u043a\u0432\u0430, \u0459\u0435\u0442\u045a\u0435 \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
-               "",
+               "MSK",
                "\u041c\u043e\u0441\u043a\u0432\u0430 \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
-               "",
+               "MSK",
             };
         final String[] Ponape = new String[] {
                "\u041f\u043e\u043d\u043f\u0435\u0458 \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
@@ -380,11 +380,11 @@ public class TimeZoneNames_sr_Cyrl_BA extends TimeZoneNamesBundle {
             };
         final String[] Taipei = new String[] {
                "\u0422\u0430\u0458\u043f\u0435\u0458, \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0434\u043d\u043e \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
-               "",
+               "CST",
                "\u0422\u0430\u0458\u043f\u0435\u0458, \u0459\u0435\u0442\u045a\u0435 \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
-               "",
+               "CDT",
                "\u0422\u0430\u0458\u043f\u0435\u0458 \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
-               "",
+               "CT",
             };
         final String[] Tuvalu = new String[] {
                "\u0422\u0443\u0432\u0430\u043b\u0443 \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
@@ -572,11 +572,11 @@ public class TimeZoneNames_sr_Cyrl_BA extends TimeZoneNamesBundle {
             };
         final String[] Atlantic = new String[] {
                "\u0410\u0442\u043b\u0430\u043d\u0442\u0441\u043a\u043e \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0434\u043d\u043e \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
-               "",
+               "AST",
                "\u0410\u0442\u043b\u0430\u043d\u0442\u0441\u043a\u043e \u0459\u0435\u0442\u045a\u0435 \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
-               "",
+               "ADT",
                "\u0410\u0442\u043b\u0430\u043d\u0442\u0441\u043a\u043e \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
-               "",
+               "AT",
             };
         final String[] Brasilia = new String[] {
                "\u0411\u0440\u0430\u0437\u0438\u043b\u0438\u0458\u0430, \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0434\u043d\u043e \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
@@ -588,11 +588,11 @@ public class TimeZoneNames_sr_Cyrl_BA extends TimeZoneNamesBundle {
             };
         final String[] Chamorro = new String[] {
                "\u0427\u0430\u043c\u043e\u0440\u043e \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
+               "ChST",
                "",
+               "ChST",
                "",
-               "",
-               "",
-               "",
+               "ChST",
             };
         final String[] Colombia = new String[] {
                "\u041a\u043e\u043b\u0443\u043c\u0431\u0438\u0458\u0430, \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0434\u043d\u043e \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
@@ -636,11 +636,11 @@ public class TimeZoneNames_sr_Cyrl_BA extends TimeZoneNamesBundle {
             };
         final String[] Pakistan = new String[] {
                "\u041f\u0430\u043a\u0438\u0441\u0442\u0430\u043d, \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0434\u043d\u043e \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
-               "",
+               "PKT",
                "\u041f\u0430\u043a\u0438\u0441\u0442\u0430\u043d, \u0459\u0435\u0442\u045a\u0435 \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
-               "",
+               "PKST",
                "\u041f\u0430\u043a\u0438\u0441\u0442\u0430\u043d \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
-               "",
+               "PKT",
             };
         final String[] Paraguay = new String[] {
                "\u041f\u0430\u0440\u0430\u0433\u0432\u0430\u0458, \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0434\u043d\u043e \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
@@ -700,11 +700,11 @@ public class TimeZoneNames_sr_Cyrl_BA extends TimeZoneNamesBundle {
             };
         final String[] Hong_Kong = new String[] {
                "\u0425\u043e\u043d\u0433 \u041a\u043e\u043d\u0433, \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0434\u043d\u043e \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
-               "",
+               "HKT",
                "\u0425\u043e\u043d\u0433 \u041a\u043e\u043d\u0433, \u0459\u0435\u0442\u045a\u0435 \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
-               "",
+               "HKST",
                "\u0425\u043e\u043d\u0433 \u041a\u043e\u043d\u0433 \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
-               "",
+               "HKT",
             };
         final String[] Indochina = new String[] {
                "\u0418\u043d\u0434\u043e\u043a\u0438\u043d\u0430 \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
@@ -764,11 +764,11 @@ public class TimeZoneNames_sr_Cyrl_BA extends TimeZoneNamesBundle {
             };
         final String[] Volgograd = new String[] {
                "\u0412\u043e\u043b\u0433\u043e\u0433\u0440\u0430\u0434, \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0434\u043d\u043e \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
-               "",
+               "MSK",
                "\u0412\u043e\u043b\u0433\u043e\u0433\u0440\u0430\u0434, \u0459\u0435\u0442\u045a\u0435 \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
-               "",
+               "MSK",
                "\u0412\u043e\u043b\u0433\u043e\u0433\u0440\u0430\u0434 \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
-               "",
+               "MSK",
             };
         final String[] Azerbaijan = new String[] {
                "\u0410\u0437\u0435\u0440\u0431\u0435\u0458\u045f\u0430\u043d, \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0434\u043d\u043e \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
@@ -844,11 +844,11 @@ public class TimeZoneNames_sr_Cyrl_BA extends TimeZoneNamesBundle {
             };
         final String[] New_Zealand = new String[] {
                "\u041d\u043e\u0432\u0438 \u0417\u0435\u043b\u0430\u043d\u0434, \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0434\u043d\u043e \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
-               "",
+               "NZST",
                "\u041d\u043e\u0432\u0438 \u0417\u0435\u043b\u0430\u043d\u0434, \u0459\u0435\u0442\u045a\u0435 \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
-               "",
+               "NZDT",
                "\u041d\u043e\u0432\u0438 \u0417\u0435\u043b\u0430\u043d\u0434 \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
-               "",
+               "NZT",
             };
         final String[] Novosibirsk = new String[] {
                "\u041d\u043e\u0432\u043e\u0441\u0438\u0431\u0438\u0440\u0441\u043a, \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0434\u043d\u043e \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
@@ -860,11 +860,11 @@ public class TimeZoneNames_sr_Cyrl_BA extends TimeZoneNamesBundle {
             };
         final String[] Philippines = new String[] {
                "\u0424\u0438\u043b\u0438\u043f\u0438\u043d\u0438, \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0434\u043d\u043e \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
-               "",
+               "PST",
                "\u0424\u0438\u043b\u0438\u043f\u0438\u043d\u0438, \u0459\u0435\u0442\u045a\u0435 \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
-               "",
+               "PDT",
                "\u0424\u0438\u043b\u0438\u043f\u0438\u043d\u0438 \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
-               "",
+               "PT",
             };
         final String[] Vladivostok = new String[] {
                "\u0412\u043b\u0430\u0434\u0438\u0432\u043e\u0441\u0442\u043e\u043a, \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0434\u043d\u043e \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
@@ -892,11 +892,11 @@ public class TimeZoneNames_sr_Cyrl_BA extends TimeZoneNamesBundle {
             };
         final String[] Newfoundland = new String[] {
                "\u040a\u0443\u0444\u0430\u0443\u043d\u0434\u043b\u0435\u043d\u0434, \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0434\u043d\u043e \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
-               "",
+               "NST",
                "\u040a\u0443\u0444\u0430\u0443\u043d\u0434\u043b\u0435\u043d\u0434, \u0459\u0435\u0442\u045a\u0435 \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
-               "",
+               "NDT",
                "\u040a\u0443\u0444\u0430\u0443\u043d\u0434\u043b\u0435\u043d\u0434",
-               "",
+               "NT",
             };
         final String[] Turkmenistan = new String[] {
                "\u0422\u0443\u0440\u043a\u043c\u0435\u043d\u0438\u0441\u0442\u0430\u043d, \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0434\u043d\u043e \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
@@ -940,27 +940,27 @@ public class TimeZoneNames_sr_Cyrl_BA extends TimeZoneNamesBundle {
             };
         final String[] Africa_Central = new String[] {
                "\u0426\u0435\u043d\u0442\u0440\u0430\u043b\u043d\u043e-\u0430\u0444\u0440\u0438\u0447\u043a\u043e \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
+               "SAST",
                "",
+               "SAST",
                "",
-               "",
-               "",
-               "",
+               "SAST",
             };
         final String[] Africa_Eastern = new String[] {
                "\u0418\u0441\u0442\u043e\u0447\u043d\u043e-\u0430\u0444\u0440\u0438\u0447\u043a\u043e \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
+               "EAT",
                "",
+               "EAT",
                "",
-               "",
-               "",
-               "",
+               "EAT",
             };
         final String[] Africa_Western = new String[] {
                "\u0417\u0430\u043f\u0430\u0434\u043d\u043e-\u0430\u0444\u0440\u0438\u0447\u043a\u043e \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0434\u043d\u043e \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
-               "",
+               "WAT",
                "\u0417\u0430\u043f\u0430\u0434\u043d\u043e-\u0430\u0444\u0440\u0438\u0447\u043a\u043e \u0459\u0435\u0442\u045a\u0435 \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
-               "",
+               "WAT",
                "\u0417\u0430\u043f\u0430\u0434\u043d\u043e-\u0430\u0444\u0440\u0438\u0447\u043a\u043e \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
-               "",
+               "WAT",
             };
         final String[] DumontDUrville = new String[] {
                "\u0414\u0438\u043c\u043e\u043d \u0434\u2019\u0418\u0440\u0432\u0438\u043b \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
@@ -996,43 +996,43 @@ public class TimeZoneNames_sr_Cyrl_BA extends TimeZoneNamesBundle {
             };
         final String[] Mexico_Pacific = new String[] {
                "\u041c\u0435\u043a\u0441\u0438\u0447\u043a\u0438 \u041f\u0430\u0446\u0438\u0444\u0438\u043a, \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0434\u043d\u043e \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
-               "",
+               "MST",
                "\u041c\u0435\u043a\u0441\u0438\u0447\u043a\u0438 \u041f\u0430\u0446\u0438\u0444\u0438\u043a, \u0459\u0435\u0442\u045a\u0435 \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
-               "",
+               "MDT",
                "\u041c\u0435\u043a\u0441\u0438\u0447\u043a\u0438 \u041f\u0430\u0446\u0438\u0444\u0438\u043a",
-               "",
+               "MT",
             };
         final String[] Africa_Southern = new String[] {
                "\u0408\u0443\u0436\u043d\u043e-\u0430\u0444\u0440\u0438\u0447\u043a\u043e \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
+               "SAST",
                "",
+               "SAST",
                "",
-               "",
-               "",
-               "",
+               "SAST",
             };
         final String[] America_Central = new String[] {
                "\u0421\u0458\u0435\u0432\u0435\u0440\u043d\u043e\u0430\u043c\u0435\u0440\u0438\u0447\u043a\u043e \u0446\u0435\u043d\u0442\u0440\u0430\u043b\u043d\u043e \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0434\u043d\u043e \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
-               "",
+               "CST",
                "\u0421\u0458\u0435\u0432\u0435\u0440\u043d\u043e\u0430\u043c\u0435\u0440\u0438\u0447\u043a\u043e \u0446\u0435\u043d\u0442\u0440\u0430\u043b\u043d\u043e \u0459\u0435\u0442\u045a\u0435 \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
-               "",
+               "CDT",
                "\u0421\u0458\u0435\u0432\u0435\u0440\u043d\u043e\u0430\u043c\u0435\u0440\u0438\u0447\u043a\u043e \u0446\u0435\u043d\u0442\u0440\u0430\u043b\u043d\u043e \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
-               "",
+               "CT",
             };
         final String[] America_Eastern = new String[] {
                "\u0421\u0458\u0435\u0432\u0435\u0440\u043d\u043e\u0430\u043c\u0435\u0440\u0438\u0447\u043a\u043e \u0438\u0441\u0442\u043e\u0447\u043d\u043e \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0434\u043d\u043e \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
-               "",
+               "EST",
                "\u0421\u0458\u0435\u0432\u0435\u0440\u043d\u043e\u0430\u043c\u0435\u0440\u0438\u0447\u043a\u043e \u0438\u0441\u0442\u043e\u0447\u043d\u043e \u0459\u0435\u0442\u045a\u0435 \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
-               "",
+               "EST",
                "\u0421\u0458\u0435\u0432\u0435\u0440\u043d\u043e\u0430\u043c\u0435\u0440\u0438\u0447\u043a\u043e \u0438\u0441\u0442\u043e\u0447\u043d\u043e \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
-               "",
+               "EST",
             };
         final String[] America_Pacific = new String[] {
                "\u0421\u0458\u0435\u0432\u0435\u0440\u043d\u043e\u0430\u043c\u0435\u0440\u0438\u0447\u043a\u043e \u043f\u0430\u0446\u0438\u0444\u0438\u0447\u043a\u043e \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0434\u043d\u043e \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
-               "",
+               "PST",
                "\u0421\u0458\u0435\u0432\u0435\u0440\u043d\u043e\u0430\u043c\u0435\u0440\u0438\u0447\u043a\u043e \u043f\u0430\u0446\u0438\u0444\u0438\u0447\u043a\u043e \u043b\u0435\u0442\u045a\u0435 \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
-               "",
+               "PDT",
                "\u0421\u0458\u0435\u0432\u0435\u0440\u043d\u043e\u0430\u043c\u0435\u0440\u0438\u0447\u043a\u043e \u043f\u0430\u0446\u0438\u0444\u0438\u0447\u043a\u043e \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
-               "",
+               "PT",
             };
         final String[] French_Southern = new String[] {
                "\u0424\u0440\u0430\u043d\u0446\u0443\u0441\u043a\u043e \u0458\u0443\u0436\u043d\u043e \u0438 \u0430\u043d\u0442\u0430\u0440\u043a\u0442\u0438\u0447\u043a\u043e \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
@@ -1052,11 +1052,11 @@ public class TimeZoneNames_sr_Cyrl_BA extends TimeZoneNamesBundle {
             };
         final String[] Hawaii_Aleutian = new String[] {
                "\u0425\u0430\u0432\u0430\u0458\u0441\u043a\u043e-\u0430\u043b\u0435\u0443\u0442\u0441\u043a\u043e \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0434\u043d\u043e \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
-               "",
+               "HST",
                "\u0425\u0430\u0432\u0430\u0458\u0441\u043a\u043e-\u0430\u043b\u0435\u0443\u0442\u0441\u043a\u043e \u0459\u0435\u0442\u045a\u0435 \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
-               "",
+               "HST",
                "\u0425\u0430\u0432\u0430\u0458\u0441\u043a\u043e-\u0430\u043b\u0435\u0443\u0442\u0441\u043a\u043e \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
-               "",
+               "HST",
             };
         final String[] Phoenix_Islands = new String[] {
                "\u0424\u0435\u043d\u0438\u043a\u0441 \u043e\u0441\u0442\u0440\u0432\u0430 \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
@@ -1076,11 +1076,11 @@ public class TimeZoneNames_sr_Cyrl_BA extends TimeZoneNamesBundle {
             };
         final String[] America_Mountain = new String[] {
                "\u0421\u0458\u0435\u0432\u0435\u0440\u043d\u043e\u0430\u043c\u0435\u0440\u0438\u0447\u043a\u043e \u043f\u043b\u0430\u043d\u0438\u043d\u0441\u043a\u043e \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0434\u043d\u043e \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
-               "",
+               "MST",
                "\u0421\u0458\u0435\u0432\u0435\u0440\u043d\u043e\u0430\u043c\u0435\u0440\u0438\u0447\u043a\u043e \u043f\u043b\u0430\u043d\u0438\u043d\u0441\u043a\u043e \u0459\u0435\u0442\u045a\u0435 \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
-               "",
+               "MDT",
                "\u0421\u0458\u0435\u0432\u0435\u0440\u043d\u043e\u0430\u043c\u0435\u0440\u0438\u0447\u043a\u043e \u043f\u043b\u0430\u043d\u0438\u043d\u0441\u043a\u043e \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
-               "",
+               "MT",
             };
         final String[] Marshall_Islands = new String[] {
                "\u041c\u0430\u0440\u0448\u0430\u043b\u0441\u043a\u0430 \u041e\u0441\u0442\u0440\u0432\u0430 \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
@@ -1108,19 +1108,19 @@ public class TimeZoneNames_sr_Cyrl_BA extends TimeZoneNamesBundle {
             };
         final String[] Australia_Central = new String[] {
                "\u0410\u0443\u0441\u0442\u0440\u0430\u043b\u0438\u0458\u0441\u043a\u043e \u0446\u0435\u043d\u0442\u0440\u0430\u043b\u043d\u043e \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0434\u043d\u043e \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
-               "",
+               "ACST",
                "\u0410\u0443\u0441\u0442\u0440\u0430\u043b\u0438\u0458\u0441\u043a\u043e \u0446\u0435\u043d\u0442\u0440\u0430\u043b\u043d\u043e \u0459\u0435\u0442\u045a\u0435 \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
-               "",
+               "ACDT",
                "\u0410\u0443\u0441\u0442\u0440\u0430\u043b\u0438\u0458\u0441\u043a\u043e \u0446\u0435\u043d\u0442\u0440\u0430\u043b\u043d\u043e \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
-               "",
+               "ACT",
             };
         final String[] Australia_Eastern = new String[] {
                "\u0410\u0443\u0441\u0442\u0440\u0430\u043b\u0438\u0458\u0441\u043a\u043e \u0438\u0441\u0442\u043e\u0447\u043d\u043e \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0434\u043d\u043e \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
-               "",
+               "AEST",
                "\u0410\u0443\u0441\u0442\u0440\u0430\u043b\u0438\u0458\u0441\u043a\u043e \u0438\u0441\u0442\u043e\u0447\u043d\u043e \u0459\u0435\u0442\u045a\u0435 \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
-               "",
+               "AEDT",
                "\u0410\u0443\u0441\u0442\u0440\u0430\u043b\u0438\u0458\u0441\u043a\u043e \u0438\u0441\u0442\u043e\u0447\u043d\u043e \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
-               "",
+               "AET",
             };
         final String[] Australia_Western = new String[] {
                "\u0410\u0443\u0441\u0442\u0440\u0430\u043b\u0438\u0458\u0441\u043a\u043e \u0437\u0430\u043f\u0430\u0434\u043d\u043e \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0434\u043d\u043e \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
@@ -1148,27 +1148,27 @@ public class TimeZoneNames_sr_Cyrl_BA extends TimeZoneNamesBundle {
             };
         final String[] Indonesia_Central = new String[] {
                "\u0426\u0435\u043d\u0442\u0440\u0430\u043b\u043d\u043e-\u0438\u043d\u0434\u043e\u043d\u0435\u0437\u0438\u0458\u0441\u043a\u043e \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
+               "WITA",
                "",
+               "WITA",
                "",
-               "",
-               "",
-               "",
+               "WITA",
             };
         final String[] Indonesia_Eastern = new String[] {
                "\u0418\u0441\u0442\u043e\u0447\u043d\u043e-\u0438\u043d\u0434\u043e\u043d\u0435\u0437\u0438\u0458\u0441\u043a\u043e \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
+               "WIT",
                "",
+               "WIT",
                "",
-               "",
-               "",
-               "",
+               "WIT",
             };
         final String[] Indonesia_Western = new String[] {
                "\u0417\u0430\u043f\u0430\u0434\u043d\u043e-\u0438\u043d\u0434\u043e\u043d\u0435\u0437\u0438\u0458\u0441\u043a\u043e \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
+               "WIB",
                "",
+               "WIB",
                "",
-               "",
-               "",
-               "",
+               "WIB",
             };
         final String[] Kazakhstan_Eastern = new String[] {
                "\u0418\u0441\u0442\u043e\u0447\u043d\u043e-\u043a\u0430\u0437\u0430\u0445\u0441\u0442\u0430\u043d\u0441\u043a\u043e \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
@@ -1357,9 +1357,9 @@ public class TimeZoneNames_sr_Cyrl_BA extends TimeZoneNamesBundle {
                     "\u0421\u0440\u0435\u0434\u045a\u0435 \u0432\u0440\u0438\u0458\u0435\u043c\u0435 \u043f\u043e \u0413\u0440\u0438\u043d\u0438\u0447\u0443",
                     "GMT",
                     "\u0418\u0440\u0441\u043a\u0430, \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0434\u043d\u043e \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
+                    "IST",
                     "",
-                    "",
-                    "",
+                    "GMT",
                 }
             },
             { "Europe/Jersey", GMT },
@@ -1369,9 +1369,9 @@ public class TimeZoneNames_sr_Cyrl_BA extends TimeZoneNamesBundle {
                     "\u0421\u0440\u0435\u0434\u045a\u0435 \u0432\u0440\u0438\u0458\u0435\u043c\u0435 \u043f\u043e \u0413\u0440\u0438\u043d\u0438\u0447\u0443",
                     "GMT",
                     "\u0411\u0440\u0438\u0442\u0430\u043d\u0438\u0458\u0430, \u0459\u0435\u0442\u045a\u0435 \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
+                    "BST",
                     "",
-                    "",
-                    "",
+                    "GMT",
                 }
             },
             { "Europe/Madrid", Europe_Central },
@@ -1428,9 +1428,9 @@ public class TimeZoneNames_sr_Cyrl_BA extends TimeZoneNamesBundle {
                     "\u0421\u0440\u0435\u0434\u045a\u0435 \u0432\u0440\u0438\u0458\u0435\u043c\u0435 \u043f\u043e \u0413\u0440\u0438\u043d\u0438\u0447\u0443",
                     "GMT",
                     "\u0411\u0440\u0438\u0442\u0430\u043d\u0438\u0458\u0430, \u0459\u0435\u0442\u045a\u0435 \u0432\u0440\u0438\u0458\u0435\u043c\u0435",
+                    "BST",
                     "",
-                    "",
-                    "",
+                    "GMT",
                 }
             },
             { "Europe/Tallinn", Europe_Eastern },
