@@ -70,9 +70,9 @@ public class TimeZoneNames_sr_Latn extends TimeZoneNamesBundle {
                "Srednje vreme po Grini\u010du",
                "GMT",
                "",
+               "GMT",
                "",
-               "",
-               "",
+               "GMT",
             };
         final String[] Acre = new String[] {
                "Akre standardno vreme",
@@ -100,11 +100,11 @@ public class TimeZoneNames_sr_Latn extends TimeZoneNamesBundle {
             };
         final String[] Cuba = new String[] {
                "Kuba, standardno vreme",
-               "",
+               "CST",
                "Kuba, letnje vreme",
-               "",
+               "CDT",
                "Kuba",
-               "",
+               "CT",
             };
         final String[] Fiji = new String[] {
                "Fid\u017ei, standardno vreme",
@@ -188,11 +188,11 @@ public class TimeZoneNames_sr_Latn extends TimeZoneNamesBundle {
             };
         final String[] China = new String[] {
                "Kinesko standardno vreme",
-               "",
+               "CST",
                "Kina, letnje vreme",
-               "",
+               "CDT",
                "Kina vreme",
-               "",
+               "CT",
             };
         final String[] Cocos = new String[] {
                "Kokos (Keling) Ostrva vreme",
@@ -220,19 +220,19 @@ public class TimeZoneNames_sr_Latn extends TimeZoneNamesBundle {
             };
         final String[] Japan = new String[] {
                "Japansko standardno vreme",
-               "",
+               "JST",
                "Japansko letnje vreme",
-               "",
+               "JDT",
                "Japansko vreme",
-               "",
+               "JT",
             };
         final String[] Korea = new String[] {
                "Korejsko standardno vreme",
-               "",
+               "KST",
                "Korejsko letnje vreme",
-               "",
+               "KST",
                "Korejsko vreme",
-               "",
+               "KST",
             };
         final String[] Nauru = new String[] {
                "Nauru vreme",
@@ -260,11 +260,11 @@ public class TimeZoneNames_sr_Latn extends TimeZoneNamesBundle {
             };
         final String[] Samoa = new String[] {
                "Samoa, standardno vreme",
-               "",
+               "SST",
                "Samoa, letnje vreme",
-               "",
+               "SST",
                "Samoa vreme",
-               "",
+               "SST",
             };
         final String[] Syowa = new String[] {
                "\u0160ova vreme",
@@ -284,11 +284,11 @@ public class TimeZoneNames_sr_Latn extends TimeZoneNamesBundle {
             };
         final String[] Yukon = new String[] {
                "Jukon",
+               "MST",
                "",
+               "MST",
                "",
-               "",
-               "",
-               "",
+               "MST",
             };
         final String[] Alaska = new String[] {
                "Aljaska, standardno vreme",
@@ -316,11 +316,11 @@ public class TimeZoneNames_sr_Latn extends TimeZoneNamesBundle {
             };
         final String[] Azores = new String[] {
                "Azori, standardno vreme",
-               "",
+               "HMT",
                "Azori, letnje vreme",
-               "",
+               "HMT",
                "Azori vreme",
-               "",
+               "HMT",
             };
         final String[] Bhutan = new String[] {
                "Butan vreme",
@@ -356,11 +356,11 @@ public class TimeZoneNames_sr_Latn extends TimeZoneNamesBundle {
             };
         final String[] Israel = new String[] {
                "Izraelsko standardno vreme",
-               "",
+               "IST",
                "Izraelsko letnje vreme",
-               "",
+               "IDT",
                "Izraelsko vreme",
-               "",
+               "IT",
             };
         final String[] Kosrae = new String[] {
                "Ko\u0161re vreme",
@@ -380,11 +380,11 @@ public class TimeZoneNames_sr_Latn extends TimeZoneNamesBundle {
             };
         final String[] Moscow = new String[] {
                "Moskva, standardno vreme",
-               "",
+               "MSK",
                "Moskva, letnje vreme",
-               "",
+               "MSK",
                "Moskva vreme",
-               "",
+               "MSK",
             };
         final String[] Ponape = new String[] {
                "Ponpej vreme",
@@ -412,11 +412,11 @@ public class TimeZoneNames_sr_Latn extends TimeZoneNamesBundle {
             };
         final String[] Taipei = new String[] {
                "Tajpej, standardno vreme",
-               "",
+               "CST",
                "Tajpej, letnje vreme",
-               "",
+               "CDT",
                "Tajpej vreme",
-               "",
+               "CT",
             };
         final String[] Tuvalu = new String[] {
                "Tuvalu vreme",
@@ -604,11 +604,11 @@ public class TimeZoneNames_sr_Latn extends TimeZoneNamesBundle {
             };
         final String[] Atlantic = new String[] {
                "Atlantsko standardno vreme",
-               "",
+               "AST",
                "Atlantsko letnje vreme",
-               "",
+               "ADT",
                "Atlantsko vreme",
-               "",
+               "AT",
             };
         final String[] Brasilia = new String[] {
                "Brazilija, standardno vreme",
@@ -620,11 +620,11 @@ public class TimeZoneNames_sr_Latn extends TimeZoneNamesBundle {
             };
         final String[] Chamorro = new String[] {
                "\u010camoro vreme",
+               "ChST",
                "",
+               "ChST",
                "",
-               "",
-               "",
-               "",
+               "ChST",
             };
         final String[] Colombia = new String[] {
                "Kolumbija, standardno vreme",
@@ -668,11 +668,11 @@ public class TimeZoneNames_sr_Latn extends TimeZoneNamesBundle {
             };
         final String[] Pakistan = new String[] {
                "Pakistan, standardno vreme",
-               "",
+               "PKT",
                "Pakistan, letnje vreme",
-               "",
+               "PKST",
                "Pakistan vreme",
-               "",
+               "PKT",
             };
         final String[] Paraguay = new String[] {
                "Paragvaj, standardno vreme",
@@ -732,11 +732,11 @@ public class TimeZoneNames_sr_Latn extends TimeZoneNamesBundle {
             };
         final String[] Hong_Kong = new String[] {
                "Hong Kong, standardno vreme",
-               "",
+               "HKT",
                "Hong Kong, letnje vreme",
-               "",
+               "HKST",
                "Hong Kong vreme",
-               "",
+               "HKT",
             };
         final String[] Indochina = new String[] {
                "Indokina vreme",
@@ -804,11 +804,11 @@ public class TimeZoneNames_sr_Latn extends TimeZoneNamesBundle {
             };
         final String[] Volgograd = new String[] {
                "Volgograd, standardno vreme",
-               "",
+               "MSK",
                "Volgograd, letnje vreme",
-               "",
+               "MSK",
                "Volgograd vreme",
-               "",
+               "MSK",
             };
         final String[] Azerbaijan = new String[] {
                "Azerbejd\u017ean, standardno vreme",
@@ -884,11 +884,11 @@ public class TimeZoneNames_sr_Latn extends TimeZoneNamesBundle {
             };
         final String[] New_Zealand = new String[] {
                "Novi Zeland, standardno vreme",
-               "",
+               "NZST",
                "Novi Zeland, letnje vreme",
-               "",
+               "NZDT",
                "Novi Zeland vreme",
-               "",
+               "NZT",
             };
         final String[] Novosibirsk = new String[] {
                "Novosibirsk, standardno vreme",
@@ -900,11 +900,11 @@ public class TimeZoneNames_sr_Latn extends TimeZoneNamesBundle {
             };
         final String[] Philippines = new String[] {
                "Filipini, standardno vreme",
-               "",
+               "PST",
                "Filipini, letnje vreme",
-               "",
+               "PDT",
                "Filipini vreme",
-               "",
+               "PT",
             };
         final String[] Vladivostok = new String[] {
                "Vladivostok, standardno vreme",
@@ -932,11 +932,11 @@ public class TimeZoneNames_sr_Latn extends TimeZoneNamesBundle {
             };
         final String[] Newfoundland = new String[] {
                "Njufaundlend, standardno vreme",
-               "",
+               "NST",
                "Njufaundlend, letnje vreme",
-               "",
+               "NDT",
                "Njufaundlend",
-               "",
+               "NT",
             };
         final String[] Turkmenistan = new String[] {
                "Turkmenistan, standardno vreme",
@@ -980,27 +980,27 @@ public class TimeZoneNames_sr_Latn extends TimeZoneNamesBundle {
             };
         final String[] Africa_Central = new String[] {
                "Centralno-afri\u010dko vreme",
+               "SAST",
                "",
+               "SAST",
                "",
-               "",
-               "",
-               "",
+               "SAST",
             };
         final String[] Africa_Eastern = new String[] {
                "Isto\u010dno-afri\u010dko vreme",
+               "EAT",
                "",
+               "EAT",
                "",
-               "",
-               "",
-               "",
+               "EAT",
             };
         final String[] Africa_Western = new String[] {
                "Zapadno-afri\u010dko standardno vreme",
-               "",
+               "WAT",
                "Zapadno-afri\u010dko letnje vreme",
-               "",
+               "WAT",
                "Zapadno-afri\u010dko vreme",
-               "",
+               "WAT",
             };
         final String[] DumontDUrville = new String[] {
                "Dimon d\u2019Urvil vreme",
@@ -1036,43 +1036,43 @@ public class TimeZoneNames_sr_Latn extends TimeZoneNamesBundle {
             };
         final String[] Mexico_Pacific = new String[] {
                "Meksi\u010dki Pacifik, standardno vreme",
-               "",
+               "MST",
                "Meksi\u010dki Pacifik, letnje vreme",
-               "",
+               "MDT",
                "Meksi\u010dki Pacifik",
-               "",
+               "MT",
             };
         final String[] Africa_Southern = new String[] {
                "Ju\u017eno-afri\u010dko vreme",
+               "SAST",
                "",
+               "SAST",
                "",
-               "",
-               "",
-               "",
+               "SAST",
             };
         final String[] America_Central = new String[] {
                "Severnoameri\u010dko centralno standardno vreme",
-               "",
+               "CST",
                "Severnoameri\u010dko centralno letnje vreme",
-               "",
+               "CDT",
                "Severnoameri\u010dko centralno vreme",
-               "",
+               "CT",
             };
         final String[] America_Eastern = new String[] {
                "Severnoameri\u010dko isto\u010dno standardno vreme",
-               "",
+               "EST",
                "Severnoameri\u010dko isto\u010dno letnje vreme",
-               "",
+               "EST",
                "Severnoameri\u010dko isto\u010dno vreme",
-               "",
+               "EST",
             };
         final String[] America_Pacific = new String[] {
                "Severnoameri\u010dko pacifi\u010dko standardno vreme",
-               "",
+               "PST",
                "Severnoameri\u010dko pacifi\u010dko letnje vreme",
-               "",
+               "PDT",
                "Severnoameri\u010dko pacifi\u010dko vreme",
-               "",
+               "PT",
             };
         final String[] French_Southern = new String[] {
                "Francusko ju\u017eno i antarkti\u010dko vreme",
@@ -1092,11 +1092,11 @@ public class TimeZoneNames_sr_Latn extends TimeZoneNamesBundle {
             };
         final String[] Hawaii_Aleutian = new String[] {
                "Havajsko-aleutsko standardno vreme",
-               "",
+               "HST",
                "Havajsko-aleutsko letnje vreme",
-               "",
+               "HST",
                "Havajsko-aleutsko vreme",
-               "",
+               "HST",
             };
         final String[] Phoenix_Islands = new String[] {
                "Feniks ostrva vreme",
@@ -1116,11 +1116,11 @@ public class TimeZoneNames_sr_Latn extends TimeZoneNamesBundle {
             };
         final String[] America_Mountain = new String[] {
                "Severnoameri\u010dko planinsko standardno vreme",
-               "",
+               "MST",
                "Severnoameri\u010dko planinsko letnje vreme",
-               "",
+               "MDT",
                "Severnoameri\u010dko planinsko vreme",
-               "",
+               "MT",
             };
         final String[] Marshall_Islands = new String[] {
                "Mar\u0161alska Ostrva vreme",
@@ -1148,19 +1148,19 @@ public class TimeZoneNames_sr_Latn extends TimeZoneNamesBundle {
             };
         final String[] Australia_Central = new String[] {
                "Australijsko centralno standardno vreme",
-               "",
+               "ACST",
                "Australijsko centralno letnje vreme",
-               "",
+               "ACDT",
                "Australijsko centralno vreme",
-               "",
+               "ACT",
             };
         final String[] Australia_Eastern = new String[] {
                "Australijsko isto\u010dno standardno vreme",
-               "",
+               "AEST",
                "Australijsko isto\u010dno letnje vreme",
-               "",
+               "AEDT",
                "Australijsko isto\u010dno vreme",
-               "",
+               "AET",
             };
         final String[] Australia_Western = new String[] {
                "Australijsko zapadno standardno vreme",
@@ -1188,27 +1188,27 @@ public class TimeZoneNames_sr_Latn extends TimeZoneNamesBundle {
             };
         final String[] Indonesia_Central = new String[] {
                "Centralno-indonezijsko vreme",
+               "WITA",
                "",
+               "WITA",
                "",
-               "",
-               "",
-               "",
+               "WITA",
             };
         final String[] Indonesia_Eastern = new String[] {
                "Isto\u010dno-indonezijsko vreme",
+               "WIT",
                "",
+               "WIT",
                "",
-               "",
-               "",
-               "",
+               "WIT",
             };
         final String[] Indonesia_Western = new String[] {
                "Zapadno-indonezijsko vreme",
+               "WIB",
                "",
+               "WIB",
                "",
-               "",
-               "",
-               "",
+               "WIB",
             };
         final String[] Kazakhstan_Eastern = new String[] {
                "Isto\u010dno-kazahstansko vreme",
@@ -1398,9 +1398,9 @@ public class TimeZoneNames_sr_Latn extends TimeZoneNamesBundle {
                     "Srednje vreme po Grini\u010du",
                     "GMT",
                     "Irska, standardno vreme",
+                    "IST",
                     "",
-                    "",
-                    "",
+                    "GMT",
                 }
             },
             { "Europe/Jersey", GMT },
@@ -1410,9 +1410,9 @@ public class TimeZoneNames_sr_Latn extends TimeZoneNamesBundle {
                     "Srednje vreme po Grini\u010du",
                     "GMT",
                     "Britanija, letnje vreme",
+                    "BST",
                     "",
-                    "",
-                    "",
+                    "GMT",
                 }
             },
             { "Europe/Madrid", Europe_Central },
@@ -1472,9 +1472,9 @@ public class TimeZoneNames_sr_Latn extends TimeZoneNamesBundle {
                     "Srednje vreme po Grini\u010du",
                     "GMT",
                     "Britanija, letnje vreme",
+                    "BST",
                     "",
-                    "",
-                    "",
+                    "GMT",
                 }
             },
             { "Europe/Tallinn", Europe_Eastern },
