@@ -76,11 +76,11 @@ public class TimeZoneNames_sw_KE extends TimeZoneNamesBundle {
             };
         final String[] Cuba = new String[] {
                "Saa za Wastani za Kuba",
-               "",
+               "CST",
                "Saa za Mchana za Kuba",
-               "",
+               "CDT",
                "Saa za Kuba",
-               "",
+               "CT",
             };
         final String[] Gulf = new String[] {
                "Saa za Wastani za Ghuba",
@@ -124,11 +124,11 @@ public class TimeZoneNames_sw_KE extends TimeZoneNamesBundle {
             };
         final String[] Japan = new String[] {
                "Saa za Wastani za Japani",
-               "",
+               "JST",
                "Saa za Mchana za Japani",
-               "",
+               "JDT",
                "Saa za Japani",
-               "",
+               "JT",
             };
         final String[] Nepal = new String[] {
                "Saa za Nepali",
@@ -140,11 +140,11 @@ public class TimeZoneNames_sw_KE extends TimeZoneNamesBundle {
             };
         final String[] Samoa = new String[] {
                "Saa za Wastani za Samoa",
-               "",
+               "SST",
                "Saa za Mchana za Samoa",
-               "",
+               "SST",
                "Saa za Samoa",
-               "",
+               "SST",
             };
         final String[] Tonga = new String[] {
                "Saa za Wastani za Tonga",
@@ -164,11 +164,11 @@ public class TimeZoneNames_sw_KE extends TimeZoneNamesBundle {
             };
         final String[] Azores = new String[] {
                "Saa za Wastani za Azores",
-               "",
+               "HMT",
                "Saa za Majira ya Joto za Azores",
-               "",
+               "HMT",
                "Saa za Azores",
-               "",
+               "HMT",
             };
         final String[] Bhutan = new String[] {
                "Saa za Butani",
@@ -188,11 +188,11 @@ public class TimeZoneNames_sw_KE extends TimeZoneNamesBundle {
             };
         final String[] Moscow = new String[] {
                "Saa za Wastani za Moscow",
-               "",
+               "MSK",
                "Saa za Majira ya Joto za Moscow",
-               "",
+               "MSK",
                "Saa za Moscow",
-               "",
+               "MSK",
             };
         final String[] Armenia = new String[] {
                "Saa za Wastani za Armenia",
@@ -316,11 +316,11 @@ public class TimeZoneNames_sw_KE extends TimeZoneNamesBundle {
             };
         final String[] Pakistan = new String[] {
                "Saa za Wastani za Pakistani",
-               "",
+               "PKT",
                "Saa za Majira ya Joto za Pakistani",
-               "",
+               "PKST",
                "Saa za Pakistani",
-               "",
+               "PKT",
             };
         final String[] Paraguay = new String[] {
                "Saa za Wastani za Paragwai",
@@ -348,11 +348,11 @@ public class TimeZoneNames_sw_KE extends TimeZoneNamesBundle {
             };
         final String[] Hong_Kong = new String[] {
                "Saa za Wastani za Hong Kong",
-               "",
+               "HKT",
                "Saa za Majira ya Joto za Hong Kong",
-               "",
+               "HKST",
                "Saa za Hong Kong",
-               "",
+               "HKT",
             };
         final String[] Mauritius = new String[] {
                "Saa za Wastani za Morisi",
@@ -372,11 +372,11 @@ public class TimeZoneNames_sw_KE extends TimeZoneNamesBundle {
             };
         final String[] Volgograd = new String[] {
                "Saa za Wastani za Volgograd",
-               "",
+               "MSK",
                "Saa za Majira ya Joto za Volgograd",
-               "",
+               "MSK",
                "Saa za Volgograd",
-               "",
+               "MSK",
             };
         final String[] Azerbaijan = new String[] {
                "Saa za Wastani za Azabajani",
@@ -436,11 +436,11 @@ public class TimeZoneNames_sw_KE extends TimeZoneNamesBundle {
             };
         final String[] New_Zealand = new String[] {
                "Saa za Wastani za Nyuzilandi",
-               "",
+               "NZST",
                "Saa za Mchana za Nyuzilandi",
-               "",
+               "NZDT",
                "Saa za Nyuzilandi",
-               "",
+               "NZT",
             };
         final String[] Novosibirsk = new String[] {
                "Saa za Wastani za Novosibirsk",
@@ -452,11 +452,11 @@ public class TimeZoneNames_sw_KE extends TimeZoneNamesBundle {
             };
         final String[] Philippines = new String[] {
                "Saa za Wastani za Ufilipino",
-               "",
+               "PST",
                "Saa za Majira ya Joto za Ufilipino",
-               "",
+               "PDT",
                "Saa za Ufilipino",
-               "",
+               "PT",
             };
         final String[] Vladivostok = new String[] {
                "Saa za Wastani za Vladivostok",
@@ -508,35 +508,35 @@ public class TimeZoneNames_sw_KE extends TimeZoneNamesBundle {
             };
         final String[] Africa_Western = new String[] {
                "Saa za Wastani za Afrika Magharibi",
-               "",
+               "WAT",
                "Saa za Majira ya Joto za Afrika Magharibi",
-               "",
+               "WAT",
                "Saa za Afrika Magharibi",
-               "",
+               "WAT",
             };
         final String[] Europe_Central = new String[] {
                "Saa za Wastani za Ulaya ya Kati",
-               "",
+               "CET",
                "Saa za Majira ya Joto za Ulaya ya Kati",
-               "",
+               "CEST",
                "Saa za Ulaya ya Kati",
-               "",
+               "CET",
             };
         final String[] Europe_Eastern = new String[] {
                "Saa za Wastani za Mashariki mwa Ulaya",
-               "",
+               "EET",
                "Saa za Majira ya Joto za Mashariki mwa Ulaya",
-               "",
+               "EEST",
                "Saa za Mashariki mwa Ulaya",
-               "",
+               "EET",
             };
         final String[] Europe_Western = new String[] {
                "Saa za Wastani za Magharibi mwa Ulaya",
-               "",
+               "FMT",
                "Saa za Majira ya Joto za Magharibi mwa Ulaya",
-               "",
+               "FMT",
                "Saa za Magharibi mwa Ulaya",
-               "",
+               "FMT",
             };
         final String[] Phoenix_Islands = new String[] {
                "Saa za Visiwa vya Finiksi",
