@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,7 +26,7 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
  * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
@@ -67,12 +67,12 @@ public class TimeZoneNames_tg extends TimeZoneNamesBundle {
     @Override
     protected final Object[][] getContents() {
         final String[] GMT = new String[] {
-               "\u0411\u0430 \u0432\u0430\u049b\u0442\u0438 \u0413\u0440\u0438\u043d\u0432\u0438\u0447",
-               "",
-               "",
-               "",
+               "\u0412\u0430\u049b\u0442\u0438 \u043c\u0438\u0451\u043d\u0430\u0438 \u0413\u0440\u0438\u043d\u0432\u0438\u0447",
+               "GMT",
                "",
+               "BST",
                "",
+               "GMT",
             };
         final String[] ETC_UTC = new String[] {
                "\u0412\u0430\u049b\u0442\u0438 \u04b7\u0430\u04b3\u043e\u043d\u0438\u0438 \u04b3\u0430\u043c\u043e\u04b3\u0430\u043d\u0433\u0441\u043e\u0437\u04e3",
@@ -84,67 +84,67 @@ public class TimeZoneNames_tg extends TimeZoneNamesBundle {
             };
         final String[] Atlantic = new String[] {
                "\u0412\u0430\u049b\u0442\u0438 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442\u0438\u0438 \u0430\u0442\u043b\u0430\u043d\u0442\u0438\u043a\u04e3",
-               "",
+               "AST",
                "\u0412\u0430\u049b\u0442\u0438 \u0440\u04ef\u0437\u043e\u043d\u0430\u0438 \u0430\u0442\u043b\u0430\u043d\u0442\u0438\u043a\u04e3",
-               "",
+               "ADT",
                "\u0412\u0430\u049b\u0442\u0438 \u0430\u0442\u043b\u0430\u043d\u0442\u0438\u043a\u04e3",
-               "",
+               "AT",
             };
         final String[] Europe_Central = new String[] {
                "\u0412\u0430\u049b\u0442\u0438 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442\u0438\u0438 \u0430\u0432\u0440\u0443\u043f\u043e\u0438\u0438 \u043c\u0430\u0440\u043a\u0430\u0437\u04e3",
-               "",
+               "CET",
                "\u0412\u0430\u049b\u0442\u0438 \u0442\u043e\u0431\u0438\u0441\u0442\u043e\u043d\u0430\u0438 \u0430\u0432\u0440\u0443\u043f\u043e\u0438\u0438 \u043c\u0430\u0440\u043a\u0430\u0437\u04e3",
-               "",
+               "CEST",
                "\u0412\u0430\u049b\u0442\u0438 \u0430\u0432\u0440\u0443\u043f\u043e\u0438\u0438 \u043c\u0430\u0440\u043a\u0430\u0437\u04e3",
-               "",
+               "CET",
             };
         final String[] Europe_Eastern = new String[] {
                "\u0412\u0430\u049b\u0442\u0438 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442\u0438\u0438 \u0430\u0432\u0440\u0443\u043f\u043e\u0438\u0438 \u0448\u0430\u0440\u049b\u04e3",
-               "",
+               "EET",
                "\u0412\u0430\u049b\u0442\u0438 \u0442\u043e\u0431\u0438\u0441\u0442\u043e\u043d\u0430\u0438 \u0430\u0432\u0440\u0443\u043f\u043e\u0438\u0438 \u0448\u0430\u0440\u049b\u04e3",
-               "",
+               "EEST",
                "\u0412\u0430\u049b\u0442\u0438 \u0430\u0432\u0440\u0443\u043f\u043e\u0438\u0438 \u0448\u0430\u0440\u049b\u04e3",
-               "",
+               "EET",
             };
         final String[] Europe_Western = new String[] {
                "\u0412\u0430\u049b\u0442\u0438 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442\u0438\u0438 \u0430\u0432\u0440\u0443\u043f\u043e\u0438\u0438 \u0493\u0430\u0440\u0431\u04e3",
-               "",
+               "FMT",
                "\u0412\u0430\u049b\u0442\u0438 \u0442\u043e\u0431\u0438\u0441\u0442\u043e\u043d\u0430\u0438 \u0430\u0432\u0440\u0443\u043f\u043e\u0438\u0438 \u0493\u0430\u0440\u0431\u04e3",
-               "",
+               "FMT",
                "\u0412\u0430\u049b\u0442\u0438 \u0430\u0432\u0440\u0443\u043f\u043e\u0438\u0438 \u0493\u0430\u0440\u0431\u04e3",
-               "",
+               "FMT",
             };
         final String[] America_Central = new String[] {
                "\u0412\u0430\u049b\u0442\u0438 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442\u0438\u0438 \u043c\u0430\u0440\u043a\u0430\u0437\u04e3",
-               "",
+               "CST",
                "\u0412\u0430\u049b\u0442\u0438 \u0440\u04ef\u0437\u043e\u043d\u0430\u0438 \u043c\u0430\u0440\u043a\u0430\u0437\u04e3",
-               "",
+               "CDT",
                "\u0412\u0430\u049b\u0442\u0438 \u043c\u0430\u0440\u043a\u0430\u0437\u04e3",
-               "",
+               "CT",
             };
         final String[] America_Eastern = new String[] {
                "\u0412\u0430\u049b\u0442\u0438 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442\u0438\u0438 \u0448\u0430\u0440\u049b\u04e3",
-               "",
+               "EST",
                "\u0412\u0430\u049b\u0442\u0438 \u0440\u04ef\u0437\u043e\u043d\u0430\u0438 \u0448\u0430\u0440\u049b\u04e3",
-               "",
+               "EST",
                "\u0412\u0430\u049b\u0442\u0438 \u0448\u0430\u0440\u049b\u04e3",
-               "",
+               "EST",
             };
         final String[] America_Pacific = new String[] {
                "\u0412\u0430\u049b\u0442\u0438 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442\u0438\u0438 \u0423\u049b\u0451\u043d\u0443\u0441\u0438 \u041e\u0440\u043e\u043c",
-               "",
+               "PST",
                "\u0412\u0430\u049b\u0442\u0438 \u0440\u04ef\u0437\u043e\u043d\u0430\u0438 \u0423\u049b\u0451\u043d\u0443\u0441\u0438 \u041e\u0440\u043e\u043c",
-               "",
+               "PDT",
                "\u0412\u0430\u049b\u0442\u0438 \u0423\u049b\u0451\u043d\u0443\u0441\u0438 \u041e\u0440\u043e\u043c",
-               "",
+               "PT",
             };
         final String[] America_Mountain = new String[] {
                "\u0412\u0430\u049b\u0442\u0438 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442\u0438\u0438 \u043a\u04ef\u04b3\u04e3",
-               "",
+               "MST",
                "\u0412\u0430\u049b\u0442\u0438 \u0440\u04ef\u0437\u043e\u043d\u0430\u0438 \u043a\u04ef\u04b3\u04e3",
-               "",
+               "MDT",
                "\u0412\u0430\u049b\u0442\u0438 \u043a\u04ef\u04b3\u04e3",
-               "",
+               "MT",
             };
         final Object[][] data = new Object[][] {
             { "America/Los_Angeles", America_Pacific },
@@ -171,7 +171,6 @@ public class TimeZoneNames_tg extends TimeZoneNamesBundle {
             { "MST7MDT", America_Mountain },
             { "PST8PDT", America_Pacific },
             { "Asia/Gaza", Europe_Eastern },
-            { "Asia/Amman", Europe_Eastern },
             { "Africa/Lome", GMT },
             { "Asia/Beirut", Europe_Eastern },
             { "Asia/Hebron", Europe_Eastern },
@@ -198,7 +197,6 @@ public class TimeZoneNames_tg extends TimeZoneNamesBundle {
             { "America/Aruba", Atlantic },
             { "America/Boise", America_Mountain },
             { "America/Thule", Atlantic },
-            { "Asia/Damascus", Europe_Eastern },
             { "Europe/Athens", Europe_Eastern },
             { "Europe/Berlin", Europe_Central },
             { "Europe/Dublin", GMT },
@@ -221,7 +219,6 @@ public class TimeZoneNames_tg extends TimeZoneNamesBundle {
             { "America/Belize", America_Central },
             { "America/Cancun", America_Eastern },
             { "America/Cayman", America_Eastern },
-            { "America/Dawson", America_Mountain },
             { "America/Inuvik", America_Mountain },
             { "America/Merida", America_Central },
             { "America/Nassau", America_Eastern },
@@ -247,7 +244,7 @@ public class TimeZoneNames_tg extends TimeZoneNamesBundle {
             { "America/Marigot", Atlantic },
             { "America/Moncton", Atlantic },
             { "America/Nipigon", America_Eastern },
-            { "America/Ojinaga", America_Mountain },
+            { "America/Ojinaga", America_Central },
             { "America/Tijuana", America_Pacific },
             { "America/Toronto", America_Eastern },
             { "America/Tortola", Atlantic },
@@ -287,6 +284,7 @@ public class TimeZoneNames_tg extends TimeZoneNamesBundle {
             { "Europe/Podgorica", Europe_Central },
             { "Europe/Stockholm", Europe_Central },
             { "Africa/Nouakchott", GMT },
+            { "America/Chihuahua", America_Central },
             { "America/Glace_Bay", Atlantic },
             { "America/Goose_Bay", Atlantic },
             { "America/Guatemala", America_Central },
@@ -309,7 +307,6 @@ public class TimeZoneNames_tg extends TimeZoneNamesBundle {
             { "America/Martinique", Atlantic },
             { "America/Montserrat", Atlantic },
             { "America/St_Vincent", Atlantic },
-            { "America/Whitehorse", America_Mountain },
             { "Atlantic/Jan_Mayen", Europe_Central },
             { "Atlantic/Reykjavik", GMT },
             { "Atlantic/St_Helena", GMT },
@@ -331,6 +328,7 @@ public class TimeZoneNames_tg extends TimeZoneNamesBundle {
             { "America/Indiana/Knox", America_Central },
             { "America/Rankin_Inlet", America_Central },
             { "America/Cambridge_Bay", America_Mountain },
+            { "America/Ciudad_Juarez", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
             { "America/Indiana/Vevay", America_Eastern },
             { "America/Lower_Princes", Atlantic },
