@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -72,11 +68,11 @@ public class TimeZoneNames_ug extends TimeZoneNamesBundle {
     protected final Object[][] getContents() {
         final String[] GMT = new String[] {
                "\u06af\u0649\u0631\u0649\u0646\u06cb\u0649\u0686 \u06cb\u0627\u0642\u062a\u0649",
+               "GMT",
                "",
+               "GMT",
                "",
-               "",
-               "",
-               "",
+               "GMT",
             };
         final String[] Acre = new String[] {
                "\u0626\u0627\u0643\u0631\u06d0 \u0626\u06c6\u0644\u0686\u06d5\u0645\u0644\u0649\u0643 \u06cb\u0627\u0642\u062a\u0649",
@@ -96,11 +92,11 @@ public class TimeZoneNames_ug extends TimeZoneNamesBundle {
             };
         final String[] Cuba = new String[] {
                "\u0643\u06c7\u0628\u0627 \u0626\u06c6\u0644\u0686\u06d5\u0645\u0644\u0649\u0643 \u06cb\u0627\u0642\u062a\u0649",
-               "",
+               "CST",
                "\u0643\u06c7\u0628\u0627 \u064a\u0627\u0632\u0644\u0649\u0642 \u06cb\u0627\u0642\u062a\u0649",
-               "",
+               "CDT",
                "\u0643\u06c7\u0628\u0627 \u06cb\u0627\u0642\u062a\u0649",
-               "",
+               "CT",
             };
         final String[] Fiji = new String[] {
                "\u0641\u0649\u062c\u0649 \u0626\u06c6\u0644\u0686\u06d5\u0645\u0644\u0649\u0643 \u06cb\u0627\u0642\u062a\u0649",
@@ -174,6 +170,14 @@ public class TimeZoneNames_ug extends TimeZoneNamesBundle {
                "",
                "",
             };
+        final String[] Casey = new String[] {
+               "\u0643\u0627\u0633\u06d0\u064a \u06cb\u0627\u0642\u062a\u0649",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Chile = new String[] {
                "\u0686\u0649\u0644\u0649 \u0626\u06c6\u0644\u0686\u06d5\u0645\u0644\u0649\u0643 \u06cb\u0627\u0642\u062a\u0649",
                "",
@@ -184,11 +188,11 @@ public class TimeZoneNames_ug extends TimeZoneNamesBundle {
             };
         final String[] China = new String[] {
                "\u062c\u06c7\u06ad\u06af\u0648 \u0626\u06c6\u0644\u0686\u06d5\u0645\u0644\u0649\u0643 \u06cb\u0627\u0642\u062a\u0649",
-               "",
+               "CST",
                "\u062c\u06c7\u06ad\u06af\u0648 \u064a\u0627\u0632\u0644\u0649\u0642 \u06cb\u0627\u0642\u062a\u0649",
-               "",
+               "CDT",
                "\u062c\u06c7\u06ad\u06af\u0648 \u06cb\u0627\u0642\u062a\u0649",
-               "",
+               "CT",
             };
         final String[] Cocos = new String[] {
                "\u0643\u0648\u0643\u06c7\u0633 \u0626\u0627\u0631\u0649\u0644\u0649 \u06cb\u0627\u0642\u062a\u0649",
@@ -216,19 +220,19 @@ public class TimeZoneNames_ug extends TimeZoneNamesBundle {
             };
         final String[] Japan = new String[] {
                "\u064a\u0627\u067e\u0648\u0646\u0649\u064a\u06d5 \u0626\u06c6\u0644\u0686\u06d5\u0645\u0644\u0649\u0643 \u06cb\u0627\u0642\u062a\u0649",
-               "",
+               "JST",
                "\u064a\u0627\u067e\u0648\u0646\u0649\u064a\u06d5 \u064a\u0627\u0632\u0644\u0649\u0642 \u06cb\u0627\u0642\u062a\u0649",
-               "",
+               "JDT",
                "\u064a\u0627\u067e\u0648\u0646\u0649\u064a\u06d5 \u06cb\u0627\u0642\u062a\u0649",
-               "",
+               "JT",
             };
         final String[] Korea = new String[] {
                "\u0643\u0648\u0631\u0649\u064a\u06d5 \u0626\u06c6\u0644\u0686\u06d5\u0645\u0644\u0649\u0643 \u06cb\u0627\u0642\u062a\u0649",
-               "",
+               "KST",
                "\u0643\u0648\u0631\u0649\u064a\u06d5 \u064a\u0627\u0632\u0644\u0649\u0642 \u06cb\u0627\u0642\u062a\u0649",
-               "",
+               "KST",
                "\u0643\u0648\u0631\u0649\u064a\u06d5 \u06cb\u0627\u0642\u062a\u0649",
-               "",
+               "KST",
             };
         final String[] Nauru = new String[] {
                "\u0646\u0627\u06cb\u0631\u06c7 \u06cb\u0627\u0642\u062a\u0649",
@@ -256,11 +260,11 @@ public class TimeZoneNames_ug extends TimeZoneNamesBundle {
             };
         final String[] Samoa = new String[] {
                "\u0633\u0627\u0645\u0648\u0626\u0627 \u0626\u06c6\u0644\u0686\u06d5\u0645\u0644\u0649\u0643 \u06cb\u0627\u0642\u062a\u0649",
-               "",
+               "SST",
                "\u0633\u06d5\u0645\u06d5\u0631\u0642\u06d5\u0646\u062a \u064a\u0627\u0632\u0644\u0649\u0642 \u06cb\u0627\u0642\u062a\u0649",
-               "",
+               "SST",
                "\u0633\u0627\u0645\u0648\u0626\u0627 \u06cb\u0627\u0642\u062a\u0649",
-               "",
+               "SST",
             };
         final String[] Syowa = new String[] {
                "\u0634\u0648\u06cb\u0627 \u06cb\u0627\u0642\u062a\u0649",
@@ -304,11 +308,11 @@ public class TimeZoneNames_ug extends TimeZoneNamesBundle {
             };
         final String[] Azores = new String[] {
                "\u0626\u0627\u0632\u0648\u0631 \u0626\u06c6\u0644\u0686\u06d5\u0645\u0644\u0649\u0643 \u06cb\u0627\u0642\u062a\u0649",
-               "",
+               "HMT",
                "\u0626\u0627\u0632\u0648\u0631 \u064a\u0627\u0632\u0644\u0649\u0642 \u06cb\u0627\u0642\u062a\u0649",
-               "",
+               "HMT",
                "\u0626\u0627\u0632\u0648\u0631 \u06cb\u0627\u0642\u062a\u0649",
-               "",
+               "HMT",
             };
         final String[] Bhutan = new String[] {
                "\u0628\u06c7\u062a\u0627\u0646 \u06cb\u0627\u0642\u062a\u0649",
@@ -344,11 +348,11 @@ public class TimeZoneNames_ug extends TimeZoneNamesBundle {
             };
         final String[] Israel = new String[] {
                "\u0626\u0649\u0633\u0631\u0627\u0626\u0649\u0644\u0649\u064a\u06d5 \u0626\u06c6\u0644\u0686\u06d5\u0645\u0644\u0649\u0643 \u06cb\u0627\u0642\u062a\u0649",
-               "",
+               "IST",
                "\u0626\u0649\u0633\u0631\u0627\u0626\u0649\u0644\u0649\u064a\u06d5 \u064a\u0627\u0632\u0644\u0649\u0642 \u06cb\u0627\u0642\u062a\u0649",
-               "",
+               "IDT",
                "\u0626\u0649\u0633\u0631\u0627\u0626\u0649\u0644\u0649\u064a\u06d5 \u06cb\u0627\u0642\u062a\u0649",
-               "",
+               "IT",
             };
         final String[] Kosrae = new String[] {
                "\u0643\u0648\u0633\u0631\u0627\u0626\u06d0 \u06cb\u0627\u0642\u062a\u0649",
@@ -368,11 +372,11 @@ public class TimeZoneNames_ug extends TimeZoneNamesBundle {
             };
         final String[] Moscow = new String[] {
                "\u0645\u0648\u0633\u0643\u06cb\u0627 \u0626\u06c6\u0644\u0686\u06d5\u0645\u0644\u0649\u0643 \u06cb\u0627\u0642\u062a\u0649",
-               "",
+               "MSK",
                "\u0645\u0648\u0633\u0643\u06cb\u0627 \u064a\u0627\u0632\u0644\u0649\u0642 \u06cb\u0627\u0642\u062a\u0649",
-               "",
+               "MSK",
                "\u0645\u0648\u0633\u0643\u06cb\u0627 \u06cb\u0627\u0642\u062a\u0649",
-               "",
+               "MSK",
             };
         final String[] Ponape = new String[] {
                "\u067e\u0648\u0646\u067e\u06d0\u064a \u06cb\u0627\u0642\u062a\u0649",
@@ -400,11 +404,11 @@ public class TimeZoneNames_ug extends TimeZoneNamesBundle {
             };
         final String[] Taipei = new String[] {
                "\u062a\u06d5\u064a\u0628\u06d0\u064a \u0626\u06c6\u0644\u0686\u06d5\u0645\u0644\u0649\u0643 \u06cb\u0627\u0642\u062a\u0649",
-               "",
+               "CST",
                "\u062a\u06d5\u064a\u0628\u06d0\u064a \u064a\u0627\u0632\u0644\u0649\u0642 \u06cb\u0627\u0642\u062a\u0649",
-               "",
+               "CDT",
                "\u062a\u06d5\u064a\u0628\u06d0\u064a \u06cb\u0627\u0642\u062a\u0649",
-               "",
+               "CT",
             };
         final String[] Tuvalu = new String[] {
                "\u062a\u06c7\u06cb\u0627\u0644\u06c7 \u06cb\u0627\u0642\u062a\u0649",
@@ -584,11 +588,11 @@ public class TimeZoneNames_ug extends TimeZoneNamesBundle {
             };
         final String[] Atlantic = new String[] {
                "\u0626\u0627\u062a\u0644\u0627\u0646\u062a\u0649\u0643 \u0626\u0648\u0643\u064a\u0627\u0646 \u0626\u06c6\u0644\u0686\u06d5\u0645\u0644\u0649\u0643 \u06cb\u0627\u0642\u062a\u0649",
-               "",
+               "AST",
                "\u0626\u0627\u062a\u0644\u0627\u0646\u062a\u0649\u0643 \u0626\u0648\u0643\u064a\u0627\u0646 \u064a\u0627\u0632\u0644\u0649\u0642 \u06cb\u0627\u0642\u062a\u0649",
-               "",
+               "ADT",
                "\u0626\u0627\u062a\u0644\u0627\u0646\u062a\u0649\u0643 \u0626\u0648\u0643\u064a\u0627\u0646 \u06cb\u0627\u0642\u062a\u0649",
-               "",
+               "AT",
             };
         final String[] Brasilia = new String[] {
                "\u0628\u0649\u0631\u0627\u0632\u0649\u0644\u0649\u064a\u06d5 \u0626\u06c6\u0644\u0686\u06d5\u0645\u0644\u0649\u0643 \u06cb\u0627\u0642\u062a\u0649",
@@ -600,11 +604,11 @@ public class TimeZoneNames_ug extends TimeZoneNamesBundle {
             };
         final String[] Chamorro = new String[] {
                "\u0686\u0627\u0645\u0648\u0631\u0631\u0648 \u0626\u06c6\u0644\u0686\u06d5\u0645\u0644\u0649\u0643 \u06cb\u0627\u0642\u062a\u0649",
+               "ChST",
                "",
+               "ChST",
                "",
-               "",
-               "",
-               "",
+               "ChST",
             };
         final String[] Colombia = new String[] {
                "\u0643\u0648\u0644\u0648\u0645\u0628\u0649\u064a\u06d5 \u0626\u06c6\u0644\u0686\u06d5\u0645\u0644\u0649\u0643 \u06cb\u0627\u0642\u062a\u0649",
@@ -648,11 +652,11 @@ public class TimeZoneNames_ug extends TimeZoneNamesBundle {
             };
         final String[] Pakistan = new String[] {
                "\u067e\u0627\u0643\u0649\u0633\u062a\u0627\u0646 \u0626\u06c6\u0644\u0686\u06d5\u0645\u0644\u0649\u0643 \u06cb\u0627\u0642\u062a\u0649",
-               "",
+               "PKT",
                "\u067e\u0627\u0643\u0649\u0633\u062a\u0627\u0646 \u064a\u0627\u0632\u0644\u0649\u0642 \u06cb\u0627\u0642\u062a\u0649",
-               "",
+               "PKST",
                "\u067e\u0627\u0643\u0649\u0633\u062a\u0627\u0646 \u06cb\u0627\u0642\u062a\u0649",
-               "",
+               "PKT",
             };
         final String[] Paraguay = new String[] {
                "\u067e\u0627\u0631\u0627\u06af\u06cb\u0627\u064a \u0626\u06c6\u0644\u0686\u06d5\u0645\u0644\u0649\u0643 \u06cb\u0627\u0642\u062a\u0649",
@@ -712,11 +716,11 @@ public class TimeZoneNames_ug extends TimeZoneNamesBundle {
             };
         final String[] Hong_Kong = new String[] {
                "\u0634\u064a\u0627\u06ad\u06af\u0627\u06ad \u0626\u06c6\u0644\u0686\u06d5\u0645\u0644\u0649\u0643 \u06cb\u0627\u0642\u062a\u0649",
-               "",
+               "HKT",
                "\u0634\u064a\u0627\u06ad\u06af\u0627\u06ad \u064a\u0627\u0632\u0644\u0649\u0642 \u06cb\u0627\u0642\u062a\u0649",
-               "",
+               "HKST",
                "\u0634\u064a\u0627\u06ad\u06af\u0627\u06ad \u06cb\u0627\u0642\u062a\u0649",
-               "",
+               "HKT",
             };
         final String[] Indochina = new String[] {
                "\u06be\u0649\u0646\u062f\u0649 \u0686\u0649\u0646\u0649 \u06cb\u0627\u0642\u062a\u0649",
@@ -750,14 +754,6 @@ public class TimeZoneNames_ug extends TimeZoneNamesBundle {
                "\u0644\u0648\u0631\u062f-\u062e\u0627\u064a \u06cb\u0627\u0642\u062a\u0649",
                "",
             };
-        final String[] Macquarie = new String[] {
-               "\u0645\u0627\u0643\u0643\u06c7\u06cb\u0627\u0631\u0649 \u0626\u0627\u0631\u0627\u0644\u0644\u0649\u0631\u0649 \u06cb\u0627\u0642\u062a\u0649",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] Marquesas = new String[] {
                "\u0645\u0627\u0631\u0643\u0649\u0632 \u06cb\u0627\u0642\u062a\u0649",
                "",
@@ -792,11 +788,11 @@ public class TimeZoneNames_ug extends TimeZoneNamesBundle {
             };
         final String[] Volgograd = new String[] {
                "\u06cb\u0648\u0644\u06af\u0627\u06af\u0631\u0627\u062f \u0626\u06c6\u0644\u0686\u06d5\u0645\u0644\u0649\u0643 \u06cb\u0627\u0642\u062a\u0649",
-               "",
+               "MSK",
                "\u06cb\u0648\u0644\u06af\u0627\u06af\u0631\u0627\u062f \u064a\u0627\u0632\u0644\u0649\u0642 \u06cb\u0627\u0642\u062a\u0649",
-               "",
+               "MSK",
                "\u06cb\u0648\u0644\u06af\u0627\u06af\u0631\u0627\u062f \u06cb\u0627\u0642\u062a\u0649",
-               "",
+               "MSK",
             };
         final String[] Azerbaijan = new String[] {
                "\u0626\u06d5\u0632\u06d5\u0631\u0628\u06d5\u064a\u062c\u0627\u0646 \u0626\u06c6\u0644\u0686\u06d5\u0645\u0644\u0649\u0643 \u06cb\u0627\u0642\u062a\u0649",
@@ -880,11 +876,11 @@ public class TimeZoneNames_ug extends TimeZoneNamesBundle {
             };
         final String[] New_Zealand = new String[] {
                "\u064a\u06d0\u06ad\u0649 \u0632\u06d0\u0644\u0627\u0646\u062f\u0649\u064a\u06d5 \u0626\u06c6\u0644\u0686\u06d5\u0645\u0644\u0649\u0643 \u06cb\u0627\u0642\u062a\u0649",
-               "",
+               "NZST",
                "\u064a\u06d0\u06ad\u0649 \u0632\u06d0\u0644\u0627\u0646\u062f\u0649\u064a\u06d5 \u064a\u0627\u0632\u0644\u0649\u0642 \u06cb\u0627\u0642\u062a\u0649",
-               "",
+               "NZDT",
                "\u064a\u06d0\u06ad\u0649 \u0632\u06d0\u0644\u0627\u0646\u062f\u0649\u064a\u06d5 \u06cb\u0627\u0642\u062a\u0649",
-               "",
+               "NZT",
             };
         final String[] Novosibirsk = new String[] {
                "\u0646\u0648\u06cb\u0648\u0633\u0649\u0628\u0649\u0631\u0633\u0643 \u0626\u06c6\u0644\u0686\u06d5\u0645\u0644\u0649\u0643 \u06cb\u0627\u0642\u062a\u0649",
@@ -896,11 +892,11 @@ public class TimeZoneNames_ug extends TimeZoneNamesBundle {
             };
         final String[] Philippines = new String[] {
                "\u0641\u0649\u0644\u0649\u067e\u067e\u0649\u0646 \u0626\u06c6\u0644\u0686\u06d5\u0645\u0644\u0649\u0643 \u06cb\u0627\u0642\u062a\u0649",
-               "",
+               "PST",
                "\u0641\u0649\u0644\u0649\u067e\u067e\u0649\u0646 \u064a\u0627\u0632\u0644\u0649\u0642 \u06cb\u0627\u0642\u062a\u0649",
-               "",
+               "PDT",
                "\u0641\u0649\u0644\u0649\u067e\u067e\u0649\u0646 \u06cb\u0627\u0642\u062a\u0649",
-               "",
+               "PT",
             };
         final String[] Vladivostok = new String[] {
                "\u06cb\u0649\u0644\u0627\u062f\u0649\u06cb\u0648\u0633\u062a\u0648\u0643 \u0626\u06c6\u0644\u0686\u06d5\u0645\u0644\u0649\u0643 \u06cb\u0627\u0642\u062a\u0649",
@@ -928,11 +924,11 @@ public class TimeZoneNames_ug extends TimeZoneNamesBundle {
             };
         final String[] Newfoundland = new String[] {
                "\u0646\u0649\u06cb\u0641\u0648\u0626\u06c7\u0646\u0644\u0627\u0646\u062f \u0626\u06c6\u0644\u0686\u06d5\u0645\u0644\u0649\u0643 \u06cb\u0627\u0642\u062a\u0649",
-               "",
+               "NST",
                "\u0646\u0649\u06cb\u0641\u0648\u0626\u06c7\u0646\u0644\u0627\u0646\u062f \u064a\u0627\u0632\u0644\u0649\u0642 \u06cb\u0627\u0642\u062a\u0649",
-               "",
+               "NDT",
                "\u0646\u0649\u06cb\u0641\u0648\u0626\u06c7\u0646\u0644\u0627\u0646\u062f \u06cb\u0627\u0642\u062a\u0649",
-               "",
+               "NT",
             };
         final String[] Turkmenistan = new String[] {
                "\u062a\u06c8\u0631\u0643\u0645\u06d5\u0646\u0649\u0633\u062a\u0627\u0646 \u0626\u06c6\u0644\u0686\u06d5\u0645\u0644\u0649\u0643 \u06cb\u0627\u0642\u062a\u0649",
@@ -976,27 +972,27 @@ public class TimeZoneNames_ug extends TimeZoneNamesBundle {
             };
         final String[] Africa_Central = new String[] {
                "\u0626\u0648\u062a\u062a\u06c7\u0631\u0627 \u0626\u0627\u0641\u0631\u0649\u0642\u0627 \u06cb\u0627\u0642\u062a\u0649",
+               "SAST",
                "",
+               "SAST",
                "",
-               "",
-               "",
-               "",
+               "SAST",
             };
         final String[] Africa_Eastern = new String[] {
                "\u0634\u06d5\u0631\u0642\u0649\u064a \u0626\u0627\u0641\u0631\u0649\u0642\u0627 \u06cb\u0627\u0642\u062a\u0649",
+               "EAT",
                "",
+               "EAT",
                "",
-               "",
-               "",
-               "",
+               "EAT",
             };
         final String[] Africa_Western = new String[] {
                "\u063a\u06d5\u0631\u0628\u0649\u064a \u0626\u0627\u0641\u0631\u0649\u0642\u0627 \u0626\u06c6\u0644\u0686\u06d5\u0645\u0644\u0649\u0643 \u06cb\u0627\u0642\u062a\u0649",
-               "",
+               "WAT",
                "\u063a\u06d5\u0631\u0628\u0649\u064a \u0626\u0627\u0641\u0631\u0649\u0642\u0627 \u064a\u0627\u0632\u0644\u0649\u0642 \u06cb\u0627\u0642\u062a\u0649",
-               "",
+               "WAT",
                "\u063a\u06d5\u0631\u0628\u0649\u064a \u0626\u0627\u0641\u0631\u0649\u0642\u0627 \u06cb\u0627\u0642\u062a\u0649",
-               "",
+               "WAT",
             };
         final String[] DumontDUrville = new String[] {
                "\u062f\u06c7\u0645\u0648\u0646\u062a-\u062f\u06c7\u0631\u06cb\u0649\u0644 \u06cb\u0627\u0642\u062a\u0649",
@@ -1008,67 +1004,67 @@ public class TimeZoneNames_ug extends TimeZoneNamesBundle {
             };
         final String[] Europe_Central = new String[] {
                "\u0626\u0648\u062a\u062a\u06c7\u0631\u0627 \u064a\u0627\u06cb\u0631\u0648\u067e\u0627 \u0626\u06c6\u0644\u0686\u06d5\u0645\u0644\u0649\u0643 \u06cb\u0627\u0642\u062a\u0649",
-               "",
+               "CET",
                "\u0626\u0648\u062a\u062a\u06c7\u0631\u0627 \u064a\u0627\u06cb\u0631\u0648\u067e\u0627 \u064a\u0627\u0632\u0644\u0649\u0642 \u06cb\u0627\u0642\u062a\u0649",
-               "",
+               "CEST",
                "\u0626\u0648\u062a\u062a\u06c7\u0631\u0627 \u064a\u0627\u06cb\u0631\u0648\u067e\u0627 \u06cb\u0627\u0642\u062a\u0649",
-               "",
+               "CET",
             };
         final String[] Europe_Eastern = new String[] {
                "\u0634\u06d5\u0631\u0642\u0649\u064a \u064a\u0627\u06cb\u0631\u0648\u067e\u0627 \u0626\u06c6\u0644\u0686\u06d5\u0645\u0644\u0649\u0643 \u06cb\u0627\u0642\u062a\u0649",
-               "",
+               "EET",
                "\u0634\u06d5\u0631\u0642\u0649\u064a \u064a\u0627\u06cb\u0631\u0648\u067e\u0627 \u064a\u0627\u0632\u0644\u0649\u0642 \u06cb\u0627\u0642\u062a\u0649",
-               "",
+               "EEST",
                "\u0634\u06d5\u0631\u0642\u0649\u064a \u064a\u0627\u06cb\u0631\u0648\u067e\u0627 \u06cb\u0627\u0642\u062a\u0649",
-               "",
+               "EET",
             };
         final String[] Europe_Western = new String[] {
                "\u063a\u06d5\u0631\u0628\u0649\u064a \u064a\u0627\u06cb\u0631\u0648\u067e\u0627 \u0626\u06c6\u0644\u0686\u06d5\u0645\u0644\u0649\u0643 \u06cb\u0627\u0642\u062a\u0649",
-               "",
+               "FMT",
                "\u063a\u06d5\u0631\u0628\u0649\u064a \u064a\u0627\u06cb\u0631\u0648\u067e\u0627 \u064a\u0627\u0632\u0644\u0649\u0642 \u06cb\u0627\u0642\u062a\u0649",
-               "",
+               "FMT",
                "\u063a\u06d5\u0631\u0628\u0649\u064a \u064a\u0627\u06cb\u0631\u0648\u067e\u0627 \u06cb\u0627\u0642\u062a\u0649",
-               "",
+               "FMT",
             };
         final String[] Mexico_Pacific = new String[] {
                "\u0645\u06d0\u0643\u0633\u0649\u0643\u0627 \u062a\u0649\u0646\u0686 \u0626\u0648\u0643\u064a\u0627\u0646 \u0626\u06c6\u0644\u0686\u06d5\u0645\u0644\u0649\u0643 \u06cb\u0627\u0642\u062a\u0649",
-               "",
+               "MST",
                "\u0645\u06d0\u0643\u0633\u0649\u0643\u0627 \u062a\u0649\u0646\u0686 \u0626\u0648\u0643\u064a\u0627\u0646 \u064a\u0627\u0632\u0644\u0649\u0642 \u06cb\u0627\u0642\u062a\u0649",
-               "",
+               "MDT",
                "\u0645\u06d0\u0643\u0633\u0649\u0643\u0627 \u062a\u0649\u0646\u0686 \u0626\u0648\u0643\u064a\u0627\u0646 \u06cb\u0627\u0642\u062a\u0649",
-               "",
+               "MT",
             };
         final String[] Africa_Southern = new String[] {
                "\u062c\u06d5\u0646\u06c7\u0628\u0649\u064a \u0626\u0627\u0641\u0631\u0649\u0642\u0627 \u0626\u06c6\u0644\u0686\u06d5\u0645\u0644\u0649\u0643 \u06cb\u0627\u0642\u062a\u0649",
+               "SAST",
                "",
+               "SAST",
                "",
-               "",
-               "",
-               "",
+               "SAST",
             };
         final String[] America_Central = new String[] {
                "\u0626\u0648\u062a\u062a\u06c7\u0631\u0627 \u0642\u0649\u0633\u0649\u0645 \u0626\u06c6\u0644\u0686\u06d5\u0645\u0644\u0649\u0643 \u06cb\u0627\u0642\u062a\u0649",
-               "",
+               "CST",
                "\u0626\u0648\u062a\u062a\u06c7\u0631\u0627 \u0642\u0649\u0633\u0649\u0645 \u064a\u0627\u0632\u0644\u0649\u0642 \u06cb\u0627\u0642\u062a\u0649",
-               "",
+               "CDT",
                "\u0626\u0648\u062a\u062a\u06c7\u0631\u0627 \u0642\u0649\u0633\u0649\u0645 \u06cb\u0627\u0642\u062a\u0649",
-               "",
+               "CT",
             };
         final String[] America_Eastern = new String[] {
                "\u0634\u06d5\u0631\u0642\u0649\u064a \u0642\u0649\u0633\u0649\u0645 \u0626\u06c6\u0644\u0686\u06d5\u0645\u0644\u0649\u0643 \u06cb\u0627\u0642\u062a\u0649",
-               "",
+               "EST",
                "\u0634\u06d5\u0631\u0642\u0649\u064a \u0642\u0649\u0633\u0649\u0645 \u064a\u0627\u0632\u0644\u0649\u0642 \u06cb\u0627\u0642\u062a\u0649",
-               "",
+               "EST",
                "\u0634\u06d5\u0631\u0642\u0649\u064a \u0642\u0649\u0633\u0649\u0645 \u06cb\u0627\u0642\u062a\u0649",
-               "",
+               "EST",
             };
         final String[] America_Pacific = new String[] {
                "\u062a\u0649\u0646\u0686 \u0626\u0648\u0643\u064a\u0627\u0646 \u0626\u06c6\u0644\u0686\u06d5\u0645\u0644\u0649\u0643 \u06cb\u0627\u0642\u062a\u0649",
-               "",
+               "PST",
                "\u062a\u0649\u0646\u0686 \u0626\u0648\u0643\u064a\u0627\u0646 \u064a\u0627\u0632\u0644\u0649\u0642 \u06cb\u0627\u0642\u062a\u0649",
-               "",
+               "PDT",
                "\u062a\u0649\u0646\u0686 \u0626\u0648\u0643\u064a\u0627\u0646 \u06cb\u0627\u0642\u062a\u0649",
-               "",
+               "PT",
             };
         final String[] French_Southern = new String[] {
                "\u0641\u0649\u0631\u0627\u0646\u0633\u0649\u064a\u06d5\u06af\u06d5 \u0642\u0627\u0631\u0627\u0634\u0644\u0649\u0642 \u062c\u06d5\u0646\u06c7\u0628\u0649\u064a \u06cb\u06d5 \u0626\u0627\u0646\u062a\u0627\u0631\u0643\u062a\u0649\u0643\u0627 \u06cb\u0627\u0642\u062a\u0649",
@@ -1088,11 +1084,11 @@ public class TimeZoneNames_ug extends TimeZoneNamesBundle {
             };
         final String[] Hawaii_Aleutian = new String[] {
                "\u06be\u0627\u06cb\u0627\u064a-\u0626\u0627\u0644\u06d0\u064a\u06c7\u062a \u0626\u06c6\u0644\u0686\u06d5\u0645\u0644\u0649\u0643 \u06cb\u0627\u0642\u062a\u0649",
-               "",
+               "HST",
                "\u06be\u0627\u06cb\u0627\u064a-\u0626\u0627\u0644\u06d0\u064a\u06c7\u062a \u064a\u0627\u0632\u0644\u0649\u0642 \u06cb\u0627\u0642\u062a\u0649",
-               "",
+               "HST",
                "\u06be\u0627\u06cb\u0627\u064a-\u0626\u0627\u0644\u06d0\u064a\u06c7\u062a \u06cb\u0627\u0642\u062a\u0649",
-               "",
+               "HST",
             };
         final String[] Phoenix_Islands = new String[] {
                "\u0641\u06d0\u0646\u0649\u0643\u0633 \u0626\u0627\u0631\u0627\u0644\u0644\u0649\u0631\u0649 \u06cb\u0627\u0642\u062a\u0649",
@@ -1112,11 +1108,11 @@ public class TimeZoneNames_ug extends TimeZoneNamesBundle {
             };
         final String[] America_Mountain = new String[] {
                "\u062a\u0627\u063a \u0626\u06c6\u0644\u0686\u06d5\u0645\u0644\u0649\u0643 \u06cb\u0627\u0642\u062a\u0649",
-               "",
+               "MST",
                "\u062a\u0627\u063a \u064a\u0627\u0632\u0644\u0649\u0642 \u06cb\u0627\u0642\u062a\u0649",
-               "",
+               "MDT",
                "\u062a\u0627\u063a \u06cb\u0627\u0642\u062a\u0649",
-               "",
+               "MT",
             };
         final String[] Marshall_Islands = new String[] {
                "\u0645\u0627\u0631\u0634\u0627\u0644 \u0626\u0627\u0631\u0627\u0644\u0644\u0649\u0631\u0649 \u06cb\u0627\u0642\u062a\u0649",
@@ -1144,19 +1140,19 @@ public class TimeZoneNames_ug extends TimeZoneNamesBundle {
             };
         final String[] Australia_Central = new String[] {
                "\u0626\u0627\u06cb\u0633\u062a\u0631\u0627\u0644\u0649\u064a\u06d5 \u0626\u0648\u062a\u062a\u06c7\u0631\u0627 \u0642\u0649\u0633\u0649\u0645 \u0626\u06c6\u0644\u0686\u06d5\u0645\u0644\u0649\u0643 \u06cb\u0627\u0642\u062a\u0649",
-               "",
+               "ACST",
                "\u0626\u0627\u06cb\u0633\u062a\u0631\u0627\u0644\u0649\u064a\u06d5 \u0626\u0648\u062a\u062a\u06c7\u0631\u0627 \u0642\u0649\u0633\u0649\u0645 \u064a\u0627\u0632\u0644\u0649\u0642 \u06cb\u0627\u0642\u062a\u0649",
-               "",
+               "ACDT",
                "\u0626\u0627\u06cb\u0633\u062a\u0631\u0627\u0644\u0649\u064a\u06d5 \u0626\u0648\u062a\u062a\u06c7\u0631\u0627 \u0642\u0649\u0633\u0649\u0645 \u06cb\u0627\u0642\u062a\u0649",
-               "",
+               "ACT",
             };
         final String[] Australia_Eastern = new String[] {
                "\u0626\u0627\u06cb\u0633\u062a\u0631\u0627\u0644\u0649\u064a\u06d5 \u0634\u06d5\u0631\u0642\u0649\u064a \u0642\u0649\u0633\u0649\u0645 \u0626\u06c6\u0644\u0686\u06d5\u0645\u0644\u0649\u0643 \u06cb\u0627\u0642\u062a\u0649",
-               "",
+               "AEST",
                "\u0626\u0627\u06cb\u0633\u062a\u0631\u0627\u0644\u0649\u064a\u06d5 \u0634\u06d5\u0631\u0642\u0649\u064a \u0642\u0649\u0633\u0649\u0645 \u064a\u0627\u0632\u0644\u0649\u0642 \u06cb\u0627\u0642\u062a\u0649",
-               "",
+               "AEDT",
                "\u0626\u0627\u06cb\u0633\u062a\u0631\u0627\u0644\u0649\u064a\u06d5 \u0634\u06d5\u0631\u0642\u0649\u064a \u0642\u0649\u0633\u0649\u0645 \u06cb\u0627\u0642\u062a\u0649",
-               "",
+               "AET",
             };
         final String[] Australia_Western = new String[] {
                "\u0626\u0627\u06cb\u0633\u062a\u0631\u0627\u0644\u0649\u064a\u06d5 \u063a\u06d5\u0631\u0628\u0649\u064a \u0642\u0649\u0633\u0649\u0645 \u0626\u06c6\u0644\u0686\u06d5\u0645\u0644\u0649\u0643 \u06cb\u0627\u0642\u062a\u0649",
@@ -1184,27 +1180,27 @@ public class TimeZoneNames_ug extends TimeZoneNamesBundle {
             };
         final String[] Indonesia_Central = new String[] {
                "\u0626\u0648\u062a\u062a\u06c7\u0631\u0627 \u06be\u0649\u0646\u062f\u0648\u0646\u06d0\u0632\u0649\u064a\u06d5 \u06cb\u0627\u0642\u062a\u0649",
+               "WITA",
                "",
+               "WITA",
                "",
-               "",
-               "",
-               "",
+               "WITA",
             };
         final String[] Indonesia_Eastern = new String[] {
                "\u0634\u06d5\u0631\u0642\u0649\u064a \u06be\u0649\u0646\u062f\u0648\u0646\u06d0\u0632\u0649\u064a\u06d5 \u06cb\u0627\u0642\u062a\u0649",
+               "WIT",
                "",
+               "WIT",
                "",
-               "",
-               "",
-               "",
+               "WIT",
             };
         final String[] Indonesia_Western = new String[] {
                "\u063a\u06d5\u0631\u0628\u0649\u064a \u06be\u0649\u0646\u062f\u0648\u0646\u06d0\u0632\u0649\u064a\u06d5 \u06cb\u0627\u0642\u062a\u0649",
+               "WIB",
                "",
+               "WIB",
                "",
-               "",
-               "",
-               "",
+               "WIB",
             };
         final String[] Kazakhstan_Eastern = new String[] {
                "\u0634\u06d5\u0631\u0642\u0649\u064a \u0642\u0627\u0632\u0627\u0642\u0649\u0633\u062a\u0627\u0646 \u06cb\u0627\u0642\u062a\u0649",
@@ -1281,7 +1277,6 @@ public class TimeZoneNames_ug extends TimeZoneNamesBundle {
             { "Asia/Hovd", Hovd },
             { "Asia/Omsk", Omsk },
             { "Asia/Oral", Kazakhstan_Western },
-            { "Asia/Amman", Europe_Eastern },
             { "Asia/Aqtau", Kazakhstan_Western },
             { "Asia/Chita", Yakutsk },
             { "Asia/Dhaka", Bangladesh },
@@ -1290,7 +1285,7 @@ public class TimeZoneNames_ug extends TimeZoneNamesBundle {
             { "Asia/Macau", China },
             { "Asia/Qatar", Arabian },
             { "Asia/Seoul", Korea },
-            { "Africa/Juba", Africa_Eastern },
+            { "Africa/Juba", Africa_Central },
             { "Africa/Lome", GMT },
             { "Asia/Almaty", Kazakhstan_Eastern },
             { "Asia/Anadyr", Anadyr },
@@ -1376,7 +1371,6 @@ public class TimeZoneNames_ug extends TimeZoneNamesBundle {
             { "America/Thule", Atlantic },
             { "Asia/Ashgabat", Turkmenistan },
             { "Asia/Calcutta", India },
-            { "Asia/Damascus", Europe_Eastern },
             { "Asia/Dushanbe", Tajikistan },
             { "Asia/Jayapura", Indonesia_Eastern },
             { "Asia/Katmandu", Nepal },
@@ -1391,11 +1385,11 @@ public class TimeZoneNames_ug extends TimeZoneNamesBundle {
             { "Europe/Dublin",
                 new String[] {
                     "\u06af\u0649\u0631\u0649\u0646\u06cb\u0649\u0686 \u06cb\u0627\u0642\u062a\u0649",
-                    "",
+                    "GMT",
                     "\u0626\u0649\u0631\u06d0\u0644\u0627\u0646\u062f \u064a\u0627\u0632\u0644\u0649\u0642 \u06cb\u0627\u0642\u062a\u0649",
+                    "IST",
                     "",
-                    "",
-                    "",
+                    "GMT",
                 }
             },
             { "Europe/Jersey", GMT },
@@ -1403,11 +1397,11 @@ public class TimeZoneNames_ug extends TimeZoneNamesBundle {
             { "Europe/London",
                 new String[] {
                     "\u06af\u0649\u0631\u0649\u0646\u06cb\u0649\u0686 \u06cb\u0627\u0642\u062a\u0649",
-                    "",
+                    "GMT",
                     "\u0626\u06d5\u0646\u06af\u0644\u0649\u064a\u06d5 \u064a\u0627\u0632\u0644\u0649\u0642 \u06cb\u0627\u0642\u062a\u0649",
+                    "BST",
                     "",
-                    "",
-                    "",
+                    "GMT",
                 }
             },
             { "Europe/Madrid", Europe_Central },
@@ -1439,7 +1433,6 @@ public class TimeZoneNames_ug extends TimeZoneNamesBundle {
             { "America/Cancun", America_Eastern },
             { "America/Cayman", America_Eastern },
             { "America/Cuiaba", Amazon },
-            { "America/Dawson", America_Pacific },
             { "America/Guyana", Guyana },
             { "America/Havana", Cuba },
             { "America/Inuvik", America_Mountain },
@@ -1465,11 +1458,11 @@ public class TimeZoneNames_ug extends TimeZoneNamesBundle {
             { "Europe/Belfast",
                 new String[] {
                     "\u06af\u0649\u0631\u0649\u0646\u06cb\u0649\u0686 \u06cb\u0627\u0642\u062a\u0649",
-                    "",
+                    "GMT",
                     "\u0626\u06d5\u0646\u06af\u0644\u0649\u064a\u06d5 \u064a\u0627\u0632\u0644\u0649\u0642 \u06cb\u0627\u0642\u062a\u0649",
+                    "BST",
                     "",
-                    "",
-                    "",
+                    "GMT",
                 }
             },
             { "Europe/Tallinn", Europe_Eastern },
@@ -1515,7 +1508,7 @@ public class TimeZoneNames_ug extends TimeZoneNamesBundle {
             { "America/Moncton", Atlantic },
             { "America/Nipigon", America_Eastern },
             { "America/Noronha", Noronha },
-            { "America/Ojinaga", America_Mountain },
+            { "America/Ojinaga", America_Central },
             { "America/Tijuana", America_Pacific },
             { "America/Toronto", America_Eastern },
             { "America/Tortola", Atlantic },
@@ -1565,7 +1558,7 @@ public class TimeZoneNames_ug extends TimeZoneNamesBundle {
             { "America/St_Kitts", Atlantic },
             { "America/St_Lucia", Atlantic },
             { "America/Winnipeg", America_Central },
-            { "Antarctica/Casey", Australia_Western },
+            { "Antarctica/Casey", Casey },
             { "Antarctica/Davis", Davis },
             { "Antarctica/Syowa", Syowa },
             { "Antarctica/Troll", GMT },
@@ -1601,7 +1594,7 @@ public class TimeZoneNames_ug extends TimeZoneNamesBundle {
             { "America/Araguaina", Brasilia },
             { "America/Boa_Vista", Amazon },
             { "America/Catamarca", Argentina },
-            { "America/Chihuahua", Mexico_Pacific },
+            { "America/Chihuahua", America_Central },
             { "America/Fortaleza", Brasilia },
             { "America/Glace_Bay", Atlantic },
             { "America/Goose_Bay", Atlantic },
@@ -1646,7 +1639,6 @@ public class TimeZoneNames_ug extends TimeZoneNamesBundle {
             { "America/Paramaribo", Suriname },
             { "America/Rio_Branco", Acre },
             { "America/St_Vincent", Atlantic },
-            { "America/Whitehorse", America_Pacific },
             { "Antarctica/McMurdo", New_Zealand },
             { "Antarctica/Rothera", Rothera },
             { "Asia/Yekaterinburg", Yekaterinburg },
@@ -1686,9 +1678,10 @@ public class TimeZoneNames_ug extends TimeZoneNamesBundle {
             { "America/Rankin_Inlet", America_Central },
             { "America/Santa_Isabel", Mexico_Northwest },
             { "America/Scoresbysund", Greenland_Eastern },
-            { "Antarctica/Macquarie", Macquarie },
+            { "Antarctica/Macquarie", Australia_Eastern },
             { "Pacific/Port_Moresby", Papua_New_Guinea },
             { "America/Cambridge_Bay", America_Mountain },
+            { "America/Ciudad_Juarez", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
             { "America/Indiana/Vevay", America_Eastern },
             { "America/Lower_Princes", Atlantic },
