@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -72,11 +68,11 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
     protected final Object[][] getContents() {
         final String[] GMT = new String[] {
                "\u0413\u0440\u0438\u043d\u0432\u0438\u0447 \u0432\u0430\u049b\u0442\u0438",
+               "GMT",
                "",
+               "GMT",
                "",
-               "",
-               "",
-               "",
+               "GMT",
             };
         final String[] Cook = new String[] {
                "\u041a\u0443\u043a \u043e\u0440\u043e\u043b\u043b\u0430\u0440\u0438 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
@@ -88,11 +84,11 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
             };
         final String[] Cuba = new String[] {
                "\u041a\u0443\u0431\u0430 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
-               "",
+               "CST",
                "\u041a\u0443\u0431\u0430 \u043a\u0443\u043d\u0434\u0443\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
-               "",
+               "CDT",
                "\u041a\u0443\u0431\u0430 \u0432\u0430\u049b\u0442\u0438",
-               "",
+               "CT",
             };
         final String[] Fiji = new String[] {
                "\u0424\u0438\u0436\u0438 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
@@ -176,11 +172,11 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
             };
         final String[] China = new String[] {
                "\u0425\u0438\u0442\u043e\u0439 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
-               "",
+               "CST",
                "\u0425\u0438\u0442\u043e\u0439 \u043a\u0443\u043d\u0434\u0443\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
-               "",
+               "CDT",
                "\u0425\u0438\u0442\u043e\u0439 \u0432\u0430\u049b\u0442\u0438",
-               "",
+               "CT",
             };
         final String[] Cocos = new String[] {
                "\u041a\u043e\u043a\u043e\u0441 \u043e\u0440\u043e\u043b\u043b\u0430\u0440\u0438 \u0432\u0430\u049b\u0442\u0438",
@@ -208,19 +204,19 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
             };
         final String[] Japan = new String[] {
                "\u042f\u043f\u043e\u043d\u0438\u044f \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
-               "",
+               "JST",
                "\u042f\u043f\u043e\u043d\u0438\u044f \u043a\u0443\u043d\u0434\u0443\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
-               "",
+               "JDT",
                "\u042f\u043f\u043e\u043d\u0438\u044f \u0432\u0430\u049b\u0442\u0438",
-               "",
+               "JT",
             };
         final String[] Korea = new String[] {
                "\u041a\u043e\u0440\u0435\u044f \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
-               "",
+               "KST",
                "\u041a\u043e\u0440\u0435\u044f \u043a\u0443\u043d\u0434\u0443\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
-               "",
+               "KST",
                "\u041a\u043e\u0440\u0435\u044f \u0432\u0430\u049b\u0442\u0438",
-               "",
+               "KST",
             };
         final String[] Nauru = new String[] {
                "\u041d\u0430\u0443\u0440\u0443 \u0432\u0430\u049b\u0442\u0438",
@@ -248,11 +244,11 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
             };
         final String[] Samoa = new String[] {
                "\u0421\u0430\u043c\u043e\u0430 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
-               "",
+               "SST",
                "\u0421\u0430\u043c\u043e\u0430 \u043a\u0443\u043d\u0434\u0443\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
-               "",
+               "SST",
                "\u0421\u0430\u043c\u043e\u0430 \u0432\u0430\u049b\u0442\u0438",
-               "",
+               "SST",
             };
         final String[] Syowa = new String[] {
                "\u0421\u044c\u043e\u0432\u0430 \u0432\u0430\u049b\u0442\u0438",
@@ -288,11 +284,11 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
             };
         final String[] Azores = new String[] {
                "\u0410\u0437\u043e\u0440 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
-               "",
+               "HMT",
                "\u0410\u0437\u043e\u0440 \u0451\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
-               "",
+               "HMT",
                "\u0410\u0437\u043e\u0440 \u0432\u0430\u049b\u0442\u0438",
-               "",
+               "HMT",
             };
         final String[] Bhutan = new String[] {
                "\u0411\u0443\u0442\u0430\u043d \u0432\u0430\u049b\u0442\u0438",
@@ -328,11 +324,11 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
             };
         final String[] Israel = new String[] {
                "\u0418\u0441\u0440\u043e\u0438\u043b \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
-               "",
+               "IST",
                "\u0418\u0441\u0440\u043e\u0438\u043b \u043a\u0443\u043d\u0434\u0443\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
-               "",
+               "IDT",
                "\u0418\u0441\u0440\u043e\u0438\u043b \u0432\u0430\u049b\u0442\u0438",
-               "",
+               "IT",
             };
         final String[] Kosrae = new String[] {
                "\u041a\u043e\u0441\u0440\u0430\u0435 \u0432\u0430\u049b\u0442\u0438",
@@ -352,11 +348,11 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
             };
         final String[] Moscow = new String[] {
                "\u041c\u043e\u0441\u043a\u0432\u0430 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
-               "",
+               "MSK",
                "\u041c\u043e\u0441\u043a\u0432\u0430 \u0451\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
-               "",
+               "MSK",
                "\u041c\u043e\u0441\u043a\u0432\u0430 \u0432\u0430\u049b\u0442\u0438",
-               "",
+               "MSK",
             };
         final String[] Ponape = new String[] {
                "\u041f\u043e\u043d\u0430\u043f\u0435 \u0432\u0430\u049b\u0442\u0438",
@@ -376,11 +372,11 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
             };
         final String[] Taipei = new String[] {
                "\u0422\u0430\u0439\u043f\u0435\u0439 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
-               "",
+               "CST",
                "\u0422\u0430\u0439\u043f\u0435\u0439 \u043a\u0443\u043d\u0434\u0443\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
-               "",
+               "CDT",
                "\u0422\u0430\u0439\u043f\u0435\u0439 \u0432\u0430\u049b\u0442\u0438",
-               "",
+               "CT",
             };
         final String[] Tuvalu = new String[] {
                "\u0422\u0443\u0432\u0430\u043b\u0443 \u0432\u0430\u049b\u0442\u0438",
@@ -560,11 +556,11 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
             };
         final String[] Atlantic = new String[] {
                "\u0410\u0442\u043b\u0430\u043d\u0442\u0438\u043a\u0430 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
-               "",
+               "AST",
                "\u0410\u0442\u043b\u0430\u043d\u0442\u0438\u043a\u0430 \u043a\u0443\u043d\u0434\u0443\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
-               "",
+               "ADT",
                "\u0410\u0442\u043b\u0430\u043d\u0442\u0438\u043a\u0430 \u0432\u0430\u049b\u0442\u0438",
-               "",
+               "AT",
             };
         final String[] Brasilia = new String[] {
                "\u0411\u0440\u0430\u0437\u0438\u043b\u0438\u044f \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
@@ -576,11 +572,11 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
             };
         final String[] Chamorro = new String[] {
                "\u041a\u0430\u043c\u043e\u0440\u0440\u043e \u0432\u0430\u049b\u0442\u0438",
+               "ChST",
                "",
+               "ChST",
                "",
-               "",
-               "",
-               "",
+               "ChST",
             };
         final String[] Colombia = new String[] {
                "\u041a\u043e\u043b\u0443\u043c\u0431\u0438\u044f \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
@@ -624,11 +620,11 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
             };
         final String[] Pakistan = new String[] {
                "\u041f\u043e\u043a\u0438\u0441\u0442\u043e\u043d \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
-               "",
+               "PKT",
                "\u041f\u043e\u043a\u0438\u0441\u0442\u043e\u043d \u0451\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
-               "",
+               "PKST",
                "\u041f\u043e\u043a\u0438\u0441\u0442\u043e\u043d \u0432\u0430\u049b\u0442\u0438",
-               "",
+               "PKT",
             };
         final String[] Paraguay = new String[] {
                "\u041f\u0430\u0440\u0430\u0433\u0432\u0430\u0439 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
@@ -688,11 +684,11 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
             };
         final String[] Hong_Kong = new String[] {
                "\u0413\u043e\u043d\u043a\u043e\u043d\u0433 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
-               "",
+               "HKT",
                "\u0413\u043e\u043d\u043a\u043e\u043d\u0433 \u0451\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
-               "",
+               "HKST",
                "\u0413\u043e\u043d\u043a\u043e\u043d\u0433 \u0432\u0430\u049b\u0442\u0438",
-               "",
+               "HKT",
             };
         final String[] Indochina = new String[] {
                "\u04b2\u0438\u043d\u0434-\u0425\u0438\u0442\u043e\u0439 \u0432\u0430\u049b\u0442\u0438",
@@ -718,14 +714,6 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
                "\u041b\u043e\u0440\u0434 \u0425\u043e\u0432\u0435 \u0432\u0430\u049b\u0442\u0438",
                "",
             };
-        final String[] Macquarie = new String[] {
-               "\u041c\u0430\u043a\u0432\u0430\u0440\u0438 \u043e\u0440\u043e\u043b\u0438 \u0432\u0430\u049b\u0442\u0438",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] Marquesas = new String[] {
                "\u041c\u0430\u0440\u043a\u0435\u0437\u0430\u0441 \u0432\u0430\u049b\u0442\u0438",
                "",
@@ -760,11 +748,11 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
             };
         final String[] Volgograd = new String[] {
                "\u0412\u043e\u043b\u0433\u043e\u0433\u0440\u0430\u0434 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
-               "",
+               "MSK",
                "\u0412\u043e\u043b\u0433\u043e\u0433\u0440\u0430\u0434 \u0451\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
-               "",
+               "MSK",
                "\u0412\u043e\u043b\u0433\u043e\u0433\u0440\u0430\u0434 \u0432\u0430\u049b\u0442\u0438",
-               "",
+               "MSK",
             };
         final String[] Azerbaijan = new String[] {
                "\u041e\u0437\u0430\u0440\u0431\u0430\u0439\u0436\u043e\u043d \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
@@ -848,11 +836,11 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
             };
         final String[] New_Zealand = new String[] {
                "\u042f\u043d\u0433\u0438 \u0417\u0435\u043b\u0430\u043d\u0434\u0438\u044f \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
-               "",
+               "NZST",
                "\u042f\u043d\u0433\u0438 \u0417\u0435\u043b\u0430\u043d\u0434\u0438\u044f \u043a\u0443\u043d\u0434\u0443\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
-               "",
+               "NZDT",
                "\u042f\u043d\u0433\u0438 \u0417\u0435\u043b\u0430\u043d\u0434\u0438\u044f \u0432\u0430\u049b\u0442\u0438",
-               "",
+               "NZT",
             };
         final String[] Novosibirsk = new String[] {
                "\u041d\u043e\u0432\u043e\u0441\u0438\u0431\u0438\u0440\u0441\u043a \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
@@ -864,11 +852,11 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
             };
         final String[] Philippines = new String[] {
                "\u0424\u0438\u043b\u0438\u043f\u043f\u0438\u043d \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
-               "",
+               "PST",
                "\u0424\u0438\u043b\u0438\u043f\u043f\u0438\u043d \u0451\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
-               "",
+               "PDT",
                "\u0424\u0438\u043b\u0438\u043f\u043f\u0438\u043d \u0432\u0430\u049b\u0442\u0438",
-               "",
+               "PT",
             };
         final String[] Vladivostok = new String[] {
                "\u0412\u043b\u0430\u0434\u0438\u0432\u043e\u0441\u0442\u043e\u043a \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
@@ -896,11 +884,11 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
             };
         final String[] Newfoundland = new String[] {
                "\u041d\u044c\u044e\u0444\u0430\u0443\u043d\u0434\u043b\u0435\u043d\u0434 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
-               "",
+               "NST",
                "\u041d\u044c\u044e\u0444\u0430\u0443\u043d\u0434\u043b\u0435\u043d\u0434 \u043a\u0443\u043d\u0434\u0443\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
-               "",
+               "NDT",
                "\u041d\u044c\u044e\u0444\u0430\u0443\u043d\u0434\u043b\u0435\u043d\u0434 \u0432\u0430\u049b\u0442\u0438",
-               "",
+               "NT",
             };
         final String[] Turkmenistan = new String[] {
                "\u0422\u0443\u0440\u043a\u043c\u0430\u043d\u0438\u0441\u0442\u043e\u043d \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
@@ -944,27 +932,27 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
             };
         final String[] Africa_Central = new String[] {
                "\u041c\u0430\u0440\u043a\u0430\u0437\u0438\u0439 \u0410\u0444\u0440\u0438\u043a\u0430 \u0432\u0430\u049b\u0442\u0438",
+               "SAST",
                "",
+               "SAST",
                "",
-               "",
-               "",
-               "",
+               "SAST",
             };
         final String[] Africa_Eastern = new String[] {
                "\u0428\u0430\u0440\u049b\u0438\u0439 \u0410\u0444\u0440\u0438\u043a\u0430 \u0432\u0430\u049b\u0442\u0438",
+               "EAT",
                "",
+               "EAT",
                "",
-               "",
-               "",
-               "",
+               "EAT",
             };
         final String[] Africa_Western = new String[] {
                "\u0492\u0430\u0440\u0431\u0438\u0439 \u0410\u0444\u0440\u0438\u043a\u0430 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
-               "",
+               "WAT",
                "\u0492\u0430\u0440\u0431\u0438\u0439 \u0410\u0444\u0440\u0438\u043a\u0430 \u0451\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
-               "",
+               "WAT",
                "\u0492\u0430\u0440\u0431\u0438\u0439 \u0410\u0444\u0440\u0438\u043a\u0430 \u0432\u0430\u049b\u0442\u0438",
-               "",
+               "WAT",
             };
         final String[] DumontDUrville = new String[] {
                "\u0414\u0443\u043c\u043e\u043d\u0442-\u0434-\u0423\u0440\u0432\u0438\u043b \u0432\u0430\u049b\u0442\u0438",
@@ -976,59 +964,59 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
             };
         final String[] Europe_Central = new String[] {
                "\u041c\u0430\u0440\u043a\u0430\u0437\u0438\u0439 \u0415\u0432\u0440\u043e\u043f\u0430 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
-               "",
+               "CET",
                "\u041c\u0430\u0440\u043a\u0430\u0437\u0438\u0439 \u0415\u0432\u0440\u043e\u043f\u0430 \u0451\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
-               "",
+               "CEST",
                "\u041c\u0430\u0440\u043a\u0430\u0437\u0438\u0439 \u0415\u0432\u0440\u043e\u043f\u0430 \u0432\u0430\u049b\u0442\u0438",
-               "",
+               "CET",
             };
         final String[] Europe_Eastern = new String[] {
                "\u0428\u0430\u0440\u049b\u0438\u0439 \u0415\u0432\u0440\u043e\u043f\u0430 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
-               "",
+               "EET",
                "\u0428\u0430\u0440\u049b\u0438\u0439 \u0415\u0432\u0440\u043e\u043f\u0430 \u0451\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
-               "",
+               "EEST",
                "\u0428\u0430\u0440\u049b\u0438\u0439 \u0415\u0432\u0440\u043e\u043f\u0430 \u0432\u0430\u049b\u0442\u0438",
-               "",
+               "EET",
             };
         final String[] Europe_Western = new String[] {
                "\u0492\u0430\u0440\u0431\u0438\u0439 \u0415\u0432\u0440\u043e\u043f\u0430 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
-               "",
+               "FMT",
                "\u0492\u0430\u0440\u0431\u0438\u0439 \u0415\u0432\u0440\u043e\u043f\u0430 \u0451\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
-               "",
+               "FMT",
                "\u0492\u0430\u0440\u0431\u0438\u0439 \u0415\u0432\u0440\u043e\u043f\u0430 \u0432\u0430\u049b\u0442\u0438",
-               "",
+               "FMT",
             };
         final String[] Africa_Southern = new String[] {
                "\u0416\u0430\u043d\u0443\u0431\u0438\u0439 \u0410\u0444\u0440\u0438\u043a\u0430 \u0432\u0430\u049b\u0442\u0438",
+               "SAST",
                "",
+               "SAST",
                "",
-               "",
-               "",
-               "",
+               "SAST",
             };
         final String[] America_Central = new String[] {
                "\u0428\u0438\u043c\u043e\u043b\u0438\u0439 \u0410\u043c\u0435\u0440\u0438\u043a\u0430 \u043c\u0430\u0440\u043a\u0430\u0437\u0438\u0439 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
-               "",
+               "CST",
                "\u0428\u0438\u043c\u043e\u043b\u0438\u0439 \u0410\u043c\u0435\u0440\u0438\u043a\u0430 \u043c\u0430\u0440\u043a\u0430\u0437\u0438\u0439 \u043a\u0443\u043d\u0434\u0443\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
-               "",
+               "CDT",
                "\u0428\u0438\u043c\u043e\u043b\u0438\u0439 \u0410\u043c\u0435\u0440\u0438\u043a\u0430",
-               "",
+               "CT",
             };
         final String[] America_Eastern = new String[] {
                "\u0428\u0438\u043c\u043e\u043b\u0438\u0439 \u0410\u043c\u0435\u0440\u0438\u043a\u0430 \u0448\u0430\u0440\u049b\u0438\u0439 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
-               "",
+               "EST",
                "\u0428\u0438\u043c\u043e\u043b\u0438\u0439 \u0410\u043c\u0435\u0440\u0438\u043a\u0430 \u0448\u0430\u0440\u049b\u0438\u0439 \u043a\u0443\u043d\u0434\u0443\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
-               "",
+               "EST",
                "\u0428\u0438\u043c\u043e\u043b\u0438\u0439 \u0410\u043c\u0435\u0440\u0438\u043a\u0430 \u0448\u0430\u0440\u049b\u0438\u0439 \u0432\u0430\u049b\u0442\u0438",
-               "",
+               "EST",
             };
         final String[] America_Pacific = new String[] {
                "\u0428\u0438\u043c\u043e\u043b\u0438\u0439 \u0410\u043c\u0435\u0440\u0438\u043a\u0430 \u0442\u0438\u043d\u0447 \u043e\u043a\u0435\u0430\u043d\u0438 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
-               "",
+               "PST",
                "\u0428\u0438\u043c\u043e\u043b\u0438\u0439 \u0410\u043c\u0435\u0440\u0438\u043a\u0430 \u0442\u0438\u043d\u0447 \u043e\u043a\u0435\u0430\u043d\u0438 \u043a\u0443\u043d\u0434\u0443\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
-               "",
+               "PDT",
                "\u0428\u0438\u043c\u043e\u043b\u0438\u0439 \u0410\u043c\u0435\u0440\u0438\u043a\u0430 \u0442\u0438\u043d\u0447 \u043e\u043a\u0435\u0430\u043d\u0438 \u0432\u0430\u049b\u0442\u0438",
-               "",
+               "PT",
             };
         final String[] French_Southern = new String[] {
                "\u0424\u0440\u0430\u043d\u0446\u0443\u0437 \u0436\u0430\u043d\u0443\u0431\u0438\u0439 \u0432\u0430 \u0410\u043d\u0442\u0430\u0440\u043a\u0442\u0438\u043a\u0430 \u0432\u0430\u049b\u0442\u0438",
@@ -1048,11 +1036,11 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
             };
         final String[] Hawaii_Aleutian = new String[] {
                "\u0413\u0430\u0432\u0430\u0439\u0438-\u0430\u043b\u0435\u0443\u0442 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
-               "",
+               "HST",
                "\u0413\u0430\u0432\u0430\u0439\u0438-\u0430\u043b\u0435\u0443\u0442 \u043a\u0443\u043d\u0434\u0443\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
-               "",
+               "HST",
                "\u0413\u0430\u0432\u0430\u0439\u0438-\u0430\u043b\u0435\u0443\u0442 \u0432\u0430\u049b\u0442\u0438",
-               "",
+               "HST",
             };
         final String[] Phoenix_Islands = new String[] {
                "\u0424\u0435\u043d\u0438\u043a\u0441 \u043e\u0440\u043e\u043b\u043b\u0430\u0440\u0438 \u0432\u0430\u049b\u0442\u0438",
@@ -1072,11 +1060,11 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
             };
         final String[] America_Mountain = new String[] {
                "\u0428\u0438\u043c\u043e\u043b\u0438\u0439 \u0410\u043c\u0435\u0440\u0438\u043a\u0430 \u0442\u043e\u0493 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
-               "",
+               "MST",
                "\u0428\u0438\u043c\u043e\u043b\u0438\u0439 \u0410\u043c\u0435\u0440\u0438\u043a\u0430 \u0442\u043e\u0493 \u043a\u0443\u043d\u0434\u0443\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
-               "",
+               "MDT",
                "\u0428\u0438\u043c\u043e\u043b\u0438\u0439 \u0410\u043c\u0435\u0440\u0438\u043a\u0430 \u0442\u043e\u0493 \u0432\u0430\u049b\u0442\u0438",
-               "",
+               "MT",
             };
         final String[] Marshall_Islands = new String[] {
                "\u041c\u0430\u0440\u0448\u0430\u043b\u043b \u043e\u0440\u043e\u043b\u043b\u0430\u0440\u0438 \u0432\u0430\u049b\u0442\u0438",
@@ -1096,19 +1084,19 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
             };
         final String[] Australia_Central = new String[] {
                "\u041c\u0430\u0440\u043a\u0430\u0437\u0438\u0439 \u0410\u0432\u0441\u0442\u0440\u0430\u043b\u0438\u044f \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
-               "",
+               "ACST",
                "\u041c\u0430\u0440\u043a\u0430\u0437\u0438\u0439 \u0410\u0432\u0441\u0442\u0440\u0430\u043b\u0438\u044f \u043a\u0443\u043d\u0434\u0443\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
-               "",
+               "ACDT",
                "\u041c\u0430\u0440\u043a\u0430\u0437\u0438\u0439 \u0410\u0432\u0441\u0442\u0440\u0430\u043b\u0438\u044f \u0432\u0430\u049b\u0442\u0438",
-               "",
+               "ACT",
             };
         final String[] Australia_Eastern = new String[] {
                "\u0428\u0430\u0440\u049b\u0438\u0439 \u0410\u0432\u0441\u0442\u0440\u0430\u043b\u0438\u044f \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
-               "",
+               "AEST",
                "\u0428\u0430\u0440\u049b\u0438\u0439 \u0410\u0432\u0441\u0442\u0440\u0430\u043b\u0438\u044f \u043a\u0443\u043d\u0434\u0443\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
-               "",
+               "AEDT",
                "\u0428\u0430\u0440\u049b\u0438\u0439 \u0410\u0432\u0441\u0442\u0440\u0430\u043b\u0438\u044f \u0432\u0430\u049b\u0442\u0438",
-               "",
+               "AET",
             };
         final String[] Australia_Western = new String[] {
                "\u0492\u0430\u0440\u0431\u0438\u0439 \u0410\u0432\u0441\u0442\u0440\u0430\u043b\u0438\u044f \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
@@ -1136,27 +1124,27 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
             };
         final String[] Indonesia_Central = new String[] {
                "\u041c\u0430\u0440\u043a\u0430\u0437\u0438\u0439 \u0418\u043d\u0434\u043e\u043d\u0435\u0437\u0438\u044f \u0432\u0430\u049b\u0442\u0438",
+               "WITA",
                "",
+               "WITA",
                "",
-               "",
-               "",
-               "",
+               "WITA",
             };
         final String[] Indonesia_Eastern = new String[] {
                "\u0428\u0430\u0440\u049b\u0438\u0439 \u0418\u043d\u0434\u043e\u043d\u0435\u0437\u0438\u044f \u0432\u0430\u049b\u0442\u0438",
+               "WIT",
                "",
+               "WIT",
                "",
-               "",
-               "",
-               "",
+               "WIT",
             };
         final String[] Indonesia_Western = new String[] {
                "\u0492\u0430\u0440\u0431\u0438\u0439 \u0418\u043d\u0434\u043e\u043d\u0435\u0437\u0438\u044f \u0432\u0430\u049b\u0442\u0438",
+               "WIB",
                "",
+               "WIB",
                "",
-               "",
-               "",
-               "",
+               "WIB",
             };
         final String[] Kazakhstan_Eastern = new String[] {
                "\u0428\u0430\u0440\u049b\u0438\u0439 \u049a\u043e\u0437\u043e\u0493\u0438\u0441\u0442\u043e\u043d \u0432\u0430\u049b\u0442\u0438",
@@ -1233,7 +1221,6 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
             { "Asia/Hovd", Hovd },
             { "Asia/Omsk", Omsk },
             { "Asia/Oral", Kazakhstan_Western },
-            { "Asia/Amman", Europe_Eastern },
             { "Asia/Aqtau", Kazakhstan_Western },
             { "Asia/Chita", Yakutsk },
             { "Asia/Dhaka", Bangladesh },
@@ -1242,7 +1229,7 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
             { "Asia/Macau", China },
             { "Asia/Qatar", Arabian },
             { "Asia/Seoul", Korea },
-            { "Africa/Juba", Africa_Eastern },
+            { "Africa/Juba", Africa_Central },
             { "Africa/Lome", GMT },
             { "Asia/Almaty", Kazakhstan_Eastern },
             { "Asia/Aqtobe", Kazakhstan_Western },
@@ -1327,7 +1314,6 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
             { "America/Thule", Atlantic },
             { "Asia/Ashgabat", Turkmenistan },
             { "Asia/Calcutta", India },
-            { "Asia/Damascus", Europe_Eastern },
             { "Asia/Dushanbe", Tajikistan },
             { "Asia/Jayapura", Indonesia_Eastern },
             { "Asia/Katmandu", Nepal },
@@ -1342,11 +1328,11 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
             { "Europe/Dublin",
                 new String[] {
                     "\u0413\u0440\u0438\u043d\u0432\u0438\u0447 \u0432\u0430\u049b\u0442\u0438",
-                    "",
+                    "GMT",
                     "\u0418\u0440\u043b\u0430\u043d\u0434\u0438\u044f \u0451\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
+                    "IST",
                     "",
-                    "",
-                    "",
+                    "GMT",
                 }
             },
             { "Europe/Jersey", GMT },
@@ -1354,11 +1340,11 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
             { "Europe/London",
                 new String[] {
                     "\u0413\u0440\u0438\u043d\u0432\u0438\u0447 \u0432\u0430\u049b\u0442\u0438",
-                    "",
+                    "GMT",
                     "\u0411\u0440\u0438\u0442\u0430\u043d\u0438\u044f \u0451\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
+                    "BST",
                     "",
-                    "",
-                    "",
+                    "GMT",
                 }
             },
             { "Europe/Madrid", Europe_Central },
@@ -1389,7 +1375,6 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
             { "America/Cancun", America_Eastern },
             { "America/Cayman", America_Eastern },
             { "America/Cuiaba", Amazon },
-            { "America/Dawson", America_Pacific },
             { "America/Guyana", Guyana },
             { "America/Havana", Cuba },
             { "America/Inuvik", America_Mountain },
@@ -1414,11 +1399,11 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
             { "Europe/Belfast",
                 new String[] {
                     "\u0413\u0440\u0438\u043d\u0432\u0438\u0447 \u0432\u0430\u049b\u0442\u0438",
-                    "",
+                    "GMT",
                     "\u0411\u0440\u0438\u0442\u0430\u043d\u0438\u044f \u0451\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
+                    "BST",
                     "",
-                    "",
-                    "",
+                    "GMT",
                 }
             },
             { "Europe/Tallinn", Europe_Eastern },
@@ -1464,7 +1449,7 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
             { "America/Moncton", Atlantic },
             { "America/Nipigon", America_Eastern },
             { "America/Noronha", Noronha },
-            { "America/Ojinaga", America_Mountain },
+            { "America/Ojinaga", America_Central },
             { "America/Tijuana", America_Pacific },
             { "America/Toronto", America_Eastern },
             { "America/Tortola", Atlantic },
@@ -1512,7 +1497,6 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
             { "America/St_Kitts", Atlantic },
             { "America/St_Lucia", Atlantic },
             { "America/Winnipeg", America_Central },
-            { "Antarctica/Casey", Australia_Western },
             { "Antarctica/Davis", Davis },
             { "Antarctica/Syowa", Syowa },
             { "Antarctica/Troll", GMT },
@@ -1548,6 +1532,7 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
             { "America/Araguaina", Brasilia },
             { "America/Boa_Vista", Amazon },
             { "America/Catamarca", Argentina },
+            { "America/Chihuahua", America_Central },
             { "America/Fortaleza", Brasilia },
             { "America/Glace_Bay", Atlantic },
             { "America/Goose_Bay", Atlantic },
@@ -1590,7 +1575,6 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
             { "America/Montserrat", Atlantic },
             { "America/Paramaribo", Suriname },
             { "America/St_Vincent", Atlantic },
-            { "America/Whitehorse", America_Pacific },
             { "Antarctica/McMurdo", New_Zealand },
             { "Antarctica/Rothera", Rothera },
             { "Asia/Yekaterinburg", Yekaterinburg },
@@ -1629,9 +1613,10 @@ public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
             { "America/Indiana/Knox", America_Central },
             { "America/Rankin_Inlet", America_Central },
             { "America/Scoresbysund", Greenland_Eastern },
-            { "Antarctica/Macquarie", Macquarie },
+            { "Antarctica/Macquarie", Australia_Eastern },
             { "Pacific/Port_Moresby", Papua_New_Guinea },
             { "America/Cambridge_Bay", America_Mountain },
+            { "America/Ciudad_Juarez", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
             { "America/Indiana/Vevay", America_Eastern },
             { "America/Lower_Princes", Atlantic },
