@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2023, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -68,11 +68,11 @@ public class TimeZoneNames_yrl extends TimeZoneNamesBundle {
     protected final Object[][] getContents() {
         final String[] GMT = new String[] {
                "Greenwich Miridiyanu yara Hurariyu",
+               "GMT",
                "",
+               "GMT",
                "",
-               "",
-               "",
-               "",
+               "GMT",
             };
         final String[] Acre = new String[] {
                "Hurariyu Retewa Acre yara",
@@ -100,11 +100,11 @@ public class TimeZoneNames_yrl extends TimeZoneNamesBundle {
             };
         final String[] Cuba = new String[] {
                "Kuba Hurariyu Retewa",
-               "",
+               "CST",
                "Kuba Kuras\u00ed Ara Hurariyu",
-               "",
+               "CDT",
                "Kuba Hurariyu",
-               "",
+               "CT",
             };
         final String[] Fiji = new String[] {
                "Fiyi Hurariyu Retewa",
@@ -188,11 +188,11 @@ public class TimeZoneNames_yrl extends TimeZoneNamesBundle {
             };
         final String[] China = new String[] {
                "Xina Hurariyu Retewa",
-               "",
+               "CST",
                "Xina Kuras\u00ed Ara Hurariyu",
-               "",
+               "CDT",
                "Xina Hurariyu",
-               "",
+               "CT",
             };
         final String[] Cocos = new String[] {
                "Kapu\u00e3-ita Kuku-ita Hurariyu",
@@ -220,19 +220,19 @@ public class TimeZoneNames_yrl extends TimeZoneNamesBundle {
             };
         final String[] Japan = new String[] {
                "Nip\u00f5 Hurariyu Retewa",
-               "",
+               "JST",
                "Nip\u00f5 Kuras\u00ed Ara Hurariyu",
-               "",
+               "JDT",
                "Nip\u00f5 Hurariyu",
-               "",
+               "JT",
             };
         final String[] Korea = new String[] {
                "Kureya Hurariyu Retewa",
-               "",
+               "KST",
                "Kureya Kuras\u00ed Ara Hurariyu",
-               "",
+               "KST",
                "Kureya Hurariyu",
-               "",
+               "KST",
             };
         final String[] Nauru = new String[] {
                "Nauru Hurariyu",
@@ -260,11 +260,11 @@ public class TimeZoneNames_yrl extends TimeZoneNamesBundle {
             };
         final String[] Samoa = new String[] {
                "Samowa Hurariyu Retewa",
-               "",
+               "SST",
                "Samowa Kuras\u00ed Ara Hurariyu",
-               "",
+               "SST",
                "Samowa Hurariyu",
-               "",
+               "SST",
             };
         final String[] Syowa = new String[] {
                "Siyowa Hurariyu",
@@ -308,11 +308,11 @@ public class TimeZoneNames_yrl extends TimeZoneNamesBundle {
             };
         final String[] Azores = new String[] {
                "Asori-ita Hurariyu Retewa",
-               "",
+               "HMT",
                "Asori-ita Kuras\u00ed Ara Hurariyu",
-               "",
+               "HMT",
                "Asori-ita Hurariyu",
-               "",
+               "HMT",
             };
         final String[] Bhutan = new String[] {
                "But\u00e3u Hurariyu",
@@ -348,11 +348,11 @@ public class TimeZoneNames_yrl extends TimeZoneNamesBundle {
             };
         final String[] Israel = new String[] {
                "Isirayeu Hurariyu Retewa",
-               "",
+               "IST",
                "Isirayeu Kuras\u00ed Ara Hurariyu",
-               "",
+               "IDT",
                "Isirayeu Hurariyu",
-               "",
+               "IT",
             };
         final String[] Kosrae = new String[] {
                "Kusirai Hurariyu",
@@ -372,11 +372,11 @@ public class TimeZoneNames_yrl extends TimeZoneNamesBundle {
             };
         final String[] Moscow = new String[] {
                "Moskou Hurariyu Retewa",
-               "",
+               "MSK",
                "Moskou Kuras\u00ed Ara Hurariyu",
-               "",
+               "MSK",
                "Moskou Hurariyu",
-               "",
+               "MSK",
             };
         final String[] Ponape = new String[] {
                "Ponape Hurariyu",
@@ -404,11 +404,11 @@ public class TimeZoneNames_yrl extends TimeZoneNamesBundle {
             };
         final String[] Taipei = new String[] {
                "Taipei Hurariyu Retewa",
-               "",
+               "CST",
                "Taipei Kuras\u00ed Ara Hurariyu",
-               "",
+               "CDT",
                "Taipei Hurariyu",
-               "",
+               "CT",
             };
         final String[] Tuvalu = new String[] {
                "Tuvaru Hurariyu",
@@ -596,11 +596,11 @@ public class TimeZoneNames_yrl extends TimeZoneNamesBundle {
             };
         final String[] Atlantic = new String[] {
                "Atal\u00e3tiku Hurariyu Retewa",
-               "",
+               "AST",
                "Atal\u00e3tku Kuras\u00ed Ara Hurariyu",
-               "",
+               "ADT",
                "Atal\u00e3tiku Hurariyu",
-               "",
+               "AT",
             };
         final String[] Brasilia = new String[] {
                "\u00d3ra P\u00e3 Bras\u00edlia t\u00e1",
@@ -612,11 +612,11 @@ public class TimeZoneNames_yrl extends TimeZoneNamesBundle {
             };
         final String[] Chamorro = new String[] {
                "Xamoro Hurariyu",
+               "ChST",
                "",
+               "ChST",
                "",
-               "",
-               "",
-               "",
+               "ChST",
             };
         final String[] Colombia = new String[] {
                "Kur\u0169bia Hurariyu Retewa",
@@ -660,11 +660,11 @@ public class TimeZoneNames_yrl extends TimeZoneNamesBundle {
             };
         final String[] Pakistan = new String[] {
                "Pakiret\u00e3ma Hurariyu Retewa",
-               "",
+               "PKT",
                "Pakiret\u00e3ma Kuras\u00ed Ara Hurariyu",
-               "",
+               "PKST",
                "Pakiret\u00e3ma Hurariyu",
-               "",
+               "PKT",
             };
         final String[] Paraguay = new String[] {
                "Paraguwai Hurariyu Retewa",
@@ -724,11 +724,11 @@ public class TimeZoneNames_yrl extends TimeZoneNamesBundle {
             };
         final String[] Hong_Kong = new String[] {
                "H\u0169g K\u0169g Hurariyu Retewa",
-               "",
+               "HKT",
                "H\u0169g K\u0169g Kuras\u00ed Ara Hurariyu",
-               "",
+               "HKST",
                "H\u0169g K\u0169g Hurariyu",
-               "",
+               "HKT",
             };
         final String[] Indochina = new String[] {
                "\u0128doxina Hurariyu",
@@ -796,11 +796,11 @@ public class TimeZoneNames_yrl extends TimeZoneNamesBundle {
             };
         final String[] Volgograd = new String[] {
                "Worwogaradu Hurariyu Retewa",
-               "",
+               "MSK",
                "Worwogaradu Kuras\u00ed Ara Hurariyu",
-               "",
+               "MSK",
                "Worwogaradu Hurariyu",
-               "",
+               "MSK",
             };
         final String[] Azerbaijan = new String[] {
                "Aseriret\u00e3ma Hurariyu Retewa",
@@ -876,11 +876,11 @@ public class TimeZoneNames_yrl extends TimeZoneNamesBundle {
             };
         final String[] New_Zealand = new String[] {
                "Ser\u00e3diya Pisas\u00fa Hurariyu Retewa",
-               "",
+               "NZST",
                "Ser\u00e3diya Pisas\u00fa Kuras\u00ed Ara Hurariyu",
-               "",
+               "NZDT",
                "Ser\u00e3diya Pisas\u00fa Hurariyu",
-               "",
+               "NZT",
             };
         final String[] Novosibirsk = new String[] {
                "Sibirisiki Pisas\u00fa Hurariyu Retewa",
@@ -892,11 +892,11 @@ public class TimeZoneNames_yrl extends TimeZoneNamesBundle {
             };
         final String[] Philippines = new String[] {
                "Firipina Hurariyu Retewa",
-               "",
+               "PST",
                "Firipina Kuras\u00ed Ara Hurariyu",
-               "",
+               "PDT",
                "Firipina Hurariyu",
-               "",
+               "PT",
             };
         final String[] Vladivostok = new String[] {
                "Waradiwosituki Hurariyu Retewa",
@@ -924,11 +924,11 @@ public class TimeZoneNames_yrl extends TimeZoneNamesBundle {
             };
         final String[] Newfoundland = new String[] {
                "Iw\u00ed Pisas\u00fa Hurariyu Retewa",
-               "",
+               "NST",
                "Iw\u00ed Pisas\u00fa Kuras\u00ed Ara Hurariyu",
-               "",
+               "NDT",
                "Iw\u00ed Pisas\u00fa Hurariyu",
-               "",
+               "NT",
             };
         final String[] Turkmenistan = new String[] {
                "Turkuranaret\u00e3ma Hurariyu Retewa",
@@ -972,27 +972,27 @@ public class TimeZoneNames_yrl extends TimeZoneNamesBundle {
             };
         final String[] Africa_Central = new String[] {
                "Afirika Piterawara Hurariyu",
+               "SAST",
                "",
+               "SAST",
                "",
-               "",
-               "",
-               "",
+               "SAST",
             };
         final String[] Africa_Eastern = new String[] {
                "Afirika Uri\u1ebdtawara Hurariyu",
+               "EAT",
                "",
+               "EAT",
                "",
-               "",
-               "",
-               "",
+               "EAT",
             };
         final String[] Africa_Western = new String[] {
                "Afirika Usid\u1ebdtawara Hurariyu Retewa",
-               "",
+               "WAT",
                "Afirika Usid\u1ebdtawara Kuras\u00ed Ara Hurariyu",
-               "",
+               "WAT",
                "Afirikia Usid\u1ebdtawara Hurariyu",
-               "",
+               "WAT",
             };
         final String[] DumontDUrville = new String[] {
                "Dumont-d\u2019Urville Hurariyu",
@@ -1004,67 +1004,67 @@ public class TimeZoneNames_yrl extends TimeZoneNamesBundle {
             };
         final String[] Europe_Central = new String[] {
                "Eurupa Piterawara Hurariyu Retewa",
-               "",
+               "CET",
                "Eurupa Piterawara Kuras\u00ed Ara Hurariyu",
-               "",
+               "CEST",
                "Eurupa Piterawara Hurariyu",
-               "",
+               "CET",
             };
         final String[] Europe_Eastern = new String[] {
                "Eurupa Uri\u1ebdtawara Hurariyu Retewa",
-               "",
+               "EET",
                "Eurupa Uri\u1ebdtawara Kuras\u00ed Ara Hurariyu",
-               "",
+               "EEST",
                "Eurupa Uri\u1ebdtawara Hurariyu",
-               "",
+               "EET",
             };
         final String[] Europe_Western = new String[] {
                "Eurupa Usid\u1ebdtawara Hurariyu Retewa",
-               "",
+               "FMT",
                "Eurupa Usid\u1ebdtawara Kuras\u00ed Ara Hurariyu",
-               "",
+               "FMT",
                "Eurupa Usid\u1ebdtawara Hurariyu",
-               "",
+               "FMT",
             };
         final String[] Mexico_Pacific = new String[] {
                "Pasifiku Mexikanu Hurariyu Retewa",
-               "",
+               "MST",
                "Pasifiku Mexikanu Kuras\u00ed Ara Hurariyu",
-               "",
+               "MDT",
                "Pasifiku Mexikanu Hurariyu",
-               "",
+               "MT",
             };
         final String[] Africa_Southern = new String[] {
                "Afirika Su su\u00ed Hurariyu",
+               "SAST",
                "",
+               "SAST",
                "",
-               "",
-               "",
-               "",
+               "SAST",
             };
         final String[] America_Central = new String[] {
                "Hurariyu Retewa Piterawara",
-               "",
+               "CST",
                "Hurariyu Kuras\u00ed Ara Piterawara",
-               "",
+               "CDT",
                "\u00d3ra Kuju",
-               "",
+               "CT",
             };
         final String[] America_Eastern = new String[] {
                "Hurariyu Retewa Lesiti yara",
-               "",
+               "EST",
                "Hurariyu Kuras\u00ed Ara Lesiti",
-               "",
+               "EST",
                "Hurariyu Lesiti",
-               "",
+               "EST",
             };
         final String[] America_Pacific = new String[] {
                "\u00d3ra P\u00e3 Pasifiku t\u00e1",
-               "",
+               "PST",
                "R\u1ef9 K\u00e3 \u00d3ra Pasifiku t\u00e1",
-               "",
+               "PDT",
                "\u00d3ra Pasifiku t\u00e1",
-               "",
+               "PT",
             };
         final String[] French_Southern = new String[] {
                "Tet\u00e3ma Su su\u00ed Fr\u00e3sa yara asu\u00ed \u00c3tartida Hurariyu",
@@ -1084,11 +1084,11 @@ public class TimeZoneNames_yrl extends TimeZoneNamesBundle {
             };
         final String[] Hawaii_Aleutian = new String[] {
                "Hawa\u00ed asu\u00ed Kapu\u00e3-ita Areuta-ita Hurariyu Retewa",
-               "",
+               "HST",
                "Hawa\u00ed asu\u00ed Kapu\u00e3-ita Areuta-ita Kuras\u00ed Ara Hurariyu",
-               "",
+               "HST",
                "Hawa\u00ed asu\u00ed Kapu\u00e3-ita Areuta-ita Hurariyu",
-               "",
+               "HST",
             };
         final String[] Phoenix_Islands = new String[] {
                "Kapu\u00e3-ita F\u1ebdnix",
@@ -1108,11 +1108,11 @@ public class TimeZoneNames_yrl extends TimeZoneNamesBundle {
             };
         final String[] America_Mountain = new String[] {
                "\u00d3ra P\u00e3 Kr\u0129-ag t\u00e1",
-               "",
+               "MST",
                "R\u1ef9 k\u00e3 \u00d3ra Kr\u0129-ag t\u00e1",
-               "",
+               "MDT",
                "\u00d3ra Kr\u0129-ag t\u00e1",
-               "",
+               "MT",
             };
         final String[] Marshall_Islands = new String[] {
                "Kapu\u00e3-ita Marshall Hurariyu",
@@ -1140,19 +1140,19 @@ public class TimeZoneNames_yrl extends TimeZoneNamesBundle {
             };
         final String[] Australia_Central = new String[] {
                "Ausitaraliya Piterawara Hurariyu Retewa",
-               "",
+               "ACST",
                "Ausitaraliya Piterawara Kuras\u00ed Ara Hurariyu",
-               "",
+               "ACDT",
                "Ausitaraliya Piterawara Hurariyu",
-               "",
+               "ACT",
             };
         final String[] Australia_Eastern = new String[] {
                "Ausitaraliya Uri\u1ebdtawara Hurariyu Retewa",
-               "",
+               "AEST",
                "Ausitaraliya Uri\u1ebdtawara Kuras\u00ed Ara Hurariyu",
-               "",
+               "AEDT",
                "Ausitaraliya Uri\u1ebdtawara Hurariyu",
-               "",
+               "AET",
             };
         final String[] Australia_Western = new String[] {
                "Ausitaraliya Usid\u1ebdtawara Hurariyu Retewa",
@@ -1180,27 +1180,27 @@ public class TimeZoneNames_yrl extends TimeZoneNamesBundle {
             };
         final String[] Indonesia_Central = new String[] {
                "\u0128donesiya Piterawara Hurariyu",
+               "WITA",
                "",
+               "WITA",
                "",
-               "",
-               "",
-               "",
+               "WITA",
             };
         final String[] Indonesia_Eastern = new String[] {
                "\u0128donesiya Uri\u1ebdtawara Hurariyu",
+               "WIT",
                "",
+               "WIT",
                "",
-               "",
-               "",
-               "",
+               "WIT",
             };
         final String[] Indonesia_Western = new String[] {
                "\u0128donesiya Usid\u1ebdtawara Hurariyu",
+               "WIB",
                "",
+               "WIB",
                "",
-               "",
-               "",
-               "",
+               "WIB",
             };
         final String[] Kazakhstan_Eastern = new String[] {
                "Kasakiret\u00e3ma Uri\u1ebdtawara Hurariyu",
@@ -1279,7 +1279,6 @@ public class TimeZoneNames_yrl extends TimeZoneNamesBundle {
             { "Asia/Hovd", Hovd },
             { "Asia/Omsk", Omsk },
             { "Asia/Oral", Kazakhstan_Western },
-            { "Asia/Amman", Europe_Eastern },
             { "Asia/Aqtau", Kazakhstan_Western },
             { "Asia/Chita", Yakutsk },
             { "Asia/Dhaka", Bangladesh },
@@ -1375,7 +1374,6 @@ public class TimeZoneNames_yrl extends TimeZoneNamesBundle {
             { "America/Thule", Atlantic },
             { "Asia/Ashgabat", Turkmenistan },
             { "Asia/Calcutta", India },
-            { "Asia/Damascus", Europe_Eastern },
             { "Asia/Dushanbe", Tajikistan },
             { "Asia/Jayapura", Indonesia_Eastern },
             { "Asia/Katmandu", Nepal },
@@ -1390,11 +1388,11 @@ public class TimeZoneNames_yrl extends TimeZoneNamesBundle {
             { "Europe/Dublin",
                 new String[] {
                     "Greenwich Miridiyanu yara Hurariyu",
-                    "",
+                    "GMT",
                     "Hurariyu Retewa Ir\u00e3dei",
+                    "IST",
                     "",
-                    "",
-                    "",
+                    "GMT",
                 }
             },
             { "Europe/Jersey", GMT },
@@ -1402,11 +1400,11 @@ public class TimeZoneNames_yrl extends TimeZoneNamesBundle {
             { "Europe/London",
                 new String[] {
                     "Greenwich Miridiyanu yara Hurariyu",
-                    "",
+                    "GMT",
                     "Hurariyu Kuras\u00ed Ara Birit\u00e3niku",
+                    "BST",
                     "",
-                    "",
-                    "",
+                    "GMT",
                 }
             },
             { "Europe/Madrid", Europe_Central },
@@ -1463,11 +1461,11 @@ public class TimeZoneNames_yrl extends TimeZoneNamesBundle {
             { "Europe/Belfast",
                 new String[] {
                     "Greenwich Miridiyanu yara Hurariyu",
-                    "",
+                    "GMT",
                     "Hurariyu Kuras\u00ed Ara Birit\u00e3niku",
+                    "BST",
                     "",
-                    "",
-                    "",
+                    "GMT",
                 }
             },
             { "Europe/Tallinn", Europe_Eastern },
@@ -1685,6 +1683,7 @@ public class TimeZoneNames_yrl extends TimeZoneNamesBundle {
             { "Antarctica/Macquarie", Australia_Eastern },
             { "Pacific/Port_Moresby", Papua_New_Guinea },
             { "America/Cambridge_Bay", America_Mountain },
+            { "America/Ciudad_Juarez", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
             { "America/Indiana/Vevay", America_Eastern },
             { "America/Lower_Princes", Atlantic },
@@ -1706,7 +1705,6 @@ public class TimeZoneNames_yrl extends TimeZoneNamesBundle {
             { "America/Indiana/Vincennes", America_Eastern },
             { "Antarctica/DumontDUrville", DumontDUrville },
             { "timezone.excity.Asia/Aden", "Ad\u1ebd" },
-            { "timezone.excity.Asia/Baku", "Baku" },
             { "timezone.excity.Asia/Dili", "Diri" },
             { "timezone.excity.Asia/Gaza", "Gasa" },
             { "timezone.excity.Asia/Hovd", "Howidi" },
@@ -1720,7 +1718,6 @@ public class TimeZoneNames_yrl extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Aqtau", "Akitau" },
             { "timezone.excity.Asia/Chita", "Xita" },
             { "timezone.excity.Asia/Dhaka", "Daka" },
-            { "timezone.excity.Asia/Dubai", "Dubai" },
             { "timezone.excity.Asia/Kabul", "Kab\u00fa" },
             { "timezone.excity.Asia/Macau", "Makau" },
             { "timezone.excity.Asia/Qatar", "Katari" },
@@ -1743,19 +1740,16 @@ public class TimeZoneNames_yrl extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Manila", "Manira" },
             { "timezone.excity.Asia/Muscat", "Masikati" },
             { "timezone.excity.Asia/Riyadh", "Riade" },
-            { "timezone.excity.Asia/Taipei", "Taipei" },
             { "timezone.excity.Asia/Tehran", "Teyer\u00e3" },
             { "timezone.excity.Asia/Urumqi", "Ur\u0169ki" },
             { "timezone.excity.Etc/Unknown", "Tawa-was\u00fa \u0168bawaukuamam\u1ebd" },
             { "timezone.excity.Europe/Kiev", "Kiyewe" },
             { "timezone.excity.Europe/Oslo", "Usiru" },
-            { "timezone.excity.Europe/Riga", "Riga" },
             { "timezone.excity.Europe/Rome", "Roma" },
             { "timezone.excity.Indian/Mahe", "Ma\u00e9" },
             { "timezone.excity.Africa/Accra", "Akara" },
             { "timezone.excity.Africa/Cairo", "Kairu" },
             { "timezone.excity.Africa/Ceuta", "Seuta" },
-            { "timezone.excity.Africa/Dakar", "Dakar" },
             { "timezone.excity.Africa/Lagos", "Ipawaita" },
             { "timezone.excity.Africa/Tunis", "Tuni-ita" },
             { "timezone.excity.America/Adak", "Adaki" },
@@ -1781,7 +1775,6 @@ public class TimeZoneNames_yrl extends TimeZoneNamesBundle {
             { "timezone.excity.Europe/Kirov", "Kirowi" },
             { "timezone.excity.Europe/Malta", "Mauta" },
             { "timezone.excity.Europe/Minsk", "M\u0129siki" },
-            { "timezone.excity.Europe/Paris", "Paris" },
             { "timezone.excity.Europe/Sofia", "Sufiya" },
             { "timezone.excity.Europe/Vaduz", "Vadusi" },
             { "timezone.excity.Indian/Cocos", "Kuku-ita" },
@@ -1789,22 +1782,17 @@ public class TimeZoneNames_yrl extends TimeZoneNamesBundle {
             { "timezone.excity.Pacific/Fiji", "Fiyi" },
             { "timezone.excity.Pacific/Guam", "Guw\u00e3" },
             { "timezone.excity.Pacific/Niue", "Niwe" },
-            { "timezone.excity.Pacific/Wake", "Wake" },
             { "timezone.excity.Africa/Asmera", "Asimara" },
             { "timezone.excity.Africa/Bamako", "Bamaku" },
             { "timezone.excity.Africa/Bangui", "B\u00e3ki" },
             { "timezone.excity.Africa/Banjul", "B\u00e3j\u00fa" },
             { "timezone.excity.Africa/Bissau", "Bisau" },
             { "timezone.excity.Africa/Douala", "Duwala" },
-            { "timezone.excity.Africa/Harare", "Harare" },
             { "timezone.excity.Africa/Kigali", "Kigari" },
             { "timezone.excity.Africa/Luanda", "Ru\u00e3da" },
-            { "timezone.excity.Africa/Lusaka", "Lusaka" },
             { "timezone.excity.Africa/Malabo", "Malabu" },
             { "timezone.excity.Africa/Maputo", "Maputu" },
-            { "timezone.excity.Africa/Maseru", "Maseru" },
             { "timezone.excity.Africa/Niamey", "Niamei" },
-            { "timezone.excity.America/Aruba", "Aruba" },
             { "timezone.excity.America/Bahia", "Ba\u00edya" },
             { "timezone.excity.America/Belem", "Bel\u1ebd" },
             { "timezone.excity.America/Boise", "Buwis\u00e9" },
@@ -1833,7 +1821,6 @@ public class TimeZoneNames_yrl extends TimeZoneNamesBundle {
             { "timezone.excity.Europe/Monaco", "Munaku" },
             { "timezone.excity.Europe/Moscow", "Moskou" },
             { "timezone.excity.Europe/Prague", "Praga" },
-            { "timezone.excity.Europe/Samara", "Samara" },
             { "timezone.excity.Europe/Skopje", "Isikupiye" },
             { "timezone.excity.Europe/Tirane", "Tirana" },
             { "timezone.excity.Europe/Vienna", "Wiyena" },
@@ -1843,7 +1830,6 @@ public class TimeZoneNames_yrl extends TimeZoneNamesBundle {
             { "timezone.excity.Indian/Chagos", "Xagu-ita" },
             { "timezone.excity.Indian/Comoro", "Kumure-ita" },
             { "timezone.excity.Pacific/Efate", "Efat\u00e9" },
-            { "timezone.excity.Pacific/Nauru", "Nauru" },
             { "timezone.excity.Pacific/Palau", "Parau" },
             { "America/Argentina/Rio_Gallegos", Argentina },
             { "America/North_Dakota/New_Salem", America_Central },
@@ -1865,10 +1851,8 @@ public class TimeZoneNames_yrl extends TimeZoneNamesBundle {
             { "timezone.excity.America/Havana", "Hawana" },
             { "timezone.excity.America/Inuvik", "Inuwiki" },
             { "timezone.excity.America/Juneau", "Yuneau" },
-            { "timezone.excity.America/La_Paz", "La Paz" },
             { "timezone.excity.America/Maceio", "Masey\u00f3" },
             { "timezone.excity.America/Manaus", "Manau" },
-            { "timezone.excity.America/Merida", "M\u00e9rida" },
             { "timezone.excity.America/Nassau", "Nasau" },
             { "timezone.excity.America/Panama", "Panam\u00e3" },
             { "timezone.excity.America/Recife", "Resifi" },
@@ -1897,7 +1881,6 @@ public class TimeZoneNames_yrl extends TimeZoneNamesBundle {
             { "timezone.excity.Pacific/Noumea", "Numeya" },
             { "timezone.excity.Pacific/Saipan", "Saip\u00e3" },
             { "timezone.excity.Pacific/Tahiti", "Taiti" },
-            { "timezone.excity.Pacific/Tarawa", "Tarawa" },
             { "timezone.excity.Pacific/Wallis", "Wari-ita" },
             { "timezone.excity.Africa/Blantyre", "Bar\u00e3tire" },
             { "timezone.excity.Africa/Djibouti", "Dijibuti" },
@@ -1917,10 +1900,8 @@ public class TimeZoneNames_yrl extends TimeZoneNamesBundle {
             { "timezone.excity.America/Cordoba", "K\u00f3duba" },
             { "timezone.excity.America/Creston", "Kerest\u0169" },
             { "timezone.excity.America/Curacao", "Kurasau" },
-            { "timezone.excity.America/Detroit", "Detroit" },
             { "timezone.excity.America/Godthab", "Nuki" },
             { "timezone.excity.America/Grenada", "Garanada" },
-            { "timezone.excity.America/Halifax", "Halifax" },
             { "timezone.excity.America/Iqaluit", "Ikaruiti" },
             { "timezone.excity.America/Jamaica", "Yamaika" },
             { "timezone.excity.America/Managua", "Man\u00e1guwa" },
@@ -1978,13 +1959,11 @@ public class TimeZoneNames_yrl extends TimeZoneNamesBundle {
             { "timezone.excity.Antarctica/Casey", "Kasei" },
             { "timezone.excity.Antarctica/Davis", "Dawi" },
             { "timezone.excity.Antarctica/Syowa", "Siyowa" },
-            { "timezone.excity.Antarctica/Troll", "Troll" },
             { "timezone.excity.Asia/Krasnoyarsk", "Karasinoyarisiki" },
             { "timezone.excity.Asia/Novosibirsk", "Sibirisiki Pisas\u00fa" },
             { "timezone.excity.Asia/Ulaanbaatar", "Ur\u00e3 Baturu" },
             { "timezone.excity.Asia/Vladivostok", "Waradiwosituki" },
             { "timezone.excity.Atlantic/Bermuda", "Bemuda" },
-            { "timezone.excity.Atlantic/Madeira", "Madeira" },
             { "timezone.excity.Atlantic/Stanley", "Isit\u00e3rei" },
             { "timezone.excity.Australia/Currie", "Kurie" },
             { "timezone.excity.Australia/Darwin", "Dariw\u0129" },
@@ -2004,10 +1983,8 @@ public class TimeZoneNames_yrl extends TimeZoneNamesBundle {
             { "timezone.excity.Indian/Kerguelen", "Kergel\u1ebd" },
             { "timezone.excity.Indian/Mauritius", "Maurisiyu" },
             { "timezone.excity.Pacific/Auckland", "\u00d3kir\u00e3di" },
-            { "timezone.excity.Pacific/Funafuti", "Funafuti" },
             { "timezone.excity.Pacific/Honolulu", "Hunururu" },
             { "timezone.excity.Pacific/Johnston", "J\u0169sit\u0169" },
-            { "timezone.excity.Pacific/Pitcairn", "Pitcairn" },
             { "timezone.excity.Africa/Casablanca", "Uka Murut\u0129ga" },
             { "timezone.excity.Africa/Libreville", "Riberevili" },
             { "timezone.excity.Africa/Lubumbashi", "Lub\u0169baxi" },
@@ -2075,11 +2052,9 @@ public class TimeZoneNames_yrl extends TimeZoneNamesBundle {
             { "timezone.excity.Australia/Lindeman", "R\u0129dem\u00e3" },
             { "timezone.excity.Europe/Isle_of_Man", "M\u00e3 Kapu\u00e3ma" },
             { "timezone.excity.Europe/Kaliningrad", "Karin\u0129garadu" },
-            { "timezone.excity.Pacific/Kiritimati", "Kiritimati" },
             { "timezone.excity.Africa/Johannesburg", "Juanesibugu" },
             { "timezone.excity.America/El_Salvador", "Eu Sawadu" },
             { "timezone.excity.America/Fort_Nelson", "Futi Neus\u0169" },
-            { "timezone.excity.America/Los_Angeles", "Los Angeles" },
             { "timezone.excity.America/Mexico_City", "\u1ebcm\u00e3 t\u1ef9 M\u1ebdsiku" },
             { "timezone.excity.America/Pangnirtung", "P\u00e3ginit\u0169gi" },
             { "timezone.excity.America/Porto_Velho", "Igarapawa Kuximawara" },
