@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2022, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -68,11 +68,11 @@ public class TimeZoneNames_zu extends TimeZoneNamesBundle {
     protected final Object[][] getContents() {
         final String[] GMT = new String[] {
                "Isikhathi sase-Greenwich Mean",
+               "GMT",
                "",
+               "GMT",
                "",
-               "",
-               "",
-               "",
+               "GMT",
             };
         final String[] Apia = new String[] {
                "Isikhathi sase-Apia esivamile",
@@ -92,11 +92,11 @@ public class TimeZoneNames_zu extends TimeZoneNamesBundle {
             };
         final String[] Cuba = new String[] {
                "Isikhathi sase-Cuba esijwayelekile",
-               "",
+               "CST",
                "Isikhathi sase-Cuba sasemini",
-               "",
+               "CDT",
                "Isikhathi sase-Cuba",
-               "",
+               "CT",
             };
         final String[] Fiji = new String[] {
                "Isikhathi esivamile sase-Fiji",
@@ -180,11 +180,11 @@ public class TimeZoneNames_zu extends TimeZoneNamesBundle {
             };
         final String[] China = new String[] {
                "Isikhathi esivamile sase-China",
-               "",
+               "CST",
                "Isikhathi semini sase-China",
-               "",
+               "CDT",
                "Isikhathi sase-China",
-               "",
+               "CT",
             };
         final String[] Cocos = new String[] {
                "Isikhathi sase-Cocos Islands",
@@ -212,19 +212,19 @@ public class TimeZoneNames_zu extends TimeZoneNamesBundle {
             };
         final String[] Japan = new String[] {
                "Isikhathi esivamile sase-Japan",
-               "",
+               "JST",
                "Isikhathi semini sase-Japan",
-               "",
+               "JDT",
                "Isikhathi sase-Japan",
-               "",
+               "JT",
             };
         final String[] Korea = new String[] {
                "Isikhathi Esivamile sase-Korea",
-               "",
+               "KST",
                "Isikhathi semini sase-Korea",
-               "",
+               "KST",
                "Isikhathi sase-Korea",
-               "",
+               "KST",
             };
         final String[] Nauru = new String[] {
                "Isikhathi sase-Nauru",
@@ -252,11 +252,11 @@ public class TimeZoneNames_zu extends TimeZoneNamesBundle {
             };
         final String[] Samoa = new String[] {
                "Isikhathi sase-Samoa esivamile",
-               "",
+               "SST",
                "Isikhathi sase-Samoa sasemini",
-               "",
+               "SST",
                "Isikhathi sase-Samoa",
-               "",
+               "SST",
             };
         final String[] Syowa = new String[] {
                "Isikhathi sase-Syowa",
@@ -276,11 +276,11 @@ public class TimeZoneNames_zu extends TimeZoneNamesBundle {
             };
         final String[] Yukon = new String[] {
                "Yukon Time",
+               "MST",
                "",
+               "MST",
                "",
-               "",
-               "",
-               "",
+               "MST",
             };
         final String[] Alaska = new String[] {
                "Isikhathi sase-Alaska esijwayelekile",
@@ -308,11 +308,11 @@ public class TimeZoneNames_zu extends TimeZoneNamesBundle {
             };
         final String[] Azores = new String[] {
                "Isikhathi esijwayelekile sase-Azores",
-               "",
+               "HMT",
                "Isikhathi sasehlobo sase-Azores",
-               "",
+               "HMT",
                "Isikhathi sase-Azores",
-               "",
+               "HMT",
             };
         final String[] Bhutan = new String[] {
                "Isikhathi sase-Bhutan",
@@ -348,11 +348,11 @@ public class TimeZoneNames_zu extends TimeZoneNamesBundle {
             };
         final String[] Israel = new String[] {
                "Isikhathi esivamile sase-Israel",
-               "",
+               "IST",
                "Isikhathi sasemini sakwa-Israel",
-               "",
+               "IDT",
                "Isikhathi sase-Israel",
-               "",
+               "IT",
             };
         final String[] Kosrae = new String[] {
                "Isikhathi sase-Kosrae",
@@ -372,11 +372,11 @@ public class TimeZoneNames_zu extends TimeZoneNamesBundle {
             };
         final String[] Moscow = new String[] {
                "Isikhathi sase-Moscow esijwayelekile",
-               "",
+               "MSK",
                "Isikhathi sasehlobo e-Moscow",
-               "",
+               "MSK",
                "Isikhathi sase-Moscow",
-               "",
+               "MSK",
             };
         final String[] Ponape = new String[] {
                "Isikhathi sase-Ponape",
@@ -404,11 +404,11 @@ public class TimeZoneNames_zu extends TimeZoneNamesBundle {
             };
         final String[] Taipei = new String[] {
                "Isikhathi esivamile sase-Taipei",
-               "",
+               "CST",
                "Isikhathi semini sase-Taipei",
-               "",
+               "CDT",
                "Isikhathi sase-Taipei",
-               "",
+               "CT",
             };
         final String[] Tuvalu = new String[] {
                "Isikhathi sase-Tuvalu",
@@ -596,11 +596,11 @@ public class TimeZoneNames_zu extends TimeZoneNamesBundle {
             };
         final String[] Atlantic = new String[] {
                "Isikhathi sase-Atlantic esijwayelekile",
-               "",
+               "AST",
                "Isikhathi sase-Atlantic sasemini",
-               "",
+               "ADT",
                "Isikhathi sase-Atlantic",
-               "",
+               "AT",
             };
         final String[] Brasilia = new String[] {
                "Isikhathi sase-Brasilia esijwayelekile",
@@ -612,11 +612,11 @@ public class TimeZoneNames_zu extends TimeZoneNamesBundle {
             };
         final String[] Chamorro = new String[] {
                "Isikhathi esivamile sase-Chamorro",
+               "ChST",
                "",
+               "ChST",
                "",
-               "",
-               "",
-               "",
+               "ChST",
             };
         final String[] Colombia = new String[] {
                "Isikhathi sase-Colombia esijwayelekile",
@@ -660,11 +660,11 @@ public class TimeZoneNames_zu extends TimeZoneNamesBundle {
             };
         final String[] Pakistan = new String[] {
                "Isikhathi sase-Pakistan esivamile",
-               "",
+               "PKT",
                "Isikhathi sase-Pakistan sasehlobo",
-               "",
+               "PKST",
                "Isikhathi sase-Pakistan",
-               "",
+               "PKT",
             };
         final String[] Paraguay = new String[] {
                "Isikhathi sase-Paraguay esivamile",
@@ -724,11 +724,11 @@ public class TimeZoneNames_zu extends TimeZoneNamesBundle {
             };
         final String[] Hong_Kong = new String[] {
                "Isikhathi esivamile sase-Hong Kong",
-               "",
+               "HKT",
                "Isikhathi sehlobo sase-Hong Kong",
-               "",
+               "HKST",
                "Isikhathi sase-Hong Kong",
-               "",
+               "HKT",
             };
         final String[] Indochina = new String[] {
                "Isikhathi sase-Indochina",
@@ -796,11 +796,11 @@ public class TimeZoneNames_zu extends TimeZoneNamesBundle {
             };
         final String[] Volgograd = new String[] {
                "Isikhathi Esivamile sase-Volgograd",
-               "",
+               "MSK",
                "Isikhathi sase-Volgograd sasehlobo",
-               "",
+               "MSK",
                "Isikhathi sase-Volgograd",
-               "",
+               "MSK",
             };
         final String[] Azerbaijan = new String[] {
                "Isikhathi esivamile sase-Azerbaijan",
@@ -876,11 +876,11 @@ public class TimeZoneNames_zu extends TimeZoneNamesBundle {
             };
         final String[] New_Zealand = new String[] {
                "Isikhathi esivamile sase-New Zealand",
-               "",
+               "NZST",
                "Isikhathi sasemini sase-New Zealand",
-               "",
+               "NZDT",
                "Isikhathi sase-New Zealand",
-               "",
+               "NZT",
             };
         final String[] Novosibirsk = new String[] {
                "Isikhathi Esivamile sase-Novosibirsk",
@@ -892,11 +892,11 @@ public class TimeZoneNames_zu extends TimeZoneNamesBundle {
             };
         final String[] Philippines = new String[] {
                "Isikhathi esivamile sase-Philippine",
-               "",
+               "PST",
                "Isikhathi sehlobo sase-Philippine",
-               "",
+               "PDT",
                "Isikhathi sase-Philippine",
-               "",
+               "PT",
             };
         final String[] Vladivostok = new String[] {
                "Isikhathi Esivamile sase-Vladivostok",
@@ -924,11 +924,11 @@ public class TimeZoneNames_zu extends TimeZoneNamesBundle {
             };
         final String[] Newfoundland = new String[] {
                "Isikhathi sase-Newfoundland esijwayelekile",
-               "",
+               "NST",
                "Isikhathi sase-Newfoundland sasemini",
-               "",
+               "NDT",
                "Isikhathi sase-Newfoundland",
-               "",
+               "NT",
             };
         final String[] Turkmenistan = new String[] {
                "Isikhathi esivamile sase-Turkmenistan",
@@ -972,27 +972,27 @@ public class TimeZoneNames_zu extends TimeZoneNamesBundle {
             };
         final String[] Africa_Central = new String[] {
                "Isikhathi sase-Central Africa",
+               "SAST",
                "",
+               "SAST",
                "",
-               "",
-               "",
-               "",
+               "SAST",
             };
         final String[] Africa_Eastern = new String[] {
                "Isikhathi saseMpumalanga Afrika",
+               "EAT",
                "",
+               "EAT",
                "",
-               "",
-               "",
-               "",
+               "EAT",
             };
         final String[] Africa_Western = new String[] {
                "Isikhathi esivamile saseNtshonalanga Afrika",
-               "",
+               "WAT",
                "Isikhathi sasehlobo saseNtshonalanga Afrika",
-               "",
+               "WAT",
                "Isikhathi saseNtshonalanga Afrika",
-               "",
+               "WAT",
             };
         final String[] DumontDUrville = new String[] {
                "Isikhathi sase-Dumont-d\u2019Urville",
@@ -1004,67 +1004,67 @@ public class TimeZoneNames_zu extends TimeZoneNamesBundle {
             };
         final String[] Europe_Central = new String[] {
                "Isikhathi esijwayelekile sase-Central Europe",
-               "",
+               "CET",
                "Isikhathi sasehlobo sase-Central Europe",
-               "",
+               "CEST",
                "Isikhathi sase-Central Europe",
-               "",
+               "CET",
             };
         final String[] Europe_Eastern = new String[] {
                "Isikhathi esijwayelekile sase-Eastern Europe",
-               "",
+               "EET",
                "Isikhathi sasehlobo sase-Eastern Europe",
-               "",
+               "EEST",
                "Isikhathi sase-Eastern Europe",
-               "",
+               "EET",
             };
         final String[] Europe_Western = new String[] {
                "Isikhathi esijwayelekile sase-Western Europe",
-               "",
+               "FMT",
                "Isikhathi sasehlobo sase-Western Europe",
-               "",
+               "FMT",
                "Isikhathi sase-Western Europe",
-               "",
+               "FMT",
             };
         final String[] Mexico_Pacific = new String[] {
                "Isikhathi sase-Mexican Pacific esijwayelekile",
-               "",
+               "MST",
                "Isikhathi sase-Mexican Pacific sasemini",
-               "",
+               "MDT",
                "Isikhathi sase-Mexican Pacific",
-               "",
+               "MT",
             };
         final String[] Africa_Southern = new String[] {
                "Isikhathi esivamile saseNingizimu Afrika",
+               "SAST",
                "",
+               "SAST",
                "",
-               "",
-               "",
-               "",
+               "SAST",
             };
         final String[] America_Central = new String[] {
                "Isikhathi sase-North American Central esijwayelekile",
-               "",
+               "CST",
                "Isikhathi sase-North American Central sasemini",
-               "",
+               "CDT",
                "Isikhathi sase-North American Central",
-               "",
+               "CT",
             };
         final String[] America_Eastern = new String[] {
                "Isikhathi sase-North American East esijwayelekile",
-               "",
+               "EST",
                "Isikhathi sase-North American East sasemini",
-               "",
+               "EST",
                "Isikhathi sase-North American East",
-               "",
+               "EST",
             };
         final String[] America_Pacific = new String[] {
                "Isikhathi sase-North American Pacific esijwayelekile",
-               "",
+               "PST",
                "Isikhathi sase-North American Pacific sasemini",
-               "",
+               "PDT",
                "Isikhathi sase-North American Pacific",
-               "",
+               "PT",
             };
         final String[] French_Southern = new String[] {
                "Isikhathi sase-French Southern nase-Antarctic",
@@ -1084,11 +1084,11 @@ public class TimeZoneNames_zu extends TimeZoneNamesBundle {
             };
         final String[] Hawaii_Aleutian = new String[] {
                "Isikhathi sase-Hawaii-Aleutia esijwayelekile",
-               "",
+               "HST",
                "Isikhathi sase-Hawaii-Aleutia sasemini",
-               "",
+               "HST",
                "Isikhathi sase-Hawaii-Aleutia",
-               "",
+               "HST",
             };
         final String[] Phoenix_Islands = new String[] {
                "Isikhathi sase-Phoenix Islands",
@@ -1108,11 +1108,11 @@ public class TimeZoneNames_zu extends TimeZoneNamesBundle {
             };
         final String[] America_Mountain = new String[] {
                "Isikhathi sase-North American Mountain esijwayelekile",
-               "",
+               "MST",
                "Isikhathi sase-North American Mountain sasemini",
-               "",
+               "MDT",
                "Isikhathi sase-North American Mountain",
-               "",
+               "MT",
             };
         final String[] Marshall_Islands = new String[] {
                "Isikhathi sase-Marshall Islands",
@@ -1140,19 +1140,19 @@ public class TimeZoneNames_zu extends TimeZoneNamesBundle {
             };
         final String[] Australia_Central = new String[] {
                "Isikhathi sase-Australian Central esivamile",
-               "",
+               "ACST",
                "Isikhathi sase-Australian Central sasemini",
-               "",
+               "ACDT",
                "Isikhathi sase-Central Australia",
-               "",
+               "ACT",
             };
         final String[] Australia_Eastern = new String[] {
                "Isikhathi esivamile sase-Australian East",
-               "",
+               "AEST",
                "Isikhathi sasemini sase-Australian East",
-               "",
+               "AEDT",
                "Isikhathi sase-Eastern Australia",
-               "",
+               "AET",
             };
         final String[] Australia_Western = new String[] {
                "Isikhathi sase-Australian Western esivamile",
@@ -1180,27 +1180,27 @@ public class TimeZoneNames_zu extends TimeZoneNamesBundle {
             };
         final String[] Indonesia_Central = new String[] {
                "Isikhathi sase-Central Indonesia",
+               "WITA",
                "",
+               "WITA",
                "",
-               "",
-               "",
-               "",
+               "WITA",
             };
         final String[] Indonesia_Eastern = new String[] {
                "Isikhathi sase-Eastern Indonesia",
+               "WIT",
                "",
+               "WIT",
                "",
-               "",
-               "",
-               "",
+               "WIT",
             };
         final String[] Indonesia_Western = new String[] {
                "Isikhathi sase-Western Indonesia",
+               "WIB",
                "",
+               "WIB",
                "",
-               "",
-               "",
-               "",
+               "WIB",
             };
         final String[] Kazakhstan_Eastern = new String[] {
                "Isikhathi sase-Mpumalanga ne-Kazakhstan",
@@ -1279,7 +1279,6 @@ public class TimeZoneNames_zu extends TimeZoneNamesBundle {
             { "Asia/Hovd", Hovd },
             { "Asia/Omsk", Omsk },
             { "Asia/Oral", Kazakhstan_Western },
-            { "Asia/Amman", Europe_Eastern },
             { "Asia/Aqtau", Kazakhstan_Western },
             { "Asia/Chita", Yakutsk },
             { "Asia/Dhaka", Bangladesh },
@@ -1375,7 +1374,6 @@ public class TimeZoneNames_zu extends TimeZoneNamesBundle {
             { "America/Thule", Atlantic },
             { "Asia/Ashgabat", Turkmenistan },
             { "Asia/Calcutta", India },
-            { "Asia/Damascus", Europe_Eastern },
             { "Asia/Dushanbe", Tajikistan },
             { "Asia/Jayapura", Indonesia_Eastern },
             { "Asia/Katmandu", Nepal },
@@ -1390,11 +1388,11 @@ public class TimeZoneNames_zu extends TimeZoneNamesBundle {
             { "Europe/Dublin",
                 new String[] {
                     "Isikhathi sase-Greenwich Mean",
-                    "",
+                    "GMT",
                     "isikhathi sase-Irish esivamile",
+                    "IST",
                     "",
-                    "",
-                    "",
+                    "GMT",
                 }
             },
             { "Europe/Jersey", GMT },
@@ -1402,11 +1400,11 @@ public class TimeZoneNames_zu extends TimeZoneNamesBundle {
             { "Europe/London",
                 new String[] {
                     "Isikhathi sase-Greenwich Mean",
-                    "",
+                    "GMT",
                     "isikhathi sase-British sasehlobo",
+                    "BST",
                     "",
-                    "",
-                    "",
+                    "GMT",
                 }
             },
             { "Europe/Madrid", Europe_Central },
@@ -1464,11 +1462,11 @@ public class TimeZoneNames_zu extends TimeZoneNamesBundle {
             { "Europe/Belfast",
                 new String[] {
                     "Isikhathi sase-Greenwich Mean",
-                    "",
+                    "GMT",
                     "isikhathi sase-British sasehlobo",
+                    "BST",
                     "",
-                    "",
-                    "",
+                    "GMT",
                 }
             },
             { "Europe/Tallinn", Europe_Eastern },
@@ -1514,7 +1512,7 @@ public class TimeZoneNames_zu extends TimeZoneNamesBundle {
             { "America/Moncton", Atlantic },
             { "America/Nipigon", America_Eastern },
             { "America/Noronha", Noronha },
-            { "America/Ojinaga", America_Mountain },
+            { "America/Ojinaga", America_Central },
             { "America/Tijuana", America_Pacific },
             { "America/Toronto", America_Eastern },
             { "America/Tortola", Atlantic },
@@ -1598,7 +1596,7 @@ public class TimeZoneNames_zu extends TimeZoneNamesBundle {
             { "America/Araguaina", Brasilia },
             { "America/Boa_Vista", Amazon },
             { "America/Catamarca", Argentina },
-            { "America/Chihuahua", Mexico_Pacific },
+            { "America/Chihuahua", America_Central },
             { "America/Fortaleza", Brasilia },
             { "America/Glace_Bay", Atlantic },
             { "America/Goose_Bay", Atlantic },
@@ -1685,6 +1683,7 @@ public class TimeZoneNames_zu extends TimeZoneNamesBundle {
             { "Antarctica/Macquarie", Australia_Eastern },
             { "Pacific/Port_Moresby", Papua_New_Guinea },
             { "America/Cambridge_Bay", America_Mountain },
+            { "America/Ciudad_Juarez", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
             { "America/Indiana/Vevay", America_Eastern },
             { "America/Lower_Princes", Atlantic },
@@ -1875,7 +1874,6 @@ public class TimeZoneNames_zu extends TimeZoneNamesBundle {
             { "timezone.excity.America/Panama", "i-Panama" },
             { "timezone.excity.America/Recife", "i-Recife" },
             { "timezone.excity.America/Regina", "i-Regina" },
-            { "timezone.excity.Asia/Famagusta", "Famagusta" },
             { "timezone.excity.Asia/Hong_Kong", "i-Hong Kong" },
             { "timezone.excity.Asia/Jerusalem", "i-Jerusalem" },
             { "timezone.excity.Asia/Kamchatka", "i-Kamchatka" },
